@@ -9,8 +9,8 @@ OC.L10N.register(
     "No files found for the selected circles" : "Не знайдено файлів для вибраних кіл",
     "You created the circle {circle}" : "Ви створили коло {circle}",
     "{author} created the circle {circle}" : "{author} створив коло {circle}",
-    "You deleted {circle}" : "Ви видалили {circle}",
-    "{author} deleted {circle}" : "{author} видалив {circle}",
+    "You deleted {circle}" : "Ви вилучили коло {circle}",
+    "{author} deleted {circle}" : "{author} вилучив коло {circle}",
     "You linked {group} to {circle}" : "Ви приєднали {group} до {circle}",
     "{group} has been linked to {circle} by {author}" : "{group} було пов’язано з {circle} автором {author}",
     "You unlinked {group} from {circle}" : "Ви від’єднали {group} від {circle}",
@@ -37,9 +37,9 @@ OC.L10N.register(
     "{member} joined {circle}" : "{member} приєднався до {circle}",
     "You accepted the invitation to join {circle}" : "Ви прийняли запрошення приєднатися до {circle}",
     "{member} accepted the invitation to join {circle}" : "{member} прийняв запрошення приєднатися до {circle}",
-    "You added {member} as member to {circle}" : "Ви додали {member} як члена {circle}",
-    "You have been added as member to {circle} by {author}" : "{author} додав вас як члена {circle}",
-    "{member} has been added as member to {circle} by {author}" : "{member} був доданий як член до {circle} автором {author}",
+    "You added {member} as member to {circle}" : "Ви додали {member} учасником кола {circle}",
+    "You have been added as member to {circle} by {author}" : "{author} додав вас учасником кола {circle}",
+    "{member} has been added as member to {circle} by {author}" : "{author} додав {member} учасником кола {circle}",
     "You added {external} to {circle}" : "Ви додали {external} до {circle}",
     "{external} has been added to {circle} by {author}" : "{external} додано до {circle} {author}",
     "You accepted {member}'s request to join {circle}" : "Ви прийняли запит {member} приєднатися до {circle}",
@@ -53,9 +53,9 @@ OC.L10N.register(
     "{member} cancelled his request to join {circle}" : "{member} скасував свій запит на приєднання до {circle}",
     "You removed {member} from {circle}" : "Ви вилучили {member} із {circle}",
     "You have been removed from {circle} by {author}" : "{author} вилучив вас із {circle}",
-    "{member} has been removed from {circle} by {author}" : "{member} видалено з {circle} автором {author}",
-    "You removed {external} from {circle}" : "Ви видалили {external} із {circle}",
-    "{external} has been removed from {circle} by {author}" : "{external} видалено з {circle} автором {author}",
+    "{member} has been removed from {circle} by {author}" : "{member} вилучено з кола {circle} автором {author}",
+    "You removed {external} from {circle}" : "Ви вилучили {external} із {circle}",
+    "{external} has been removed from {circle} by {author}" : "{external} вилучено з кола {circle} автором {author}",
     "You cancelled {member}'s invitation to join {circle}" : "Ви скасували запрошення користувача {member} приєднатися до {circle}",
     "Your invitation to join {circle} has been cancelled by {author}" : "Ваше запрошення приєднатися до {circle} було скасовано {author}",
     "{author} cancelled {member}'s invitation to join {circle}" : "{author} скасував запрошення {member} приєднатися до {circle}",
@@ -65,7 +65,7 @@ OC.L10N.register(
     "You invited {member} to join {circle}" : "Ви запросили {member} приєднатися до {circle}",
     "You have been invited to join {circle} by {author}" : "{author} запросив вас приєднатися до {circle}",
     "{member} has been invited to join {circle} by {author}" : "{member} отримав запрошення приєднатися до {circle} від {author}",
-    "You changed {member}'s level in {circle} to %1$s" : "Ви змінили рівень {member} у {circle} на %1$s",
+    "You changed {member}'s level in {circle} to %1$s" : "Ви змінили рівень участи {member} у колі {circle} на %1$s",
     "{author} changed your level in {circle} to %1$s" : "{author} змінив ваш рівень у колі {circle} на %1$s",
     "{author} changed {member}'s level in {circle} to %1$s" : "{author} змінив ваш рівень у колі {circle} на %1$s",
     "You sent a request to join {circle}" : "Ви надіслали запит на приєднання до {circle}",
@@ -97,31 +97,31 @@ OC.L10N.register(
     "Email Address" : "Адреса електронної пошти",
     "Contact" : "Контакт",
     "Circle" : "Коло",
-    "Nextcloud App" : "Додаток Nextcloud",
+    "Nextcloud App" : "Застосунок Nextcloud",
     "Member" : "Учасник",
     "Moderator" : "Модератор",
     "Admin" : "Адміністратор",
     "Owner" : "Власник",
-    "%s shared »%s« with you." : "%s надав Вам доступ до »%s«.",
-    "%s shared »%s« with \"%s\"." : "%s поділився »%s« з «%s».",
+    "%s shared »%s« with you." : "%s надано доступ до \"%s\".",
+    "%s shared »%s« with \"%s\"." : "%s надано доступ до \"%s\" із \"%s\".",
     "%s on %s" : "%s на %s",
-    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$sподілився »%2$s« з вами. \nВи вже мали отримати окремий електронний лист із посиланням для доступу до нього.\n",
-    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s поділився »%2$s« з вами. Ви вже мали отримати окремий електронний лист із посиланням для доступу до нього.",
-    "Password to access »%1$s« shared to you by %2$s" : "Пароль для доступу »%1$s« %2$s поділився з вами",
-    "Password to access »%s«" : "Пароль для доступу »%s«",
+    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$sподілився з вами \"%2$s\". \nНа вашу ел.скриньку було надіслано лист із посиланням для доступу до ресурсу.\n",
+    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s поділився з вами \"%2$s\". На вашу ел.скриньку було надіслано лист із посиланням для доступу до ресурсу.",
+    "Password to access »%1$s« shared to you by %2$s" : "Пароль для доступу до %1$s, яким з вами поділився %2$s",
+    "Password to access »%s«" : "Пароль доступу до \"%s\"",
     "It is protected with the following password:" : "Він захищений таким паролем:",
     "%1$s via %2$s" : "%1$s через %2$s",
     "Click the button below to open it." : "Для відкриття натисніть кнопку нижче.",
-    "Open »%s«" : "Відкритт 1%s",
-    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s поділився з вами кількома файлами. \nВи вже мали отримати окремий електронний лист із посиланням для доступу до них.\n",
-    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s поділився з вами кількома файлами. Ви вже мали отримати окремий електронний лист із посиланням для доступу до них.",
+    "Open »%s«" : "Відкрити \"%s\"",
+    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s поділився з вами кількома файлами. \nНа вашу ел.скриньку надійшов лист із посиланням для доступу до файлів.\n",
+    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s поділився з вами кількома файлами. На вашу ел.скриньку надійшов лист із посиланням для доступу до файлів.",
     "Password to access files shared to you by %1$s" : "Пароль для доступу до файлів, наданих вам %1$s",
     "Password to access files" : "Пароль для доступу до файлів",
     "%s shared multiple files with \"%s\"." : "%s поділився кількома файлами з \"%s\".",
     "%s shared multiple files with you." : "%s поділився з вами кількома файлами.",
     "Boot up" : "Завантаження",
     "Initialisation Nextcloud" : "Ініціалізація Nextcloud",
-    "Initialisation Circles App" : "Ініціалізація додатку кіл",
+    "Initialisation Circles App" : "Ініціалізація застосунку Circle",
     "Fresh installation status" : "Статус свіжої інсталяції",
     "Building Local Database" : "Створення локальної бази даних",
     "Testing Basic Circle Creation" : "Тестування створення базового кола",
@@ -169,8 +169,8 @@ OC.L10N.register(
     "You have no permission to create a new circle" : "У вас немає дозволу на створення нового кола",
     "%s shared a file with \"%s\"." : "%sподілився файлом з \"%s\".",
     "%s shared a file with you." : "%s поділився з вами файлом.",
-    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s поділився з вами деяким вмістом. \nВи вже мали отримати окремий електронний лист із посиланням для доступу до нього.\n",
-    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s поділився з вами деяким вмістом. Ви вже мали отримати окремий електронний лист із посиланням для доступу до нього.",
+    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s поділився з вами деяким вмістом. \nНа вашу ел.скриньку надійшов лист із посиланням для доступу до ресурсу.\n",
+    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s поділився з вами деяким вмістом. На вашу ел.скриньку надійшов лист із посиланням для доступу до ресурсу.",
     "Password to access content shared with you by %1$s" : "Пароль для доступу до вмісту, яким з вами поділився %1$s",
     "Password to access content" : "Пароль для доступу до вмісту",
     "This item is already shared with this circle" : "Цей елемент уже надано спільно для цього кола",
