@@ -9,6 +9,8 @@ OC.L10N.register(
     "Download" : "Λήψη",
     "Delete" : "Διαγραφή",
     "Tags" : "Ετικέτες",
+    "Show list view" : "Προβολή λίστας",
+    "Show grid view" : "Προβολή πλέγματος",
     "Home" : "Αρχική",
     "Close" : "Κλείσιμο",
     "Favorites" : "Αγαπημένα",
@@ -34,6 +36,7 @@ OC.L10N.register(
     "Move" : "Μετακίνηση",
     "Copy" : "Αντιγραφή",
     "Choose target folder" : "Επιλογή φακέλου προορισμού",
+    "Edit locally" : "Επεξεργασία τοπικά",
     "Open" : "Άνοιγμα",
     "Delete file" : "Διαγραφή αρχείου",
     "Delete folder" : "Διαγραφή φακέλου",
@@ -57,7 +60,7 @@ OC.L10N.register(
     "Could not copy \"{file}\"" : "Αδυναμία αντιγραφής του \"{file}\"",
     "Copied {origin} inside {destination}" : "Αντιγράφτηκε το {origin} στο {destination}",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "Αντιγράφτηκε το {origin} και {nbfiles} άλλα αρχεία στο {destination}",
-    "{newName} already exists" : "Το {newname} υπάρχει ήδη",
+    "{newName} already exists" : "Το {newName} υπάρχει ήδη",
     "Could not rename \"{fileName}\", it does not exist any more" : "Αδυναμία μετονομασίας του \"{fileName}\", το αρχείο δεν υπάρχει πια.",
     "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Το όνομα \"{targetName}\" χρησιμοποιείται ήδη στον φάκελο\"{dir}\". Παρακαλούμε διαλέξτε ένα διαφορετικό όνομα.",
     "Could not rename \"{fileName}\"" : "Αδυναμία μετονομασίας του \"{fileName}\"",
@@ -77,7 +80,9 @@ OC.L10N.register(
     "_including %n hidden_::_including %n hidden_" : ["περιλαμβάνεται %n κρυφό","περιλαμβάνονται %n κρυφά"],
     "You do not have permission to upload or create files here" : "Δεν έχετε δικαιώματα μεταφόρτωσης ή δημιουργίας αρχείων εδώ",
     "_Uploading %n file_::_Uploading %n files_" : ["Μεταφόρτωση %n αρχείου","Μεταφόρτωση %n αρχείων"],
+    "New file/folder menu" : "Μενού νέου αρχείου/φακέλου",
     "Select file range" : "Επιλέξτε εύρος αρχείων",
+    "{used}%" : "{used}%",
     "{used} of {quota} used" : "Χρήση {used} από {quota} ",
     "{used} used" : "Σε χρήση {used}",
     "\"{name}\" is an invalid file name." : "Το \"{name}\" δεν είναι έγκυρο όνομα αρχείου.",
@@ -187,7 +192,9 @@ OC.L10N.register(
     "Templates" : "Πρότυπα",
     "Unable to initialize the templates directory" : "Δεν είναι δυνατή η προετοιμασία του καταλόγου προτύπων",
     "%s used" : "%s σε χρήση",
+    "%s%%" : "%s%%",
     "%1$s of %2$s used" : "χρησιμοποιούνται %1$s από %2$s",
+    "Files settings" : "Ρυθμίσεις αρχείων",
     "Show hidden files" : "Εμφάνιση κρυφών αρχείων",
     "Crop image previews" : "Περικοπή προεπισκόπησης εικόνας",
     "WebDAV" : "WebDAV",
