@@ -4,42 +4,43 @@ OC.L10N.register(
     "Storage is temporarily not available" : "Storage is temporarily not available",
     "Storage invalid" : "Storage invalid",
     "Unknown error" : "Unknown error",
-    "All files" : "All files",
-    "Recent" : "Recent",
-    "Favorites" : "Favourites",
     "File could not be found" : "File could not be found",
     "Move or copy" : "Move or copy",
     "Download" : "Download",
     "Delete" : "Delete",
+    "Tags" : "Tags",
     "Home" : "Home",
     "Close" : "Close",
+    "Favorites" : "Favourites",
     "Could not create folder \"{dir}\"" : "Could not create folder \"{dir}\"",
     "Upload cancelled." : "Upload cancelled.",
+    "…" : "…",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "Unable to upload {filename} as it is a directory or has 0 bytes",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "Not enough free space, you are uploading {size1} but only {size2} is left",
     "Target folder \"{dir}\" does not exist any more" : "Target folder \"{dir}\" does not exist any more",
     "Not enough free space" : "Not enough free space",
     "Uploading …" : "Uploading …",
-    "…" : "…",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} of {totalSize} ({bitrate})",
     "Target folder does not exist any more" : "Target folder does not exist any more",
     "Error when assembling chunks, status code {status}" : "Error when assembling chunks, status code {status}",
     "Actions" : "Actions",
     "Rename" : "Rename",
+    "Move" : "Move",
     "Copy" : "Copy",
-    "Target folder" : "Target folder",
+    "Open" : "Open",
+    "Delete file" : "Delete file",
+    "Delete folder" : "Delete folder",
     "Disconnect storage" : "Disconnect storage",
-    "Unshare" : "Unshare",
     "Could not load info for file \"{file}\"" : "Could not load info for file \"{file}\"",
     "Files" : "Files",
     "Details" : "Details",
-    "Select" : "Select",
     "Pending" : "Pending",
     "Unable to determine date" : "Unable to determine date",
     "This operation is forbidden" : "This operation is forbidden",
     "This directory is unavailable, please check the logs or contact the administrator" : "This directory is unavailable, please check the logs or contact the administrator",
     "Could not move \"{file}\", target exists" : "Could not move \"{file}\", target exists",
     "Could not move \"{file}\"" : "Could not move \"{file}\"",
+    "copy" : "copy",
     "Could not copy \"{file}\", target exists" : "Could not copy \"{file}\", target exists",
     "Could not copy \"{file}\"" : "Could not copy \"{file}\"",
     "Copied {origin} inside {destination}" : "Copied {origin} inside {destination}",
@@ -60,20 +61,13 @@ OC.L10N.register(
     "_%n file_::_%n files_" : ["%n file","%n files"],
     "{dirs} and {files}" : "{dirs} and {files}",
     "_including %n hidden_::_including %n hidden_" : ["including %n hidden","including %n hidden"],
-    "You don’t have permission to upload or create files here" : "You don’t have permission to upload or create files here",
     "_Uploading %n file_::_Uploading %n files_" : ["Uploading %n file","Uploading %n files"],
-    "New" : "New",
     "{used} of {quota} used" : "{used} of {quota} used",
     "{used} used" : "{used} used",
     "\"{name}\" is an invalid file name." : "\"{name}\" is an invalid file name.",
     "File name cannot be empty." : "File name cannot be empty.",
     "\"/\" is not allowed inside a file name." : "\"/\" is not allowed inside a file name.",
     "\"{name}\" is not an allowed filetype" : "\"{name}\" is not an allowed filetype",
-    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Storage of {owner} is full, files can not be updated or synced anymore!",
-    "Your storage is full, files can not be updated or synced anymore!" : "Your storage is full, files can not be updated or synced anymore!",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Storage of {owner} is almost full ({usedSpacePercent}%)",
-    "Your storage is almost full ({usedSpacePercent}%)" : "Your storage is almost full ({usedSpacePercent}%)",
-    "_matches '{filter}'_::_match '{filter}'_" : ["matches '{filter}'","match '{filter}'"],
     "View in folder" : "View in folder",
     "Copied!" : "Copied!",
     "Copy direct link (only works for users who have access to this file/folder)" : "Copy direct link (only works for users who have access to this file/folder)",
@@ -81,8 +75,10 @@ OC.L10N.register(
     "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
     "Favorited" : "Favourited",
     "Favorite" : "Favourite",
+    "You can only favorite a single file or folder at a time" : "You can only favourite a single file or folder at a time",
     "New folder" : "New folder",
     "Upload file" : "Upload file",
+    "Recent" : "Recent",
     "Not favorited" : "Not favourited",
     "Remove from favorites" : "Remove from favourites",
     "Add to favorites" : "Add to favourites",
@@ -119,26 +115,23 @@ OC.L10N.register(
     "You moved {oldfile} to {newfile}" : "You moved {oldfile} to {newfile}",
     "{user} moved {oldfile} to {newfile}" : "{user} moved {oldfile} to {newfile}",
     "A file has been added to or removed from your <strong>favorites</strong>" : "A file has been added to or removed from your <strong>favourites</strong>",
-    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>",
-    "A new file or folder has been <strong>created</strong>" : "A new file or folder has been <strong>created</strong>",
-    "A file or folder has been <strong>deleted</strong>" : "A file or folder has been <strong>deleted</strong>",
-    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limit notifications about creation and changes to your <strong>favourite files</strong> <em>(Stream only)</em>",
-    "A file or folder has been <strong>restored</strong>" : "A file or folder has been <strong>restored</strong>",
+    "A file or folder has been <strong>changed</strong>" : "A file or folder has been <strong>changed</strong>",
+    "A favorite file or folder has been <strong>changed</strong>" : "A favourite file or folder has been <strong>changed</strong>",
+    "All files" : "All files",
     "Unlimited" : "Unlimited",
     "Upload (max. %s)" : "Upload (max. %s)",
-    "File handling" : "File handling",
-    "Maximum upload size" : "Maximum upload size",
-    "max. possible: " : "max. possible: ",
-    "Save" : "Save",
-    "With PHP-FPM it might take 5 minutes for changes to be applied." : "With PHP-FPM it might take 5 minutes for changes to be applied.",
-    "Missing permissions to edit from here." : "Missing permissions to edit from here.",
-    "%s of %s used" : "%s of %s used",
+    "Accept" : "Accept",
+    "Reject" : "Reject",
+    "in %s" : "in %s",
+    "File Management" : "File Management",
+    "Change" : "Change",
+    "Transfer" : "Transfer",
+    "Cancel" : "Cancel",
+    "Create" : "Create",
     "%s used" : "%s used",
-    "Settings" : "Settings",
+    "%1$s of %2$s used" : "%1$s of %2$s used",
     "Show hidden files" : "Show hidden files",
     "WebDAV" : "WebDAV",
-    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>",
-    "Cancel upload" : "Cancel upload",
     "No files in here" : "No files in here",
     "Upload some content or sync with your devices!" : "Upload some content or sync with your devices!",
     "No entries found in this folder" : "No entries found in this folder",
@@ -147,16 +140,16 @@ OC.L10N.register(
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "The files you are trying to upload exceed the maximum size for file uploads on this server.",
     "No favorites yet" : "No favourites yet",
     "Files and folders you mark as favorite will show up here" : "Files and folders you mark as favourite will show up here",
-    "Tags" : "Tags",
     "Deleted files" : "Deleted files",
+    "Shares" : "Shares",
     "Shared with others" : "Shared with others",
     "Shared with you" : "Shared with you",
     "Shared by link" : "Shared by link",
     "Text file" : "Text file",
     "New text file.txt" : "New text file.txt",
-    "Move" : "Move",
-    "A new file or folder has been <strong>deleted</strong>" : "A new file or folder has been <strong>deleted</strong>",
-    "A new file or folder has been <strong>restored</strong>" : "A new file or folder has been <strong>restored</strong>",
-    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>"
+    "Select" : "Select",
+    "You don’t have permission to upload or create files here" : "You don’t have permission to upload or create files here",
+    "New" : "New",
+    "Settings" : "Settings"
 },
 "nplurals=2; plural=(n != 1);");
