@@ -1,21 +1,22 @@
 OC.L10N.register(
     "files",
     {
-    "Storage is temporarily not available" : "Biltegia ez dago erabilgarri aldi baterako",
+    "Storage is temporarily not available" : "Biltegia ez dago erabilgarri momentu honetan",
     "Storage invalid" : "Biltegi baliogabea",
     "Unknown error" : "Errore ezezaguna",
-    "All files" : "Fitxategi guztiak",
-    "Recent" : "Azkenak",
-    "Favorites" : "Gogokoak",
     "File could not be found" : "Ezin izan da fitxategia aurkitu",
-    "Move or copy" : "Lekuz aldatu edo kopiatu",
+    "Move or copy" : "Mugitu edo kopiatu",
     "Download" : "Deskargatu",
     "Delete" : "Ezabatu",
+    "Tags" : "Etiketak",
+    "Show list view" : "Erakutsi zerrenda ikuspegia",
+    "Show grid view" : "Erakutsi sareta-ikuspegia",
     "Home" : "Etxea",
     "Close" : "Itxi",
+    "Favorites" : "Gogokoak",
     "Could not create folder \"{dir}\"" : "Ezin izan da \"{dir}\" karpeta sortu",
-    "This will stop your current uploads." : "Honek zure uneko kargatzeak geldituko ditu.",
-    "Upload cancelled." : "Kargatzea bertan behera utzi da.",
+    "This will stop your current uploads." : "Honek martxan dauzkazun igoerak geldituko ditu.",
+    "Upload cancelled." : "Karga bertan behera utzi da.",
     "Processing files …" : "Fitxategiak prozesatzen...",
     "…" : "…",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "Ezin da {filename} kargatu karpeta bat delako edo 0 byte dituelako",
@@ -23,31 +24,38 @@ OC.L10N.register(
     "Target folder \"{dir}\" does not exist any more" : "\"{dir}\" helburuko karpeta ez da existitzen jadanik",
     "Not enough free space" : "Ez dago leku libre nahikorik",
     "An unknown error has occurred" : "Errore ezezagun bat gertatu da",
+    "File could not be uploaded" : "Fitxategia ezin izan da kargatu",
     "Uploading …" : "Kargatzen...",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} / {totalSize} ({bitrate})",
     "Uploading that item is not supported" : "Ez da onartzen elementu hori kargatzea",
     "Target folder does not exist any more" : "Helburuko karpeta ez da existitzen jadanik",
+    "Operation is blocked by access control" : "Sarbide kontrolak eragiketa blokeatu du",
     "Error when assembling chunks, status code {status}" : "Errorea zatiak elkartzean, egoera kodea {status}",
     "Actions" : "Ekintzak",
     "Rename" : "Berrizendatu",
+    "Move" : "Mugitu",
     "Copy" : "Kopiatu",
     "Choose target folder" : "Aukeratu helburuko karpeta",
+    "Edit locally" : "Editatu lokalean",
     "Open" : "Ireki",
     "Delete file" : "Ezabatu fitxategia",
     "Delete folder" : "Ezabatu karpeta",
     "Disconnect storage" : "Deskonektatu biltegia",
-    "Unshare" : "Ez partekatu",
+    "Leave this share" : "Utzi partekatze hau",
     "Could not load info for file \"{file}\"" : "Ezin izan da \"{file}\" fitxategiaren informazioa kargatu",
     "Files" : "Fitxategiak",
     "Details" : "Xehetasunak",
-    "Select" : "Hautatu",
+    "Please select tag(s) to add to the selection" : "Hautatu etiketa(k) hautapenera gehitzeko",
+    "Apply tag(s) to selection" : "Aplikatu etiketa(k) hautapenari",
+    "Select directory \"{dirName}\"" : "Hautatu \"{dirName}\" direktorioa",
+    "Select file \"{fileName}\"" : "Hautatu \"{fileName}\" fitxategia",
     "Pending" : "Zain",
     "Unable to determine date" : "Ezin izan da data zehaztu",
     "This operation is forbidden" : "Eragiketa hau debekatuta dago",
     "This directory is unavailable, please check the logs or contact the administrator" : "Direktorio hau ez dago erabilgarri, egiaztatu egunkariak edo jarri administratzailearekin harremanetan",
     "Could not move \"{file}\", target exists" : "Ezin izan da \"{file}\" lekuz aldatu, helburua existitzen da jadanik",
     "Could not move \"{file}\"" : "Ezin izan da \"{file}\" lekuz aldatu",
-    "copy" : "kopiatu",
+    "copy" : "kopia",
     "Could not copy \"{file}\", target exists" : "Ezin izan da \"{file}\" kopiatu; helburua existitzen da",
     "Could not copy \"{file}\"" : "Ezin izan da \"{file}\" kopiatu",
     "Copied {origin} inside {destination}" : "{origin} {destination} barruan kopiatu da",
@@ -59,8 +67,10 @@ OC.L10N.register(
     "Could not create file \"{file}\"" : "Ezin izan da \"{file}\" fitxategia sortu",
     "Could not create file \"{file}\" because it already exists" : "Ezin izan da \"{file}\" fitxategia sortu, dagoeneko existitzen delako",
     "Could not create folder \"{dir}\" because it already exists" : "Ezin izan da \"{dir}\" karpeta sortu, dagoeneko existitzen delako",
+    "Could not fetch file details \"{file}\"" : "Ezin izan dira \"{file}\" fitxategiaren xehetasunak eskuratu",
     "Error deleting file \"{fileName}\"." : "Errorea \"{fileName}\" fitxategia ezabatzerakoan.",
     "No search results in other folders for {tag}{filter}{endtag}" : "Ez da '{tag}{filter}{endtag}' bilaketarako emaitzarik aurkitu beste karpetetan",
+    "Enter more than two characters to search in other folders" : "Sartu bi karaktere baino gehiago beste karpetetan bilatu ahal izateko",
     "Name" : "Izena",
     "Size" : "Tamaina",
     "Modified" : "Aldatuta",
@@ -68,21 +78,26 @@ OC.L10N.register(
     "_%n file_::_%n files_" : ["Fitxategi %n","%n fitxategi"],
     "{dirs} and {files}" : "{dirs} eta {files}",
     "_including %n hidden_::_including %n hidden_" : ["ezkutuko %n barne","ezkutuko %n barne"],
-    "You don’t have permission to upload or create files here" : "Ez duzu baimenik fitxategiak hona kargatu edo hemen sortzeko",
+    "You do not have permission to upload or create files here" : "Ez duzu hemen fitxategiak kargatzeko edo sortzeko baimenik",
     "_Uploading %n file_::_Uploading %n files_" : ["Fitxategi %n kargatzen","%n fitxategi kargatzen"],
-    "New" : "Berria",
+    "New file/folder menu" : "Fitxategi/karpeta berri menua",
     "Select file range" : "Hautatu fitxategi-barrutia",
+    "{used}%" : "%{used}",
     "{used} of {quota} used" : "{used} / {quota} erabilita",
     "{used} used" : "{used} erabilita",
     "\"{name}\" is an invalid file name." : "\"{name}\" fitxategi-izen baliogabea da.",
     "File name cannot be empty." : "Fitxategi-izena ezin da hutsa izan.",
     "\"/\" is not allowed inside a file name." : "\"/\" ez da onartzen fitxategi-izenen barnean.",
     "\"{name}\" is not an allowed filetype" : "\"{name}\" fitxategi-mota ez da onartzen",
-    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} erabiltzailearen biltegia beteta dago, fitxategiak ezin dira eguneratu edo sinkronizatu jada!",
-    "Your storage is full, files can not be updated or synced anymore!" : "Zure biltegia beteta dago, ezin duzu fitxategirik igo edo sinkronizatu jada!",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} erabiltzailearen biltegia ia beteta dago ({usedSpacePercent}%)",
-    "Your storage is almost full ({usedSpacePercent}%)" : "Zure biltegia ia beteta dago (%{usedSpacePercent})",
-    "_matches '{filter}'_::_match '{filter}'_" : ["bat dator '{filter}' iragazkiarekin","bat datoz '{filter}' iragazkiarekin"],
+    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "{owner} erabiltzailearen biltegia beteta dago, fitxategiak ezin dira jada eguneratu edo sinkronizatu!",
+    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "\"{MountPoint}\" taldeko karpeta beteta dago, fitxategiak ezin dira eguneratu edo sinkronizatu gehiago!",
+    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "\"{MountPoint}\" kanpoko biltegia beteta dago, fitxategiak ezin dira eguneratu edo sinkronizatu gehiago!",
+    "Your storage is full, files cannot be updated or synced anymore!" : "Biltegiratzea beteta dago, fitxategiak ezin dira eguneratu edo sinkronizatu gehiago!",
+    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "{owner}-(r)en biltegia betetzear dago ({usedSpacePercent}%).",
+    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "\"{mountPoint}\" talde karpeta betetzear dago ({usedSpacePercent}%).",
+    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "\"{mountPoint}\" kanpoko biltegia betetzear dago ({usedSpacePercent}%).",
+    "Your storage is almost full ({usedSpacePercent}%)." : "Zure biltegia betetzear dago ({usedSpacePercent}%).",
+    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["\"{filter}\" emaitza","\"{filter}\" emaitza"],
     "View in folder" : "Ikusi karpetan",
     "Copied!" : "Kopiatua!",
     "Copy direct link (only works for users who have access to this file/folder)" : "Kopiatu esteka zuzena (fitxategi/karpeta honetara sarbidea duten erabiltzaileentzat bakarrik balio du)",
@@ -93,6 +108,7 @@ OC.L10N.register(
     "You can only favorite a single file or folder at a time" : "Fitxategi edo karpeta bakarra markatu dezakezu gogoko gisa aldiko",
     "New folder" : "Karpeta berria",
     "Upload file" : "Kargatu fitxategia",
+    "Recent" : "Azkenak",
     "Not favorited" : "Ez da gogokoa",
     "Remove from favorites" : "Kendu gogokoetatik",
     "Add to favorites" : "Gehitu gogokoetara",
@@ -124,31 +140,66 @@ OC.L10N.register(
     "{user} deleted an encrypted file in {file}" : "{user} erabiltzaileak enkriptatutako fitxategi bat ezabatu du {file} karpetan",
     "You restored {file}" : "{file} leheneratu duzu",
     "{user} restored {file}" : "{user} erabiltzaileak {file} leheneratu du",
+    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "{oldfile} (ezkutukoa) {newfile} (ezkutukoa) bezala berrizendatu duzu",
+    "You renamed {oldfile} (hidden) to {newfile}" : "{oldfile} (ezkutukoa) {newfile} bezala berrizendatu duzu",
+    "You renamed {oldfile} to {newfile} (hidden)" : "{oldfile} {newfile} (ezkutukoa) bezala berrizendatu duzu",
     "You renamed {oldfile} to {newfile}" : "{oldfile} {newfile} bezala berrizendatu duzu",
+    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} erabiltzaileak {oldfile} (ezkutukoa) {newfile} (ezkutukoa) bezala berrizendatu du",
+    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} erabiltzaileak {oldfile} (ezkutukoa) {newfile} bezala berrizendatu du",
+    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} erabiltzaileak {oldfile} {newfile} (ezkutukoa) bezala berrizendatu du",
     "{user} renamed {oldfile} to {newfile}" : "{user} erabiltzaileak {oldfile} {newfile} bezala berrizendatu du",
     "You moved {oldfile} to {newfile}" : "{oldfile} lekuz aldatu duzu {newfile}(e)ra",
     "{user} moved {oldfile} to {newfile}" : "{user} erabiltzaileak {oldfile} lekuz aldatu du {newfile}(e)ra",
     "A file has been added to or removed from your <strong>favorites</strong>" : "Fitxategi bat gehitu edo kendu da zure <strong>gogokoetatik</strong>",
-    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Fitxategi edo karpeta bat <strong>aldatu</strong> edo <strong>berrizendatu</strong> da",
-    "A new file or folder has been <strong>created</strong>" : "Fitxategi edo karpeta berri bat <strong>sortu</strong> da",
-    "A file or folder has been <strong>deleted</strong>" : "Fitxategi edo karpeta bat <strong>ezabatu</strong> da",
-    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Mugatu <strong>gogoko fitxategien</strong> sorrera eta aldaketen jakinarazpenak <em>(Jarioa soilik)</em>",
-    "A file or folder has been <strong>restored</strong>" : "Fitxategia edo karpeta bat <strong>leheneratu</strong> da",
+    "A file or folder has been <strong>changed</strong>" : "Fitxategi edo karpeta bat <strong>aldatu da</strong>",
+    "A favorite file or folder has been <strong>changed</strong>" : "Gogoko fitxategi edo karpeta bat <strong>aldatu</strong> egin da.",
+    "All files" : "Fitxategi guztiak",
     "Unlimited" : "Mugarik gabe",
     "Upload (max. %s)" : "Kargatu (%s gehienez)",
     "Accept" : "Onartu",
+    "Reject" : "Ukatu",
+    "Incoming ownership transfer from {user}" : "{user}-ren jabetza-transferentzia",
+    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "{path} onartu nahi duzu?\n\nOharra: onarpenaren ondoren transferentzia prozesuak ordu 1 iraun dezake.",
+    "Ownership transfer failed" : "Jabetzaren transferentziak huts egin du",
+    "Your ownership transfer of {path} to {user} failed." : "{path}-aren jabetza {user} erabiltzaileari transferitzeak huts egin du.",
+    "The ownership transfer of {path} from {user} failed." : "{path}-ren jabetza {user} erabiltzailetik transferitzeak huts egin du.",
+    "Ownership transfer done" : "Jabetzaren transferentzia egina",
+    "Your ownership transfer of {path} to {user} has completed." : "{path}-ren jabetza {user} erabiltzaileari transferitzea osatu da.",
+    "The ownership transfer of {path} from {user} has completed." : "{path}-ren jabetza {user} erabiltzailetik transferitzea osatu da.",
+    "in %s" : "%s-an",
     "File Management" : "Fitxategi-kudeaketa",
+    "Transfer ownership of a file or folder" : "Transferitu fitxategiaren edo karpetaren jabetza",
+    "Choose file or folder to transfer" : "Aukeratu fitxategia edo karpeta transferitzeko",
+    "Change" : "Aldatu",
+    "New owner" : "Jabe berria",
+    "Search users" : "Bilatu erabiltzaileak",
+    "Choose a file or folder to transfer" : "Aukeratu fitxategi edo karpeta bat transferitzeko",
+    "Transfer" : "Transferitu",
+    "Transfer {path} to {userid}" : "Transfereritu {path}  {userid} erabiltzaileari",
     "Invalid path selected" : "Bide baliogabea hautatuta",
     "Ownership transfer request sent" : "Jabetza transferentzia eskaera bidalita",
-    "Error while loading the file data" : "Errorea fitxategiaren datuak kargatzerakoan",
+    "Cannot transfer ownership of a file or folder you do not own" : "Ezin da zurea ez den fitxategi edo karpeta baten jabetza transferitu  ",
     "Unable to change the favourite state of the file" : "Ezinezkoa fitxategiaren gogoko egoera aldatzea",
+    "Error while loading the file data" : "Errorea fitxategiaren datuak kargatzerakoan",
+    "Pick a template for {name}" : "Hautatu  {name}-ren txantiloia",
+    "Cancel" : "Utzi",
+    "Create" : "Sortu",
+    "Create a new file with the selected template" : "Sortu fitxategi berria hautatutako txantiloiarekin",
+    "Creating file" : "Fitxategia sortzen",
+    "Blank" : "Hutsik",
+    "Unable to create new file from template" : "Ezin da fitxategi berria sortu txantiloitik",
+    "Set up templates folder" : "Konfiguratu txantiloien karpeta",
+    "Templates" : "Txantiloia",
+    "Unable to initialize the templates directory" : "Ezin da txantiloien direktorioa hasieratu",
     "%s used" : "%s erabilita",
-    "%s%% of %s used" : "%s%% / %s erabilita",
+    "%s%%" : "%s%%",
     "%1$s of %2$s used" : "%1$s / %2$s erabilita",
-    "Settings" : "Ezarpenak",
+    "Files settings" : "FItxategien ezarpenak",
     "Show hidden files" : "Erakutsi ezkutuko fitxategiak",
+    "Crop image previews" : "Moztu irudien aurrebistak",
     "WebDAV" : "WebDAV",
-    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Erabili helbide hau <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">zure fitxategiak WebDAV bidez atzitzeko</a>",
+    "Use this address to access your Files via WebDAV" : "Erabili helbide hau WebDAV bidez zure fitxategietara sartzeko",
+    "Toggle %1$s sublist" : "Txandakatu %1$sazpizerrenda",
     "Toggle grid view" : "Txandakatu sareta ikuspegia",
     "No files in here" : "Ez dago fitxategirik hemen",
     "Upload some content or sync with your devices!" : "Kargatu edukiren bat edo sinkronizatu zure gailuekin!",
@@ -158,23 +209,20 @@ OC.L10N.register(
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Kargatzen saiatzen ari zaren fitxategiek zerbitzari honek onartzen duen gehienezko tamaina gainditzen dute.",
     "No favorites yet" : "Gogokorik ez oraindik",
     "Files and folders you mark as favorite will show up here" : "Gogokotzat markatutako fitxategi eta karpetak hemen agertuko dira",
-    "Tags" : "Etiketak",
     "Deleted files" : "Ezabatutako fitxategiak",
     "Shares" : "Partekatzeak",
     "Shared with others" : "Besteekin partekatuta",
     "Shared with you" : "Zurekin partekatuta",
     "Shared by link" : "Partekatua esteka bidez",
     "Deleted shares" : "Ezabatutako partekatzeak",
+    "Pending shares" : "Zain dauden partekatzeak",
     "Text file" : "Testu-fitxategia",
     "New text file.txt" : "Testu-fitxategi berria.txt",
-    "File handling" : "Fitxategien kudeaketa",
-    "Maximum upload size" : "Karga daitekeen gehienezko tamaina",
-    "max. possible: " : "gehienez:",
-    "Save" : "Gorde",
-    "With PHP-FPM it might take 5 minutes for changes to be applied." : "PHP-FPMrekin 5 minutu pasa daitezke aldaketak aplikatu arte.",
-    "Missing permissions to edit from here." : "Hemendik editatzeko baimenik ez duzu.",
-    "Cancel upload" : "Karga bertan behera utzita",
-    "%s of %s used" : "%s / %s erabilita",
-    "%1$s%% of %2$s used" : "%1$s%% / %2$serabilita"
+    "Select" : "Hautatu",
+    "You don’t have permission to upload or create files here" : "Ez duzu baimenik fitxategiak hona kargatu edo hemen sortzeko",
+    "New" : "Berria",
+    "Cannot transfer ownership of a file or folder you don't own" : "Ezin da zurea ez den fitxategi edo karpeta baten jabetza transferitu",
+    "%s%% of %s used" : "%s%% / %s erabilita",
+    "Settings" : "Ezarpenak"
 },
 "nplurals=2; plural=(n != 1);");
