@@ -19,7 +19,7 @@ OC.L10N.register(
     "Upload cancelled." : "Envoi annulé.",
     "Processing files …" : "Fichiers en cours de traitement …",
     "…" : "…",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Impossible d'envoyer {filename} car il s'agit d'un dossier ou d'un fichier vide",
+    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Impossible de téléverser {filename} car il s'agit d'un dossier ou d'un fichier vide",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "Espace libre insuffisant : vous tentez d'envoyer {size1} mais seulement {size2} sont disponibles",
     "Target folder \"{dir}\" does not exist any more" : "Le dossier cible \"{dir}\" n'existe plus",
     "Not enough free space" : "Espace disponible insuffisant",
@@ -60,6 +60,7 @@ OC.L10N.register(
     "Could not copy \"{file}\"" : "Impossible de copier \"{file}\"",
     "Copied {origin} inside {destination}" : "{origin} copié dans {destination}",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} et {nbfiles} autres fichiers copiés dans {destination}",
+    "Failed to redirect to client" : "Échec de la redirection vers le client",
     "{newName} already exists" : "{newName} existe déjà",
     "Could not rename \"{fileName}\", it does not exist any more" : "Impossible de renommer \"{fileName}\" car il n'existe plus",
     "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Le nom \"{targetName}\" est déjà utilisé dans le dossier \"{dir}\". Merci de choisir un nom différent.",
@@ -107,7 +108,7 @@ OC.L10N.register(
     "Favorite" : "Favoris",
     "You can only favorite a single file or folder at a time" : "Vous ne pouvez ajouter qu'un seul favori de dossier ou de fichier à la fois.",
     "New folder" : "Nouveau dossier",
-    "Upload file" : "Envoyer un fichier",
+    "Upload file" : "Téléverser un fichier",
     "Recent" : "Récent",
     "Not favorited" : "Non marqué comme favori",
     "Remove from favorites" : "Retirer des favoris",
@@ -151,7 +152,7 @@ OC.L10N.register(
     "You moved {oldfile} to {newfile}" : "Vous avez déplacé {oldfile} dans {newfile}",
     "{user} moved {oldfile} to {newfile}" : "{user} a déplacé {oldfile} dans {newfile}",
     "A file has been added to or removed from your <strong>favorites</strong>" : "Un fichier a été ajouté ou retiré de vos <strong>favoris</strong>",
-    "A file or folder has been <strong>changed</strong>" : "Un fichier ou un répertoire a été <strong>modifié</strong>",
+    "A file or folder has been <strong>changed</strong>" : "Un fichier ou un dossier a été <strong>modifié</strong>",
     "A favorite file or folder has been <strong>changed</strong>" : "Un fichier ou un dossier favori a été <strong>modifié </strong>",
     "All files" : "Tous les fichiers",
     "Unlimited" : "Illimité",
@@ -190,7 +191,7 @@ OC.L10N.register(
     "Unable to create new file from template" : "Impossible de créer un nouveau fichier à partir du modèle",
     "Set up templates folder" : "Configurer le dossier des modèles",
     "Templates" : "Modèles",
-    "Unable to initialize the templates directory" : "Impossible d'initialiser le répertoire des modèles",
+    "Unable to initialize the templates directory" : "Impossible d'initialiser le dossier des modèles",
     "%s used" : "%s utilisés",
     "%s%%" : "%s%%",
     "%1$s of %2$s used" : "%1$s utilisés sur %2$s",
