@@ -8,6 +8,9 @@ OC.L10N.register(
     "Move or copy" : "移動またはコピー",
     "Download" : "ダウンロード",
     "Delete" : "削除",
+    "Tags" : "タグ",
+    "Show list view" : "リストビューで表示",
+    "Show grid view" : "グリッドビューで表示",
     "Home" : "ホーム",
     "Close" : "閉じる",
     "Favorites" : "お気に入り",
@@ -21,23 +24,30 @@ OC.L10N.register(
     "Target folder \"{dir}\" does not exist any more" : "対象フォルダー \"{dir}\" がもう存在しません",
     "Not enough free space" : "十分な空き容量がありません",
     "An unknown error has occurred" : "不明なエラーが発生しました",
+    "File could not be uploaded" : "ファイルをアップロードできませんでした",
     "Uploading …" : "アップロード中...",
     "{loadedSize} of {totalSize} ({bitrate})" : "{totalSize} 中 {loadedSize} ({bitrate})",
-    "Uploading that item is not supported" : "そのアイテムのアップロードはサポートされていません",
+    "Uploading that item is not supported" : "そのアイテムのアップロードに対応していません",
     "Target folder does not exist any more" : "対象フォルダーがもう存在しません",
+    "Operation is blocked by access control" : "アクセス制御により操作がブロックされました",
     "Error when assembling chunks, status code {status}" : "チャンクを組み立てる際のエラー、ステータスコード{status}",
     "Actions" : "アクション",
     "Rename" : "名前の変更",
+    "Move" : "移動",
     "Copy" : "コピー",
     "Choose target folder" : "ターゲットフォルダーを選択",
     "Open" : "開く",
     "Delete file" : "ファイルを削除",
-    "Delete folder" : "フォルダを削除",
+    "Delete folder" : "フォルダーを削除",
     "Disconnect storage" : "ストレージを切断する",
+    "Leave this share" : "この共有から抜ける",
     "Could not load info for file \"{file}\"" : "\"{file}\" ファイルの情報を読み込めませんでした",
     "Files" : "ファイル",
     "Details" : "詳細",
-    "Select" : "選択",
+    "Please select tag(s) to add to the selection" : "選択項目に付与するタグを選択してください",
+    "Apply tag(s) to selection" : "選択項目にタグを適用",
+    "Select directory \"{dirName}\"" : "ディレクトリを選択: \"{dirName}\"",
+    "Select file \"{fileName}\"" : "ファイルを選択: \"{fileName}\"",
     "Pending" : "保留中",
     "Unable to determine date" : "更新日不明",
     "This operation is forbidden" : "この操作は禁止されています",
@@ -59,6 +69,7 @@ OC.L10N.register(
     "Could not fetch file details \"{file}\"" : "\"{file}\" の詳細が取得できませんでした",
     "Error deleting file \"{fileName}\"." : "ファイル\"{fileName}\"の削除エラー。",
     "No search results in other folders for {tag}{filter}{endtag}" : "他のフォルダーに {tag}{filter}{endtag} の検索結果はありません",
+    "Enter more than two characters to search in other folders" : "他のフォルダーで検索するには、3文字以上を入力してください",
     "Name" : "名前",
     "Size" : "サイズ",
     "Modified" : "更新日時",
@@ -66,19 +77,26 @@ OC.L10N.register(
     "_%n file_::_%n files_" : ["%n 個のファイル"],
     "{dirs} and {files}" : "{dirs} と {files}",
     "_including %n hidden_::_including %n hidden_" : ["%n 個の隠しファイルが含まれています"],
-    "You don’t have permission to upload or create files here" : "ここにファイルをアップロードまたは作成する権限がありません",
+    "You do not have permission to upload or create files here" : "ここにファイルをアップロードまたは作成する権限がありません",
     "_Uploading %n file_::_Uploading %n files_" : ["%n 個のファイルをアップロード中"],
-    "New" : "新規作成",
+    "New file/folder menu" : "新規ファイル/フォルダメニュー",
     "Select file range" : "ファイルを範囲選択",
+    "{used}%" : "{used}%",
     "{used} of {quota} used" : "{used} / {quota} 使用中",
     "{used} used" : "{used} 使用中",
     "\"{name}\" is an invalid file name." : "\"{name}\" は無効なファイル名です。",
     "File name cannot be empty." : "ファイル名を空にすることはできません。",
     "\"/\" is not allowed inside a file name." : "\"/\" はファイル名に利用できません。",
     "\"{name}\" is not an allowed filetype" : "\"{name}\" は無効なファイル形式です",
-    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} のストレージは一杯です。ファイルの更新と同期はもうできません！",
-    "Your storage is full, files can not be updated or synced anymore!" : "あなたのストレージは一杯です。ファイルの更新と同期はもうできません！",
-    "_matches '{filter}'_::_match '{filter}'_" : [" '{filter}' にマッチ"],
+    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "{owner} のストレージは一杯です。ファイルの更新と同期はできません！",
+    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "グループフォルダー ”{mountPoint}\" がいっぱいになり、ファイルを更新または同期できなくなりました。",
+    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "外部ストレージ \"{mountPoint}\" がいっぱいになり、ファイルを更新または同期できなくなりました。",
+    "Your storage is full, files cannot be updated or synced anymore!" : "ストレージがいっぱいで、ファイルを更新または同期できなくなりました。",
+    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "{owner} のストレージがほぼ一杯 ({usedSpacePercent}％) です",
+    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "グループフォルダー \"{mountPoint}\" がほぼいっぱい ({usedSpacePercent}％) です。",
+    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "外部ストレージ \"{mountPoint}\" はほぼいっぱい ({usedSpacePercent}％) です",
+    "Your storage is almost full ({usedSpacePercent}%)." : "ストレージがほぼいっぱい ({usedSpacePercent}％) です　",
+    "_matches \"{filter}\"_::_match \"{filter}\"_" : [" \"{filter}\" にマッチ"],
     "View in folder" : "フォルダー内で表示",
     "Copied!" : "コピー完了",
     "Copy direct link (only works for users who have access to this file/folder)" : "ダイレクトリンクをコピー (このファイル/フォルダーにアクセスできるユーザーのみ)",
@@ -121,12 +139,19 @@ OC.L10N.register(
     "{user} deleted an encrypted file in {file}" : "{user}が{file}で暗号化されたファイルを削除しました",
     "You restored {file}" : "{file} を復元しました",
     "{user} restored {file}" : "{user} が {file} を復元しました",
+    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "{oldfile}(非表示) の名前を {newfile}(非表示) に変更しました",
+    "You renamed {oldfile} (hidden) to {newfile}" : "{oldfile} (非表示)の名前を{newfile}に変更しました",
+    "You renamed {oldfile} to {newfile} (hidden)" : "{oldfile}の名前を{newfile}(非表示)に変更しました",
     "You renamed {oldfile} to {newfile}" : "{oldfile} を {newfile} に変更しました",
+    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} は {oldfile}(非表示) の名前を {newfile}(非表示)  に変更しました",
+    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} は {oldfile} (非表示) の名前を {newfile} に変更しました",
+    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user}は{oldfile}を{newfile} (非表示)に名前変更しました",
     "{user} renamed {oldfile} to {newfile}" : "{user} が {oldfile} を{newfile} に変更しました",
     "You moved {oldfile} to {newfile}" : "{oldfile} を {newfile} に移動しました",
     "{user} moved {oldfile} to {newfile}" : "{user} が {oldfile} を {newfile} に移動しました",
     "A file has been added to or removed from your <strong>favorites</strong>" : "<strong>お気に入り</strong>にファイルが追加または削除されたとき",
-    "A file or folder has been <strong>changed</strong>" : "ファイルまたはフォルダーを<strong>変更</strong>したとき",
+    "A file or folder has been <strong>changed</strong>" : "ファイルまたはフォルダーが<strong>変更</strong>されたとき",
+    "A favorite file or folder has been <strong>changed</strong>" : "お気に入りのファイルまたはフォルダーが <strong>変更</strong>されたとき",
     "All files" : "すべてのファイル",
     "Unlimited" : "無制限",
     "Upload (max. %s)" : "アップロード ( 最大 %s )",
@@ -143,28 +168,37 @@ OC.L10N.register(
     "in %s" : "%s で",
     "File Management" : "ファイル管理",
     "Transfer ownership of a file or folder" : "ファイルまたはフォルダーの所有権を譲渡する",
-    "Choose file or folder to transfer" : "譲渡するファイルまたはフォルダを選択してください",
+    "Choose file or folder to transfer" : "譲渡するファイルまたはフォルダーを選択してください",
     "Change" : "変更",
     "New owner" : "新しい所有者",
     "Search users" : "ユーザーを検索",
-    "Choose a file or folder to transfer" : "譲渡するファイルまたはフォルダを選択してください",
+    "Choose a file or folder to transfer" : "譲渡するファイルまたはフォルダーを選択してください",
     "Transfer" : "転送",
     "Transfer {path} to {userid}" : "{path} を {userid} に転送する",
     "Invalid path selected" : "無効なパスが選択されました",
     "Ownership transfer request sent" : "所有権転送のリクエストを送信しました",
-    "Cannot transfer ownership of a file or folder you don't own" : "所有していないファイルまたはフォルダの所有権を譲渡することはできません",
-    "Tags" : "タグ",
+    "Cannot transfer ownership of a file or folder you do not own" : "所有していないファイルまたはフォルダーの所有権を譲渡することはできません",
     "Unable to change the favourite state of the file" : "ファイルのお気に入りの状態を変更できません",
     "Error while loading the file data" : "ファイルデータの読み込み中にエラーが発生しました",
+    "Pick a template for {name}" : "{name} のテンプレートを選択してください",
     "Cancel" : "キャンセル",
     "Create" : "作成",
+    "Create a new file with the selected template" : "選択したテンプレートを使用して新しいファイルを作成します",
+    "Creating file" : "ファイル作成",
+    "Blank" : "ブランク",
+    "Unable to create new file from template" : "テンプレートから新しいファイルを作成できません",
+    "Set up templates folder" : "テンプレートフォルダーを設定",
+    "Templates" : "テンプレート",
+    "Unable to initialize the templates directory" : "テンプレートディレクトリを初期化できませんでした",
     "%s used" : "%s 使用中",
-    "%s%% of %s used" : "%s中%s%%が使われています。",
-    "%1$s of %2$s used" : "%2$s 中%1$s が使われています。",
-    "Settings" : "設定",
+    "%s%%" : "%s%%",
+    "%1$s of %2$s used" : "%2$s 中%1$s 使用中",
+    "Files settings" : "ファイル設定",
     "Show hidden files" : "隠しファイルを表示",
+    "Crop image previews" : "プレビュー画像を切り抜く",
     "WebDAV" : "WebDAV",
-    "Use this address to access your Files via WebDAV" : "このアドレスを使用して、WebDAV経由でファイルにアクセスします",
+    "Use this address to access your Files via WebDAV" : "このアドレスを使用すれば、WebDAV経由でファイルにアクセスできます",
+    "Toggle %1$s sublist" : "サブリスト %1$s を切り替え",
     "Toggle grid view" : "グリッド表示の切り替え",
     "No files in here" : "ファイルがありません",
     "Upload some content or sync with your devices!" : "何かコンテンツをアップロードするか、デバイスからファイルを同期してください。",
@@ -183,13 +217,11 @@ OC.L10N.register(
     "Pending shares" : "保留中の共有",
     "Text file" : "テキストファイル",
     "New text file.txt" : "新規のテキストファイル作成",
-    "Unshare" : "共有解除",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} のストレージはほぼ一杯です。({usedSpacePercent}%)",
-    "Your storage is almost full ({usedSpacePercent}%)" : "ストレージがほぼ一杯です（{usedSpacePercent}%）",
-    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "ファイルまたはフォルダーが<strong>更新</ strong>されたか、<strong>名前が変更</strong>されたとき",
-    "A new file or folder has been <strong>created</strong>" : "新しいファイルまたはフォルダーが<strong>作成</strong>されたとき",
-    "A file or folder has been <strong>deleted</strong>" : "ファイルまたはフォルダーが<strong>削除</strong>されたとき",
-    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "<strong>お気に入りファイル</strong>の作成と変更の通知を制限する<em>（ストリームのみ）</em>",
-    "A file or folder has been <strong>restored</strong>" : "ファイルまたはフォルダーが<strong>復元</strong>されたとき"
+    "Select" : "選択",
+    "You don’t have permission to upload or create files here" : "ここにファイルをアップロードまたは作成する権限がありません",
+    "New" : "新規作成",
+    "Cannot transfer ownership of a file or folder you don't own" : "所有していないファイルまたはフォルダーの所有権を譲渡することはできません",
+    "%s%% of %s used" : "%s%% 使用中、全体は%s",
+    "Settings" : "設定"
 },
 "nplurals=1; plural=0;");
