@@ -46,17 +46,17 @@ OC.L10N.register(
     "Pending" : "На чекању",
     "Unable to determine date" : "Не могу да одредим датум",
     "This operation is forbidden" : "Ова радња је забрањена",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Овај директоријум није доступан, проверите записе или контактирајте администратора",
-    "Could not move \"{file}\", target exists" : "Не могу да померим „{file}“, одредиште већ постоји",
-    "Could not move \"{file}\"" : "Не могу да померим „{file}“",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Овај директоријум није доступан, проверите дневник или контактирајте администратора",
+    "Could not move \"{file}\", target exists" : "Не могу да преместим „{file}“. Одредиште већ постоји",
+    "Could not move \"{file}\"" : "Не могу да преместим „{file}“",
     "copy" : "копиран",
     "Could not copy \"{file}\", target exists" : "Не могу да копирам „{file}“, одредиште већ постоји",
     "Could not copy \"{file}\"" : "Не могу да копирам „{file}“",
     "Copied {origin} inside {destination}" : "Копиран {origin} у {destination}",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "Копиран{origin} и још {nbfiles} других фајлова у {destination}",
     "{newName} already exists" : "{newName} већ постоји",
-    "Could not rename \"{fileName}\", it does not exist any more" : "Не могу да преименујем „{fileName}“, фајл више не постоји",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Име „{targetName}“ се већ користи за фасциклу „{dir}“. Одаберите неко друго име.",
+    "Could not rename \"{fileName}\", it does not exist any more" : "Не могу да преименујем „{fileName}“. Фајл више не постоји",
+    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Назив „{targetName}“ се већ користи у фасцикли „{dir}“. Одаберите неко друго име.",
     "Could not rename \"{fileName}\"" : "Не могу да преименујем „{fileName}“",
     "Could not create file \"{file}\"" : "Не могу да направим фајл „{file}“",
     "Could not create file \"{file}\" because it already exists" : "Не могу да направим фајл „{file}“ јер већ постоји",
@@ -90,7 +90,7 @@ OC.L10N.register(
     "Path" : "Путања",
     "_%n byte_::_%n bytes_" : ["%n бајт","%n бајта","%n бајтова"],
     "Favorited" : "Омиљено",
-    "Favorite" : "Омиљени",
+    "Favorite" : "Омиљено",
     "You can only favorite a single file or folder at a time" : "Можете поставити као омиљени само један фајл или фасциклу одједном",
     "New folder" : "Нова фасцикла",
     "Upload file" : "Отпреми фајл",
@@ -172,7 +172,7 @@ OC.L10N.register(
     "Upload some content or sync with your devices!" : "Отпремите неки садржај или синхронизујте са вашим уређајима!",
     "No entries found in this folder" : "Нема ничега у овој фасцикли",
     "Select all" : "Означи све",
-    "Upload too large" : "Фајл за отпремање је превелики",
+    "Upload too large" : "Отпремање је превелико",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Фајлови које желите да отпремите превазилазе ограничење отпремања на овом серверу.",
     "No favorites yet" : "Још нема омиљених",
     "Files and folders you mark as favorite will show up here" : "Фајлови и фасцикле које обележите као омиљене појавиће се овде",
