@@ -7,8 +7,10 @@ OC.L10N.register(
     "File could not be found" : "Fil kunde inte hittas",
     "Move or copy" : "Flytta eller kopiera",
     "Download" : "Hämta",
-    "Delete" : "Ta bort",
+    "Delete" : "Radera",
     "Tags" : "Taggar",
+    "Show list view" : "Visa listvy",
+    "Show grid view" : "Visa rutnätsvy",
     "Home" : "Hem",
     "Close" : "Stäng",
     "Favorites" : "Favoriter",
@@ -22,6 +24,7 @@ OC.L10N.register(
     "Target folder \"{dir}\" does not exist any more" : "Målmapp \"{dir}\" existerar inte mer",
     "Not enough free space" : "Inte tillräckligt med ledigt utrymme",
     "An unknown error has occurred" : "Ett okänt fel uppstod",
+    "File could not be uploaded" : "Filen kunde inte laddas upp",
     "Uploading …" : "Laddar upp ..",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} av {totalSize} ({bitrate})",
     "Uploading that item is not supported" : "Uppladdning av det här objektet stöds inte",
@@ -33,6 +36,7 @@ OC.L10N.register(
     "Move" : "Flytta",
     "Copy" : "Kopiera",
     "Choose target folder" : "Välj målmapp",
+    "Edit locally" : "Redigera lokalt",
     "Open" : "Öppna",
     "Delete file" : "Ta bort fil",
     "Delete folder" : "Ta bort mapp",
@@ -43,6 +47,8 @@ OC.L10N.register(
     "Details" : "Detaljer",
     "Please select tag(s) to add to the selection" : "Vänligen välj tagg(ar) att lägga till i ditt urval",
     "Apply tag(s) to selection" : "Lägg till tagg(ar) i ditt urval",
+    "Select directory \"{dirName}\"" : "Välj mapp \"{dirName}\"",
+    "Select file \"{fileName}\"" : "Välj fil \"{fileName}\"",
     "Pending" : "Väntar",
     "Unable to determine date" : "Misslyckades avgöra datum",
     "This operation is forbidden" : "Denna operation är förbjuden",
@@ -54,6 +60,7 @@ OC.L10N.register(
     "Could not copy \"{file}\"" : "Kunde inte kopiera \"{file}\"",
     "Copied {origin} inside {destination}" : "Kopierade {origin} till {destination}",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "Kopierade {origin} och {nbfiles} andra filer i {destination}",
+    "Failed to redirect to client" : "Det gick inte att omdirigera till klienten",
     "{newName} already exists" : "{newName} existerar redan",
     "Could not rename \"{fileName}\", it does not exist any more" : "Kunde inte döpa om \"{fileName}\", filen existerar inte mer",
     "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Namnet \"{targetName}\" används redan i mappen \"{dir}\". Välj ett annat namn.",
@@ -72,7 +79,9 @@ OC.L10N.register(
     "_%n file_::_%n files_" : ["%n fil","%n filer"],
     "{dirs} and {files}" : "{dirs} och {files}",
     "_including %n hidden_::_including %n hidden_" : ["inkluderar %n dold","inkluderar %n dolda"],
+    "You do not have permission to upload or create files here" : "Du har inte behörighet att ladda upp eller skapa filer här",
     "_Uploading %n file_::_Uploading %n files_" : ["Laddar upp %n fil","Laddar upp %n filer"],
+    "New file/folder menu" : "Ny fil/mapp -meny",
     "Select file range" : "Välj filintervall",
     "{used} of {quota} used" : "{used} av {quota} använt",
     "{used} used" : "{used} använt",
@@ -125,9 +134,9 @@ OC.L10N.register(
     "You changed an encrypted file in {file}" : "Du ändrade en krypterad fil i {file}",
     "{user} changed {file}" : "{user} ändrade {file}",
     "{user} changed an encrypted file in {file}" : "{user} ändrade en krypterad fil i {file}",
-    "You deleted {file}" : "Du tog bort {file}",
+    "You deleted {file}" : "Du raderade {file}",
     "You deleted an encrypted file in {file}" : "Du tog bort en krypterad fil i {file}",
-    "{user} deleted {file}" : "{user} tog bort {file}",
+    "{user} deleted {file}" : "{user} raderade {file}",
     "{user} deleted an encrypted file in {file}" : "{user} tog bort en krypterad fil i {file}",
     "You restored {file}" : "Du återställde {file}",
     "{user} restored {file}" : "{user} återställde {file}",
@@ -169,6 +178,7 @@ OC.L10N.register(
     "Transfer {path} to {userid}" : "Överför {path} till {userid}",
     "Invalid path selected" : "Ogiltig sökväg vald",
     "Ownership transfer request sent" : "Förfrågan om ägaröverföring skickad",
+    "Cannot transfer ownership of a file or folder you do not own" : "Det går inte att överföra äganderätten till en fil eller mapp som du inte äger",
     "Unable to change the favourite state of the file" : "Kan inte ändra filens favoritstatus",
     "Error while loading the file data" : "Fel vid inläsning av fildata",
     "Pick a template for {name}" : "Välj en mall för {name}",
@@ -183,6 +193,7 @@ OC.L10N.register(
     "Unable to initialize the templates directory" : "Kunde inte initialisera mall-mappen",
     "%s used" : "%s använt",
     "%1$s of %2$s used" : "%1$s av %2$s använt",
+    "Files settings" : "Filinställningar",
     "Show hidden files" : "Visa dolda filer",
     "Crop image previews" : "Beskär förhandsgranskningar för bilder",
     "WebDAV" : "WebDAV",
@@ -199,8 +210,8 @@ OC.L10N.register(
     "Files and folders you mark as favorite will show up here" : "Filer och mappar markerade som favoriter kommer att visas här",
     "Deleted files" : "Borttagna filer",
     "Shares" : "Delningar",
-    "Shared with others" : "Delad med andra",
-    "Shared with you" : "Delad med dig",
+    "Shared with others" : "Delas med andra",
+    "Shared with you" : "Delas med mig",
     "Shared by link" : "Delad via länk",
     "Deleted shares" : "Borttagna delningar",
     "Pending shares" : "Väntande delningar",
