@@ -5,7 +5,7 @@ OC.L10N.register(
     "Storage invalid" : "Некоректне сховище",
     "Unknown error" : "Невідома помилка",
     "File could not be found" : "Неможливо знайти файл",
-    "Move or copy" : "Перенести або скопіювати",
+    "Move or copy" : "Перемістити або копіювати",
     "Download" : "Звантажити",
     "Delete" : "Вилучити",
     "Tags" : "Мітки",
@@ -13,7 +13,7 @@ OC.L10N.register(
     "Show grid view" : "Подання сіткою",
     "Home" : "Домівка",
     "Close" : "Закрити",
-    "Favorites" : "Вподобані",
+    "Favorites" : "Із зірочкою",
     "Could not create folder \"{dir}\"" : "Неможливо створити каталог \"{dir}\"",
     "This will stop your current uploads." : "Ця дія призведе до зупинки поточних завантажень на сервер.",
     "Upload cancelled." : "Завантаження скасовано.",
@@ -74,7 +74,7 @@ OC.L10N.register(
     "Name" : "Ім'я",
     "Size" : "Розмір",
     "Modified" : "Змінено",
-    "_%n folder_::_%n folders_" : ["%n тека ","теки : %n ","теки : %n ","%n каталоги "],
+    "_%n folder_::_%n folders_" : ["%n каталог ","%n каталоги ","%n каталогів ","%n каталогів"],
     "_%n file_::_%n files_" : ["%n файл ","файли : %n ","файли : %n ","файли: %n "],
     "{dirs} and {files}" : "{dirs} та {files}",
     "_including %n hidden_::_including %n hidden_" : ["включаючи %n прихований","включаючи %n прихованих","включаючи %n прихованих","включно %n прихованих"],
@@ -108,8 +108,8 @@ OC.L10N.register(
     "You can only favorite a single file or folder at a time" : "Одночасно можна вподобати лише один файл або каталог",
     "New folder" : "Новий каталог",
     "Upload file" : "Завантажити файл",
-    "Recent" : "Нещодавні",
-    "Not favorited" : "Не вподобані",
+    "Recent" : "Останні",
+    "Not favorited" : "Без зірочки",
     "Remove from favorites" : "Прибрати із вподобаного",
     "Add to favorites" : "Вподобати",
     "An error occurred while trying to update the tags" : "Виникла помилка при спробі оновити мітки",
@@ -130,7 +130,7 @@ OC.L10N.register(
     "{user} created {file}" : "Користувач {user} створив {file}",
     "{user} created an encrypted file in {file}" : "{user} створив зашифрований файл у {file}",
     "{file} was created in a public folder" : "Файл {file} створено у публічному каталозі",
-    "You changed {file}" : "Ви змінили {file}",
+    "You changed {file}" : "Ви змінили файл {file}",
     "You changed an encrypted file in {file}" : "Ви змінили зашифрований файл у {file}",
     "{user} changed {file}" : "Користувач {user} змінив файл {file}",
     "{user} changed an encrypted file in {file}" : "{user} змінив зашифрований файл у {file}",
@@ -187,18 +187,18 @@ OC.L10N.register(
     "Create a new file with the selected template" : "Створити новий файл на основі вибраного шаблону",
     "Creating file" : "Створення файлу",
     "Blank" : "Порожньо",
-    "Unable to create new file from template" : "зНеможливо створити новий файл з шаблону",
+    "Unable to create new file from template" : "Неможливо створити новий файл з шаблону",
     "Set up templates folder" : "Встановити каталог з шаблонами",
     "Templates" : "Шаблони",
     "Unable to initialize the templates directory" : "Неможливо встановити каталог з шаблонами",
     "%s used" : "%s використано",
     "%s%%" : "%s%%",
-    "%1$s of %2$s used" : "Використано %1$s з %2$s",
+    "%1$s of %2$s used" : "Використано %1$s із %2$s",
     "Files settings" : "Налаштування файлів",
     "Show hidden files" : "Показувати приховані файли",
-    "Crop image previews" : "Обрізати попередній перегляд зображень",
+    "Crop image previews" : "Кадрування попереднього перегляду зображень",
     "WebDAV" : "WebDAV",
-    "Use this address to access your Files via WebDAV" : "Використовуйте цю адресу для доступу до ваших файлів за допомогою протоколу WebDAV",
+    "Use this address to access your Files via WebDAV" : "Адреса для доступу до файлів за допомогою протоколу WebDAV",
     "Toggle %1$s sublist" : "Перемкнути вкладений список %1$s",
     "Toggle grid view" : "Перемкнути подання сіткою",
     "No files in here" : "Тут немає файлів",
@@ -208,21 +208,21 @@ OC.L10N.register(
     "Upload too large" : "Файл занадто великий",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Файли, які ви намагаєтеся завантажити, перевищують максимально дозволений розмір завантаження файлів на сервер.",
     "No favorites yet" : "Поки немає вподобаного",
-    "Files and folders you mark as favorite will show up here" : "Файли та каталоги, які ви позначили як вподобані, з’являться тут",
+    "Files and folders you mark as favorite will show up here" : "Файли та каталоги, які ви вподобали, з’являться тут",
     "Deleted files" : "Кошик",
     "Shares" : "Спільний доступ",
     "Shared with others" : "Ви поділилися",
     "Shared with you" : "Надано доступ вам",
     "Shared by link" : "Доступ за посиланням",
-    "Deleted shares" : "Вилучено зі спільного доступу",
-    "Pending shares" : "Запит на доступ",
+    "Deleted shares" : "Більше недоступні",
+    "Pending shares" : "Запити на доступ",
     "Text file" : "Текстовий файл",
     "New text file.txt" : "Новий текстовий файл.txt",
     "Select" : "Вибрати",
     "You don’t have permission to upload or create files here" : "У вас недостатньо прав для завантаження або створення файлів тут",
     "New" : "Створити",
     "Cannot transfer ownership of a file or folder you don't own" : "Неможливо передати права власності на файл або каталог, що вам не належить",
-    "%s%% of %s used" : "%s%% з %s використано",
+    "%s%% of %s used" : "%s%% із %s використано",
     "Settings" : "Налаштування"
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
