@@ -123,7 +123,6 @@ OC.L10N.register(
     "Could not lock node" : "Solmua ei voitu lukita",
     "Could not lock path" : "Polun lukitseminen ei onnistunut",
     "Wrong or no update parameter given" : "Päivitettävä parametri puuttuu tai on väärin",
-    "Cannot increase permissions" : "Oikeuksien lisääminen ei onnistu",
     "shared by %s" : "käyttäjän %s jakama",
     "Download all files" : "Lataa kaikki tiedostot",
     "Direct link" : "Suora linkki",
@@ -196,6 +195,7 @@ OC.L10N.register(
     "Add another link" : "Lisää toinen linkki",
     "Create a new share link" : "Luo uusi jakolinkki",
     "Shared via link by {initiator}" : "Jaettu linkin kautta käyttäjältä {initiator}",
+    "Mail share ({label})" : "Sähköpostijako ({label})",
     "Share link ({label})" : "Jaa linkki ({label})",
     "Share link" : "Jaa linkki",
     "Error, please enter proper password and/or expiration date" : "Virhe, lisää kelvollinen salasana ja/tai päättymispäivä",
