@@ -65,7 +65,7 @@ OC.L10N.register(
     "Public link of {actor} expired" : "Offentlig lenke av {actor} er utløpt",
     "You shared {file} as public link" : "Du delte {file} som offentlig lenke",
     "You removed public link for {file}" : "Du fjernet offentlig lenke for {file}",
-    "Public link expired for {file}" : "Offentlig lenke er utløprt for {file}",
+    "Public link expired for {file}" : "Offentlig lenke er utløpt for {file}",
     "{actor} shared {file} as public link" : "{actor} delte {file} som offentlig lenke",
     "{actor} removed public link for {file}" : "{actor} fjernet offentlig lenke for {file}",
     "Public link of {actor} for {file} expired" : "Offentlig lenke av {actor} for {file} har utløpt",
@@ -119,7 +119,6 @@ OC.L10N.register(
     "Not a directory" : "Ikke en mappe",
     "Could not lock path" : "Kunne ikke låse sti",
     "Wrong or no update parameter given" : "Feil eller ingen parametre for oppdatering er angitt",
-    "Cannot increase permissions" : "Kan ikke øke tillatelser",
     "shared by %s" : "delt av %s",
     "Download all files" : "Last ned alle filer",
     "Direct link" : "Direkte lenke",
