@@ -100,8 +100,10 @@ OC.L10N.register(
     "Files" : "文件",
     "A file or folder has been <strong>shared</strong>" : "一个文件或文件夹已<strong>共享</strong>。",
     "Shared link" : "已共享的链接",
+    "Wrong share ID, share does not exist" : "错误的分享 ID，分享不存在",
     "Could not delete share" : "不能删除共享",
     "Please specify a file or folder path" : "请指定一个文件或文件夹路径",
+    "Wrong path, file/folder does not exist" : "错误的路径，文件/文件夹不存在",
     "Could not create share" : "无法创建共享",
     "Invalid permissions" : "无效的权限 ",
     "Please specify a valid user" : "请指定一个有效的用户",
@@ -123,7 +125,8 @@ OC.L10N.register(
     "Could not lock node" : "无法锁定节点",
     "Could not lock path" : "无法锁定路径",
     "Wrong or no update parameter given" : "错误或没有更新参数给出",
-    "Cannot increase permissions" : "不能增加权限",
+    "Share must at least have READ or CREATE permissions" : "分享至少具有 READ 或 CREATE 权限",
+    "Share must have READ permission if UPDATE or DELETE permission is set" : "分享如果设置了 UPDATE 或 DELETE 权限，则必须具有 READ 权限",
     "\"Sending the password by Nextcloud Talk\" for sharing a file or folder failed because Nextcloud Talk is not enabled." : "“通过Nextcloud Talk发送密码”共享文件或文件夹失败了，因为未启用 Nextcloud Talk",
     "shared by %s" : "共享者 %s",
     "Download all files" : "下载所有文件",
@@ -152,9 +155,11 @@ OC.L10N.register(
     "Read only" : "只读",
     "Allow upload and editing" : "允许上传和编辑",
     "File drop (upload only)" : "文件拖放（仅上传）",
+    "Custom permissions" : "自定义权限",
     "Read" : "读取",
     "Upload" : "上传",
     "Edit" : "编辑",
+    "Bundled permissions" : "权限包",
     "Allow creating" : "允许创建",
     "Allow deleting" : "允许删除",
     "Allow resharing" : "允许二次共享",
@@ -171,14 +176,17 @@ OC.L10N.register(
     "Shared with the group {user} by {owner}" : "{owner} 共享给分组 {user}",
     "Shared with the conversation {user} by {owner}" : "由{owner}共享给会话{user}",
     "Shared with {user} by {owner}" : "{owner} 共享给 {user}",
+    "Allow download" : "允许下载",
     "Added by {initiator}" : "由 {initiator} 添加",
     "Via “{folder}”" : "通过 “{folder}”",
     "Internal link" : "内部链接",
+    "Copy internal link to clipboard" : "复制内部链接到剪贴板",
     "Link copied" : "已复制链接",
     "Cannot copy, please copy the link manually" : "无法复制，请手动复制链接",
     "Copy to clipboard" : "复制到剪贴板",
     "Only works for users with access to this folder" : "仅适用于有权限访问此文件夹的用户",
     "Only works for users with access to this file" : "仅适用于有权限访问此文件的用户",
+    "Copy public link to clipboard" : "复制公开链接到剪贴板",
     "Please enter the following required information before creating the share" : "请在创建共享前输入以下必填信息",
     "Password protection (enforced)" : "密码保护（强制）",
     "Password protection" : "密码保护",
@@ -189,6 +197,8 @@ OC.L10N.register(
     "Share label" : "分享标签",
     "Hide download" : "隐藏下载",
     "Password protect" : "密码保护",
+    "Password expires {passwordExpirationTime}" : "密码于 {passwordExpirationTime} 过期",
+    "Password expired" : "密码已过期",
     "Video verification" : "视频验证",
     "Enter a note for the share recipient" : "给共享接收人留备注",
     "Add another link" : "添加其他链接",
@@ -232,6 +242,7 @@ OC.L10N.register(
     "Name" : "名称",
     "Share time" : "共享时间",
     "Expiration date" : "过期日期 ",
+    "Sorry, this link does not seem to work anymore." : "抱歉，此链接已失效。",
     "Reasons might be:" : "可能原因是：",
     "the item was removed" : "此项已移除",
     "the link expired" : "链接过期",
