@@ -1,6 +1,7 @@
 OC.L10N.register(
     "photos",
     {
+    "Public link" : "Публична връзка",
     "Photos" : "Снимки",
     "Your memories under your control" : "Вашите спомени под ваш контрол",
     "All media" : "Всички медии",
@@ -30,7 +31,7 @@ OC.L10N.register(
     "Create album" : "Създаване на албум",
     "Back to the new album form." : "Обратно към формата на новия албум.",
     "Add to Album" : "Добавяне към Албум",
-    "Add selection to album {ablumName}" : "Добавяне на селекция към албум {ablumName}",
+    "Add selection to album {albumName}" : "Добавяне на селекция към албум {ablumName}",
     "Create a new album." : "Създаване на нов албум.",
     "Create new album" : "Създаване на нов албум",
     "New album" : "Нов албум",
@@ -42,10 +43,14 @@ OC.L10N.register(
     "Add {collaboratorLabel} to the collaborators list" : "Добавяне на {collaboratorLabel} към списъка със сътрудници",
     "No collaborators available" : "Няма налични сътрудници",
     "Remove {collaboratorLabel} from the collaborators list" : "Премахване на {collaboratorLabel} от списъка със сътрудници",
+    "Copy the public link" : "Копиране на публичната връзка",
     "Public link copied!" : "Копирана е публична връзка!",
     "Copy public link" : "Копирай публичната връзка",
+    "Delete the public link" : "Изтриване на публичната връзка",
     "Share via public link" : "Споделяне чрез публична връзка",
     "Failed to fetch collaborators list." : "Неуспешно извличане на списък със сътрудници.",
+    "Failed to fetch album." : "Неуспешно извличане на албум.",
+    "Failed to update album." : "Неуспешно обновяване на албум.",
     "This collection does not exist" : "Тази колекция не съществува",
     "An error occurred" : "Възникна грешка",
     "_%n photos_::_%n photos_" : ["%n снимки ","%n снимки"],
@@ -94,6 +99,7 @@ OC.L10N.register(
     "This folder does not exist" : "Тази папка не съществува",
     "Loading folders …" : "Зареждане на папките …",
     "No photos in here" : "Тук няма снимки",
+    "Failed to fetch albums list." : "Неуспешно извличане на списък с албуми.",
     "Shared albums" : "Споделени албуми",
     "Cover photo for shared album {albumName}." : "Снимка на корицата на споделен албум {albumName}",
     "Back to tags overview" : "Обратно към преглед на етикети",
