@@ -61,7 +61,7 @@ OC.L10N.register(
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "Si us plau, proporcioneu una contrasenya d'administrador de recuperació; en cas contrari, es perdran totes les dades.",
     "Wrong admin recovery password. Please check the password and try again." : "La contrasenya d'administrador de recuperació és incorrecta. Si us plau, comproveu-la i torneu-ho a provar.",
     "Backend does not support password change, but the user's encryption key was updated." : "El rerefons no admet el canvi de contrasenya, però s'ha actualitzat la clau de xifratge de l'usuari.",
-    "installing and updating apps via the App Store or Federated Cloud Sharing" : "instal·lació i actualització d'aplicacions a través de la botiga d'aplicacions o el Núvol Federat",
+    "installing and updating apps via the App Store or Federated Cloud Sharing" : "instal·lació i actualització d'aplicacions a través del magatzem d'aplicacions o el Núvol Federat",
     "Federated Cloud Sharing" : "Compartició de Núvols Federats",
     "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL està fent servir una versió %1$s antiquada (%2$s). Si us plau, actualitzeu el vostre sistema operatiu o característiques com %3$s no funcionaran amb fiabilitat.",
     "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the Nextcloud log file for more details." : "No s'ha pogut determinar si la versió TLS de cURL està obsoleta o no perquè s'ha produït un error durant la sol·licitud HTTPS contra https://nextcloud.com. Comproveu el fitxer de registre de Nextcloud per obtenir més detalls.",
@@ -74,7 +74,7 @@ OC.L10N.register(
     "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.memory_consumption</code> to your PHP configuration with a value higher than <code>%s</code>." : "La memòria intermèdia d'OPcache està gairebé plena. Per garantir que tots els scripts es puguin mantenir a la memòria cau, us recomanem que apliqueu <code>opcache.memory.consumption</code> a la configuració de PHP amb un valor superior a <code>%s</code>.",
     "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply <code>opcache.interned_strings_buffer</code> to your PHP configuration with a value higher than <code>%s</code>." : "La memòria cau de cadenes internades OPcache està gairebé plena. Per assegurar-vos que les cadenes que es repeteixen es poden emmagatzemar a la memòria cau de manera efectiva, es recomana aplicar <code>opcache.interned.strings.buffer</code> a la configuració de PHP amb un valor superior a <code>%s</code>.",
     "Invalid SMTP password." : "Contrasenya SMTP no vàlida.",
-    "Email setting test" : "Prova de configuració del correu electrònic",
+    "Email setting test" : "Prova de paràmetres del correu electrònic",
     "Well done, %s!" : "Ben fet, %s!",
     "If you received this email, the email configuration seems to be correct." : "Si heu rebut aquest correu electrònic, sembla que la configuració del correu electrònic és correcta.",
     "Email could not be sent. Check your mail server log" : "No s'ha pogut enviar el correu electrònic. Comproveu el registre del servidor de correu",
@@ -119,7 +119,7 @@ OC.L10N.register(
     "Administration privileges" : "Privilegis d'administració",
     "Groupware" : "Treball en grup",
     "Overview" : "Resum",
-    "Basic settings" : "Configuració bàsica",
+    "Basic settings" : "Paràmetres bàsics",
     "Sharing" : "Compartició",
     "Personal info" : "Informació personal",
     "Mobile & desktop" : "Mòbil i escriptori",
@@ -154,14 +154,14 @@ OC.L10N.register(
     "Enforced groups" : "Grups forçats",
     "Two-factor authentication is not enforced for members of the following groups." : "L'autenticació de doble factor no està obligada per als membres dels següents grups.",
     "Excluded groups" : "Grups exclosos",
-    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Quan es seleccionen/exclouen grups, es fa servir la lògica següent per determinar si un usuari té 2FA (Autenticació de 2 Factors) forçosa: si no hi ha grups seleccionats, 2FA està activada per a tothom, a excepció de membres dels grups exclosos. Si els grups estan seleccionats, 2FA està activada per a tots els membres d'aquests. Si un usuari està tant en un grup seleccionat com exclòs, els seleccionats tenen prioritat i 2FA s'imposa.",
+    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Quan es seleccionen/exclouen grups, es fa servir la lògica següent per determinar si un usuari té 2FA (Autenticació de 2 Factors) forçosa: si no hi ha grups seleccionats, 2FA està habilitat per a tothom, a excepció de membres dels grups exclosos. Si els grups estan seleccionats, 2FA està activada per a tots els membres d'aquests. Si un usuari està tant en un grup seleccionat com exclòs, els seleccionats tenen prioritat i 2FA s'imposa.",
     "Save changes" : "Desa els canvis",
     "All" : "Tots",
     "Limit app usage to groups" : "Limita l’ús de l’aplicació als grups",
     "No results" : "No hi ha resultats",
     "Update to {version}" : "Actualitza a {version}",
     "Remove" : "Suprimeix",
-    "Disable" : "Desactiva",
+    "Disable" : "Inhabilita",
     "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Aquesta aplicació no té cap versió mínima de Nextcloud assignada. Això serà un error en el futur.",
     "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Aquesta aplicació no té cap versió màxima de Nextcloud assignada. Això serà un error en el futur.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Aquesta aplicació no es pot instal·lar perquè les següents dependències no es compleixen:",
@@ -179,8 +179,8 @@ OC.L10N.register(
     "All apps are up-to-date." : "Totes les aplicacions estan actualitzades.",
     "Results from other categories" : "Resultats d'altres categories",
     "No apps found for your version" : "No s'han trobat aplicacions per la vostra versió",
-    "Disable all" : "Desactiva-ho tot",
-    "Enable all" : "Activa-ho tot",
+    "Disable all" : "Inhabilita tot",
+    "Enable all" : "Habilita tot",
     "_%n app has an update available_::_%n apps have an update available_" : ["%n  aplicació té una actualització disponible","%n aplicacions tenen una actualització disponible"],
     "_Update_::_Update all_" : ["Actualitza","Actualitza tot"],
     "Marked for remote wipe" : "Marcat per netejar remotament",
@@ -233,38 +233,38 @@ OC.L10N.register(
     "AJAX" : "AJAX",
     "Execute one task with each page loaded. Use case: Single user instance." : "Executeu una tasca amb cada pàgina carregada. Cas d'ús: instància d'un sol usuari.",
     "Webcron" : "Webcron",
-    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php està registrat en un servei webcron per trucar a cron.php cada 5 minuts per HTTP. Cas d'ús: instància molt petita (1-5 usuaris segons l'ús).",
+    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php està registrat en un servei webcron per cridar a cron.php cada 5 minuts per HTTP. Cas d'ús: instància molt petita (1-5 usuaris segons l'ús).",
     "Cron (Recommended)" : "Cron (recomanat)",
     "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Per executar això es necessita l'extensió POSIX de PHP. Per més detalls, vegeu {linkstart}documentació de PHP{linkend}.",
     "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "Utilitzeu el servei cron del sistema per a cridar el fitxer cron.php cada 5 minuts. Recomanat per a totes les instàncies.",
     "The cron.php needs to be executed by the system user \"{user}\"." : "El cron.php l'ha d'executar l'usuari del sistema \"{user}\".",
     "Unable to update background job mode" : "No s'ha pogut actualitzar el mode de tasca en segon pla",
     "Profile" : "Perfil",
-    "Enable or disable profile by default for new users." : "Habiliteu o deshabiliteu el perfil per defecte per als usuaris nous.",
+    "Enable or disable profile by default for new users." : "Habilitar o deshabilitar el perfil per defecte per als usuaris nous.",
     "Enable" : "Activa",
-    "Unable to update profile default setting" : "No s'ha pogut actualitzar la configuració predeterminada del perfil",
-    "Server-side encryption" : "Encriptació en el servidor",
-    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "L'encriptació en el servidor permet xifrar els fitxers que s'hi carreguen. Això afecta al rendiment, així que activeu-ho només si és necessari.",
-    "Enable server-side encryption" : "Activa l'encriptació en el servidor",
+    "Unable to update profile default setting" : "No s'ha pogut actualitzar els paràmetres predeterminats del perfil",
+    "Server-side encryption" : "Xifratge en el servidor",
+    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "El xifratge en el servidor permet xifrar els fitxers que s'hi carreguen. Això afecta al rendiment, així que activeu-ho només si és necessari.",
+    "Enable server-side encryption" : "Activa el xifratge en el servidor",
     "Please read carefully before activating server-side encryption:" : "Llegiu atentament abans d'activar el xifratge del servidor:",
-    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Un cop s’activi l'encriptació, tots els fitxers carregats al servidor des d'aquest punt cap endavant quedaran encriptats al servidor. Només serà possible desactivar l'encriptació posteriorment si el mòdul criptogràfic actiu té aquesta funció, i es compleixen totes les pre-condicions (p. ex. definir una clau de recuperació).",
-    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "L'encriptació per si mateixa no garanteix la seguretat del sistema. Consulteu la documentació per a més informació sobre com funciona l'aplicació d'encriptació i els casos d'ús suportats.",
-    "Be aware that encryption always increases the file size." : "Tingueu en compte que l'encriptació sempre augmenta la mida del fitxer.",
-    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Sempre és bó crear còpies de seguretat de les vostres dades amb regularitat, en el cas de encriptació assegureu-vos de desar les claus d'encriptació juntament amb les vostres dades a la còpia de seguretat.",
-    "This is the final warning: Do you really want to enable encryption?" : "Avís final: Realment voleu activar l'encriptació?",
-    "No encryption module loaded, please enable an encryption module in the app menu." : "No s'ha carregat cap mòdul d'encriptació, si us plau activeu un mòdul d'encriptació al menú d'aplicacions.",
+    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Un cop s’activi el xifratge, tots els fitxers carregats al servidor des d'aquest punt cap endavant quedaran xifrats al servidor. Només serà possible desactivar el xifratge posteriorment si el mòdul criptogràfic actiu té aquesta funció, i es compleixen totes les pre-condicions (p. ex. definir una clau de recuperació).",
+    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "El xifratge per si mateix no garanteix la seguretat del sistema. Consulteu la documentació per a més informació sobre com funciona l'aplicació de xifratge i els casos d'ús suportats.",
+    "Be aware that encryption always increases the file size." : "Tingueu en compte que el xifratge sempre augmenta la mida del fitxer.",
+    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Sempre és bó crear còpies de seguretat de les vostres dades amb regularitat, en el cas de xifratge assegureu-vos de desar les claus de xifratge juntament amb les vostres dades a la còpia de seguretat.",
+    "This is the final warning: Do you really want to enable encryption?" : "Avís final: Realment voleu activar xifratge?",
+    "No encryption module loaded, please enable an encryption module in the app menu." : "No s'ha carregat cap mòdul de xifratge, si us plau activeu un mòdul de xifratge al menú d'aplicacions.",
     "Select default encryption module:" : "Seleccioneu el mòdul criptogràfic per defecte:",
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Heu de migrar les claus de xifratge del xifratge anterior (ownCloud .= 8.0) al nou. Habiliteu el \"Mòdul de xifratge peredeterminat\" i executeu {command}",
     "Unable to update server side encryption config" : "No es pot actualitzar la configuració del xifratge de la banda del servidor",
     "Rename group" : "Canvia el nom del grup",
-    "Remove group" : "Suprimeix el grup",
+    "Remove group" : "Suprimir el grup",
     "You are about to remove the group {group}. The users will NOT be deleted." : "Esteu a punt de suprimir el grup {group}. Els usuaris NO seran suprimits.",
     "Please confirm the group removal " : "Confirmeu la supressió del grup ",
     "Current password" : "Contrasenya actual",
     "New password" : "Contrasenya nova",
     "Change password" : "Canvia la contrasenya",
     "Your profile picture" : "La vostra imatge de perfil",
-    "Upload profile picture" : "Puja la imatge de perfil",
+    "Upload profile picture" : "Pujar la imatge de perfil",
     "Choose profile picture from files" : "Trieu una imatge de perfil als fitxers",
     "Remove profile picture" : "Treu la imatge de perfil",
     "png or jpg, max. 20 MB" : "png o jpg, màx. 20 MB",
@@ -285,25 +285,25 @@ OC.L10N.register(
     "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Esteu utilitzant <strong>{usage}</strong> de <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
     "Your full name" : "El vostre nom complet",
     "Email options" : "Opcions de correu electrònic",
-    "Primary email for password reset and notifications" : "Adreça electrònica principal per a restablir la contrasenya i per a les notificacions",
-    "Remove primary email" : "Treu l'adreça electrònica principal",
-    "Delete email" : "Treu l'adreça electrònica",
+    "Primary email for password reset and notifications" : "Adreça de correu electrònic principal per a restablir la contrasenya i per a les notificacions",
+    "Remove primary email" : "Treu l'adreça de correu electrònic principal",
+    "Delete email" : "Treu l'adreça de correu electrònic",
     "Unset as primary email" : "Desactivat com a correu electrònic principal",
     "This address is not confirmed" : "Aquesta adreça no està confirmada",
     "Set as primary email" : "Estableix com a correu electrònic principal",
     "Your email address" : "El vostre correu electrònic",
-    "Additional email address {index}" : "Adreça electrònica addicional {index}",
-    "Unable to delete primary email address" : "No es pot suprimir l'adreça electrònica principal",
-    "Unable to update primary email address" : "No es pot actualitzar l'adreça electrònica principal",
-    "Unable to add additional email address" : "No es pot afegir una adreça electrònica addicional",
-    "Unable to update additional email address" : "No es pot actualitzar l'adreça electrònica addicional",
-    "Unable to delete additional email address" : "No es pot suprimir l'adreça electrònica addicional",
+    "Additional email address {index}" : "Adreça de correu electrònic addicional {index}",
+    "Unable to delete primary email address" : "No es pot suprimir l'adreça de correu electrònic principal",
+    "Unable to update primary email address" : "No es pot actualitzar l'adreça de correu electrònic principal",
+    "Unable to add additional email address" : "No es pot afegir una adreça de correu electrònic addicional",
+    "Unable to update additional email address" : "No es pot actualitzar l'adreça de correu electrònic addicional",
+    "Unable to delete additional email address" : "No es pot suprimir l'adreça de correu electrònic addicional",
     "No email address set" : "No s'ha establert cap adreça de correu electrònic",
-    "Additional emails" : "Correus electrònics addicionals",
+    "Additional emails" : "Adreces de correu electrònic addicionals",
     "Your headline" : "El teu titular",
     "Language" : "Llengua",
     "Help translate" : "Ajudeu-nos amb la traducció",
-    "Unable to update language" : "No es pot actualitzar l'idioma",
+    "Unable to update language" : "No es pot actualitzar la llengua",
     "No language set" : "No s'ha establert cap idioma",
     "Locale" : "Configuració local",
     "Week starts on {firstDayOfWeek}" : "La setmana comença el {firstDayOfWeek}",
@@ -312,9 +312,9 @@ OC.L10N.register(
     "Your location" : "La vostra localització",
     "Your organisation" : "La vostra organització",
     "Your phone number" : "El vostre número de telèfon",
-    "Edit your Profile visibility" : "Editeu la visibilitat del vostre perfil",
-    "Enable Profile" : "Activa el perfil",
-    "Unable to update profile enabled state" : "No es pot actualitzar l'estat d'activació del perfil",
+    "Edit your Profile visibility" : "Edició de la visibilitat del vostre perfil",
+    "Enable Profile" : "Habilira el perfil",
+    "Unable to update profile enabled state" : "No es pot actualitzar l'estat d'habilitació del perfil",
     "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "La configuració més restrictiva de visibilitat o abast es respecta al vostre perfil. Per exemple, si la visibilitat s'estableix a \"Mostra a tothom\" i l'abast s'estableix a \"Privat\", es respectarà \"Privat\".",
     "{displayId}" : "{displayId}",
     "Unable to update visibility of {displayId}" : "No es pot actualitzar la visibilitat de {displayId}",
@@ -336,15 +336,15 @@ OC.L10N.register(
     "Select user quota" : "Selecciona la quota d'usuari",
     "Delete user" : "Suprimeix l'usuari",
     "Wipe all devices" : "Esborra tots els dispositius",
-    "Disable user" : "Desactiva l'usuari",
-    "Enable user" : "Activa l'usuari",
+    "Disable user" : "Inhabilita l'usuari",
+    "Enable user" : "Habilita l'usuari",
     "Resend welcome email" : "Torna a enviar el correu electrònic de benvinguda",
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "En cas de perdre un dispositiu o sortir de l’organització, es pot esborrar de forma remota les dades del Nextcloud de tots els dispositius associats a {userid}. Només funciona si els dispositius estan connectats a Internet.",
     "Remote wipe of devices" : "Neteja remota de dispositius",
     "Wipe {userid}'s devices" : "Neteja els dispositius de {userid}",
-    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Suprimeix completament el compte de {userid} inclosos tots els seus fitxers personals, dades d'aplicacions, etc.",
+    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Suprimir completament el compte de {userid} inclosos tots els seus fitxers personals, dades d'aplicacions, etc.",
     "Account deletion" : "Supressió del compte",
-    "Delete {userid}'s account" : "Suprimeix el compte de {userid}",
+    "Delete {userid}'s account" : "Suprimir el compte de {userid}",
     "Welcome mail sent!" : "S'ha enviat el correu electrònic de benvinguda!",
     "Edit User" : "Edita Usuari",
     "Toggle user actions menu" : "Commuta el menú d'accions d'usuari",
@@ -359,12 +359,12 @@ OC.L10N.register(
     "Quota" : "Quota",
     "User backend" : "Rerefons d'usuari",
     "Storage location" : "Ubicació de l'emmagatzematge",
-    "Last login" : "Darrer accés",
+    "Last login" : "Darrer inici de sessió",
     "No users in here" : "No hi ha usuaris aquí dins",
     "Default quota" : "Quota per defecte",
     "Common languages" : "Llengües freqüents",
     "Other languages" : "Altres llengües",
-    "Password change is disabled because the master key is disabled" : "El canvi de contrasenya està desactivat perquè la clau mestra està desactivada",
+    "Password change is disabled because the master key is disabled" : "El canvi de contrasenya està inhabilitat perquè la clau mestra està desactivada",
     "Passwordless authentication requires a secure connection." : "L'autenticació sense contrasenya necessita una connexió segura.",
     "Add WebAuthn device" : "Afegeix un dispositiu WebAuthn",
     "Please authorize your WebAuthn device." : "Si us plau, autoritzeu el vostre dispositiu WebAuthn.",
@@ -380,7 +380,7 @@ OC.L10N.register(
     "Your browser does not support WebAuthn." : "El vostre navegador no suporta WebAuthn.",
     "Your apps" : "Les vostres aplicacions",
     "Active apps" : "Aplicacions actives",
-    "Disabled apps" : "Aplicacions desactivades",
+    "Disabled apps" : "Aplicacions inhabilitades",
     "Updates" : "Actualitzacions",
     "App bundles" : "Paquets d'aplicacions",
     "Featured apps" : "Aplicacions destacades",
@@ -391,13 +391,13 @@ OC.L10N.register(
     "Add group" : "Afegeix un grup",
     "Active users" : "Usuaris actius",
     "Admins" : "Administradors",
-    "Disabled users" : "Usuaris desactivats",
+    "Disabled users" : "Usuaris inhabilitats",
     "Default quota:" : "Quota per defecte:",
     "Select default quota" : "Seleccioneu la quota per defecte",
     "Show Languages" : "Mostra els idiomes",
     "Show last login" : "Mostra el darrer inici de sessió",
     "Show user backend" : "Mostra el rerefons d'usuari",
-    "Show storage path" : "Mostra la ubicació del magatzem",
+    "Show storage path" : "Mostra el camí del magatzem",
     "Send email to new user" : "Enviar correu electrònic al nou usuari",
     "Not saved" : "No s'ha desat",
     "Sending…" : "S'està enviant…",
@@ -406,7 +406,7 @@ OC.L10N.register(
     "Profile picture" : "Foto de perfil",
     "About" : "Quant a",
     "Full name" : "Nom complet",
-    "Additional email" : "Adreça electrònica addicional",
+    "Additional email" : "Adreça de correu electrònic addicional",
     "Headline" : "Titular",
     "Organisation" : "Organització",
     "Phone number" : "Número de telèfon",
@@ -419,14 +419,14 @@ OC.L10N.register(
     "Show to everyone" : "Mostra a tothom",
     "Show to logged in users only" : "Mostra només als usuaris connectats",
     "Hide" : "Amaga",
-    "Download and enable" : "Descarrega i activa",
-    "Enable untested app" : "Activa aplicacions no provades",
+    "Download and enable" : "Baixa i activa",
+    "Enable untested app" : "Habilita aplicacions no provades",
     "The app will be downloaded from the App Store" : "L'aplicació es baixarà des del Magatzem d'aplicacions",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Aquesta aplicació no està marcada com a compatible amb la vostra versió de Nextcloud. Si continueu, encara podreu instal·lar l’aplicació. Tingueu en compte que pot ser que l’aplicació no funcioni correctament.",
     "Never" : "Mai",
     "An error occurred during the request. Unable to proceed." : "S'ha produït un error durant la sol·licitud. No es pot continuar.",
-    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "L'aplicació s'ha activat però ha de ser actualitzada. Sereu redirigits a la pàgina d’actualització d'aquí 5 segons.",
-    "Error: This app cannot be enabled because it makes the server unstable" : "Error: aquesta aplicació no es pot activar perquè fa que el servidor sigui inestable",
+    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "L'aplicació s'ha habilitat però ha de ser actualitzada. Sereu redirigits a la pàgina d’actualització d'aquí 5 segons.",
+    "Error: This app cannot be enabled because it makes the server unstable" : "Error: aquesta aplicació no es pot habilitar perquè fa que el servidor sigui inestable",
     "Administrator documentation" : "Documentació d'administrador",
     "Documentation" : "Documentació",
     "Forum" : "Fòrum",
@@ -449,7 +449,7 @@ OC.L10N.register(
     "SMTP Username" : "Nom d'usuari SMTP",
     "SMTP Password" : "Contrasenya SMTP",
     "Save" : "Desa",
-    "Test and verify email settings" : "Prova i verifica la configuració del correu electrònic",
+    "Test and verify email settings" : "Prova i verifica els paràmetres del correu electrònic",
     "Send email" : "Envia el correu electrònic",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "És important per a la seguretat i el rendiment de la vostra instància que tot estigui configurat correctament. Per ajudar-vos, fem algunes comprovacions automàtiques. Si us plau, consulteu la documentació enllaçada per obtenir més informació.",
     "All checks passed." : "Totes les comprovacions correctes.",
@@ -459,33 +459,33 @@ OC.L10N.register(
     "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Si us plau reviseu les <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">guies d’instal·lació ↗</a>, i comproveu si hi ha errors o advertències en el <a href=\"%2$s\">registre</a>.",
     "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Reviseu la seguretat del vostre Nextcloud mitjançant el <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">nostre escaneig de seguretat ↗</a>.",
     "Version" : "Versió",
-    "You need to enable the File sharing App." : "Heu d'activar l'aplicació per compartir Fitxers.",
+    "You need to enable the File sharing App." : "Heu d'habilitar l'aplicació per compartir Fitxers.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Com a administrador, podeu afinar els ajustaments per compartir fitxers. Si us plau, per més informació llegiu la documentació.",
     "Allow apps to use the Share API" : "Permet que les aplicacions utilitzin l'API de compartir",
     "Set default expiration date for shares" : "Estableix la data de caducitat per defecte per comparticions",
-    "Expire after" : "Expira després",
+    "Expire after" : "Caduca després",
     "day(s)" : "dies",
     "Enforce expiration date" : "Força la data de caducitat",
-    "Set default expiration date for shares to other servers" : "Estableix la data de caducitat predeterminada per a les accions a altres servidors",
+    "Set default expiration date for shares to other servers" : "Estableix la data de caducitat per defecte per a les accions a altres servidors",
     "Allow users to share via link and emails" : "Permet als usuaris compartir mitjançant enllaços i correus electrònics",
     "Allow public uploads" : "Permet càrregues públiques",
     "Always ask for a password" : "Demana sempre una contrasenya",
     "Enforce password protection" : "Força la protecció amb contrasenya",
-    "Exclude groups from password requirements:" : "Exclou grups dels requisits de contrasenya:",
+    "Exclude groups from password requirements:" : "Excloure grups dels requisits de contrasenya:",
     "Set default expiration date" : "Estableix la data de caducitat per defecte",
-    "Exclude groups from creating link shares:" : "Exclou grups de la creació d'enllaços compartits:",
+    "Exclude groups from creating link shares:" : "Excloure grups de la creació d'enllaços compartits:",
     "Allow resharing" : "Permet compartir de nou",
     "Allow sharing with groups" : "Permetre compartir amb grups",
     "Restrict users to only share with users in their groups" : "Restringeix als usuaris a compartir només amb usuaris del seu grup",
-    "Exclude groups from sharing" : "Exclou grups de compartició",
+    "Exclude groups from sharing" : "Excloure grups de compartició",
     "These groups will still be able to receive shares, but not to initiate them." : "Aquests grups encara podran rebre comparticions, però no en podran iniciar.",
     "Allow username autocompletion in share dialog" : "Permet l'emplenament automàtic del nom d'usuari al diàleg de compartir",
     "Allow username autocompletion to users within the same groups" : "Permet l'emplenament automàtic del nom d'usuari als usuaris dels mateixos grups",
     "Allow username autocompletion to users based on phone number integration" : "Permet la compleció automàtica del nom d'usuari als usuaris en funció de la integració del número de telèfon",
     "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Si la compleció automàtica \"mateix grup\" i \"integració de números de telèfon\" estan habilitats, n'hi ha prou amb una coincidència per mostrar a l'usuari.",
     "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Permet l'emplenament automàtic en introduir el nom complet o l'adreça de correu electrònic (ignorant la coincidència de l'agenda i estar al mateix grup)",
-    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Mostra el text de descàrrega de responsabilitat a la pàgina de l'enllaç públic de càrrega (només es mostra quan la llista de fitxers està oculta).",
-    "This text will be shown on the public link upload page when the file list is hidden." : "Aquest text es mostrarà a la pàgina de càrrega d’enllaç públic quan la llista de fitxers estigui amagada.",
+    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Mostra el text de descàrrega de responsabilitat a la pàgina de l'enllaç públic de pujada (només es mostra quan la llista de fitxers està oculta).",
+    "This text will be shown on the public link upload page when the file list is hidden." : "Aquest text es mostrarà a la pàgina de pujada d’enllaç públic quan la llista de fitxers estigui amagada.",
     "Default share permissions" : "Permisos de compatició per defecte",
     "Reasons to use Nextcloud in your organization" : "Motius per a utilitzar Nextcloud en la vostra organització",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Desenvolupat per la {communityopen}comunitat Nextcloud{linkclose}, el {githubopen}codi font{linkclose} es troba sota la llicència {licenseopen}AGPL{linkclose}.",
@@ -503,9 +503,9 @@ OC.L10N.register(
     "An error occurred while changing your locale. Please reload the page and try again." : "S'ha produït un error mentre es canviava la vostra configuració local. Si us plau, recarregueu la pàgina i torneu-ho a provar.",
     "Select a profile picture" : "Seleccioneu una imatge de perfil",
     "Week starts on {fdow}" : "La setmana comença en {fdow}",
-    "Couldn't remove app." : "No s'ha pogut suprimit l'aplicació.",
+    "Couldn't remove app." : "No s'ha pogut suprimir l'aplicació.",
     "Couldn't update app." : "No s'ha pogut actualitzar l'aplicació.",
-    "Backend doesn't support password change, but the user's encryption key was updated." : "El mòdul de suport no admet canvis de contrasenya, però la clau de xifrat de l'usuari ha estat actualitzada satisfactòriament.",
+    "Backend doesn't support password change, but the user's encryption key was updated." : "El mòdul de suport no admet canvis de contrasenya, però la clau de xifratge de l'usuari ha estat actualitzada satisfactòriament.",
     "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "No s'ha pogut determinar si la versió TLS de cURL està obsoleta o no perquè s'ha produït un error durant la sol·licitud HTTPS a https://nextcloud.com. Si us plau, comproveu el fitxer de registre nextcloud per obtenir més detalls.",
     "You need to set your user email before being able to send test emails." : "Heu d'establir un nom d'usuari abans de poder enviar correus de prova.",
     "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "Revocant aquest token impedirà la neteja del vostre dispositiu si encara no ha començat.",
@@ -516,9 +516,9 @@ OC.L10N.register(
     "An error occured during the request. Unable to proceed." : "S'ha produït un error durant la sol·licitud. No es pot continuar.",
     "Test email settings" : "Prova els paràmetres de correu electrònic",
     "Please read carefully before activating server-side encryption: " : "Si us plau, llegiu atentament abans d'activar l'encriptació en el servidor: ",
-    "Enable encryption" : "Activa l'encriptació",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Heu de migrar les claus d'encriptació de l'encriptació antiga (ownCloud <= 8.0) a la nova. Si us plau activeu el “Mòdul criptogràfic per defecte\" i executeu ‘occ encryption:migrate’",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Heu de migrar les claus d'encriptació de l'encriptació antiga (ownCloud <= 8.0) a la nova.",
+    "Enable encryption" : "Activa el xifratge",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Heu de migrar les claus de xifratge del xifratge antic (ownCloud <= 8.0) al nou. Si us plau activeu el “Mòdul criptogràfic per defecte\" i executeu ‘occ encryption:migrate’",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Heu de migrar les claus de xifratge del xifratge antic (ownCloud <= 8.0) al nou.",
     "Start migration" : "Inicia la migració",
     "Last job execution ran %s. Something seems wrong." : "La darrera tasca es va executar %s. Alguna cosa sembla malament.",
     "Some jobs haven’t been executed since %s. Please consider increasing the execution frequency." : "Algunes feines no s’han executat des de %s. Considereu augmentar la freqüència d’execució.",
@@ -526,15 +526,15 @@ OC.L10N.register(
     "Last job ran %s." : "La darrera tasca es va executar %s.",
     "Background job didn’t run yet!" : "La tasca de fons encara no s'ha executat!",
     "For the server to work properly, it's important to configure background jobs correctly. \"Cron\" is the recommended setting. Please see the documentation for more information." : "Perquè el servidor funcioni correctament, és important configurar correctament els treballs en segon pla. \"Cron\" és la configuració recomanada. Consulteu la documentació per a més informació.",
-    "Pick background job setting" : "Trieu la configuració de la tasca en segon pla",
+    "Pick background job setting" : "Trieu el paràmetre de la tasca en segon pla",
     "Recommended" : "Recomanat",
     "The cron.php needs to be executed by the system user \"%s\"." : "El cron.php ha de ser executat per l'usuari del sistema \"%s\".",
     "days" : "dies",
     "Allow username autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Permet l'emplenament automàtic del nom d'usuari en introduir el nom complet o l'adreça de correu electrònic (ignorant la coincidència de l'agenda telefònica que falta i estar al mateix grup)",
     "Change privacy level of profile picture" : "Canvia el nivell de privadesa de la foto de perfil",
-    "Upload new" : "Carrega'n una de nova",
+    "Upload new" : "Puja'n una de nova",
     "Select from Files" : "Selecciona dels Fitxers",
-    "Remove image" : "Suprimeix imatge",
+    "Remove image" : "Suprimir imatge",
     "Please note that it can take up to 24 hours for the avatar to get updated everywhere." : "Tingueu en compte que l'avatar pot trigar fins a 24 hores a actualitzar-se a tot arreu.",
     "Choose as profile picture" : "Tria una imatge de perfil",
     "You are using <strong>%s</strong>" : "Esteu utilitzant <strong>%s</strong>",
