@@ -121,6 +121,7 @@ OC.L10N.register(
     "Overview" : "Přehled",
     "Basic settings" : "Základní nastavení",
     "Sharing" : "Sdílení",
+    "Availability" : "Dostupnost",
     "Personal info" : "Osobní údaje",
     "Mobile & desktop" : "Mobilní a desktop",
     "Email server" : "E-mailový server",
@@ -415,6 +416,7 @@ OC.L10N.register(
     "Website" : "Webová stránka",
     "Profile visibility" : "Viditelnost profilu",
     "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Není k dispozici, protože tato vlastnost je vyžadována pro  hlavní funkce, včetně sdílení souborů a pozvánek v kalendáři",
+    "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "Není k dispozici protože pro váš účet bylo federování vypnuto. V případě dotazů se obraťte na svého správce",
     "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Není k dispozici protože zveřejňování údajů o konkrétních uživatelích není vyhledávacímu serveru povoleno. Pokud máte jakékoli dotazy, obraťte se na správce systémů",
     "Show to everyone" : "Ukázat všem",
     "Show to logged in users only" : "Ukázat pouze přihlášeným uživatelům",
