@@ -120,6 +120,7 @@ OC.L10N.register(
     "Overview" : "Übersicht",
     "Basic settings" : "Grundeinstellungen",
     "Sharing" : "Teilen",
+    "Availability" : "Verfügbarkeit",
     "Personal info" : "Persönliche Informationen",
     "Mobile & desktop" : "Mobil & Desktop",
     "Email server" : "E-Mail-Server",
@@ -348,7 +349,7 @@ OC.L10N.register(
     "New user" : "Neuer Benutzer",
     "Will be autogenerated" : "Wird automatisch erzeugt",
     "Display name" : "Anzeigename",
-    "Email" : "E-Mail",
+    "Email" : "E-Mail-Adresse",
     "Default language" : "Standard-Sprache",
     "Add a new user" : "Neuen Benutzer hinzufügen",
     "Group admin for" : "Gruppenadministrator für",
