@@ -121,6 +121,7 @@ OC.L10N.register(
     "Overview" : "Vista general",
     "Basic settings" : "Ajustes básicos",
     "Sharing" : "Compartir",
+    "Availability" : "Disponibilidad",
     "Personal info" : "Información personal",
     "Mobile & desktop" : "Móvil y escritorio",
     "Email server" : "Servidor de correo electrónico",
@@ -263,12 +264,26 @@ OC.L10N.register(
     "Current password" : "Contraseña actual",
     "New password" : "Nueva contraseña",
     "Change password" : "Cambiar contraseña",
+    "Your profile picture" : "Su imagen de perfil",
+    "Upload profile picture" : "Subir imagen del perfil",
+    "Choose profile picture from files" : "Seleccionar imagen del perfil desde los archivos",
+    "Remove profile picture" : "Eliminar imagen del perfil",
     "png or jpg, max. 20 MB" : "png o jpg, max. 20 MB",
     "Picture provided by original account" : "Imagen provista por la cuenta original",
     "Cancel" : "Cancelar",
+    "Set as profile picture" : "Establecer como imagen del perfil",
+    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Tenga en cuenta que puede tomar hasta 24 horas para que su imagen del perfil sea actualizada en todas partes",
+    "Choose your profile picture" : "Seleccione su imagen de perfil",
+    "Please select a valid png or jpg file" : "Por favor, seleccione un archivo png o jpg válido",
+    "Error setting profile picture" : "Error configurando imagen del perfil",
+    "Error cropping profile picture" : "Error recortando imagen del perfil",
+    "Error saving profile picture" : "Error guardando imagen del perfil",
+    "Error removing profile picture" : "Error eliminando imagen del perfil",
     "Your biography" : "Tu biografía",
     "Details" : "Detalles",
     "You are a member of the following groups:" : "Eres miembro de los siguientes grupos:",
+    "You are using <strong>{usage}</strong>" : "Estás usando <strong>{usage}</strong>",
+    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Estás usando <strong>{usage}</strong> de <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
     "Your full name" : "Tu nombre completo",
     "Email options" : "Opciones de email",
     "Primary email for password reset and notifications" : "Dirección email principal para restablecer contraseña y notificaciones",
@@ -292,6 +307,10 @@ OC.L10N.register(
     "Unable to update language" : "No se pudo actualizar tu idioma",
     "No language set" : "No se ha marcado idioma",
     "Locale" : "Región",
+    "Week starts on {firstDayOfWeek}" : "La semana comienza en {firstDayOfWeek}",
+    "Unable to update locale" : "Imposible actualizar el idioma",
+    "No locale set" : "No se ha establecido el idioma",
+    "Your location" : "Su ubicación",
     "Your organisation" : "Tu organización",
     "Your phone number" : "Su número de teléfono",
     "Edit your Profile visibility" : "Editar la visibilidad de tu perfil",
@@ -303,6 +322,11 @@ OC.L10N.register(
     "Your role" : "Tu rol",
     "Your Twitter handle" : "Su usuario de Twitter",
     "Your website" : "La dirección de su sitio web",
+    "No {property} set" : "No se ha establecido {property}",
+    "Unable to update {property}" : "Imposible actualizar {property}",
+    "Change scope level of {property}, current scope is {scope}" : "Cambiar el nivel de privacidad de {property}, el valor actual es {scope}",
+    "Unable to update federation scope of the primary {property}" : "No se puede actualizar el alcance de federación del principal {property}",
+    "Unable to update federation scope of additional {property}" : "No se puede actualizar el alcance de federación adicional de {property}",
     "Add additional email" : "Añadir un email adicional",
     "Add" : "Añadir",
     "You do not have permissions to see the details of this user" : "No tienes permisos para ver los detalles de este usuario",
@@ -392,6 +416,7 @@ OC.L10N.register(
     "Website" : "Sitio web",
     "Profile visibility" : "Visibilidad del perfil",
     "Not available as this property is required for core functionality including file sharing and calendar invitations" : "No está disponible, ya que esta característica es necesaria para la funcionalidad principal, incluyendo el intercambio de archivos y las invitaciones de calendario",
+    "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "No está disponible ya que la federación ha sido deshabilitada para su cuenta, contacte a su administrador del sistema si tiene cualquier pregunta",
     "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "No está disponible ya que la publicación de datos específicos del usuario en el servidor de búsqueda no está permitida, póngase en contacto con el administrador del sistema si tiene alguna duda",
     "Show to everyone" : "Mostrar a todos",
     "Show to logged in users only" : "Mostrar solo a usuarios con inicio de sesión",
