@@ -121,6 +121,7 @@ OC.L10N.register(
     "Overview" : "Ikuspegi orokorra",
     "Basic settings" : "Oinarrizko ezarpenak",
     "Sharing" : "Partekatzea",
+    "Availability" : "Eskuragarritasuna",
     "Personal info" : "Informazio pertsonala",
     "Mobile & desktop" : "Mugikorra eta mahaigaina",
     "Email server" : "E-posta zerbitzaria",
@@ -342,7 +343,7 @@ OC.L10N.register(
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Gailua galtzen baduzu edo erakundetik irteten bazara, honek {userid} erabiltzaileari lotutako gailu guztietako Nextcloudeko datuak garbitu ditzake. Gailuak internetera konektatuta badaude bakarrik funtzionatzen du.",
     "Remote wipe of devices" : "Gailuen urruneko garbiketa",
     "Wipe {userid}'s devices" : "Garbitu {userid}-ren gailuak",
-    "Fully delete {userid}'s account including all their personal files, app data, etc." : "{userid} erabiltzaileran kontua bere fitxategi eta aplikazioen datuak barne guztiz ezabatu.",
+    "Fully delete {userid}'s account including all their personal files, app data, etc." : "{userid} erabiltzailearen kontua, bere fitxategi eta aplikazioen datuak barne, guztiz ezabatu.",
     "Account deletion" : "Kontu ezabaketa",
     "Delete {userid}'s account" : "Ezabatu {userid} erabiltzailearen kontua",
     "Welcome mail sent!" : "Ongi etorri mezua bidalita!",
