@@ -105,6 +105,7 @@ OC.L10N.register(
     "Overview" : "Yleiskuvaus",
     "Basic settings" : "Perusasetukset",
     "Sharing" : "Jakaminen",
+    "Availability" : "Saatavuus",
     "Personal info" : "Henkilökohtaiset tiedot",
     "Mobile & desktop" : "Mobiili ja työpöytä",
     "Email server" : "Sähköpostipalvelin",
@@ -414,6 +415,7 @@ OC.L10N.register(
     "Allow public uploads" : "Salli julkiset lähetykset",
     "Always ask for a password" : "Kysy aina salasanaa",
     "Enforce password protection" : "Pakota salasanasuojaus",
+    "Exclude groups from password requirements:" : "Sulje ryhmiä salasanavaatimusten ulkopuolelle:",
     "Set default expiration date" : "Aseta lopettamispäivän oletus",
     "Allow resharing" : "Salli uudelleenjakaminen",
     "Allow sharing with groups" : "Salli jakaminen ryhmien kanssa",
