@@ -1,7 +1,7 @@
 OC.L10N.register(
     "settings",
     {
-    "Private" : "Privée",
+    "Private" : "Privé",
     "Only visible to people matched via phone number integration through Talk on mobile" : "Visible uniquement pour les utilisateurs correspondants via l'intégration du numéro de téléphone dans Talk pour mobile",
     "Local" : "Local",
     "Only visible to people on this instance and guests" : "Visible uniquement aux personnes dans l'instance et aux invités",
@@ -49,7 +49,7 @@ OC.L10N.register(
     "A login attempt using two-factor authentication failed (%1$s)" : "Une tentative de connexion utilisant l'authentification à deux facteurs a échoué (%1$s)",
     "Remote wipe was started on %1$s" : "Effaçage distant démarré pour%1$s",
     "Remote wipe has finished on %1$s" : "Effaçage distant terminé pour %1$s",
-    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Votre <strong>mot de passe</strong> ou <strong>adresse e-mail</strong> a été modifié",
+    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Votre <strong>mot de passe</strong> ou <strong>adresse e-mail</strong> a été modifié⋅e",
     "Could not remove app." : "Impossible de supprimer l'app.",
     "Could not update app." : "Impossible de mettre à jour l'app.",
     "Wrong password" : "Mot de passe incorrect",
@@ -77,7 +77,7 @@ OC.L10N.register(
     "Email setting test" : "Test des paramètres e-mail",
     "Well done, %s!" : "Bien joué, %s !",
     "If you received this email, the email configuration seems to be correct." : "Si vous avez reçu cet e-mail, la configuration de l'adresse e-mail semble être correcte.",
-    "Email could not be sent. Check your mail server log" : "L'email n'a pu être envoyé. Vérifiez le journal du serveur de messagerie",
+    "Email could not be sent. Check your mail server log" : "L'e-mail n'a pu être envoyé. Vérifiez le journal du serveur de messagerie",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Une erreur est survenue lors de l'envoi de l'e-mail. Veuillez vérifier vos paramètres. (Erreur: %s)",
     "You need to set your user email before being able to send test emails. Go to %s for that." : "Vous devez définir votre e-mail utilisateur avant de tester l'envoi d'e-mail. Aller à %s pour cela.",
     "Invalid user" : "Utilisateur non valide",
@@ -121,6 +121,7 @@ OC.L10N.register(
     "Overview" : "Vue d'ensemble",
     "Basic settings" : "Paramètres de base",
     "Sharing" : "Partage",
+    "Availability" : "Disponibilité",
     "Personal info" : "Informations personnelles",
     "Mobile & desktop" : "Mobile & bureau",
     "Email server" : "Serveur e-mail",
@@ -159,7 +160,7 @@ OC.L10N.register(
     "All" : "Tous",
     "Limit app usage to groups" : "Limiter l'utilisation de l'application aux groupes",
     "No results" : "Aucun résultat",
-    "Update to {version}" : "Mise à jour vers {version}",
+    "Update to {version}" : "Mettre à jour vers {version}",
     "Remove" : "Supprimer",
     "Disable" : "Désactiver",
     "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Cette application n'a pas de version minimum Nextcloud exigée. Ce sera considéré comme une erreur à l'avenir.",
@@ -175,13 +176,13 @@ OC.L10N.register(
     "Supported" : "Pris en charge",
     "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Les applications mises en avant sont développées par la communauté. Elles proposent des fonctionnalités centrales et sont prêtes pour la production.",
     "Featured" : "Mise en avant",
-    "Update to {update}" : "Mise à jour vers {update}",
+    "Update to {update}" : "Mettre à jour vers {update}",
     "All apps are up-to-date." : "Toutes les applications sont à jour.",
     "Results from other categories" : "Résultats d'autres catégories",
     "No apps found for your version" : "Pas d'application trouvée pour votre version",
     "Disable all" : "Tout désactiver",
     "Enable all" : "Tout activer",
-    "_%n app has an update available_::_%n apps have an update available_" : ["%n application ayant une mise à jour disponible","%n applications ayant une mise à jour disponible","%n applications ayant une mise à jour disponible"],
+    "_%n app has an update available_::_%n apps have an update available_" : ["%n application a une mise à jour disponible","%n applications ont une mise à jour disponible","%n applications ont une mise à jour disponible"],
     "_Update_::_Update all_" : ["Mettre à jour","Tout mettre à jour","Tout mettre à jour"],
     "Marked for remote wipe" : "Marqué pour l'effaçage distant",
     "Device settings" : "Paramètres de l'appareil",
@@ -281,8 +282,8 @@ OC.L10N.register(
     "Your biography" : "Votre biographie",
     "Details" : "Détails",
     "You are a member of the following groups:" : "Vous êtes membre des groupes suivants :",
-    "You are using <strong>{usage}</strong>" : "Vous utilisez actuellement <strong>{usage}</strong>",
-    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Vous utilisez actuellement <strong>{usage}</strong> sur <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
+    "You are using <strong>{usage}</strong>" : "Vous utilisez <strong>{usage}</strong>",
+    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Vous utilisez <strong>{usage}</strong> sur <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
     "Your full name" : "Votre nom complet",
     "Email options" : "Options de mail",
     "Primary email for password reset and notifications" : "Adresse e-mail principale pour la réinitialisation du mot de passe et les notifications",
@@ -351,7 +352,7 @@ OC.L10N.register(
     "{size} used" : "{size} utilisés",
     "New user" : "Nouvel utilisateur",
     "Will be autogenerated" : "Sera généré automatiquement",
-    "Display name" : "Nom affiché",
+    "Display name" : "Nom d'affichage",
     "Email" : "E-mail",
     "Default language" : "Langue par défaut",
     "Add a new user" : "Ajouter un nouvel utilisateur",
@@ -494,8 +495,8 @@ OC.L10N.register(
     "Follow us on Mastodon" : "Suivez-nous sur Mastodon",
     "Check out our blog" : "Découvrez notre blog",
     "Subscribe to our newsletter" : "Abonnez-vous à notre lettre d'information",
-    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Cette version communautaire de Nextcloud n'est pas supportée et les notifications instantanées ne sont pas disponibles.",
-    "Use a second factor besides your password to increase security for your account." : "Utilisez un second facteur d'authentification en plus de votre mot de passe pour augmenter la sécurité de votre compte.",
+    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Cette version communautaire de Nextcloud n'est pas supportée et les notifications push ne sont pas disponibles.",
+    "Use a second factor besides your password to increase security for your account." : "Utilisez un second facteur d'authentification en plus de votre mot de passe pour renforcer la sécurité de votre compte.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Si vous utilisez des applications tierces pour vous connecter à Nextcloud, assurez-vous de créer et de configurer un mot de passe d'application pour chacune avant d'activer l'authentification à deux facteurs.",
     "Migration in progress. Please wait until the migration is finished" : "Migration en cours. Veuillez attendre que celle-ci se termine",
     "Migration started …" : "Migration démarrée...",
@@ -527,7 +528,7 @@ OC.L10N.register(
     "Background job didn’t run yet!" : "La tâche de fond n'a pas encore été exécutée !",
     "For the server to work properly, it's important to configure background jobs correctly. \"Cron\" is the recommended setting. Please see the documentation for more information." : "Pour que le serveur fonctionne correctement, il est important de configurer correctement les tâches d'arrière-plan. \"Cron\" est le règlage recommandé. Veuillez vous référer à la documentation Nextcloud pour plus d'informations.",
     "Pick background job setting" : "Définir les paramètres pour la tâche d'arrière-plan",
-    "Recommended" : "Recommandée",
+    "Recommended" : "Recommandé",
     "The cron.php needs to be executed by the system user \"%s\"." : "Le cron.php doit être exécuté par l'utilisateur système \"%s\".",
     "days" : "jours",
     "Allow username autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Autoriser l'autocomplétion quand le nom complet ou l'adresse e-mail sont saisis (en ignorant la recherche du numéro de téléphone et le fait d'être dans le même groupe)",
