@@ -121,6 +121,7 @@ OC.L10N.register(
     "Overview" : "Áttekintés",
     "Basic settings" : "Alapvető beállítások",
     "Sharing" : "Megosztás",
+    "Availability" : "Elérhetőség",
     "Personal info" : "Személyes információk",
     "Mobile & desktop" : "Mobil és asztali",
     "Email server" : "E-mail kiszolgáló",
@@ -281,6 +282,7 @@ OC.L10N.register(
     "Your biography" : "Az Ön életrajza",
     "Details" : "Részletek",
     "You are a member of the following groups:" : "Ön a következő csoportok tagja:",
+    "You are using <strong>{usage}</strong>" : "Ezt használja: <strong>{usage}</strong>",
     "Your full name" : "Az Ön teljes neve",
     "Email options" : "E-mail beállítások",
     "Primary email for password reset and notifications" : "Elsődleges e-mail-cím a jelszó-visszaállításhoz és az értesítésekhez",
