@@ -107,10 +107,12 @@ OC.L10N.register(
     "Personal" : "Asmeniniai",
     "Administration" : "Administravimas",
     "Additional settings" : "Papildomi nustatymai",
+    "Administration privileges" : "Administravimo teisės",
     "Groupware" : "Grupinio darbo įranga",
     "Overview" : "Apžvalga",
     "Basic settings" : "Pagrindiniai nustatymai",
     "Sharing" : "Bendrinimas",
+    "Availability" : "Pasiekiamumas",
     "Personal info" : "Asmeninė informacija",
     "Mobile & desktop" : "Mobilieji ir darbalaukiai",
     "Email server" : "El. pašto serveris",
@@ -485,6 +487,7 @@ OC.L10N.register(
     "It can take up to 24 hours before the account is displayed as verified." : "Gali užtrukti iki 24 valandų, kol paskyra bus rodoma kaip patikrinta. ",
     "Link https://…" : "Nuoroda https://…",
     "Twitter handle @…" : "Twitter rankenėlė @…",
+    "Admin privileges" : "Administravimo teisės",
     "Unable to update biography" : "Nepavyko atnaujinti biografijos",
     "Unable to update full name" : "Nepavyko atnaujinti viso vardo",
     "No full name set" : "Nenustatyta jokio viso vardo",
