@@ -1,17 +1,12 @@
 OC.L10N.register(
     "settings",
     {
-    "Migration in progress. Please wait until the migration is finished" : "Migrering utføres. Vent til den er ferdig.",
-    "Migration started …" : "Migrering startet…",
-    "Saved" : "Lagret",
-    "Not saved" : "Ikke lagret",
-    "Sending…" : "Sender…",
-    "Email sent" : "E-post sendt",
     "Private" : "Privat",
-    "Don't synchronize to servers" : "Ikke synkroniser til servere",
-    "Trusted" : "Betrodd",
+    "Only visible to people matched via phone number integration through Talk on mobile" : "Kun synlig for personer som matches via telefonnummerintegrasjon via Talk på mobil",
+    "Local" : "Lokal",
+    "Federated" : "Sammenknyttet",
     "Only synchronize to trusted servers" : "Synkroniser kun til betrodde servere",
-    "Public" : "Offentlig",
+    "Published" : "Publisert",
     "Synchronize to trusted servers and the global and public address book" : "Synkroniser til betrodde servere og den globale og offentlige adresseboken",
     "Verify" : "Bekreft",
     "Verifying …" : "Bekrefter…",
@@ -21,10 +16,6 @@ OC.L10N.register(
     "So-so password" : "Bob-bob-passord",
     "Good password" : "Bra passord",
     "Strong password" : "Sterkt passord",
-    "An error occurred while changing your language. Please reload the page and try again." : "En feil oppstod under endring av språk. Last inn siden på nytt og prøv igjen.",
-    "An error occurred while changing your locale. Please reload the page and try again." : "En feil oppstod under endring av nasjonal innstilling. Last inn siden på nytt og prøv igjen.",
-    "Select a profile picture" : "Velg et profilbilde",
-    "Week starts on {fdow}" : "Uken starter på {fdow}",
     "Groups" : "Grupper",
     "Group list is empty" : "Gruppeliste er tom",
     "Unable to retrieve the group list" : "Kunne ikke hente gruppelisten",
@@ -57,15 +48,12 @@ OC.L10N.register(
     "Remote wipe was started on %1$s" : "Fjernsletting ble startet på %1$s",
     "Remote wipe has finished on %1$s" : "Fjernsletting er ferdig på %1$s",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "Ditt <strong>passord</strong> eller din <strong>e-postadresse</strong> ble endret",
-    "Couldn't remove app." : "Klarte ikke å fjerne app.",
-    "Couldn't update app." : "Kunne ikke oppdatere appen.",
     "Wrong password" : "Feil passord",
+    "Saved" : "Lagret",
     "No user supplied" : "Ingen bruker angitt",
     "Authentication error" : "Autentiseringsfeil",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "Angi et administrativt gjenopprettingspassord; ellers vil alle brukerdata gå tapt.",
     "Wrong admin recovery password. Please check the password and try again." : "Feil administrativt gjenopprettingspassord. Sjekk passordet og prøv igjen.",
-    "Backend doesn't support password change, but the user's encryption key was updated." : "Serveren støtter ikke endring av passord, men brukerens krypteringsnøkkel ble oppdatert.",
-    "installing and updating apps via the app store or Federated Cloud Sharing" : "installering og oppdatering av apper via app-butikken eller ved deling i sammenknyttet sky",
     "Federated Cloud Sharing" : "Sammenknyttet sky-deling",
     "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL bruker en utdatert %1$s-versjon (%2$s). Oppdater operativsystemet ditt; ellers vil ikke funksjoner som %3$s virke pålitelig.",
     "Invalid SMTP password." : "Ugyldig SMTP-passord.",
@@ -74,7 +62,7 @@ OC.L10N.register(
     "If you received this email, the email configuration seems to be correct." : "Hvis du mottar denne e-posten, er e-postoppsettet rett.",
     "Email could not be sent. Check your mail server log" : "E-post kunne ikke sendes. Sjekk serverloggen på din e-postserver",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Et problem oppstod med sending av e-post. Sjekk innstillingene. (Feil: %s)",
-    "You need to set your user email before being able to send test emails." : "Du må sette e-postadressen for brukeren din før du kan teste sending av e-post.",
+    "Invalid user" : "Ugyldig bruker",
     "Invalid mail address" : "Ugyldig e-postadresse",
     "Settings saved" : "Innstillinger lagret",
     "Unable to change full name" : "Klarte ikke å endre fullt navn",
@@ -113,6 +101,9 @@ OC.L10N.register(
     "Sharing" : "Deling",
     "Personal info" : "Personlig informasjon",
     "Mobile & desktop" : "Mobil og skrivebord",
+    "Email server" : "E-postserver",
+    "Security & setup warnings" : "Advarsler om sikkerhet og oppsett",
+    "Background jobs" : "Bakgrunnsjobber",
     "Create" : "Ny",
     "Change" : "Endre",
     "Delete" : "Slett",
@@ -120,7 +111,10 @@ OC.L10N.register(
     "Unlimited" : "Ubegrenset",
     "Verifying" : "Verifiserer",
     "The old server-side-encryption format is enabled. We recommend disabling this." : "Den gamle krypteringen på serversiden er aktivert. Vi anbefaler å deaktivere dette.",
+    "Profile information" : "Profil-informasjon",
     "Nextcloud settings" : "Nextcloud innstillinger",
+    "None" : "Ingen",
+    "Two-Factor Authentication" : "Tofaktor-autentisering",
     "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Tofaktor autentisering kan være påkrevd for alle brukere eller spesifikke grupper. Dersom de ikke har en tilbyder av tofaktor konfigurert, vil de ikke ha mulighet til å logge inn i systemet.",
     "Enforce two-factor authentication" : "Krev tofaktor-autentisering",
     "Limit to groups" : "Begrens til grupper",
@@ -150,7 +144,6 @@ OC.L10N.register(
     "Supported" : "Støttet",
     "Featured" : "Anbefalt",
     "Update to {update}" : "Oppdater til {update}",
-    "Update all" : "Oppdater alle",
     "Results from other categories" : "Resultater fra andre kategorier",
     "No apps found for your version" : "Ingen apper funnet for din versjon",
     "Disable all" : "Deaktiver alle",
@@ -169,10 +162,6 @@ OC.L10N.register(
     "Google Chrome for Android" : "Google Chrome for Android",
     "iPhone" : "iPhone",
     "iPad" : "iPad",
-    "Nextcloud iOS app" : "Nextcloud iOS-app",
-    "Nextcloud Android app" : "Nextcloud Android-app",
-    "Nextcloud Talk for iOS" : "Nextcloud Talk for iOS",
-    "Nextcloud Talk for Android" : "Nextcloud Talk for Android",
     "Sync client - {os}" : "Synkroniseringsklient - {os}",
     "This session" : "Denne økten",
     "Device" : "Enhet",
@@ -194,11 +183,45 @@ OC.L10N.register(
     "Copied!" : "Kopiert!",
     "Copy" : "Kopier",
     "Could not copy app password. Please copy it manually." : "Kunne ikke kopiere passord. Venligst kopier manuelt.",
+    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "For å kjøre denne trenger du PHP POSIX utvidelse. Se {linkstart}PHP-dokumentasjonen{linkend} for flere detaljer.",
+    "Profile" : "Profil",
+    "Enable" : "Aktiver",
+    "Server-side encryption" : "Kryptering på serversiden",
+    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Kryptering på serverdelen gjør det mulig å kryptere files som er lastet opp til denne serveren. Dette har begrensninger som ytelsesforverring, så bare skru på dette hvis det trengs.",
+    "Enable server-side encryption" : "Aktiver kryptering på serverdelen",
+    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Når kryptering er blitt aktivert, vil alle filer som lastes opp til serveren fra det tidspunktet av bli lagret kryptert på serveren. Det vil kun være mulig å deaktivere kryptering senere dersom den aktive krypteringsmodulen støtter det og alle forutsetninger (f.eks. å sette en gjenopprettingsnøkkel) er til stede.",
+    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Krypteringen alene gir ikke noen garanti for systemets sikkerhet. Sjekk Nextcloud-dokumentasjonen for mer informasjon om hvordan krypteringsappen virker, og de fungerende brukseksemplene.",
+    "Be aware that encryption always increases the file size." : "Vær oppmerksom på at kryptering alltid øker filstørrelsen.",
+    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Det er alltid bra å ta regelmessig sikkerhetskopi av dataene dine. Pass på å ta kopi av krypteringsnøklene sammen med dataene når kryptering er i bruk.",
+    "This is the final warning: Do you really want to enable encryption?" : "Dette er siste advarsel: Vil du virkelig aktivere kryptering?",
+    "No encryption module loaded, please enable an encryption module in the app menu." : "Ingen krypteringsmodul er lastet. Aktiver en krypteringsmodul i appmenyen.",
+    "Select default encryption module:" : "Velg forvalgt krypteringsmodul:",
+    "Remove group" : "Fjern gruppe",
+    "You are about to remove the group {group}. The users will NOT be deleted." : "Du skal til å fjerne gruppen {group}. Brukerne vil IKKE bli slettet.",
+    "Please confirm the group removal " : "Vennligst bekreft fjerning av gruppe",
+    "Current password" : "Nåværende passord",
+    "New password" : "Nytt passord",
+    "Change password" : "Endre passord",
+    "png or jpg, max. 20 MB" : "png eller jpg, maks. 20 MB",
+    "Picture provided by original account" : "Bilde kommer fra opprinnelig konto",
+    "Cancel" : "Avbryt",
+    "Details" : "Detaljer",
+    "You are a member of the following groups:" : "Du er medlem av følgende grupper:",
+    "Your email address" : "Din e-postadresse",
+    "No email address set" : "E-postadresse ikke satt",
+    "Language" : "Språk",
+    "Help translate" : "Bidra til oversettelsen",
+    "No language set" : "Språk ikke satt",
+    "Locale" : "Nasjonal innstilling",
+    "Your phone number" : "Ditt telefonnummer",
+    "Edit your Profile visibility" : "Endre synlighet for din profil",
+    "Enable Profile" : "Aktiver profil",
+    "Your Twitter handle" : "Din Twitter-konto",
+    "Your website" : "Din nettside",
+    "Add" : "Legg til",
     "You do not have permissions to see the details of this user" : "Du har ikke tilgang til å se detaljer om denne brukeren",
-    "Add user in group" : "Legg til bruker til gruppe",
     "Set user as admin for" : "Sett bruker som administrator for",
     "Select user quota" : "Velg brukerkvote",
-    "No language set" : "Språk ikke satt",
     "Delete user" : "Slett bruker",
     "Wipe all devices" : "Slett alle enheter",
     "Disable user" : "Deaktiver bruker",
@@ -206,28 +229,24 @@ OC.L10N.register(
     "Resend welcome email" : "Send velkomst-epost igjen",
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "I tilfelle man har mistet enheter eller skal ut av organisasjonen, så kan dette fjernslette Nextcloud data fra alle enheter tilknyttet bruker med {userid}. Dette fungerer kun dersom enhetene er tilkoblet internett.",
     "Remote wipe of devices" : "Fjernsletting av enheter",
-    "Cancel" : "Avbryt",
     "Welcome mail sent!" : "Velkomst-epost sendt!",
     "{size} used" : "{size} brukt",
+    "New user" : "Ny bruker",
     "Will be autogenerated" : "Blir generert automatisk",
     "Display name" : "Visningsnavn",
     "Email" : "E-post",
     "Default language" : "Standard språk",
     "Add a new user" : "Legg til en ny bruker",
-    "Close" : "Lukk",
     "Group admin for" : "Gruppeadministrator for",
     "Quota" : "Kvote",
-    "Language" : "Språk",
     "User backend" : "Bruker-server",
     "Storage location" : "Lagringsplassering",
     "Last login" : "Siste innlogging",
     "No users in here" : "Ingen brukere her",
     "Default quota" : "Standard kvote",
     "Common languages" : "Vanlige språk",
-    "All languages" : "Alle språk",
     "Password change is disabled because the master key is disabled" : "Passordendring er deaktivert fordi hoved-nøkkelen er deaktivert",
     "Name your device" : "Gi navn til enhet",
-    "Add" : "Legg til",
     "Adding your device …" : "Legger til enheten...",
     "Unnamed device" : "Ikke navngitt enhet",
     "Your apps" : "Dine apper",
@@ -237,14 +256,11 @@ OC.L10N.register(
     "App bundles" : "App-pakker",
     "Featured apps" : "Fremhevede apper",
     "{license}-licensed" : "{license}-lisensiert",
-    "Details" : "Detaljer",
     "Changelog" : "Endringslogg",
-    "New user" : "Ny bruker",
     "Add group" : "Legg til gruppe",
-    "Everyone" : "Alle",
+    "Active users" : "Aktive brukere",
     "Admins" : "Administratorer",
     "Disabled users" : "Deaktiverte brukere",
-    "Remove group" : "Fjern gruppe",
     "Default quota:" : "Standard kvote:",
     "Select default quota" : "Sett standard kvote",
     "Show Languages" : "Vis språk",
@@ -252,34 +268,39 @@ OC.L10N.register(
     "Show user backend" : "Vis bruker-bakende",
     "Show storage path" : "Vis lagrings-sti",
     "Send email to new user" : "Send e-post til ny bruker",
-    "You are about to remove the group {group}. The users will NOT be deleted." : "Du skal til å fjerne gruppen {group}. Brukerne vil IKKE bli slettet.",
-    "Please confirm the group removal " : "Vennligst bekreft fjerning av gruppe",
+    "Not saved" : "Ikke lagret",
+    "Sending…" : "Sender…",
+    "Email sent" : "E-post sendt",
+    "Location" : "Sted",
+    "Profile picture" : "Profilbilde",
+    "About" : "Om",
+    "Full name" : "Fullt navn",
+    "Headline" : "Overskrift",
+    "Organisation" : "Organisasion",
+    "Phone number" : "Telefonnummer",
+    "Role" : "Rolle",
+    "Twitter" : "Twitter",
+    "Website" : "Nettsted",
+    "Profile visibility" : "Profil-synlighet",
+    "Hide" : "Skjul",
     "Download and enable" : "Last ned og aktiver",
-    "Enable" : "Aktiver",
     "Enable untested app" : "Aktiver utestet app",
-    "The app will be downloaded from the app store" : "Denne appen vil bli lastet ned fra app-butikken",
     "Never" : "Aldri",
-    "An error occured during the request. Unable to proceed." : "En feil oppstod under forespørselen. Kan ikke fortsette.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Appen er aktivert men må oppdateres. Du vil bli videresendt til oppdateringssiden om 5 sekunder.",
-    "App update" : "App-oppdatering",
-    "Error: This app can not be enabled because it makes the server unstable" : "Feil: Denne appen kan ikke aktiveres fordi det gjør serveren ustabil",
     "Administrator documentation" : "Administratordokumentasjon",
     "Documentation" : "Dokumentasjon",
     "Forum" : "Forum",
-    "None" : "Ingen",
     "Login" : "Innlogging",
     "Plain" : "Enkel",
     "NT LAN Manager" : "NT LAN-behandler",
     "SSL/TLS" : "SSL/TLS",
     "STARTTLS" : "STARTTLS",
-    "Email server" : "E-postserver",
     "Open documentation" : "Åpne dokumentasjonen",
     "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Det er viktig å sette opp denne serveren for å kunne sende e-poster, som tilbakestilling av e-poster og merknader.",
     "Send mode" : "Forsendelsesmåte",
     "Encryption" : "Kryptering",
     "Sendmail mode" : "Sendmail-modus",
     "From address" : "Fra adresse",
-    "mail" : "e-post",
     "Authentication method" : "Autentiseringsmetode",
     "Authentication required" : "Autentisering kreves",
     "Server address" : "Serveradresse",
@@ -288,9 +309,7 @@ OC.L10N.register(
     "SMTP Username" : "SMTP-brukernavn",
     "SMTP Password" : "SMTP-passord",
     "Save" : "Lagre",
-    "Test email settings" : "Test innstillinger for e-post",
     "Send email" : "Send e-post",
-    "Security & setup warnings" : "Advarsler om sikkerhet og oppsett",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Det er viktig for sikkerheten og ytelsen på din installasjon at alt er satt opp rett. For å hjelpe deg er det satt i verk noen automatiske sjekker. Se vedlagt lenke for å lese mer i dokumentasjonen.",
     "All checks passed." : "Alle sjekker bestått.",
     "There are some errors regarding your setup." : "Det er noen feil angående oppsettet ditt.",
@@ -299,39 +318,13 @@ OC.L10N.register(
     "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Dobbeltsjekk <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installasjonsguidene ↗</a> og se etter feil eller advarsler i <a href=\"%2$s\">loggen</a>.",
     "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Sjekk sikkerheten til din Nextcloud med <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">vår sikkerhetsskanning ↗</a>.",
     "Version" : "Versjon",
-    "Two-Factor Authentication" : "Tofaktor-autentisering",
-    "Server-side encryption" : "Kryptering på serverdelen",
-    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Kryptering på serverdelen gjør det mulig å kryptere files som er lastet opp til denne serveren. Dette har begrensninger som ytelsesforverring, så bare skru på dette hvis det trengs.",
-    "Enable server-side encryption" : "Aktiver kryptering på serverdelen",
-    "Please read carefully before activating server-side encryption: " : "Les dette nøye før du aktiverer kryptering på serverdelen:",
-    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Når kryptering er blitt aktivert, vil alle filer som lastes opp til serveren fra det tidspunktet av bli lagret kryptert på serveren. Det vil kun være mulig å deaktivere kryptering senere dersom den aktive krypteringsmodulen støtter det og alle forutsetninger (f.eks. å sette en gjenopprettingsnøkkel) er til stede.",
-    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Krypteringen alene gir ikke noen garanti for systemets sikkerhet. Sjekk Nextcloud-dokumentasjonen for mer informasjon om hvordan krypteringsappen virker, og de fungerende brukseksemplene.",
-    "Be aware that encryption always increases the file size." : "Vær oppmerksom på at kryptering alltid øker filstørrelsen.",
-    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Det er alltid bra å ta regelmessig sikkerhetskopi av dataene dine. Pass på å ta kopi av krypteringsnøklene sammen med dataene når kryptering er i bruk.",
-    "This is the final warning: Do you really want to enable encryption?" : "Dette er siste advarsel: Vil du virkelig aktivere kryptering?",
-    "Enable encryption" : "Aktiver kryptering",
-    "No encryption module loaded, please enable an encryption module in the app menu." : "Ingen krypteringsmodul er lastet. Aktiver en krypteringsmodul i appmenyen.",
-    "Select default encryption module:" : "Velg forvalgt krypteringsmodul:",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Du må migrere krypteringsnøklene din fra den gamle krypteringen (ownCloud <= 8.0) til den nye. Aktiver \"Forvalgt krypteringsmodul\" og kjør 'occ encryption:migrate'",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Du må migrere krypteringsnøklene din fra den gamle krypteringen (ownCloud <= 8.0) til den nye.",
-    "Start migration" : "Start migrering",
-    "Background jobs" : "Bakgrunnsjobber",
-    "Last job execution ran %s. Something seems wrong." : "Siste jobbkjøring kjørte %s. Noe ser ut til å være galt.",
-    "Last job ran %s." : "Siste jobb kjørte %s.",
-    "Background job didn’t run yet!" : "Bakgrunnsjobben har ikke kjørt enda!",
-    "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "For optimal ytelse er det viktig å sette opp bakgrunnsjobber rett. For kjøring på større installasjoner er 'Cron' anbefalt innstilling. Se dokumentasjonen for mer informasjon.",
-    "Pick background job setting" : "Velg innstilling for bakgrunnsjobb",
-    "The cron.php needs to be executed by the system user \"%s\"." : "Filen cron.php må kjøres systemet som følgende bruker \"%s\".",
-    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "For å kjøre denne trenger du PHP POSIX utvidelse. Se {linkstart}PHP-dokumentasjonen{linkend} for flere detaljer.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Som administrator kan du fininnstille delingsoppførselen. Se dokumentasjonen for mer informasjon.",
     "Allow apps to use the Share API" : "Tillat apper å bruke API for deling",
-    "Expire after " : "Utløper etter",
-    "days" : "dager",
     "Enforce expiration date" : "Krev utløpsdato",
-    "Allow users to share via link" : "Tillat brukere å dele via lenke",
     "Allow public uploads" : "Tillat offentlig opplasting",
     "Always ask for a password" : "Alltid spør om passord",
     "Enforce password protection" : "Krev passordbeskyttelse",
+    "Set default expiration date" : "Sett forvalgt utløpsdato",
     "Allow resharing" : "TIllat videre deling",
     "Allow sharing with groups" : "Tillat deling med grupper",
     "Restrict users to only share with users in their groups" : "Begrens brukere til kun å dele med brukere i deres grupper",
@@ -345,53 +338,46 @@ OC.L10N.register(
     "Follow us on Mastodon" : "Følg oss på Mastadon",
     "Check out our blog" : "Sjekk ut bloggen vår",
     "Subscribe to our newsletter" : "Abonner på vårt nyhetsbrev",
-    "Profile picture" : "Profilbilde",
+    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Denne community-utgaven av NextCloud er ikke understøttet og umiddelbare varsler er derfor ikke tilgjengelig. ",
+    "Use a second factor besides your password to increase security for your account." : "Bruk en annen faktor i tillegg til passordet ditt for å øke sikkerheten for kontoen din.",
+    "Migration in progress. Please wait until the migration is finished" : "Migrering utføres. Vent til den er ferdig.",
+    "Migration started …" : "Migrering startet…",
+    "An error occurred while changing your language. Please reload the page and try again." : "En feil oppstod under endring av språk. Last inn siden på nytt og prøv igjen.",
+    "An error occurred while changing your locale. Please reload the page and try again." : "En feil oppstod under endring av nasjonal innstilling. Last inn siden på nytt og prøv igjen.",
+    "Select a profile picture" : "Velg et profilbilde",
+    "Week starts on {fdow}" : "Uken starter på {fdow}",
+    "Couldn't remove app." : "Klarte ikke å fjerne app.",
+    "Couldn't update app." : "Kunne ikke oppdatere appen.",
+    "Backend doesn't support password change, but the user's encryption key was updated." : "Serveren støtter ikke endring av passord, men brukerens krypteringsnøkkel ble oppdatert.",
+    "You need to set your user email before being able to send test emails." : "Du må sette e-postadressen for brukeren din før du kan teste sending av e-post.",
+    "All languages" : "Alle språk",
+    "Everyone" : "Alle",
+    "An error occured during the request. Unable to proceed." : "En feil oppstod under forespørselen. Kan ikke fortsette.",
+    "Test email settings" : "Test innstillinger for e-post",
+    "Please read carefully before activating server-side encryption: " : "Les dette nøye før du aktiverer kryptering på serverdelen:",
+    "Enable encryption" : "Aktiver kryptering",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Du må migrere krypteringsnøklene din fra den gamle krypteringen (ownCloud <= 8.0) til den nye. Aktiver \"Forvalgt krypteringsmodul\" og kjør 'occ encryption:migrate'",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Du må migrere krypteringsnøklene din fra den gamle krypteringen (ownCloud <= 8.0) til den nye.",
+    "Start migration" : "Start migrering",
+    "Last job execution ran %s. Something seems wrong." : "Siste jobbkjøring kjørte %s. Noe ser ut til å være galt.",
+    "Last job ran %s." : "Siste jobb kjørte %s.",
+    "Background job didn’t run yet!" : "Bakgrunnsjobben har ikke kjørt enda!",
+    "Pick background job setting" : "Velg innstilling for bakgrunnsjobb",
+    "Recommended" : "Anbefalt",
+    "The cron.php needs to be executed by the system user \"%s\"." : "Filen cron.php må kjøres systemet som følgende bruker \"%s\".",
+    "days" : "dager",
     "Upload new" : "Last opp nytt",
     "Select from Files" : "Velg fra filer",
     "Remove image" : "Fjern bilde",
-    "png or jpg, max. 20 MB" : "png eller jpg, maks. 20 MB",
-    "Picture provided by original account" : "Bilde kommer fra opprinnelig konto",
     "Choose as profile picture" : "Velg som profilbilde",
-    "You are a member of the following groups:" : "Du er medlem av følgende grupper:",
     "You are using <strong>%s</strong>" : "Du bruker <strong>%s</strong>",
     "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Du bruker <strong>%1$s</strong> av <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
-    "Full name" : "Fullt navn",
     "No display name set" : "Visningsnavn ikke satt",
-    "Your email address" : "Din e-postadresse",
-    "No email address set" : "E-postadresse ikke satt",
-    "For password reset and notifications" : "For å nullstille passord og varsler",
-    "Phone number" : "Telefonnummer",
-    "Your phone number" : "Ditt telefonnummer",
     "Address" : "Adresse",
     "Your postal address" : "Din postadresse",
-    "Website" : "Nettsted",
     "It can take up to 24 hours before the account is displayed as verified." : "Det kan ta opptil ett døgn før kontoen vises som bekreftet.",
     "Link https://…" : "Lenke https://…",
-    "Twitter" : "Twitter",
     "Twitter handle @…" : "Twitter-konto @ …",
-    "Help translate" : "Bidra til oversettelsen",
-    "Locale" : "Nasjonal innstilling",
-    "Current password" : "Nåværende passord",
-    "New password" : "Nytt passord",
-    "Change password" : "Endre passord",
-    "Use a second factor besides your password to increase security for your account." : "Bruk en annen faktor i tillegg til passordet ditt for å øke sikkerheten for kontoen din.",
-    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Det oppstod en feil. Last opp et ASCII-kodet PEM-sertifikat.",
-    "Valid until {date}" : "Gyldig til {date}",
-    "Local" : "Lokal",
-    "Only visible to local users" : "Kun synlig for lokale brukere",
-    "Only visible to you" : "Kun synlig for deg",
-    "Contacts" : "Kontakter",
-    "Visible to local users and to trusted servers" : "Synlig for lokale brukere og klarerte servere",
-    "Will be synced to a global and public address book" : "Vil blir synkronisert til global og offentlig addressbok",
-    "by" : "av",
-    "SSL Root Certificates" : "SSL-rotsertifikater",
-    "Common Name" : "Vanlig navn",
-    "Valid until" : "Gyldig til",
-    "Issued By" : "Utstedt av",
-    "Valid until %s" : "Gyldig til %s",
-    "Import root certificate" : "Importer rotsertifikat",
-    "Execute one task with each page loaded" : "Utfør en oppgave med hver side som blir lastet",
-    "Allow username autocompletion in share dialog. If this is disabled the full username or email address needs to be entered." : "Tillat automatisk fullføring i delingsdialogvindu. Dette kan skrus av hvis hele brukernavnet eller e-postadressen må skrives inn.",
-    "Show disclaimer text on the public link upload page. (Only shown when the file list is hidden.)" : "Vis ansvarsfraskrivelse på den offentlige opplastingssiden. (Vises kun nå fillisten er tom.)"
+    "Avatar" : "Avatar"
 },
 "nplurals=2; plural=(n != 1);");
