@@ -1,13 +1,9 @@
 OC.L10N.register(
     "settings",
     {
-    "Migration in progress. Please wait until the migration is finished" : "Migracion en cors. Mercés d’esperar fins que la migracion aja acabat",
-    "Migration started …" : "Migracion començada…",
-    "Saved" : "Enregistrat",
-    "Not saved" : "Pas enregistrat",
-    "Sending…" : "Mandadís…",
-    "Email sent" : "Corrièl mandat",
     "Private" : "Privat",
+    "Local" : "Local",
+    "Federated" : "Federated",
     "Only synchronize to trusted servers" : "Sincronizar pas qu’als servidors fisables",
     "Synchronize to trusted servers and the global and public address book" : "Sincronizar als servidors fisables e los annuaris d’adreças globals e publics",
     "Verify" : "Verificar",
@@ -18,10 +14,6 @@ OC.L10N.register(
     "So-so password" : "Senhal mejan",
     "Good password" : "Bon senhal",
     "Strong password" : "Senhal fòrt",
-    "An error occurred while changing your language. Please reload the page and try again." : "Una error s’es producha pendent lo cambiament de lenga. Mercés de recargar la pagina e tornar ensajar.",
-    "An error occurred while changing your locale. Please reload the page and try again." : "Una error s’es producha pendent lo cambiament de varianta lingüistica. Mercés de recargar la pagina e tornar ensajar.",
-    "Select a profile picture" : "Seleccionar un imatge de perfil",
-    "Week starts on {fdow}" : "La setmana comença lo {fdow}",
     "Groups" : "Gropes",
     "Group list is empty" : "La lista de grop es voida",
     "Unable to retrieve the group list" : "Recuperacion de la lista de grops impossibla",
@@ -46,9 +38,8 @@ OC.L10N.register(
     "You deleted app password \"{token}\"" : "Avètz suprimit lo senhal d’aplicacion « {token} »",
     "You renamed app password \"{token}\" to \"{newToken}\"" : "Avètz renommat lo senhal d’aplicacion « {token} » en « {newToken} »",
     "Security" : "Seguretat",
-    "Couldn't remove app." : "Supression impossibla de l’aplicacion.",
-    "Couldn't update app." : "Mesa a jorn impossibla de l’aplicacion.",
     "Wrong password" : "Wrong password",
+    "Saved" : "Enregistrat",
     "Authentication error" : "Error d’autentificacion",
     "Invalid SMTP password." : "Senhal SMTP invalid.",
     "Email setting test" : "Paramètres email de pròva",
@@ -67,10 +58,11 @@ OC.L10N.register(
     "Personal" : "Personal",
     "Administration" : "Administracion",
     "Additional settings" : "Paramètres addicionals",
-    "Admin privileges" : "Privilègis admin",
+    "Administration privileges" : "Privilègis d’administracion",
     "Overview" : "Apercebut",
     "Basic settings" : "Paramètres de basa",
     "Sharing" : "Partiment",
+    "Availability" : "Disponibilitat",
     "Personal info" : "Info personalas",
     "Mobile & desktop" : "Mobile e burèu",
     "Email server" : "Servidor email",
@@ -82,8 +74,8 @@ OC.L10N.register(
     "Unlimited" : "Illimitat",
     "Verifying" : "Verificacion",
     "Nextcloud settings" : "Paramètres Nextcloud",
-    "Administration privileges" : "Privilègis d’administracion",
     "None" : "Pas cap",
+    "Two-Factor Authentication" : "Autentificacion dos factors",
     "Limit to groups" : "Limitar als grops",
     "Save changes" : "Enregistrar las modificacions",
     "All" : "Tot",
@@ -97,9 +89,10 @@ OC.L10N.register(
     "User documentation" : "Documentacion utilizaire",
     "Admin documentation" : "Documentacion d’admin",
     "Developer documentation" : "Documentacion desvolopaire",
-    "Update all" : "Tot metre a jorn",
+    "Update to {update}" : "Actualizar en {update}",
     "Disable all" : "Desactivar tot",
     "Enable all" : "Activar tot",
+    "_%n app has an update available_::_%n apps have an update available_" : ["%n aplicacion an una mesa a jorn de disponibla","%n aplicacions an una mesa a jorn de disponibla"],
     "Device settings" : "Paramètres periferic",
     "Allow filesystem access" : "Permetre accès filesystem",
     "Rename" : "Renomenar",
@@ -113,6 +106,10 @@ OC.L10N.register(
     "Google Chrome for Android" : "Google Chrome per Android",
     "iPhone" : "iPhone",
     "iPad" : "iPad",
+    "{productName} iOS app" : "Aplicacion iOS {productName}",
+    "{productName} Android app" : "Aplicacion Android {productName}",
+    "{productName} Talk for iOS" : "Talk de {productName} per iOS",
+    "{productName} Talk for Android" : "Talk de {productName} per Android",
     "This session" : "Aquesta session",
     "Device" : "Periferic",
     "Last activity" : "Darrièra activitat",
@@ -123,20 +120,51 @@ OC.L10N.register(
     "Done" : "Done",
     "Copied!" : "Copiat !",
     "Copy" : "Copiar",
+    "Profile" : "Perfil",
+    "Enable" : "Activar",
+    "Remove group" : "Suprimir grop",
+    "Current password" : "Senhal actual",
+    "New password" : "Senhal novèl",
+    "Change password" : "Cambiar de senhal",
+    "png or jpg, max. 20 MB" : "png or jpg, max. 20 Mo",
+    "Picture provided by original account" : "Imatge provesit pel compte d’origina",
+    "Cancel" : "Anullar",
     "Your biography" : "Vòstra biografia",
+    "Details" : "Detalhs",
+    "You are a member of the following groups:" : "Formatz part d’aquestes grops :",
+    "Your full name" : "Vòstre nom complèt",
+    "Email options" : "Opcions d’email",
+    "This address is not confirmed" : "Aquesta adreça es pas confirmada",
+    "Set as primary email" : "Definir coma adreça principala",
     "Your email address" : "Vòstra adreça electronica",
     "No email address set" : "Cap d’adreça pas definida",
+    "Additional emails" : "Emails suplementaris",
+    "Your headline" : "Vòstre títol",
     "Language" : "Lenga",
     "Help translate" : "Ajudar a traduire",
+    "Unable to update language" : "Actualizacion de la lenga impossibla",
     "No language set" : "Cap de lenga pas definida",
+    "Locale" : "Varianta lingüistica",
+    "Your organisation" : "Vòstra organizacion",
+    "Your phone number" : "Vòstre numèro de telefòn",
+    "Edit your Profile visibility" : "Modificatz la visibilitat de vòstre perfil",
+    "Enable Profile" : "Activar Perfil",
+    "{displayId}" : "{displayId}",
+    "Your role" : "Vòstre ròtle",
     "Add" : "Ajustar",
     "Add new password" : "Apondre senhal novèl",
+    "Add new email address" : "Apondre adreça electronica",
+    "Add user to group" : "Apondre utilizaire al grop",
+    "Set user as admin for" : "Definir l’utilizaire coma admin per",
+    "Select user quota" : "Seleccionar lo quota utilizaire",
     "Delete user" : "Suprimir l’utilizaire",
     "Wipe all devices" : "Escafar totes los periferics",
     "Disable user" : "Desactivar l’utilizaire",
     "Enable user" : "Activar l’utilizaire",
-    "Cancel" : "Anullar",
+    "Resend welcome email" : "Tornar enviar l’email de benvenguda",
     "Account deletion" : "Supression de compte",
+    "Delete {userid}'s account" : "Suprimir lo compte de {userid}",
+    "Welcome mail sent!" : "Email de benvenguda enviat !",
     "Edit User" : "Modificar l’utilizaire",
     "{size} used" : "{size} utilizat",
     "New user" : "Utilizaire novèl",
@@ -144,89 +172,100 @@ OC.L10N.register(
     "Email" : "Adreça corrièl",
     "Default language" : "Lenga per defaut",
     "Add a new user" : "Apondre un utilizaire novè",
+    "Quota" : "Quota",
+    "Last login" : "Darrièra connexion",
+    "No users in here" : "Cap d’utilizaire aquí",
+    "Default quota" : "Quota per defaut",
     "Common languages" : "Lengas comunas",
+    "Other languages" : "Autras lengas",
     "Name your device" : "Nommatz vòstre periferic",
     "Adding your device …" : "Apondon del periferic…",
     "Unnamed device" : "Periferic sens nom",
     "Passwordless Authentication" : "Autentificacion sens senhal",
     "No devices configured." : "Cap de periferic pas configurat.",
+    "Your browser does not support WebAuthn." : "Vòstre navigador es pas compatible amb WebAuthn.",
     "Your apps" : "Vòstras aplicacions",
     "Active apps" : "Aplicacions activas",
     "Disabled apps" : "Aplicacions desactivadas",
     "Updates" : "Mesas a jorn",
-    "Details" : "Detalhs",
     "Changelog" : "Nòta de version",
     "by {author}\n{license}" : "per {author}\n{license}",
     "Enter group name" : "Picatz un nom de grop",
     "Add group" : "Apondre grop",
+    "Active users" : "Utilizaires actius",
     "Admins" : "Admins",
     "Disabled users" : "Utilizaires desactivats",
     "Show Languages" : "Veire las lengas",
-    "Address" : "Adreça",
+    "Show last login" : "Afichar la darrièra connexion",
+    "Not saved" : "Pas enregistrat",
+    "Sending…" : "Mandadís…",
+    "Email sent" : "Corrièl mandat",
+    "Location" : "Emplaçament",
+    "Profile picture" : "Imatge de perfil",
     "About" : "A prepaus",
     "Full name" : "Nom complèt",
+    "Additional email" : "Email suplementari",
+    "Headline" : "Títol",
     "Organisation" : "Organizacion",
     "Phone number" : "Numèro de telefòn",
-    "Profile" : "Perfil",
     "Role" : "Ròtle",
     "Twitter" : "Twitter",
     "Website" : "Site web",
-    "Enable" : "Activar",
+    "Profile visibility" : "Visibilitat perfil",
+    "Show to everyone" : "Afichar a tot lo monde",
+    "Hide" : "Amagar",
     "Never" : "Pas jamais",
     "Documentation" : "Documentacion",
+    "Forum" : "Forum",
     "Login" : "Login",
     "SSL/TLS" : "SSL/TLS",
     "STARTTLS" : "STARTTLS",
     "Open documentation" : "Dobrir la documentacion",
     "Send mode" : "Mòde de mandadís",
     "Encryption" : "Chiframent",
+    "Authentication required" : "Autentificacion requerida",
     "Server address" : "Adreça del servidor",
     "Port" : "Pòrt",
     "Credentials" : "Informacions d'identificacion",
     "SMTP Username" : "Utilizaire SMTP",
     "SMTP Password" : "Senhal SMTP",
     "Save" : "Salvar",
-    "Test email settings" : "Ensajar los paramètres email",
     "Send email" : "Enviar email",
     "Version" : "Version",
-    "Two-Factor Authentication" : "Autentificacion dos factors",
-    "Enable encryption" : "Activar lo chiframent",
-    "Start migration" : "Començar la migracion",
+    "day(s)" : "jorn(s)",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Desvolopat per la {communityopen}comunautat Nextcloud{linkclose}, lo {githubopen}còdi font{linkclose} es jos licéncia {licenseopen}AGPL{linkclose}.",
     "Like our Facebook page" : "Aimar nòstra pagina Facebook",
     "Follow us on Twitter" : "Nos seguir sus Twitter",
     "Follow us on Mastodon" : "Nos seguir sus Mastodon",
     "Check out our blog" : "Donar un còp d’uèlh a nòstre blòg",
     "Subscribe to our newsletter" : "S’abonar a l’infoletra",
-    "Profile picture" : "Imatge de perfil",
+    "Migration in progress. Please wait until the migration is finished" : "Migracion en cors. Mercés d’esperar fins que la migracion aja acabat",
+    "Migration started …" : "Migracion començada…",
+    "An error occurred while changing your language. Please reload the page and try again." : "Una error s’es producha pendent lo cambiament de lenga. Mercés de recargar la pagina e tornar ensajar.",
+    "An error occurred while changing your locale. Please reload the page and try again." : "Una error s’es producha pendent lo cambiament de varianta lingüistica. Mercés de recargar la pagina e tornar ensajar.",
+    "Select a profile picture" : "Seleccionar un imatge de perfil",
+    "Week starts on {fdow}" : "La setmana comença lo {fdow}",
+    "Couldn't remove app." : "Supression impossibla de l’aplicacion.",
+    "Couldn't update app." : "Mesa a jorn impossibla de l’aplicacion.",
+    "All languages" : "Totas las lengas",
+    "Everyone" : "Tot lo monde",
+    "Test email settings" : "Ensajar los paramètres email",
+    "Enable encryption" : "Activar lo chiframent",
+    "Start migration" : "Començar la migracion",
+    "days" : "jorns",
     "Upload new" : "Ne mandar un novèl",
     "Select from Files" : "Seleccionar dels fichièrs",
     "Remove image" : "Suprimir imatge",
-    "png or jpg, max. 20 MB" : "png or jpg, max. 20 Mo",
-    "Picture provided by original account" : "Imatge provesit pel compte d’origina",
     "Choose as profile picture" : "Causir coma imatge de perfil",
-    "You are a member of the following groups:" : "Formatz part d’aquestes grops :",
     "You are using <strong>%s</strong>" : "Utilizatz <strong>%s</strong>",
     "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Utilizatz <strong>%1$s</strong> de <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
-    "Your phone number" : "Vòstre numèro de telefòn",
+    "No display name set" : "Cap de nom d’afichatge pas definit",
+    "Address" : "Adreça",
     "Your postal address" : "Vòstra adreça postala",
     "Link https://…" : "Ligam https://…",
     "Twitter handle @…" : "Escais Twitter @…",
-    "Locale" : "Varianta lingüistica",
-    "Current password" : "Senhal actual",
-    "New password" : "Senhal novèl",
-    "Change password" : "Cambiar de senhal",
-    "Don't synchronize to servers" : "Sincronizar pas als servidors",
-    "Trusted" : "Fisable",
-    "Public" : "Public",
-    "Nextcloud iOS app" : "Aplicacion Nextcloud iOS",
-    "Nextcloud Talk for iOS" : "Nextcloud Talk per iOS",
-    "Nextcloud Talk for Android" : "Nextcloud Talk per Android",
-    "Close" : "Tampar",
-    "All languages" : "Totas las lengas",
-    "Everyone" : "Tot lo monde",
-    "days" : "jorns",
-    "No display name set" : "Cap de nom d’afichatge pas definit",
-    "For password reset and notifications" : "Per reconfigurar lo senhal e recebre las notificacions"
+    "Admin privileges" : "Privilègis admin",
+    "Unable to update full name" : "Actualizacion impossibla del nom complet",
+    "Avatar" : "Avatar"
 },
 "nplurals=2; plural=(n > 1);");
