@@ -1,12 +1,6 @@
 OC.L10N.register(
     "settings",
     {
-    "Migration in progress. Please wait until the migration is finished" : "V teku je preselitev. Počakajte, da se zaključi.",
-    "Migration started …" : "Preselitev je začeta ...",
-    "Saved" : "Shranjeno",
-    "Not saved" : "Ni shranjeno",
-    "Sending…" : "Poteka pošiljanje ...",
-    "Email sent" : "Elektronsko sporočilo je poslano",
     "Private" : "Zasebno",
     "Only visible to people matched via phone number integration through Talk on mobile" : "Vidno le uporabnikom povezanimi s programom Talk prek telefonske številke.",
     "Local" : "Krajevno",
@@ -23,10 +17,6 @@ OC.L10N.register(
     "So-so password" : "Šibko geslo",
     "Good password" : "Dobro geslo",
     "Strong password" : "Odlično geslo",
-    "An error occurred while changing your language. Please reload the page and try again." : "Med spreminjanjem jezika je prišlo do napake. Poskusite ponovno naložiti stran in poskusite znova.",
-    "An error occurred while changing your locale. Please reload the page and try again." : "Med spreminjanjem jezikovnih nastavitev je prišlo do napake. Poskusite ponovno naložiti stran in poskusite znova.",
-    "Select a profile picture" : "Izbor slike profila",
-    "Week starts on {fdow}" : "Začetek tedna je {fdow}",
     "Groups" : "Skupine",
     "Group list is empty" : "Seznam skupin je prazen",
     "Unable to retrieve the group list" : "Ni mogoče pridobiti seznama skupin",
@@ -59,17 +49,14 @@ OC.L10N.register(
     "Remote wipe was started on %1$s" : "Oddaljeno varnostno brisanje je bilo začeto na %1$s.",
     "Remote wipe has finished on %1$s" : "Oddaljeno varnostno brisanje je bilo končano na %1$s.",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "Spremenjeno je bilo <strong>geslo</strong> oziroma <strong>elektronski naslov</strong>",
-    "Couldn't remove app." : "Programa ni mogoče odstraniti.",
-    "Couldn't update app." : "Programa ni mogoče posodobiti.",
     "Wrong password" : "Napačno geslo",
+    "Saved" : "Shranjeno",
     "No user supplied" : "Ni navedenega uporabnika",
     "Authentication error" : "Napaka overjanja",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "Podati je treba skrbniško obnovitveno geslo, sicer bodo vsi uporabniški podatki izgubljeni.",
     "Wrong admin recovery password. Please check the password and try again." : "Napačno navedeno skrbniško obnovitveno geslo. Preverite geslo in poskusite znova.",
-    "Backend doesn't support password change, but the user's encryption key was updated." : "Ozadnji program ne podpira spreminjanja gesla, je pa uspešno posodobljeno uporabniški šifrirni ključ.",
     "Federated Cloud Sharing" : "Souporaba zveznega oblaka",
     "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "Program cURL uporablja zastarelo različico %1$s (%2$s). Priporočljivo je posodobiti operacijski sistem, sicer možnosti, kot je %3$s, ne bodo delovale pravilno.",
-    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "Ni mogoče določiti, ali je različica TLS cURL zastarela ali ne, ker je do napake prišlo med izvajanjem zahteve HTTPS prek https://nextcloud.com. Za več podrobnosti si oglejte datoteko dnevnika nextcloud.",
     "Invalid SMTP password." : "Neveljavno geslo SMTP",
     "Email setting test" : "Preizkus nastavitev elektronske pošte",
     "Well done, %s!" : "Odlično, %s!",
@@ -112,11 +99,12 @@ OC.L10N.register(
     "Personal" : "Osebno",
     "Administration" : "Skrbništvo",
     "Additional settings" : "Dodatne nastavitve",
-    "Admin privileges" : "Dovoljenja skrbnika",
+    "Administration privileges" : "Skrbniška dovoljenja",
     "Groupware" : "Skupinsko delo",
     "Overview" : "Splošni pregled",
     "Basic settings" : "Osnovne nastavitve",
     "Sharing" : "Souporaba",
+    "Availability" : "Razpoložljivost",
     "Personal info" : "Osebni podatki",
     "Mobile & desktop" : "Mobilni in namizni dostop",
     "Email server" : "Poštni strežnik",
@@ -131,14 +119,11 @@ OC.L10N.register(
     "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Na čakanju je ozadnje opravilo, ki preverja obstoj uporabniško uvoženih potrdil SSL. Ponovno preverite kasneje.",
     "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Shranjenih je nekaj potrdil SSL, ki z različico Nextcloud 21 ne bodo več v uporabi. Potrdila je mogoče uvoziti z ukazom \"occ security:certificates:import\". Zabeležene poti v podatkovnem imeniku so izpisane spodaj.",
     "The old server-side-encryption format is enabled. We recommend disabling this." : "Star način strežniškega šifriranja je še vedno omogočen. Priporočljivo je možnost izklopiti.",
-    "MariaDB version \"%s\" is used. Nextcloud 21 will no longer support this version and requires MariaDB 10.2 or higher." : "V uporabi je različica podatkovne zbirke MariaDB »%s«. Z namestitvijo Nextcloud 21 ta ni več podprta. Sistem zahteva nadgradnjo zbirke na različico MariaDB 10.2 ali višjo.",
-    "MySQL version \"%s\" is used. Nextcloud 21 will no longer support this version and requires MySQL 8.0 or MariaDB 10.2 or higher." : "V uporabi je različica podatkovne zbirke MySQL »%s«. Z namestitvijo Nextcloud 21 ta ni več podprta. Sistem zahteva nadgradnjo zbirke na različico MySQL 8.0, MariaDB 10.2 ali višje.",
-    "PostgreSQL version \"%s\" is used. Nextcloud 21 will no longer support this version and requires PostgreSQL 9.6 or higher." : "V uporabi je različica podatkovne zbirke PostgreSQL »%s«. Z namestitvijo Nextcloud 21 ta ni več podprta. Sistem zahteva nadgradnjo zbirke na različico PostgreSQL 9.6 ali višjo.",
     "Nextcloud settings" : "Nastavitve Nextcloud",
-    "Administration privileges" : "Skrbniška dovoljenja",
     "Here you can decide which group can access certain sections of the administration settings." : "Na tem mestu je mogoče določiti, katera skupina ima dostop do določenih možnosti skrbniških nastavitev.",
     "None" : "Brez",
     "Unable to modify setting" : "Ni mogoče spremeniti nastavitve",
+    "Two-Factor Authentication" : "Dvo-stopenjska overitev",
     "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Dvostopenjsko overjanje je mogoče vsiliti za vse uporabnike in določene skupine. Če za tovrstno prijavo nimajo nastavljenega ustreznega ponudnika, se v sistem ne bodo uspeli povezati.",
     "Enforce two-factor authentication" : "Vsili dvo-stopenjsko overjanje",
     "Limit to groups" : "Omeji na skupine",
@@ -169,7 +154,6 @@ OC.L10N.register(
     "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Uradne programe razvijajo posamezniki, ki sodelujejo s skupnostjo. Paketi vključujejo osrednje zmožnosti programa, uporaba pa je namenjena tudi končnim uporabnikom.",
     "Featured" : "Izbrano",
     "Update to {update}" : "Posodobi na različico {update}",
-    "Update all" : "Posodobi vse",
     "Results from other categories" : "Rezultati iskanja med drugimi kategorijami",
     "No apps found for your version" : "Za navedeni iskalni niz ni programov",
     "Disable all" : "Onemogoči vse",
@@ -217,14 +201,40 @@ OC.L10N.register(
     "Copied!" : "Kopirano!",
     "Copy" : "Kopiraj",
     "Could not copy app password. Please copy it manually." : "Gesla programa ni mogoče kopirati. Storite to ročno.",
+    "Last job ran {relativeTime}." : "osvežitev je bila nazadnje izvedena {relativeTime}.",
+    "AJAX" : "AJAX",
+    "Execute one task with each page loaded. Use case: Single user instance." : "izvede eno nalogo z vsako naloženo stranjo. Možnost uporabe: okolje enega uporabnika.",
+    "Webcron" : "Webcron",
+    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "Osveževanje z datoteko cron.php omogoča storitev webcron  in sicer vsakih 5 minut po protokolu HTTP. Možnost je uporabna za manše število uporabnikov (1–5 udeležencev z nezahtevnim načinom rabe okolja).",
+    "Cron (Recommended)" : "Cron (priporočeno)",
+    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Za zagon te možnosti je zahtevana razširitev PHP POSIX. Več podrobnosti je zapisanih v {linkstart}dokumentaciji PHP{linkend}.",
+    "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "Uporabljena je sistemska storitev »cron«, ki vzpostavi povezavo z datoteko cron.php vsakih 5 minut. Priporočeno za vse vrste rabe okolja.",
+    "Profile" : "Profil",
+    "Enable" : "Omogoči",
+    "Server-side encryption" : "Šifriranje na strežniku",
+    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Šifriranje na strežniku omogoča šifriranje datotek, poslanih na strežnik. Opravilo ima tudi omejitvene učinke, kot je vpliv na hitrost delovanja, Možnost je na voljo po potrebi.",
+    "Enable server-side encryption" : "Omogoči šifriranje na strežniku",
+    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Ko je šifriranje enkrat omogočeno, bodo v času manjše aktivnosti šifrirane vse datoteke, poslane na strežnik. Šifriranje bo mogoče izklopiti šele kasneje, če bo uporabljen šifrirni modul podpiral tovrstno funkcionalnost in bodo doseženi vsi ostali pogoji (na primer, ustrezno nastavljeni obnovitveni ključi).",
+    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Šifriranje samo po sebi še ne zagotavlja varnosti sistema. Več podorobnosti o delovanju programa in primeri uporabe so zabeleženi v dokumentaciji.",
+    "Be aware that encryption always increases the file size." : " Upoštevajte, da šifriranje poveča velikost datoteke.",
+    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Priporočljivo je redno ustvarjati varnostne kopije podatkov, v primeru šifriranja pa varnostno kopirati tudi šifrirne ključe.",
+    "This is the final warning: Do you really want to enable encryption?" : "To je zadnje opozorilo. Ali res želite omogočiti šifriranje?",
+    "No encryption module loaded, please enable an encryption module in the app menu." : "Modul za šifriranje ni naložen. Pred nadaljevanjem je treba modul določiti v seznamu programov.",
+    "Select default encryption module:" : "Izbor privzetega modula za šifriranje:",
+    "Rename group" : "Preimenuj skupino",
     "Remove group" : "Odstrani skupino",
     "You are about to remove the group {group}. The users will NOT be deleted." : "Odstranili boste skupino {group}. Uporabniki ne bodo odstranjeni.",
     "Please confirm the group removal " : "Potrditi je treba odstranjevanje skupine",
+    "Current password" : "Trenutno geslo",
+    "New password" : "Novo geslo",
+    "Change password" : "Spremeni geslo",
+    "png or jpg, max. 20 MB" : "png ali jpg, največ. 20 MB",
+    "Picture provided by original account" : "Slika iz izvornega računa",
+    "Cancel" : "Prekliči",
     "Your biography" : "Biografija",
-    "Unable to update biography" : "Ni mogoče posodobiti biografije",
+    "Details" : "Podrobnosti",
+    "You are a member of the following groups:" : "Omogočeno je članstvo v skupinah:",
     "Your full name" : "Polno ime",
-    "Unable to update full name" : "Ni mogoče posodobiti polnega imena",
-    "No full name set" : "Ni nastavljenega polnega imena",
     "Email options" : "Možnosti elektronske pošte",
     "Primary email for password reset and notifications" : "Osnovni elektronski naslov za obnavljanje gesla in obvestila",
     "Remove primary email" : "Odstrani osnovni elektronski naslov",
@@ -242,20 +252,20 @@ OC.L10N.register(
     "No email address set" : "Poštni naslov ni nastavljen",
     "Additional emails" : "Dodatni elektronski naslovi",
     "Your headline" : "Vaš naslov",
-    "Unable to update headline" : "Ni mogoče posodobiti naslova",
     "Language" : "Jezik",
     "Help translate" : "Sodelujte pri prevajanju",
     "Unable to update language" : "Ni mogoče posodobiti jezika",
     "No language set" : "Jezik ni nastavljen",
+    "Locale" : "Jezikovne nastavitve",
     "Your organisation" : "Ustanova",
-    "Unable to update organisation" : "Ni mogoče posodobiti imena ustanove",
+    "Your phone number" : "Osebna telefonska številka",
     "Edit your Profile visibility" : "Prilagodi vidnost profila",
     "Enable Profile" : "Omogoči profil",
     "Unable to update profile enabled state" : "Ni mogoče posodobiti omogočenega stanja profila",
     "{displayId}" : "{displayId}",
     "Unable to update visibility of {displayId}" : "Ni mogoče posodobiti vidnosti {displayId}",
     "Your role" : "Vloga",
-    "Unable to update role" : "Ni mogoče posodobiti vloge",
+    "Add additional email" : "Dodaj dodaten elektronski naslov",
     "Add" : "Dodaj",
     "You do not have permissions to see the details of this user" : "Ni ustreznih dovoljenj za pregled podatkov uporabnika",
     "Add new password" : "Vpis gesla",
@@ -271,7 +281,6 @@ OC.L10N.register(
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Možnost omogoča varnostno brisanje podatkov Nextcloud z vseh naprav, povezanih z uporabniškim računom {userid}. Možnost deluje le, če so naprave povezane v spletno omrežje. Brisanje z oddaljenih naprav je uporabno v primeru izgubljene naprave, ali na primer prekinitve sodelovanja v neki skupini.",
     "Remote wipe of devices" : "Oddaljeno varnostno brisanje naprav",
     "Wipe {userid}'s devices" : "Varnostno izbriši naprave uporabniškega računa {userid}",
-    "Cancel" : "Prekliči",
     "Fully delete {userid}'s account including all their personal files, app data, etc." : "Izbriši račun »{userid}« vključno z osebnimi podatki, datotekami, programi ...",
     "Account deletion" : "Brisanje računa",
     "Delete {userid}'s account" : "Izbriši račun {userid}",
@@ -315,7 +324,6 @@ OC.L10N.register(
     "App bundles" : "Paketi programov",
     "Featured apps" : "Predlagani programi",
     "{license}-licensed" : "dovoljenje {license}",
-    "Details" : "Podrobnosti",
     "Changelog" : "Dnevnik sprememb",
     "by {author}\n{license}" : "Razvoj: {author}\nDovoljenje: {license}",
     "Enter group name" : "Vpis imena skupine",
@@ -330,15 +338,17 @@ OC.L10N.register(
     "Show user backend" : "Pokaži ozadnji program",
     "Show storage path" : "Pokaži pot mesta shrambe",
     "Send email to new user" : "Pošlji sporočilo novemu uporabniku",
-    "Address" : "Naslov",
-    "Avatar" : "Podoba",
+    "Not saved" : "Ni shranjeno",
+    "Sending…" : "Poteka pošiljanje ...",
+    "Email sent" : "Elektronsko sporočilo je poslano",
+    "Location" : "Trenutno mesto",
+    "Profile picture" : "Slika profila",
     "About" : "O programu",
     "Full name" : "Polno ime",
     "Additional email" : "Dodatni elektronski naslov",
     "Headline" : "Naslov",
     "Organisation" : "Ustanova",
     "Phone number" : "Telefonska številka",
-    "Profile" : "Profil",
     "Role" : "Vloga",
     "Twitter" : "Račun Twitter",
     "Website" : "Spletna stran",
@@ -346,13 +356,10 @@ OC.L10N.register(
     "Show to everyone" : "Pokaži vsem",
     "Hide" : "Skrij",
     "Download and enable" : "Prejmi in omogoči",
-    "Enable" : "Omogoči",
     "Enable untested app" : "Omogoči nepreizkušen program",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Ta program ni označen kot skladen z nameščeno različico oblaka Nextcloud. Če nameravate nadaljevati, boste program lahko namestili, vendar ta morda ne bo deloval po pričakovanjih, ali pa bo vplival na stabilnost sistema.",
     "Never" : "Nikoli",
-    "An error occured during the request. Unable to proceed." : "Med izvajanjem zahteve je prišlo do napake, zato ni mogoče nadaljevati.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Program je omogočen, vendar zahteva posodobitev. Po nekaj sekundah boste preusmerjeni na stran za posodobitev.",
-    "App update" : "Posodobitev programa",
     "Error: This app cannot be enabled because it makes the server unstable" : "Napaka: tega programa ni mogoče namestiti, ker povzroča nestabilnost strežnika.",
     "Administrator documentation" : "Skrbniška dokumentacija",
     "Documentation" : "Dokumentacija",
@@ -385,34 +392,6 @@ OC.L10N.register(
     "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Preverite <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">namestitveno dokumentacijo ↗</a> in morebitne napake oziroma opozorila v <a href=\"%2$s\">sistemskem dnevniku</a>.",
     "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Preverite varnost storitev Nextcloud s <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">preverjalnikom ↗</a>.",
     "Version" : "Različica",
-    "Two-Factor Authentication" : "Dvo-stopenjska overitev",
-    "Server-side encryption" : "Šifriranje na strežniku",
-    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Šifriranje na strežniku omogoča šifriranje datotek, poslanih na strežnik. Opravilo ima tudi omejitvene učinke, kot je vpliv na hitrost delovanja, Možnost je na voljo po potrebi.",
-    "Enable server-side encryption" : "Omogoči šifriranje na strežniku",
-    "Please read carefully before activating server-side encryption: " : "Pred omogočanjem strežniškega šifriranja pozorno preberite opombe:",
-    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Ko je šifriranje enkrat omogočeno, bodo v času manjše aktivnosti šifrirane vse datoteke, poslane na strežnik. Šifriranje bo mogoče izklopiti šele kasneje, če bo uporabljen šifrirni modul podpiral tovrstno funkcionalnost in bodo doseženi vsi ostali pogoji (na primer, ustrezno nastavljeni obnovitveni ključi).",
-    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Šifriranje samo po sebi še ne zagotavlja varnosti sistema. Več podorobnosti o delovanju programa in primeri uporabe so zabeleženi v dokumentaciji.",
-    "Be aware that encryption always increases the file size." : " Upoštevajte, da šifriranje poveča velikost datoteke.",
-    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Priporočljivo je redno ustvarjati varnostne kopije podatkov, v primeru šifriranja pa varnostno kopirati tudi šifrirne ključe.",
-    "This is the final warning: Do you really want to enable encryption?" : "To je zadnje opozorilo. Ali res želite omogočiti šifriranje?",
-    "Enable encryption" : "Omogoči šifriranje",
-    "No encryption module loaded, please enable an encryption module in the app menu." : "Modul za šifriranje ni naložen. Pred nadaljevanjem je treba modul določiti v seznamu programov.",
-    "Select default encryption module:" : "Izbor privzetega modula za šifriranje:",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Preseliti je treba šifrirne ključe iz starega sistema (ownCloud ≤ 8.0) na novega. Omogočite možnost »Privzeti šifrirni modul« in zaženite ukaz »occ encryption:migrate«.",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Preseliti je treba šifrirne ključe iz starega sistema (ownCloud <= 8.0) na novega.",
-    "Start migration" : "Začni selitev",
-    "Last job execution ran %s. Something seems wrong." : "Zadnji poskus izvedbe je bil izveden %s. Kaže, da je nekaj narobe.",
-    "Some jobs haven’t been executed since %s. Please consider increasing the execution frequency." : "Nekatera opravila niso bila izvedena od %s. Priporočljivo je povečati pogostost izvajanja.",
-    "Some jobs didn’t execute since %s. Please consider switching to system cron." : "Nekatera opravila niso bila izvedena od %s. Priporočljivo je preklopiti na sistemska opravila cron.",
-    "Last job ran %s." : "Zadnje opravilo je bilo izvedeno %s.",
-    "Background job didn’t run yet!" : "Ni bilo izvedenega še nobenega opravila v ozadju.",
-    "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "Za najboljše delovanje je pomembna ustrezna nastavitev opravil v ozadju. Pri večjih namestitvah je priporočljiva nastavitev »Cron«. Več podrobnosti je zapisanih v dokumentaciji.",
-    "Pick background job setting" : "Izbor nastavitve ozadnjih opravil",
-    "Execute one task with each page loaded." : "Izvedi eno nalogo z vsako naloženo stranjo.",
-    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP." : "Datoteka cron.php je registrirana pri storitvi »webcron«, ki vzpostavi povezavo s cron.php vsakih 5 minut prek protokola HTTP.",
-    "Use system cron service to call the cron.php file every 5 minutes." : "Uporabljena je sistemska storitev »cron«, ki vzpostavi povezavo z datoteko cron.php vsakih 5 minut.",
-    "The cron.php needs to be executed by the system user \"%s\"." : "Datoteka cron.php mora biti izvedena za uporabnika »%s«.",
-    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Za zagon te možnosti je zahtevana razširitev PHP POSIX. Več podrobnosti je zapisanih v {linkstart}dokumentaciji PHP{linkend}.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Skrbnik lahko prilagodi možnosti souporabe. Več podrobnosti je zapisanih v dokumentaciji.",
     "Allow apps to use the Share API" : "Dovoli programom uporabo vmesnika API souporabe",
     "Set default expiration date for shares" : "Nastavi privzeti datuma poteka za mesta souporabe",
@@ -434,7 +413,6 @@ OC.L10N.register(
     "Allow username autocompletion to users within the same groups" : "Dovoli samodejno dopolnjevanje uporabniških imen znotraj iste skupine",
     "Allow username autocompletion to users based on phone number integration" : "Dovoli samodejno dopolnjevanje uporabniških imen po telefonskih številkah",
     "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Če je omogočeno samodejno dopolnjevanje »v isti skupini«, ali pa »po telefonskem imeniku«, se zadetek pokaže, če je uporabnik v katerikoli od teh zbirk.",
-    "Allow username autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Dovoli samodejno dokončanje uporabniškega imena pri vpisu polnega imena ali elektronskega naslova (prezrta je zahteva telefonskega imenika in iste skupine).",
     "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Pokaži izjavo o omejitvi odgovornosti pri uporabi javnih povezav za pošiljanje (če je onemogočen prikaz seznama datotek).",
     "This text will be shown on the public link upload page when the file list is hidden." : "Besedilo izjave o omejitvi odgovornosti, ki bo izpisano v oknu za pošiljanje, ko je možnost prikaza seznama datotek onemogočena.",
     "Default share permissions" : "Privzeta dovoljenja souporabe",
@@ -445,19 +423,52 @@ OC.L10N.register(
     "Follow us on Mastodon" : "Sledite nam na Mastodon",
     "Check out our blog" : "Preverite naš blog",
     "Subscribe to our newsletter" : "Naročite se na novice",
-    "Profile picture" : "Slika profila",
+    "Use a second factor besides your password to increase security for your account." : "Ob geslu je priporočljivo uporabiti tudi drugo-stopenjsko overitev za večjo varnost računa.",
+    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Če uporabljate za povezavo z oblakom Nextcloud programe tretjih oseb, najprej ustvarite in nastavite gesla za vsak program, preden omogočite dvostopenjsko overitev.",
+    "Migration in progress. Please wait until the migration is finished" : "V teku je preselitev. Počakajte, da se zaključi.",
+    "Migration started …" : "Preselitev je začeta ...",
+    "An error occurred while changing your language. Please reload the page and try again." : "Med spreminjanjem jezika je prišlo do napake. Poskusite ponovno naložiti stran in poskusite znova.",
+    "An error occurred while changing your locale. Please reload the page and try again." : "Med spreminjanjem jezikovnih nastavitev je prišlo do napake. Poskusite ponovno naložiti stran in poskusite znova.",
+    "Select a profile picture" : "Izbor slike profila",
+    "Week starts on {fdow}" : "Začetek tedna je {fdow}",
+    "Couldn't remove app." : "Programa ni mogoče odstraniti.",
+    "Couldn't update app." : "Programa ni mogoče posodobiti.",
+    "Backend doesn't support password change, but the user's encryption key was updated." : "Ozadnji program ne podpira spreminjanja gesla, je pa uspešno posodobljeno uporabniški šifrirni ključ.",
+    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "Ni mogoče določiti, ali je različica TLS cURL zastarela ali ne, ker je do napake prišlo med izvajanjem zahteve HTTPS prek https://nextcloud.com. Za več podrobnosti si oglejte datoteko dnevnika nextcloud.",
+    "You need to set your user email before being able to send test emails." : "Pred preizkusnim pošiljanjem sporočil je treba nastaviti elektronski naslov uporabnika.",
+    "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "Obnovitev tega žetona lahko prepreči varnostno brisanje naprave, če se to še ni začelo.",
+    "Set as primary mail" : "Nastavi kot osnovni elektronski naslov",
+    "Change privacy level of email" : "Spremeni pravila zasebnosti za elektronski naslov",
+    "All languages" : "Vsi jeziki",
+    "Everyone" : "Vsi",
+    "An error occured during the request. Unable to proceed." : "Med izvajanjem zahteve je prišlo do napake, zato ni mogoče nadaljevati.",
+    "Test email settings" : "Preizkus nastavitev elektronske pošte",
+    "Please read carefully before activating server-side encryption: " : "Pred omogočanjem strežniškega šifriranja pozorno preberite opombe:",
+    "Enable encryption" : "Omogoči šifriranje",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Preseliti je treba šifrirne ključe iz starega sistema (ownCloud ≤ 8.0) na novega. Omogočite možnost »Privzeti šifrirni modul« in zaženite ukaz »occ encryption:migrate«.",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Preseliti je treba šifrirne ključe iz starega sistema (ownCloud <= 8.0) na novega.",
+    "Start migration" : "Začni selitev",
+    "Last job execution ran %s. Something seems wrong." : "Zadnji poskus izvedbe je bil izveden %s. Kaže, da je nekaj narobe.",
+    "Some jobs haven’t been executed since %s. Please consider increasing the execution frequency." : "Nekatera opravila niso bila izvedena od %s. Priporočljivo je povečati pogostost izvajanja.",
+    "Some jobs didn’t execute since %s. Please consider switching to system cron." : "Nekatera opravila niso bila izvedena od %s. Priporočljivo je preklopiti na sistemska opravila cron.",
+    "Last job ran %s." : "Zadnje opravilo je bilo izvedeno %s.",
+    "Background job didn’t run yet!" : "Ni bilo izvedenega še nobenega opravila v ozadju.",
+    "Pick background job setting" : "Izbor nastavitve ozadnjih opravil",
+    "Recommended" : "Priporočljivo",
+    "The cron.php needs to be executed by the system user \"%s\"." : "Datoteka cron.php mora biti izvedena za uporabnika »%s«.",
+    "days" : "dneh.",
+    "Allow username autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Dovoli samodejno dokončanje uporabniškega imena pri vpisu polnega imena ali elektronskega naslova (prezrta je zahteva telefonskega imenika in iste skupine).",
     "Change privacy level of profile picture" : "Spremeni pravila zasebnosti profilne slike",
     "Upload new" : "Pošlji novo",
     "Select from Files" : "Izbor iz datotek",
     "Remove image" : "Odstrani sliko",
-    "png or jpg, max. 20 MB" : "png ali jpg, največ. 20 MB",
-    "Picture provided by original account" : "Slika iz izvornega računa",
     "Choose as profile picture" : "Izberi kot sliko profila",
-    "You are a member of the following groups:" : "Omogočeno je članstvo v skupinah:",
     "You are using <strong>%s</strong>" : "Uporabljate <strong>%s</strong>",
     "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "V uporabi je <strong>%1$s</strong> od <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
+    "Change privacy level of full name" : "Spremeni pravila zasebnosti za polno ime",
+    "No display name set" : "Prikazno ime ni nastavljeno",
     "Change privacy level of phone number" : "Spremeni pravila zasebnosti za telefonsko številko",
-    "Your phone number" : "Osebna telefonska številka",
+    "Address" : "Naslov",
     "Change privacy level of address" : "Spremeni pravila zasebnosti za naslov",
     "Your postal address" : "Osebni poštni naslov",
     "Change privacy level of website" : "Spremeni pravila zasebnosti za spletno stran",
@@ -465,40 +476,13 @@ OC.L10N.register(
     "Link https://…" : "Povezava https:// …",
     "Change privacy level of Twitter profile" : "Spremeni pravila zasebnosti za profil Twitter",
     "Twitter handle @…" : "Twitter @ …",
-    "Locale" : "Jezikovne nastavitve",
-    "Current password" : "Trenutno geslo",
-    "New password" : "Novo geslo",
-    "Change password" : "Spremeni geslo",
-    "Use a second factor besides your password to increase security for your account." : "Ob geslu je priporočljivo uporabiti tudi drugo-stopenjsko overitev za večjo varnost računa.",
-    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Če uporabljate za povezavo z oblakom Nextcloud programe tretjih oseb, najprej ustvarite in nastavite gesla za vsak program, preden omogočite dvostopenjsko overitev.",
-    "Don't synchronize to servers" : "Ne usklajuj s strežniki",
-    "Trusted" : "Varni strežniki",
-    "Public" : "Javno",
-    "installing and updating apps via the app store or Federated Cloud Sharing" : "nameščanje in posodabljanje programov z uporabo programske zbirke ali zveznega oblaka",
-    "You need to set your user email before being able to send test emails." : "Pred preizkusnim pošiljanjem sporočil je treba nastaviti elektronski naslov uporabnika.",
-    "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "Obnovitev tega žetona lahko prepreči varnostno brisanje naprave, če se to še ni začelo.",
-    "Nextcloud iOS app" : "Program Nextcloud iOS",
-    "Nextcloud Android app" : "Program Nextcloud Android",
-    "Nextcloud Talk for iOS" : "Nextcloud Talk za iOS",
-    "Nextcloud Talk for Android" : "Nextcloud Talk za Android",
-    "Add user in group" : "Dodaj uporabnika v skupino",
-    "Close" : "Zapri",
-    "All languages" : "Vsi jeziki",
-    "Everyone" : "Vsi",
-    "The app will be downloaded from the app store" : "Program bo prejet iz zbirke programov",
-    "Error: This app can not be enabled because it makes the server unstable" : "Napaka: tega programa ni mogoče namestiti, ker povzroča nestabilnost strežnika.",
-    "mail" : "pošta",
-    "Test email settings" : "Preizkus nastavitev elektronske pošte",
-    "Expire after " : "Povezava naj preteče po",
-    "days" : "dneh.",
-    "Allow users to share via link" : "Uporabnikom dovoli omogočanje souporabe s povezavami",
-    "Set default expiration date for link shares" : "Nastavi privzeti datuma poteka za souporabo prek povezave",
-    "Allow username autocompletion in share dialog (if this is disabled the full username or email address needs to be entered)" : "Dovoli samodejno dokončanje uporabniškega imena pri določanju souporabe (sicer je treba vpisati celotno ime ali elektronski naslov).",
-    "Restrict username autocompletion to users within the same groups" : "Omeji samodejno dokončanje uporabniškega imena na uporabnike znotraj iste skupine",
-    "No display name set" : "Prikazno ime ni nastavljeno",
-    "For password reset and notifications" : "Za ponastavitev gesla in obveščanje",
-    "Change privacy level of full name" : "Spremeni pravila zasebnosti za polno ime",
-    "Change privacy level of email" : "Spremeni pravila zasebnosti za elektronski naslov",
-    "Set as primary mail" : "Nastavi kot osnovni elektronski naslov"
+    "Admin privileges" : "Dovoljenja skrbnika",
+    "Unable to update biography" : "Ni mogoče posodobiti biografije",
+    "Unable to update full name" : "Ni mogoče posodobiti polnega imena",
+    "No full name set" : "Ni nastavljenega polnega imena",
+    "Unable to update headline" : "Ni mogoče posodobiti naslova",
+    "Unable to update organisation" : "Ni mogoče posodobiti imena ustanove",
+    "Unable to update role" : "Ni mogoče posodobiti vloge",
+    "Avatar" : "Podoba"
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
