@@ -17,10 +17,6 @@ OC.L10N.register(
     "So-so password" : "Okej lösenord",
     "Good password" : "Bra lösenord",
     "Strong password" : "Starkt lösenord",
-    "An error occurred while changing your language. Please reload the page and try again." : "Ett fel inträffade när ditt språk ändrades. Vänligen uppdatera sidan och försök igen.",
-    "An error occurred while changing your locale. Please reload the page and try again." : "Ett fel inträffade när din språk ändrades. Vänligen uppdatera sidan och försök igen.",
-    "Select a profile picture" : "Välj en profilbild",
-    "Week starts on {fdow}" : "Veckan börjar med {fdow}",
     "Groups" : "Grupper",
     "Group list is empty" : "Grupplistan är tom",
     "Unable to retrieve the group list" : "Kan inte hämta grupplistan",
@@ -104,11 +100,12 @@ OC.L10N.register(
     "Personal" : "Privat",
     "Administration" : "Administration",
     "Additional settings" : "Övriga inställningar",
-    "Admin privileges" : "Adminprivilegier",
+    "Administration privileges" : "Administreringsprivilegier",
     "Groupware" : "Grupprogram",
     "Overview" : "Översikt",
     "Basic settings" : "Generella inställningar",
     "Sharing" : "Dela",
+    "Availability" : "Tillgänglighet",
     "Personal info" : "Personlig information",
     "Mobile & desktop" : "Mobil & skrivbord",
     "Email server" : "E-postserver",
@@ -116,7 +113,7 @@ OC.L10N.register(
     "Background jobs" : "Bakgrundsjobb",
     "Create" : "Skapa",
     "Change" : "Ändra",
-    "Delete" : "Ta bort",
+    "Delete" : "Radera",
     "Reshare" : "Dela vidare",
     "Unlimited" : "Obegränsat",
     "Verifying" : "Verifiera",
@@ -124,7 +121,6 @@ OC.L10N.register(
     "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Det finns några användarimporterade SSL-certifikat närvarande som inte längre används med Nextcloud 21. De kan importeras i kommandoraden via \"occ security:certificates:import\". Deras sökvägar inuti data-mappen visas nedanför.",
     "The old server-side-encryption format is enabled. We recommend disabling this." : "Det gamla krypteringsformatet på servern är aktiverat. Vi rekommenderar att du inaktiverar detta.",
     "Nextcloud settings" : "Nextcloud-inställningar",
-    "Administration privileges" : "Administreringsprivilegier",
     "Here you can decide which group can access certain sections of the administration settings." : "Här kan du bestämma vilken gruppen som har tillgång till vissa delar av administrationsinställningarna.",
     "None" : "Ingen",
     "Unable to modify setting" : "Kunde inte ändra inställning.",
@@ -222,11 +218,18 @@ OC.L10N.register(
     "Remove group" : "Ta bort grupp",
     "You are about to remove the group {group}. The users will NOT be deleted." : "Du håller på att ta bort gruppen {group}. Användarna kommer INTE att raderas.",
     "Please confirm the group removal " : "Bekräfta borttagning av gruppen",
+    "Current password" : "Nuvarande lösenord",
+    "New password" : "Nytt lösenord",
+    "Change password" : "Ändra lösenord",
+    "png or jpg, max. 20 MB" : "png eller jpg, max 20 MB",
+    "Picture provided by original account" : "Bild gjordes tillgänglig av orginalkonto",
+    "Cancel" : "Avbryt",
     "Your biography" : "Din biografi",
-    "Unable to update biography" : "Kunde inte uppdatera biografi",
+    "Details" : "Detaljer",
+    "You are a member of the following groups:" : "Du är medlem i följande grupper:",
+    "You are using <strong>{usage}</strong>" : "Du använder <strong>{usage}</strong>",
+    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Du använder <strong>{usage}</strong> av <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
     "Your full name" : "Ditt fullständiga namn",
-    "Unable to update full name" : "Kunde inte uppdatera fullständigt namn",
-    "No full name set" : "Inget fullständigt namn angivet",
     "Email options" : "E-postinställningar",
     "Primary email for password reset and notifications" : "Primär e-postadress för notifikationer och återställning av lösenord",
     "Remove primary email" : "Ta bort primär e-postadress",
@@ -244,20 +247,22 @@ OC.L10N.register(
     "No email address set" : "Ingen e-postadress angiven",
     "Additional emails" : "Ytterligare e-postadresser",
     "Your headline" : "Din rubrik",
-    "Unable to update headline" : "Kunde inte uppdatera rubrik",
     "Language" : "Språk",
     "Help translate" : "Hjälp till med översättningarna",
     "Unable to update language" : "Kunde inte uppdatera språk",
     "No language set" : "Inget språk angivet",
+    "Locale" : "Plats",
+    "Week starts on {firstDayOfWeek}" : "Veckan börjar med {firstDayOfWeek}",
     "Your organisation" : "Din organisation",
-    "Unable to update organisation" : "Kunde inte uppdatera organisation",
+    "Your phone number" : "Ditt telefonnummer",
     "Edit your Profile visibility" : "Ändra synligheten för din profil",
     "Enable Profile" : "Aktivera profil",
     "Unable to update profile enabled state" : "Kunde inte uppdatera profilaktivering",
     "{displayId}" : "{displayId}",
     "Unable to update visibility of {displayId}" : "Kunde inte uppdatera synlighet för {displayId}",
     "Your role" : "Din roll",
-    "Unable to update role" : "Kunde inte uppdatera roll",
+    "Your Twitter handle" : "Ditt Twitterkonto",
+    "Your website" : "Din webbsida",
     "Add" : "Lägg till",
     "You do not have permissions to see the details of this user" : "Du har inte behörighet att se detaljerna för den här användaren",
     "Add new password" : "Lägg till nytt lösenord",
@@ -273,7 +278,6 @@ OC.L10N.register(
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Om användaren förlorar sin enhet eller lämnar organisationen, kan all Nextcloud-data fjärrensas från alla enheter associerade med {userid}. Fungerar bara om enheterna är anslutna till internet.",
     "Remote wipe of devices" : "Fjärrensning av enheter",
     "Wipe {userid}'s devices" : "Rensa enheter för {userid}",
-    "Cancel" : "Avbryt",
     "Fully delete {userid}'s account including all their personal files, app data, etc." : "Fullständig radering av konto för {userid} inklusive alla personliga filer, appdata etc.",
     "Account deletion" : "Radering av konto",
     "Delete {userid}'s account" : "Ta bort konto för {userid}",
@@ -317,7 +321,6 @@ OC.L10N.register(
     "App bundles" : "App-paket",
     "Featured apps" : "Utvalda appar",
     "{license}-licensed" : "{license}-licensierad",
-    "Details" : "Detaljer",
     "Changelog" : "Ändringslogg",
     "by {author}\n{license}" : "av {author}\n{license}",
     "Enter group name" : "Ange gruppnamn",
@@ -335,8 +338,8 @@ OC.L10N.register(
     "Not saved" : "Inte sparad",
     "Sending…" : "Skickar...",
     "Email sent" : "E-post skickad",
-    "Address" : "Ort/Stad",
-    "Avatar" : "Avatar",
+    "Location" : "Plats",
+    "Profile picture" : "Profilbild",
     "About" : "Om",
     "Full name" : "Namn",
     "Additional email" : "Ytterligare e-postadress",
@@ -357,7 +360,6 @@ OC.L10N.register(
     "The app will be downloaded from the App Store" : "Appen kommer hämtas från appbutiken",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Den här appen är inte markerad som kompatibel med din Nextcloud-version. Om du fortsätter kan du fortfarande installera appen. Observera att appen kanske inte fungerar som förväntat.",
     "Never" : "Aldrig",
-    "An error occured during the request. Unable to proceed." : "Ett fel uppstod under förfrågan. Kan inte fortsätta.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Appen har aktiverats men måste uppdateras. Du kommer att omdirigeras till uppdateringssidan om 5 sekunder.",
     "Error: This app cannot be enabled because it makes the server unstable" : "Fel: Denna appen kan inte aktiveras eftersom den gör servern instabil",
     "Administrator documentation" : "Administratörsdokumentation",
@@ -425,34 +427,14 @@ OC.L10N.register(
     "Check out our blog" : "Kolla in vår blogg",
     "Subscribe to our newsletter" : "Prenumerera på vårt nyhetsbrev",
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Denna community-release av Nextcloud stöds inte och direktnotifikationer är inte tillgängliga.",
-    "Profile picture" : "Profilbild",
-    "Change privacy level of profile picture" : "Ändra hemlighetsnivå för profilbild",
-    "Upload new" : "Ladda upp ny",
-    "Select from Files" : "Välj från Filer",
-    "Remove image" : "Ta bort bild",
-    "png or jpg, max. 20 MB" : "png eller jpg, max 20 MB",
-    "Picture provided by original account" : "Bild gjordes tillgänglig av orginalkonto",
-    "Choose as profile picture" : "Välj som profilbild",
-    "You are a member of the following groups:" : "Du är medlem i följande grupper:",
-    "You are using <strong>%s</strong>" : "Du använder <strong>%s</strong>",
-    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Du använder <strong>%1$s</strong> av <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
-    "Change privacy level of phone number" : "Ända hemlighetsnivå för telefonnummer",
-    "Your phone number" : "Ditt telefonnummer",
-    "Change privacy level of address" : "Ända hemlighetsnivå för adress",
-    "Your postal address" : "Ort/Stad",
-    "Change privacy level of website" : "Ända hemlighetsnivå för hemsida",
-    "It can take up to 24 hours before the account is displayed as verified." : "Det kan ta upp till 24 timmar innan kontot visas som verifierat.",
-    "Link https://…" : "Länk https://...",
-    "Change privacy level of Twitter profile" : "Ända hemlighetsnivå för Twitterprofil",
-    "Twitter handle @…" : "Twitter handle @…",
-    "Locale" : "Plats",
-    "Current password" : "Nuvarande lösenord",
-    "New password" : "Nytt lösenord",
-    "Change password" : "Ändra lösenord",
     "Use a second factor besides your password to increase security for your account." : "Använd en andra faktor förutom ditt lösenord för att öka säkerheten för ditt konto.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Om du använder tredje-parts applikationer för att ansluta till Nextcloud vänligen skapa och konfigurera ett applösenord för varje innan två-faktor autentisering aktiveras.",
     "Migration in progress. Please wait until the migration is finished" : "Migration pågår. Vänta tills migrationen är klar",
     "Migration started …" : "Migrering påbörjad ...",
+    "An error occurred while changing your language. Please reload the page and try again." : "Ett fel inträffade när ditt språk ändrades. Vänligen uppdatera sidan och försök igen.",
+    "An error occurred while changing your locale. Please reload the page and try again." : "Ett fel inträffade när din språk ändrades. Vänligen uppdatera sidan och försök igen.",
+    "Select a profile picture" : "Välj en profilbild",
+    "Week starts on {fdow}" : "Veckan börjar med {fdow}",
     "Couldn't remove app." : "Kunde inte ta bort applikationen.",
     "Couldn't update app." : "Kunde inte uppdatera appen.",
     "Backend doesn't support password change, but the user's encryption key was updated." : "Backend stödjer inte att lösenord ändras men användarens krypteringsnyckel uppdaterades.",
@@ -463,6 +445,7 @@ OC.L10N.register(
     "Change privacy level of email" : "Ändra hemlighetsnivå för e-post",
     "All languages" : "Alla språk",
     "Everyone" : "Alla",
+    "An error occured during the request. Unable to proceed." : "Ett fel uppstod under förfrågan. Kan inte fortsätta.",
     "Test email settings" : "Testa e-postinställningar",
     "Please read carefully before activating server-side encryption: " : "Läs noga innan du aktiverar kryptering på serversidan: ",
     "Enable encryption" : "Aktivera kryptering",
@@ -479,7 +462,31 @@ OC.L10N.register(
     "The cron.php needs to be executed by the system user \"%s\"." : "Cron.php behöver exekveras av systemanvändaren \"%s\".",
     "days" : "dagar",
     "Allow username autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Tillåt komplettering av användarnamn vid ifyllning av fullständigt namn eller e-postadress (bortser från saknande matchning i telefonboken eller grupptillhörighet i samma grupp)",
+    "Change privacy level of profile picture" : "Ändra hemlighetsnivå för profilbild",
+    "Upload new" : "Ladda upp ny",
+    "Select from Files" : "Välj från Filer",
+    "Remove image" : "Ta bort bild",
+    "Choose as profile picture" : "Välj som profilbild",
+    "You are using <strong>%s</strong>" : "Du använder <strong>%s</strong>",
+    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Du använder <strong>%1$s</strong> av <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
     "Change privacy level of full name" : "Ändra hemlighetsnivå för helt namn",
-    "No display name set" : "Inget visningsnamn angivet"
+    "No display name set" : "Inget visningsnamn angivet",
+    "Change privacy level of phone number" : "Ända hemlighetsnivå för telefonnummer",
+    "Address" : "Ort/Stad",
+    "Change privacy level of address" : "Ända hemlighetsnivå för adress",
+    "Your postal address" : "Ort/Stad",
+    "Change privacy level of website" : "Ända hemlighetsnivå för hemsida",
+    "It can take up to 24 hours before the account is displayed as verified." : "Det kan ta upp till 24 timmar innan kontot visas som verifierat.",
+    "Link https://…" : "Länk https://...",
+    "Change privacy level of Twitter profile" : "Ända hemlighetsnivå för Twitterprofil",
+    "Twitter handle @…" : "Twitter handle @…",
+    "Admin privileges" : "Adminprivilegier",
+    "Unable to update biography" : "Kunde inte uppdatera biografi",
+    "Unable to update full name" : "Kunde inte uppdatera fullständigt namn",
+    "No full name set" : "Inget fullständigt namn angivet",
+    "Unable to update headline" : "Kunde inte uppdatera rubrik",
+    "Unable to update organisation" : "Kunde inte uppdatera organisation",
+    "Unable to update role" : "Kunde inte uppdatera roll",
+    "Avatar" : "Avatar"
 },
 "nplurals=2; plural=(n != 1);");
