@@ -121,6 +121,7 @@ OC.L10N.register(
     "Overview" : "Özet",
     "Basic settings" : "Temel ayarlar",
     "Sharing" : "Paylaşım",
+    "Availability" : "Kullanılabilirlik",
     "Personal info" : "Kişisel bilgiler",
     "Mobile & desktop" : "Mobil ve masaüstü",
     "Email server" : "E-posta sunucusu",
@@ -415,6 +416,7 @@ OC.L10N.register(
     "Website" : "Web sitesi",
     "Profile visibility" : "Profil görünürlüğü",
     "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Bu özellik, dosya paylaşımı ve takvim çağrıları gibi temel işlevler için gerekli olduğundan kullanılamıyor",
+    "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "Hesabınızda birleşik kullanım devre dışı bırakılmış olduğundan kullanılamıyor. Herhangi bir sorunuz varsa sistem yöneticinizle görüşün.",
     "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Kullanıcıya özel verilerin arama sunucusunda yayınlanmasına izin verilmediğinden kullanılamıyor. Herhangi bir sorunuz varsa sistem yöneticinizle görüşün.",
     "Show to everyone" : "Herkese görüntülensin",
     "Show to logged in users only" : "Yalnızca oturum açmış kullanıcılara görüntülensin",
