@@ -32,25 +32,25 @@ OC.L10N.register(
     "An administrator removed {user} from group {group}" : "Адміністратор вилучив {user} з групи {group}",
     "Your <strong>group memberships</strong> were modified" : "Параметри вашої <strong>участі в групі</strong> оновлено",
     "{actor} changed your password" : "{actor} змінив ваш пароль",
-    "You changed your password" : "Ви змінили свій пароль",
+    "You changed your password" : "Ви змінили пароль",
     "Your password was reset by an administrator" : "Ваш пароль був скинутий адміністратором",
     "Your password was reset" : "Ваш пароль скинуто",
     "{actor} changed your email address" : "{actor} змінив адресу вашої ел.пошти",
-    "You changed your email address" : "Ви змінили вашу email адресу",
+    "You changed your email address" : "Ви змінили ел.адресу",
     "Your email address was changed by an administrator" : "Ваша email адреса змінена адміністратором",
     "You created app password \"{token}\"" : "Ви створили пароль програми \"{token}\"",
     "An administrator created app password \"{token}\"" : "Адміністратор створив пароль програми \"{token}\"",
-    "You deleted app password \"{token}\"" : "Ви видалили пароль програми \"{token}\"",
+    "You deleted app password \"{token}\"" : "Ви вилучили пароль застосунку \"{token}\"",
     "You renamed app password \"{token}\" to \"{newToken}\"" : "Ви перейменували пароль програми \"{token}\" на \"{newToken}\"",
     "You granted filesystem access to app password \"{token}\"" : "Ви надали доступ до файлової системи паролю програми \"{token}\"",
     "You revoked filesystem access from app password \"{token}\"" : "Ви скасували доступ до файлової системи з паролем програми \"{token}\"",
     "Security" : "Безпека",
-    "You successfully logged in using two-factor authentication (%1$s)" : "Ви успішно увійшли, використовуючи двофакторну аутентифікацію (%1$s)",
-    "A login attempt using two-factor authentication failed (%1$s)" : "Помилка спроби входу в систему, використовуючи двофакторну аутентифікацію (%1$s)",
+    "You successfully logged in using two-factor authentication (%1$s)" : "Ви успішно увійшли з використанням двофакторної автентифікації (%1$s)",
+    "A login attempt using two-factor authentication failed (%1$s)" : "Помилка спроби входу в систему з використанням двофакторної автентифікації (%1$s)",
     "Remote wipe was started on %1$s" : "Розпочато віддалене стирання на %1$s",
     "Remote wipe has finished on %1$s" : "Віддалене стирання на %1$s завершено",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "Ваш <strong>пароль</strong> чи <strong>електронна пошта</strong> були змінені",
-    "Could not remove app." : "Не вдалося видалити додаток.",
+    "Could not remove app." : "Не вдалося вилучити застосунок.",
     "Could not update app." : "Не вдалося оновити програму.",
     "Wrong password" : "Неправильний пароль",
     "Unable to change personal password" : "Неможливо змінити особистий пароль",
@@ -121,6 +121,7 @@ OC.L10N.register(
     "Overview" : "Огляд",
     "Basic settings" : "Основні налаштування",
     "Sharing" : "Спільний доступ",
+    "Availability" : "Доступність",
     "Personal info" : "Особиста інформація",
     "Mobile & desktop" : "Смартфон та ноутбук",
     "Email server" : "Сервер електронної пошти",
@@ -163,25 +164,25 @@ OC.L10N.register(
     "Remove" : "Вилучити",
     "Disable" : "Вимкнути",
     "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Цій програмі не призначено мінімальної версії Nextcloud. Це буде помилка в майбутньому.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Цьому додатку не призначено максимальну версію Nextcloud. Це буде помилка в майбутньому.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Для цього застосунку не визначено найвищу версію Nextcloud. Це може викликати помилку в майбутньому.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Цей застосунок не буде встановлено, оскільки такі залежності неможливо виконати:",
     "View in store" : "Переглянути у крамниці застосунків",
     "Visit website" : "Перейти на вебсайт",
     "Report a bug" : "Повідомити про помилку",
     "User documentation" : "Користувацька документація",
     "Admin documentation" : "Документація адміністратора",
-    "Developer documentation" : "Документація для розробників",
+    "Developer documentation" : "Документація з розробки",
     "This app is supported via your current Nextcloud subscription." : "Підтримка застосунку через вашу поточну передплату Nextcloud.",
     "Supported" : "Підтримано",
     "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Пропоновані програми розробляються спільнотою та в її рамках. Вони пропонують центральну функціональність і готові до виробничого використання.",
     "Featured" : "Функціональні",
     "Update to {update}" : "Оновити до {update}",
-    "All apps are up-to-date." : "Усі додатки оновлені.",
+    "All apps are up-to-date." : "Усі застосунки оновлено",
     "Results from other categories" : "Результати з інших категорій",
     "No apps found for your version" : "Відсутні застосунки для вашої версії",
     "Disable all" : "Вимкнути все",
     "Enable all" : "Увімкнути все",
-    "_%n app has an update available_::_%n apps have an update available_" : ["Для %n застосунків доступне оновлення","Для %n застосунків доступні оновлення","Для %n застосунків доступні оновлення","Для %n застосунків доступні оновлення"],
+    "_%n app has an update available_::_%n apps have an update available_" : ["Для %n застосунку доступне оновлення","Для %n застосунків доступні оновлення","Для %n застосунків доступні оновлення","Для %n застосунків доступні оновлення"],
     "_Update_::_Update all_" : ["Оновити","Оновити все","Оновити все","Оновити все"],
     "Marked for remote wipe" : "Позначено для віддаленого стирання",
     "Device settings" : "Налаштування пристрою",
@@ -275,12 +276,12 @@ OC.L10N.register(
     "Choose your profile picture" : "Виберіть зображення профілю",
     "Please select a valid png or jpg file" : "Виберіть дійсний файл png або jpg",
     "Error setting profile picture" : "Помилка налаштування зображення профілю",
-    "Error cropping profile picture" : "Помилка обрізання зображення профілю",
+    "Error cropping profile picture" : "Помилка кадрування зображення профілю",
     "Error saving profile picture" : "Помилка збереження зображення профілю",
     "Error removing profile picture" : "Помилка видалення зображення профілю",
     "Your biography" : "Ваша біографія",
     "Details" : "Деталі",
-    "You are a member of the following groups:" : "Ви є членом наступних груп:",
+    "You are a member of the following groups:" : "Ви є учасником таких груп:",
     "You are using <strong>{usage}</strong>" : "Ви використовуєте <strong>{usage}",
     "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Ви використовуєте <strong>{usage}</strong> із <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
     "Your full name" : "Ваше повне ім'я",
@@ -315,7 +316,7 @@ OC.L10N.register(
     "Edit your Profile visibility" : "Відредагуйте видимість свого профілю",
     "Enable Profile" : "Увімкнути профіль",
     "Unable to update profile enabled state" : "Неможливо оновити стан профілю",
-    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "Більш обмежувальні налаштування видимості або обсягу дотримуються у вашому профілі. Наприклад, якщо для видимості встановлено значення «Показувати всім», а для області — «Приватне», значення «Приватне» буде прийнято.",
+    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "Для вашого профілю можна встановити певні обмеження з показу інформації про вас. Наприклад, якщо встановлено значення \"Показувати всім\", а для певного значення \"Приватне\", значення \"Приватне\" буде мати вищий пріоритет.",
     "{displayId}" : "{displayId}",
     "Unable to update visibility of {displayId}" : "Не вдалося оновити видимість {displayId}",
     "Your role" : "Ваша роль",
@@ -351,7 +352,7 @@ OC.L10N.register(
     "{size} used" : "{size} використано",
     "New user" : "Новий користувач",
     "Will be autogenerated" : "Буде створено автоматично",
-    "Display name" : "Ім'я для відображення",
+    "Display name" : "Ім'я для показу",
     "Email" : "E-mail",
     "Default language" : "Мова за замовчуванням",
     "Add a new user" : "Додати нового користувача",
@@ -416,12 +417,12 @@ OC.L10N.register(
     "Profile visibility" : "Видимість профілю",
     "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Недоступно, оскільки ця властивість необхідна для основних функцій, включаючи спільний доступ до файлів і запрошення в календарі",
     "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Недоступно, оскільки публікація даних користувача на пошуковому сервері заборонена. Зверніться до системного адміністратора, якщо у вас виникнуть запитання",
-    "Show to everyone" : "Показати всім",
+    "Show to everyone" : "Показувати всім",
     "Show to logged in users only" : "Показувати лише авторизованим користувачам",
     "Hide" : "Сховати",
     "Download and enable" : "Завантажити та увімкнути",
     "Enable untested app" : "Увімкнути непротестований застосунок",
-    "The app will be downloaded from the App Store" : "Додаток буде завантажено з App Store",
+    "The app will be downloaded from the App Store" : "Застосунок буде завантажено з App Store",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Відсутня інформація щодо підтримки цього застосунку вашою версією Nextcloud. Ви зможете встановити цей застосунок, проте він може працювати не так, як ви очікуєте.",
     "Never" : "Ніколи",
     "An error occurred during the request. Unable to proceed." : "Під час запиту сталася помилка. Неможливо продовжити.",
@@ -459,7 +460,7 @@ OC.L10N.register(
     "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Ще раз перевірте <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">посібники зі встановлення ↗</a> та перевірте, чи немає помилок чи попереджень у <a href=\"%2$s\">журналі</a>.",
     "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Перевірте безпеку вашого Nextcloud <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">скануванням безпеки ↗</a>.",
     "Version" : "Версія",
-    "You need to enable the File sharing App." : "Потрібно ввімкнути додаток для обміну файлами.",
+    "You need to enable the File sharing App." : "Потрібно увімкнути застосунок для обміну файлами.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Як адміністратор ви можете точно налаштувати поведінку спільного використання. Будь ласка, перегляньте документацію для отримання додаткової інформації.",
     "Allow apps to use the Share API" : "Дозволити застосункам використовувати API спільного доступу",
     "Set default expiration date for shares" : "Установіть термін дії акцій за умовчанням",
@@ -508,7 +509,7 @@ OC.L10N.register(
     "Backend doesn't support password change, but the user's encryption key was updated." : "Бекенд не підтримує зміну пароля, але ключ шифрування користувача був оновлений.",
     "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "Не вдалося визначити, чи TLS-версія cURL застаріла, оскільки сталася помилка під час запиту HTTPS до https://nextcloud.com. Будь ласка, перевірте файл журналу nextcloud для отримання додаткової інформації.",
     "You need to set your user email before being able to send test emails." : "Перед надсиланням тестових листів ви повинні вказати свою email адресу.",
-    "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "Відкликання цього маркера може запобігти видаленню вашого пристрою, якщо він ще не розпочав очищення.",
+    "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "Відкликання цього токена може запобігти стиранню даних на вашому пристрої, якщо процес стирання ще не було розпочато.",
     "Set as primary mail" : "Встановити як основну пошту",
     "Change privacy level of email" : "Змінити рівень конфіденційності електронної пошти",
     "All languages" : "Всі мови",
@@ -540,7 +541,7 @@ OC.L10N.register(
     "You are using <strong>%s</strong>" : "Ви використовуєте <strong>%s</strong>",
     "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Ви використовуєте <strong>%1$s</strong> з <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
     "Change privacy level of full name" : "Змінити рівень конфіденційності повного імені",
-    "No display name set" : "Ім'я для відображення не вказано",
+    "No display name set" : "Ім'я для показу не встановлено",
     "Change privacy level of phone number" : "Змінити рівень конфіденційності номера телефону",
     "Address" : "Адреса",
     "Change privacy level of address" : "Змінити рівень конфіденційності адреси",
