@@ -121,6 +121,7 @@ OC.L10N.register(
     "Overview" : "概覽",
     "Basic settings" : "基本設定",
     "Sharing" : "分享",
+    "Availability" : "可用性",
     "Personal info" : "個人資訊",
     "Mobile & desktop" : "行動裝置及桌面",
     "Email server" : "電子郵件伺服器",
@@ -415,6 +416,7 @@ OC.L10N.register(
     "Website" : "網站",
     "Profile visibility" : "個人資料能見度",
     "Not available as this property is required for core functionality including file sharing and calendar invitations" : "無法使用，因為此屬性是核心功能（包括檔案分享和日曆邀請）所必需的。",
+    "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "因為您的帳號已停用聯盟分享，因此不可用，若您有任何問題，請聯絡您的系統管理員",
     "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "無法使用，因為不允許將使用者的特定資料發佈到查詢伺服器，若您有任何問題，請聯絡您的系統管理員",
     "Show to everyone" : "對所有人顯示",
     "Show to logged in users only" : "僅對已登入的使用者顯示",
