@@ -1,12 +1,6 @@
 OC.L10N.register(
     "theming",
     {
-    "Loading preview…" : "Načítání náhledu…",
-    "Admin" : "Správa",
-    "Saved" : "Uloženo",
-    "a safe home for all your data" : "bezpečný domov pro všechna vaše data",
-    "Error uploading the file" : "Chyba při nahrávání souboru",
-    "Name cannot be empty" : "Je třeba zadat název",
     "The given name is too long" : "Zadaný název je příliš dlouhý",
     "The given web address is too long" : "Zadaná webová adresa je příliš dlouhá",
     "The given web address is not a valid URL" : "Zadaná webová adresa není platné URL",
@@ -16,6 +10,8 @@ OC.L10N.register(
     "The given privacy policy address is not a valid URL" : "Daná adresa prohlášení o ochraně soukromí není platné URL",
     "The given slogan is too long" : "Daný slogan je příliš dlouhý",
     "The given color is invalid" : "Daná barva není platná",
+    "Disable-user-theming should be true or false" : "Volba „Vypnout opatřování vzhledem uživateli“ by měla být ano nebo ne",
+    "Saved" : "Uloženo",
     "The file was uploaded" : "Soubor byl nahrán",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Velikost nahrávaného souboru překračuje limit nastavení direktivou upload_max_filesize v php.ini",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Velikost nahrávaného souboru překračuje nastavení MAX_FILE_SIZE, která byla zadána v HTML formuláři",
@@ -25,6 +21,8 @@ OC.L10N.register(
     "Could not write file to disk" : "Soubor se nedaří zapsat na datové úložiště",
     "A PHP extension stopped the file upload" : "PHP rozšíření zastavilo nahrávání souboru",
     "No file uploaded" : "Nenahrán žádný soubor",
+    "Cleanup old theming cache" : "Čištění staré mezipaměti opatřování vzhledem",
+    "Failed to delete folder: \"%1$s\", error: %2$s" : "Nepodařilo se smazat složku: „%1$s“, chyba: %2$s",
     "You are already using a custom theme. Theming app settings might be overwritten by that." : "Už používáte svůj vlastní motiv vzhledu. Nastavení aplikace pro změnu motivu vzhledu tím mohou být přepsána.",
     "Theming" : "Motiv vzhledu",
     "Appearance and accessibility" : "Vzhled a zpřístupnění",
@@ -49,38 +47,53 @@ OC.L10N.register(
     "Legal notice" : "Právní upozornění",
     "Privacy policy" : "Zásady ochrany soukromí",
     "Adjust the Nextcloud theme" : "Upravit motiv vzhledu Nextcloud",
-    "Keyboard shortcuts" : "Klávesové zkratky",
-    "In some cases keyboard shortcuts can interfer with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "V některých případech klávesové zkratky kolidují s nástroji pro zpřístupnění. Aby bylo zajištěno správné zaměřování vámi využívaného nástroje, je zde možné vypnout veškeré klávesové zkratky pro Nextcloud. Toto také vypne veškeré zkratky, které jsou k dispozici v aplikacích.",
-    "Disable all keyboard shortcuts" : "Vypnout veškeré klávesové zkratky",
-    "Background" : "Pozadí",
-    "Set a custom background" : "Nastavit uživatelsky určené pozadí",
-    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Přístupnost pro všechny je pro nás velmi důležitá. Splňujeme webové standardy a zajišťujeme, aby všechno bylo použitelné i bez myši a s asistenčním software, jako například čtečkami obrazovky. Máme za cíl být v souladu s doporučeními {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 na úrovni AA, při použití motivu vzhledu s vysokým kontrastem dokonce na úrovni AAA.",
-    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Pokud naleznete jakékoli problémy, neváhejte s jejich nahlášením do {issuetracker}našeho systému pro správu hlášení{linkend}. A pokud se chcete zapojit, přidejte se k {designteam}týmu našich designérů{linkend}!",
-    "Pick from Files" : "Vybrat ze souborů",
-    "Default image" : "Výchozí obrázek",
-    "Plain background" : "Jednolité pozadí",
-    "Insert from {productName}" : "Vložit z {productName}",
-    "Theme selection is enforced" : "Výběr motivu vzhledu je vynucen",
-    "Open documentation" : "Otevřít dokumentaci",
     "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Motivy umožňují jednoduše přizpůsobit vzhled a dojem z vaší instance a podporovaných klientů. Projeví se všem uživatelům.",
+    "Advanced options" : "Pokročilé předvolby",
+    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Nainstalujte rozšíření ImageMagick PHP s podporou obrázků SVG, které automaticky vytváří favicon na základě nahraného loga a barvy.",
     "Name" : "Název",
-    "Reset to default" : "Vrátit zpět na výchozí hodnoty",
     "Web link" : "Webový odkaz",
-    "https://…" : "https://…",
+    "a safe home for all your data" : "bezpečný domov pro všechna vaše data",
     "Slogan" : "Slogan",
     "Color" : "Barva",
     "Logo" : "Logo",
     "Upload new logo" : "Nahrát nové logo",
-    "Login image" : "Přihlašovací obrázek",
-    "Upload new login background" : "Nahrát nové pozadí pro přihlašovací obrazovku",
-    "Remove background image" : "Odebrat obrázek z pozadí",
-    "Advanced options" : "Pokročilé předvolby",
+    "Background and login image" : "Obrázek na pozadí a přihlašovací obrazovce",
+    "Upload new background and login image" : "Nahrát nový obrázek na pozadí a přihlašovací obrazovku",
     "Legal notice link" : "Odkaz na právní upozornění",
     "Privacy policy link" : "Odkaz na zásady ochrany osobních údajů",
     "Header logo" : "Logo pro záhlaví",
     "Upload new header logo" : "Nahrát nové logo pro záhlaví",
     "Favicon" : "ikona webu",
     "Upload new favicon" : "Nahrát novou ikonu webu",
-    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Nainstalujte rozšíření Imagemagick PHP s podporou obrázků SVG, které automaticky vytváří favicon na základě nahraného loga a barvy."
+    "User settings" : "Nastavení pro uživatele",
+    "Disable user theming" : "Vypnout opatřování vzhledem uživateli",
+    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Ačkoli je možné vybrat a přizpůsobit si svou instanci, uživatelé si mohou změnit pozadí a barvy. Pokud chcete vámi nastavené přizpůsobení vynutit, můžete toto zapnout.",
+    "Keyboard shortcuts" : "Klávesové zkratky",
+    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "V některých případech mohou klávesové zkratky kolidovat s těmi v rámci nástrojů pro zpřístupnění. Aby tyto nástroje fungovaly správně, je možné zde vypnout veškeré klávesové zkratky pro Nextcloud. Toto také vypne veškeré klávesové zkratky v Nextcloud aplikacích.",
+    "Disable all keyboard shortcuts" : "Vypnout veškeré klávesové zkratky",
+    "Background" : "Pozadí",
+    "Customization has been disabled by your administrator" : "Přizpůsobení si bylo vypnuto správcem",
+    "Set a custom background" : "Nastavit uživatelsky určené pozadí",
+    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Přístupnost pro všechny je pro nás velmi důležitá. Splňujeme webové standardy a zajišťujeme, aby všechno bylo použitelné i bez myši a s asistenčním software, jako například čtečkami obrazovky. Máme za cíl být v souladu s doporučeními {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 na úrovni AA, při použití motivu vzhledu s vysokým kontrastem dokonce na úrovni AAA.",
+    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Pokud naleznete jakékoli problémy, neváhejte s jejich nahlášením do {issuetracker}našeho systému pro správu hlášení{linkend}. A pokud se chcete zapojit, přidejte se k {designteam}týmu našich designérů{linkend}!",
+    "Pick from Files" : "Vybrat ze souborů",
+    "Default image" : "Výchozí obrázek",
+    "Custom color" : "Uživatelsky určená barva",
+    "Plain background" : "Jednolité pozadí",
+    "Insert from {productName}" : "Vložit z {productName}",
+    "Theme selection is enforced" : "Výběr motivu vzhledu je vynucen",
+    "Select a custom color" : "Vybrat uživatelsky určenou barvu",
+    "Reset to default" : "Vrátit zpět na výchozí hodnoty",
+    "Upload" : "Nahrávání",
+    "Remove background image" : "Odebrat obrázek z pozadí",
+    "Loading preview…" : "Načítání náhledu…",
+    "Admin" : "Správa",
+    "Name cannot be empty" : "Je třeba zadat název",
+    "Open documentation" : "Otevřít dokumentaci",
+    "https://…" : "https://…",
+    "Login image" : "Přihlašovací obrázek",
+    "Upload new login background" : "Nahrát nové pozadí pro přihlašovací obrazovku",
+    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Nainstalujte rozšíření Imagemagick PHP s podporou obrázků SVG, které automaticky vytváří favicon na základě nahraného loga a barvy.",
+    "Error uploading the file" : "Chyba při nahrávání souboru"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
