@@ -1,17 +1,16 @@
 OC.L10N.register(
     "theming",
     {
-    "Loading preview…" : "Loading preview…",
-    "Saved" : "Saved",
-    "Admin" : "Admin",
-    "a safe home for all your data" : "a safe home for all your data",
-    "Name cannot be empty" : "Name cannot be empty",
     "The given name is too long" : "The given name is too long",
     "The given web address is too long" : "The given web address is too long",
+    "The given web address is not a valid URL" : "The given web address is not a valid URL",
     "The given legal notice address is too long" : "The given legal notice address is too long",
+    "The given legal notice address is not a valid URL" : "The given legal notice address is not a valid URL",
     "The given privacy policy address is too long" : "The given privacy policy address is too long",
+    "The given privacy policy address is not a valid URL" : "The given privacy policy address is not a valid URL",
     "The given slogan is too long" : "The given slogan is too long",
     "The given color is invalid" : "The given colour is invalid",
+    "Saved" : "Saved",
     "The file was uploaded" : "The file was uploaded",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "The uploaded file exceeds the upload_max_filesize directive in php.ini",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form",
@@ -21,31 +20,48 @@ OC.L10N.register(
     "Could not write file to disk" : "Could not write file to disk",
     "A PHP extension stopped the file upload" : "A PHP extension stopped the file upload",
     "No file uploaded" : "No file uploaded",
-    "Unsupported image type" : "Unsupported image type",
     "You are already using a custom theme. Theming app settings might be overwritten by that." : "You are already using a custom theme. Theming app settings might be overwritten by that.",
     "Theming" : "Theming",
+    "Dark theme" : "Dark theme",
+    "Enable dark theme" : "Enable dark theme",
+    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "A dark theme that is soothing for your eyes (by reducing the overall luminosity and brightness).",
+    "Dyslexia font" : "Dyslexia font",
+    "Enable dyslexia font" : "Enable dyslexia font",
+    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia.",
+    "High contrast mode" : "High contrast mode",
+    "Enable high contrast mode" : "Enable high contrast mode",
+    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased.",
     "Legal notice" : "Legal notice",
     "Privacy policy" : "Privacy policy",
     "Adjust the Nextcloud theme" : "Adjust the Nextcloud theme",
     "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Theming makes it possible to easily customise the look and feel of your instance and supported clients. This will be visible for all users.",
+    "Advanced options" : "Advanced options",
     "Name" : "Name",
-    "Reset to default" : "Reset to default",
     "Web link" : "Web link",
-    "https://…" : "https://…",
+    "a safe home for all your data" : "a safe home for all your data",
     "Slogan" : "Slogan",
     "Color" : "Colour",
     "Logo" : "Logo",
     "Upload new logo" : "Upload new logo",
-    "Login image" : "Login image",
-    "Upload new login background" : "Upload new login background",
-    "Remove background image" : "Remove background image",
-    "Advanced options" : "Advanced options",
     "Legal notice link" : "Legal notice link",
     "Privacy policy link" : "Privacy policy link",
     "Header logo" : "Header logo",
     "Upload new header logo" : "Upload new header logo",
     "Favicon" : "Favicon",
     "Upload new favicon" : "Upload new favicon",
+    "Keyboard shortcuts" : "Keyboard shortcuts",
+    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level.",
+    "Custom color" : "Custom colour",
+    "Reset to default" : "Reset to default",
+    "Upload" : "Upload",
+    "Remove background image" : "Remove background image",
+    "Loading preview…" : "Loading preview…",
+    "Admin" : "Admin",
+    "Name cannot be empty" : "Name cannot be empty",
+    "Open documentation" : "Open documentation",
+    "https://…" : "https://…",
+    "Login image" : "Login image",
+    "Upload new login background" : "Upload new login background",
     "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color."
 },
 "nplurals=2; plural=(n != 1);");
