@@ -1,11 +1,6 @@
 OC.L10N.register(
     "theming",
     {
-    "Loading preview…" : "Cargando previsualización...",
-    "Admin" : "Administración",
-    "Saved" : "Guardado",
-    "a safe home for all your data" : "un hogar seguro para todos tus datos",
-    "Name cannot be empty" : "El nombre no puede estar vacío",
     "The given name is too long" : "El nombre provisto es demasiado largo",
     "The given web address is too long" : "La dirección web es demasiado larga",
     "The given web address is not a valid URL" : "La dirección web indicada no es una URL válida",
@@ -15,6 +10,8 @@ OC.L10N.register(
     "The given privacy policy address is not a valid URL" : "La directive de privacidad indicada no es una URL válida",
     "The given slogan is too long" : "El eslogan provisto es demasiado largo",
     "The given color is invalid" : "El color provisto es inválido",
+    "Disable-user-theming should be true or false" : "Deshabilitar-tematización-de-usuario debe ser verdadero o falso",
+    "Saved" : "Guardado",
     "The file was uploaded" : "Se ha subido el archivo",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El archivo para subir excede la directiva upload_max_filesize en php.ini",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo para subir excede la directiva MAX_FILE_SIZE que se especificó en el formulario HTML",
@@ -24,6 +21,8 @@ OC.L10N.register(
     "Could not write file to disk" : "No se puede escribir el archivo en el disco",
     "A PHP extension stopped the file upload" : "Una extensión PHP ha cancelado la subida de archivos",
     "No file uploaded" : "No se ha subido archivo",
+    "Cleanup old theming cache" : "Borrar el caché antiguo de tematización",
+    "Failed to delete folder: \"%1$s\", error: %2$s" : "Fallo al eliminar la carpeta: \"%1$s\", error: %2$s",
     "You are already using a custom theme. Theming app settings might be overwritten by that." : "Ya estás usando un tema personalizado. La configuración de la aplicación de temas puede ser sobrescrita por el.",
     "Theming" : "Tema",
     "Appearance and accessibility" : "Apariencia y accesibilidad",
@@ -48,34 +47,53 @@ OC.L10N.register(
     "Legal notice" : "Aviso legal",
     "Privacy policy" : "Política de privacidad",
     "Adjust the Nextcloud theme" : "Ajusta el tema de Nextcloud",
-    "Keyboard shortcuts" : "Atajos de teclado",
-    "Background" : "Imagen de fondo",
-    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "El acceso universal es muy importante para nosotros. Seguimos los estándares web y verificamos que todo es manejable sin ratón y con software de asistencia, como un lector de pantalla. Nuestro objetivo es cumplir con las {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 en nivel AA y, con el tema de alto contraste, en nivel AAA.",
-    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Si encuentras cualquier problema, no dudes en informar de ellos en {issuetracker}nuestro tracker de problas{linkend}. Y si quieres involucrarte, ¡puedes unirte a {designteam}nuestro equipo de diseño{linkend}!",
-    "Pick from Files" : "Elegir de Archivos",
-    "Plain background" : "Fondo liso",
-    "Insert from {productName}" : "Insertar desde {productName}",
-    "Theme selection is enforced" : "La selección del tema es forzada",
-    "Open documentation" : "Abrir la documentación",
     "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Los temas hacen posible personalizar fácilmente la apariencia de tu instancia y los clientes soportados. Esto será visible para todos los usuarios.",
+    "Advanced options" : "Opciones avanzadas",
+    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instale la extensión PHP ImageMagick con soporte a imágenes SVG para generar automáticamente favicons basados en el logo cargado y el color.",
     "Name" : "Nombre",
-    "Reset to default" : "Vovler a configuración por defecto",
     "Web link" : "Enlace web",
-    "https://…" : "https://…",
+    "a safe home for all your data" : "un hogar seguro para todos tus datos",
     "Slogan" : "Eslogan",
     "Color" : "Color",
     "Logo" : "Logo",
     "Upload new logo" : "Subir nuevo logo",
-    "Login image" : "Imagen de fondo para el inicio de sesión",
-    "Upload new login background" : "Subir una nueva imagen de fondo para inicio de sesión",
-    "Remove background image" : "Eliminar imagen de fondo",
-    "Advanced options" : "Opciones avanzadas",
+    "Background and login image" : "Imágen de fondo y de ingreso",
+    "Upload new background and login image" : "Cargar una nueva imagen de fondo y de ingreso",
     "Legal notice link" : "Enlace al aviso legal",
     "Privacy policy link" : "Enlace a la política de privacidad",
     "Header logo" : "Logo de la cabecera",
     "Upload new header logo" : "Subir nuevo logo de la cabecera",
     "Favicon" : "Favicon",
     "Upload new favicon" : "Subir nuevo favicon",
-    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instala la extensión de PHP Imagemagick con soporte para imágenes SVG para generar automáticamente faviconos basados en el logo y color subidos."
+    "User settings" : "Configuración de usuario",
+    "Disable user theming" : "Deshabilitar tematización de usuario",
+    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Aunque puede seleccionar y personalizar su instancia, los usuarios pueden cambiar su fondo y colores. Si quiere forzar su personalización, puede activar esto.",
+    "Keyboard shortcuts" : "Atajos de teclado",
+    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "En algunos casos, los atajos de teclado pueden interferir con las herramientas de accesibilidad. De manera de permitir enfocar correctamente su herramienta, puede deshabilitar todos los atajos de teclado aquí. Esto también deshabilitará todos los atajos disponibles en las aplicaciones.",
+    "Disable all keyboard shortcuts" : "Deshabilitar todos los atajos de teclado",
+    "Background" : "Imagen de fondo",
+    "Customization has been disabled by your administrator" : "La personalización ha sido deshabilitada por el administrador",
+    "Set a custom background" : "Establecer un fondo personalizado",
+    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "El acceso universal es muy importante para nosotros. Seguimos los estándares web y verificamos que todo es manejable sin ratón y con software de asistencia, como un lector de pantalla. Nuestro objetivo es cumplir con las {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 en nivel AA y, con el tema de alto contraste, en nivel AAA.",
+    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Si encuentras cualquier problema, no dudes en informar de ellos en {issuetracker}nuestro tracker de problas{linkend}. Y si quieres involucrarte, ¡puedes unirte a {designteam}nuestro equipo de diseño{linkend}!",
+    "Pick from Files" : "Elegir de Archivos",
+    "Default image" : "Imagen predeterminada",
+    "Custom color" : "Colores personalizados",
+    "Plain background" : "Fondo liso",
+    "Insert from {productName}" : "Insertar desde {productName}",
+    "Theme selection is enforced" : "La selección del tema es forzada",
+    "Select a custom color" : "Seleccionar un color personalizado",
+    "Reset to default" : "Vovler a configuración por defecto",
+    "Upload" : "Subir",
+    "Remove background image" : "Eliminar imagen de fondo",
+    "Loading preview…" : "Cargando previsualización...",
+    "Admin" : "Administración",
+    "Name cannot be empty" : "El nombre no puede estar vacío",
+    "Open documentation" : "Abrir la documentación",
+    "https://…" : "https://…",
+    "Login image" : "Imagen de fondo para el inicio de sesión",
+    "Upload new login background" : "Subir una nueva imagen de fondo para inicio de sesión",
+    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instala la extensión de PHP Imagemagick con soporte para imágenes SVG para generar automáticamente faviconos basados en el logo y color subidos.",
+    "Error uploading the file" : "Error al subir el archivo"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
