@@ -1,12 +1,6 @@
 OC.L10N.register(
     "theming",
     {
-    "Loading preview…" : "Wczytywanie podglądu…",
-    "Admin" : "Administrator",
-    "Saved" : "Zapisano",
-    "a safe home for all your data" : "bezpieczny dom dla wszystkich danych",
-    "Error uploading the file" : "Błąd podczas wysyłania pliku",
-    "Name cannot be empty" : "Nazwa nie może być pusta",
     "The given name is too long" : "Podana nazwa jest za długa",
     "The given web address is too long" : "Podany adres internetowy jest za długi",
     "The given web address is not a valid URL" : "Podany adres internetowy nie jest prawidłowym adresem URL",
@@ -16,6 +10,8 @@ OC.L10N.register(
     "The given privacy policy address is not a valid URL" : "Podany adres polityki prywatności nie jest prawidłowym adresem URL",
     "The given slogan is too long" : "Podany slogan jest za długi",
     "The given color is invalid" : "Podany kolor jest nieprawidłowy",
+    "Disable-user-theming should be true or false" : "Opcja Wyłącz użytkownika powinna mieć wartość true lub false",
+    "Saved" : "Zapisano",
     "The file was uploaded" : "Plik został wysłany",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Wysłany plik przekracza wartość upload_max_filesize zdefiniowaną w php.ini",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Wysłany plik przekracza wartość MAX_FILE_SIZE określoną w formularzu HTML",
@@ -25,6 +21,8 @@ OC.L10N.register(
     "Could not write file to disk" : "Nie można zapisać pliku na dysk",
     "A PHP extension stopped the file upload" : "Rozszerzenie PHP zatrzymało wysyłanie pliku",
     "No file uploaded" : "Nie wysłano pliku",
+    "Cleanup old theming cache" : "Wyczyść starą pamięć podręczną motywów",
+    "Failed to delete folder: \"%1$s\", error: %2$s" : "Nie udało się usunąć katalogu: \"%1$s\", błąd: %2$s",
     "You are already using a custom theme. Theming app settings might be overwritten by that." : "Używasz już własnego motywu. Ustawienia aplikacji Theming mogą zostać nadpisane.",
     "Theming" : "Motyw",
     "Appearance and accessibility" : "Wygląd i dostępność",
@@ -49,38 +47,53 @@ OC.L10N.register(
     "Legal notice" : "Nota prawna",
     "Privacy policy" : "Polityka prywatności",
     "Adjust the Nextcloud theme" : "Dostosuj motyw Nextcloud",
-    "Keyboard shortcuts" : "Skróty klawiaturowe",
-    "In some cases keyboard shortcuts can interfer with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "W niektórych przypadkach skróty klawiaturowe mogą kolidować z narzędziami ułatwień dostępu. Aby umożliwić prawidłowe skupienie się na narzędziu, możesz tutaj wyłączyć wszystkie skróty klawiaturowe. Spowoduje to również wyłączenie wszystkich dostępnych skrótów w aplikacjach.",
-    "Disable all keyboard shortcuts" : "Wyłącz wszystkie skróty klawiaturowe",
-    "Background" : "Tło",
-    "Set a custom background" : "Ustaw niestandardowe tło",
-    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Uniwersalny dostęp jest dla nas bardzo ważny. Przestrzegamy standardów internetowych i sprawdzamy, aby wszystko było użyteczne również bez myszy i oprogramowania pomocniczego, takiego jak czytniki ekranu. Naszym celem jest zgodność z {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 na poziomie AA, z motywem o wysokim kontraście nawet na poziomie AAA.",
-    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Jeśli znajdziesz jakieś problemy, nie wahaj się zgłosić je na {issuetracker}listę błędów{linkend}. A jeśli chcesz się zaangażować, dołącz do {designteam}naszego zespołu projektowego{linkend}!",
-    "Pick from Files" : "Wybierz z Plików",
-    "Default image" : "Obraz domyślny",
-    "Plain background" : "Zwykłe tło",
-    "Insert from {productName}" : "Wstaw z {productName}",
-    "Theme selection is enforced" : "Wybór motywu jest wymuszony",
-    "Open documentation" : "Otwórz dokumentację",
     "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Motyw umożliwia na łatwą personalizację wyglądu instancji i wspieranych klientów. Ustawiony wygląd będzie widoczny dla wszystkich użytkowników.",
+    "Advanced options" : "Opcje zaawansowane",
+    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Zainstaluj rozszerzenie ImageMagick PHP z obsługą obrazów SVG, aby automatycznie generować favikony na podstawie przesłanego logo i koloru.",
     "Name" : "Nazwa",
-    "Reset to default" : "Przywróć domyślne",
     "Web link" : "Link",
-    "https://…" : "https://…",
+    "a safe home for all your data" : "bezpieczny dom dla wszystkich danych",
     "Slogan" : "Slogan",
     "Color" : "Kolor",
     "Logo" : "Logo",
     "Upload new logo" : "Wyślij nowe logo",
-    "Login image" : "Obraz logowania",
-    "Upload new login background" : "Wyślij nowe tło logowania",
-    "Remove background image" : "Usuń obraz tła",
-    "Advanced options" : "Opcje zaawansowane",
+    "Background and login image" : "Obraz tła i logowania",
+    "Upload new background and login image" : "Wyślij nowe tło i obraz logowania",
     "Legal notice link" : "Link do informacji prawnej",
     "Privacy policy link" : "Link do polityki prywatności",
     "Header logo" : "Logo nagłówka",
     "Upload new header logo" : "Wyślij nowe logo nagłówka",
     "Favicon" : "Ikona favicon",
     "Upload new favicon" : "Wyślij nową ikonę favicon",
-    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Zainstaluj rozszerzenie Imagemagick PHP z obsługą obrazów SVG, aby automatycznie generować favicony w oparciu o wysłane logo i kolor."
+    "User settings" : "Ustawienia użytkownika",
+    "Disable user theming" : "Wyłącz motywy użytkownika",
+    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Chociaż możesz wybrać i dostosować swoją instancję, użytkownicy mogą zmieniać swoje tło i kolory. Jeśli chcesz wymusić dostosowanie, możesz to włączyć.",
+    "Keyboard shortcuts" : "Skróty klawiaturowe",
+    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "W niektórych przypadkach skróty klawiaturowe mogą kolidować z narzędziami ułatwień dostępu. Aby umożliwić prawidłowe skupienie się na narzędziu, możesz tutaj wyłączyć wszystkie skróty klawiaturowe. Spowoduje to również wyłączenie wszystkich dostępnych skrótów w aplikacjach.",
+    "Disable all keyboard shortcuts" : "Wyłącz wszystkie skróty klawiaturowe",
+    "Background" : "Tło",
+    "Customization has been disabled by your administrator" : "Dostosowanie zostało wyłączone przez administratora",
+    "Set a custom background" : "Ustaw niestandardowe tło",
+    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Uniwersalny dostęp jest dla nas bardzo ważny. Przestrzegamy standardów internetowych i sprawdzamy, aby wszystko było użyteczne również bez myszy i oprogramowania pomocniczego, takiego jak czytniki ekranu. Naszym celem jest zgodność z {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 na poziomie AA, z motywem o wysokim kontraście nawet na poziomie AAA.",
+    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Jeśli znajdziesz jakieś problemy, nie wahaj się zgłosić je na {issuetracker}listę błędów{linkend}. A jeśli chcesz się zaangażować, dołącz do {designteam}naszego zespołu projektowego{linkend}!",
+    "Pick from Files" : "Wybierz z Plików",
+    "Default image" : "Obraz domyślny",
+    "Custom color" : "Kolor niestandardowy",
+    "Plain background" : "Zwykłe tło",
+    "Insert from {productName}" : "Wstaw z {productName}",
+    "Theme selection is enforced" : "Wybór motywu jest wymuszony",
+    "Select a custom color" : "Wybierz kolor niestandardowy",
+    "Reset to default" : "Przywróć domyślne",
+    "Upload" : "Wyślij",
+    "Remove background image" : "Usuń obraz tła",
+    "Loading preview…" : "Wczytywanie podglądu…",
+    "Admin" : "Administrator",
+    "Name cannot be empty" : "Nazwa nie może być pusta",
+    "Open documentation" : "Otwórz dokumentację",
+    "https://…" : "https://…",
+    "Login image" : "Obraz logowania",
+    "Upload new login background" : "Wyślij nowe tło logowania",
+    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Zainstaluj rozszerzenie Imagemagick PHP z obsługą obrazów SVG, aby automatycznie generować favicony w oparciu o wysłane logo i kolor.",
+    "Error uploading the file" : "Błąd podczas wysyłania pliku"
 },
 "nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
