@@ -1,11 +1,6 @@
 OC.L10N.register(
     "theming",
     {
-    "Loading preview…" : "Загружается предпросмотр…",
-    "Saved" : "Сохранено",
-    "Admin" : "Администратор",
-    "a safe home for all your data" : "надёжный дом для всех ваших данных",
-    "Name cannot be empty" : "Имя не может быть пустым",
     "The given name is too long" : "Указанное название слишком длинное",
     "The given web address is too long" : "Указанный веб-адрес слишком длинный",
     "The given web address is not a valid URL" : "Указанный веб-адрес не является действительным URL",
@@ -15,6 +10,7 @@ OC.L10N.register(
     "The given privacy policy address is not a valid URL" : "Указанный адрес политики конфиденциальности не является действительным URL",
     "The given slogan is too long" : "Указанный слоган слишком длинный",
     "The given color is invalid" : "Задан неправильный цвет",
+    "Saved" : "Сохранено",
     "The file was uploaded" : "Файл был загружен",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Размер переданного файла превышает установленный предел upload_max_filesize в php.ini:",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Размер переданного файла превышает установленный предел MAX_FILE_SIZE в HTML-форме",
@@ -23,32 +19,54 @@ OC.L10N.register(
     "Missing a temporary folder" : "Отсутствует временный каталог",
     "Could not write file to disk" : "Невозможно записать файл на диск",
     "A PHP extension stopped the file upload" : "Расширение PHP прервало загрузку файла",
-    "No file uploaded" : "Нет отправленных файлов",
-    "Unsupported image type" : "Неподдерживаемый тип изображения",
-    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Вы уже используете настраиваемую тему. Из за этого установки приложения для тем могут быть перезаписаны.",
-    "Theming" : "Темы оформления",
+    "No file uploaded" : "Нет загруженных файлов",
+    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Вы уже используете настраиваемое оформление, которое может быть перезаписано этим приложением.",
+    "Theming" : "Внешний вид",
+    "Appearance and accessibility" : "Внешний вид и доступность",
+    "Dark theme" : "Тёмное оформление",
+    "Enable dark theme" : "Использовать тёмное оформление",
+    "Dyslexia font" : "Шрифт Dyslexia",
+    "Enable dyslexia font" : "Использовать шрифт Dyslexia",
+    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic — бесплатный шрифт, который смягчает некоторые распространённые ошибки чтения, вызываемые дислексией.",
+    "High contrast mode" : "Режим высокой контрастности",
+    "Enable high contrast mode" : "Включить режим высокой контрастности",
+    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Этот режим делает ярлыки и кнопки меню более чёткими за счёт уменьшения качества.",
     "Legal notice" : "Официальное уведомление",
     "Privacy policy" : "Политика конфиденциальности",
     "Adjust the Nextcloud theme" : "Скорректируйте тему Nextcloud'а",
-    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Темы оформление позволяют легко настроить внешний вид вашего сервера и поддерживаемых клиентов. Это будет доступно для всех пользователей.",
+    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Этот модуль позволяют настроить внешний вид сервера и поддерживаемых клиентов. Настройки, определённые в этом модуле, распространяются на всех пользователей.",
+    "Advanced options" : "Дополнительные параметры",
     "Name" : "Название",
-    "Reset to default" : "Сбросить изменения",
     "Web link" : "Ссылка",
-    "https://…" : "https://",
+    "a safe home for all your data" : "надёжный дом для всех ваших данных",
     "Slogan" : "Слоган",
     "Color" : "Цвет",
     "Logo" : "Логотип",
     "Upload new logo" : "Загрузить новый логотип",
-    "Login image" : "Изображение экрана входа в систему",
-    "Upload new login background" : "Загрузить новый фон для экрана входа в систему",
-    "Remove background image" : "Убрать фоновое изображение ",
-    "Advanced options" : "Дополнительные параметры",
     "Legal notice link" : "Ссылка на официальное уведомление",
-    "Privacy policy link" : "Ссылка на политику конфеденциальности",
+    "Privacy policy link" : "Ссылка на политику конфиденциальности",
     "Header logo" : "Логотип заголовка",
     "Upload new header logo" : "Загрузить логотип заголовка",
     "Favicon" : "Favicon (значок сайта)",
     "Upload new favicon" : "Загрузить значок сайта",
+    "User settings" : "Параметры пользователя",
+    "Keyboard shortcuts" : "Сочетания клавиш",
+    "Background" : "Фон",
+    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Доступная среда очень важна для нас. При разработке мы следуем веб-стандартам, контролируя возможность пользования всем сервисом без помощи мыши и с использованием вспомогательных программ, например, выполняющих чтение с экрана. Мы стремимся к выполнению рекомендаций {guidelines}Руководства доступности Веб-Контента{linkend} 2.1 на уровне АА, а при использовании режима высокой контрастности  — даже на уровне ААА.",
+    "Pick from Files" : "Выбрать из файлов",
+    "Custom color" : "Свой цвет",
+    "Plain background" : "Обычный фон",
+    "Insert from {productName}" : "Вставить из {productName}",
+    "Reset to default" : "Сбросить изменения",
+    "Upload" : "Отправить",
+    "Remove background image" : "Убрать фоновое изображение ",
+    "Loading preview…" : "Загружается предпросмотр…",
+    "Admin" : "Администратор",
+    "Name cannot be empty" : "Имя не может быть пустым",
+    "Open documentation" : "Открыть документацию",
+    "https://…" : "https://",
+    "Login image" : "Изображение экрана входа в систему",
+    "Upload new login background" : "Загрузить новый фон для экрана входа в систему",
     "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Для автоматической генерации favicon на основе загруженного логотипа и цвета нужно установить PHP расширение Imagemagick  с поддержкой изображений SVG "
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
