@@ -40,7 +40,8 @@ OC.L10N.register(
     "Some of your link shares have been removed" : "Някои от вашите споделяния на връзки са премахнати",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Поради грешка в сигурността трябваше да премахнем някои от вашите споделяния на връзки. Моля, вижте връзката за повече информация.",
     "The user limit of this instance is reached." : " Достигнат е потребителският лимит на този екземпляр.",
-    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Въведете абонаментния си ключ, за да увеличите потребителския си лимит. За повече информация относно Nextcloud Enterprise вижте нашия уеб сайт.",
+    "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Въведете абонаментния си ключ в приложението за поддръжка, за да увеличите лимита на потребителите. Това ви дава и всички допълнителни предимства, които Nextcloud Enterprise предлага, и е силно препоръчително за работа в компании.",
+    "Learn more ↗" : "Научете повече ↗",
     "Preparing update" : "Подготовка за актуализиране",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Стъпка на поправка:",
@@ -99,7 +100,6 @@ OC.L10N.register(
     "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "В този екземпляр липсват някои препоръчани PHP модули. За подобрена производителност и по-добра съвместимост е силно препоръчително да ги инсталирате.",
     "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "PHP модулът \"imagick\" не е активиран, въпреки че приложението за теми е активирано. За да работи правилно генерирането на аватари тип favicon, трябва да инсталирате и активирате този модул.",
     "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required." : "PHP модулите \"gmp\" и/или \"bcmath\" не са активирани. Ако използвате удостоверяване без парола WebAuthn, тези модули са нужни.",
-    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page about this ↗{linkend}." : "Изглежда, че използвате 32-битова PHP версия. Приложението Nextcloud се нуждае от 64 бита, за да работи добре. Моля, надстройте вашата операционна система и PHP до 64 бита! За повече подробности прочетете {linkstart}страницата с документация за това ↗{linkend}.",
     "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "Модулът php-imagick в този случай няма поддръжка на SVG. За по-добра съвместимост се препоръчва да го инсталирате.",
     "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "В някои колони в базата данни липсва преобразуване в big int. Поради факта, че промяната на типовете колони в големи таблици може да отнеме известно време, те не се променят автоматично. Чрез стартиране на \"occ db:convert-filecache-bigint\", тези предстоящи промени могат да бъдат приложени ръчно. Тази операция трябва да се извърши, докато екземплярът е офлайн. За повече подробности прочетете {linkstart}страницата с документация за това ↗{linkend}.",
     "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "Понастоящем SQLite се използва като вътрешна база данни. За по-големи инсталации ви препоръчваме да превключите към друг сървър на базата данни.",
@@ -202,6 +202,11 @@ OC.L10N.register(
     "Search" : "Търсене",
     "An error occurred while searching for {type}" : "Възникна грешка при търсенето на {type}",
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Моля, въведете {minSearchLength} знака или повече, за да търсите","Моля, въведете {minSearchLength} знака или повече, за да търсите"],
+    "This browser is not supported" : "Този браузър не се поддържа",
+    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Вашият браузър не се поддържа. Моля, преминете към по-нова версия или към версия, която се поддържа.",
+    "Continue with this unsupported browser" : "Продължете с този неподдържан браузър",
+    "Supported versions" : "Поддържани версии",
+    "{name} version {version} and above" : "{name} версия {version} и по-нови",
     "Search {types} …" : "Търсене на  {types}  ...",
     "Settings" : "Настройки",
     "Could not load your contacts" : "Контактите не могат да бъдат заредени",
@@ -289,8 +294,8 @@ OC.L10N.register(
     "Profile not found" : "Профилът не е намерен",
     "The profile does not exist." : "Профилът не съществува.",
     "Back to %s" : "Обратно към %s",
-    "File not found" : "Файлът не е открит",
-    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Документът не можа да бъде намерен на сървъра. Може би споделянето е изтрито или е изтекло?",
+    "Page not found" : "Страницата не е намерена",
+    "The page could not be found on the server." : "Страницата не е намерена на сървъра.",
     "Too many requests" : "Твърде много заявки",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Имаше твърде много заявки от вашата мрежа. Опитайте отново по-късно или се свържете с вашия администратор, ако това е грешка.",
     "Error" : "Грешка",
@@ -397,6 +402,7 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "В момента се извършва профилактика на %s, може да продължи дълго.",
     "This page will refresh itself when the instance is available again." : "Страницата ще се зареди автоматично, когато е отново на линия.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Свържете се със системния администратор ако това съобщение се задържи твърде дълго или се е появило неочаквано.",
+    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Въведете абонаментния си ключ, за да увеличите потребителския си лимит. За повече информация относно Nextcloud Enterprise вижте нашия уеб сайт.",
     "[%d / %d]: Checking table %s" : "[%d / %d]: Проверяване на таблица %s",
     "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Сървърът няма работеща интернет връзка: Множество крайни точки не могат да бъдат достигнати. Това означава, че някои от функциите като монтиране на външно хранилище, известия за актуализации или инсталиране на приложения на трети страни няма да работят. Достъпът до файлове от разстояние и изпращането на имейли с известия също може да не работят. Установете връзка от този сървър с Интернет, за да се насладите на всички функции.",
     "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Nextcloud 20 е последното издание, поддържащо PHP 7.2. Nextcloud 21 изисква поне PHP 7.3.",
@@ -410,6 +416,8 @@ OC.L10N.register(
     "Local document editing back-end used by the Collabora Online app." : "Местно фоново редактиране на документи, чрез използване на приложението Collabora Online.",
     "restricted" : "ограничен",
     "invisible" : "невидим",
+    "File not found" : "Файлът не е открит",
+    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Документът не можа да бъде намерен на сървъра. Може би споделянето е изтрито или е изтекло?",
     "More" : "Още",
     "More apps menu" : "Още от меню за приложения",
     "Settings menu" : "Настройки",
