@@ -40,7 +40,7 @@ OC.L10N.register(
     "Some of your link shares have been removed" : "Zure esteka partekatzeetako batzuk kendu dira",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Segurtasun errore baten ondorioz zure esteka partekatze batzuk kendu ditugu. Ikusi esteka informazio gehiagorako.",
     "The user limit of this instance is reached." : "Instantzia honen erabiltzaile mugara iritsi da.",
-    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Sartu zure harpidetza-gakoa erabiltzaile muga goratzeko. Nextcloud Enterprise-ri buruzko informazio gehiagorako ikusi gure webgunea.",
+    "Learn more ↗" : "Ikasi gehiago ↗",
     "Preparing update" : "Eguneratzea prestatzen",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Konponketa pausoa:",
@@ -99,7 +99,6 @@ OC.L10N.register(
     "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "Instantzia honek gomendatutako PHP modulu batzuk falta ditu. Biziki gomendatzen da horiek instalatzea, errendimendua eta bateragarritasuna hobetzeko.",
     "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "\"Imagick\" PHP modulua  ez dago gaituta, gaikako aplikazioa badago ere. Faviconen sorrerak behar bezala funtziona dezan, modulu hau instalatu eta gaitu behar duzu.",
     "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required." : "\"gmp\" eta/edo \"bcmath\" PHP moduluak ez daude gaituta. WebAuthn pasahitz gabeko autentifikazioa erabiltzen baduzu, modulu hauek beharrezkoak dira.",
-    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page about this ↗{linkend}." : "Badirudi 32-bit-eko PHP bertsioa exekutatzen ari zarela. Nextcloudek 64-bit behar ditu ondo funtzionatzeko. Eguneratu zure SE eta PHP 64-bit-etara! Xehetasun gehiagorako irakurri {linkstart}honi buruzko dokumentazioa ↗{linkend}.",
     "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "Module php-imagick-ek ez du SVG onartzen instantzia honetan. Bateragarritasuna hobetzeko instalatzea gomendatzen da.",
     "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Datu baseko zutabe batzuek big int bihurtzea falta dute. Taula handietan zutabe motak aldatzeak denbora dezente har dezakeenez ez dira automatikoki aldatu. 'Occ db: convert-filecache-bigint' exekutatuz zain dauden aldaketak eskuz aplika litezke. Eragiketa hau instantzia lineaz kanpo dagoen bitartean egin behar da. Xehetasun gehiagorako, irakurri {linkstart} honi buruzko dokumentazio orria ↗{linkend}.",
     "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite datu-basea erabiltzen ari zara. Instalazio handiagoetarako beste datu-base sistema bat erabiltzea gomendatzen da.",
@@ -289,8 +288,8 @@ OC.L10N.register(
     "Profile not found" : "Profila ez da aurkitu",
     "The profile does not exist." : "Profila ez da existitzen",
     "Back to %s" : "Itzuli %s(e)ra",
-    "File not found" : "Ez da fitxategia aurkitu",
-    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Dokumentua ezin izan da aurkitu zerbitzarian. Agian partekatutakoa ezabatua izan da ala iraungitu egin da?",
+    "Page not found" : "Orria ez da aurkitu",
+    "The page could not be found on the server." : "Orria ez da zerbitzarian aurkitu.",
     "Too many requests" : "Eskaera gehiegi",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Eskaera gehiegi zeuden zure saretik. Saiatu beranduago edo kontaktatu zure administrailearekin errorerik balego",
     "Error" : "Errorea",
@@ -397,6 +396,7 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "%s instantzia hau mantenu-moduan dago une honetan, honek denbora tarte bat iraun dezake.",
     "This page will refresh itself when the instance is available again." : "Instantzia berriz ere erabilgarri dagoenean orri hau freskatuko da.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Jarri harremanetan zure sistema administratzailearekin mezu honek irauten badu edo ezustean agertu bada.",
+    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Sartu zure harpidetza-gakoa erabiltzaile muga goratzeko. Nextcloud Enterprise-ri buruzko informazio gehiagorako ikusi gure webgunea.",
     "[%d / %d]: Checking table %s" : "[%d / %d]: Taula egiaztatzen %s",
     "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Zerbitzari honek ez dauka Interneteko konexiorik: hainbat amaiera-puntu ezin izan dira atzitu. Horren ondorioz, hainbat ezaugarrik ez dute funtzionatuko, hala nola, kanpoko biltegiratzeak muntatzeak, eguneraketei buruzko jakinarazpenak edo hirugarrengoen aplikazioak. Urruneko fitxategiak atzitzeak eta posta elektroniko bidezko jakinarazpenek ere ez dute funtzionatuko. Ezarri Interneterako konexioa zerbitzari honetan ezaugarri horiek izateko.",
     "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Nextcloud 20 da PHP 7.2rekin erabili daitekeen azken bertsioa. Nextcloud 21 erabiltzeko gutxienez PHP 7.3 behar da.",
@@ -410,6 +410,8 @@ OC.L10N.register(
     "Local document editing back-end used by the Collabora Online app." : "Colabora Online aplikazioak dokumentu lokalak editatzeko erabiltzen duen atzealdekoa. ",
     "restricted" : "mugatua",
     "invisible" : "ikusezina",
+    "File not found" : "Ez da fitxategia aurkitu",
+    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Dokumentua ezin izan da aurkitu zerbitzarian. Agian partekatutakoa ezabatua izan da ala iraungitu egin da?",
     "More" : "Gehiago",
     "More apps menu" : "Aplikazio gehiago menua",
     "Settings menu" : "Ezarpenak menua",
