@@ -5,11 +5,19 @@ OC.L10N.register(
     "File is too big" : "فایل خیلی بزرگ است",
     "The selected file is not an image." : "فایل انتخاب شده عکس نمی باشد.",
     "The selected file cannot be read." : "فایل انتخاب شده خوانده نمی شود.",
+    "The file was uploaded" : "پرونده، بارگذاری شد",
+    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "حجم پرونده بارگذاری شده بیشتر از تنظیمات upload_max_filesize در پرونده php.ini است",
+    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "حجم پرونده بازگذاری شده بیشتر از تنظیمات MAX_FILE_SIZE مشخص شده در فرم HTML است",
+    "The file was only partially uploaded" : "پرونده به صورت ناقص بارگذاری شد",
+    "No file was uploaded" : "پرونده‌ای بارگذاری نشد",
+    "Missing a temporary folder" : "پوشه موقت موجود نیست",
+    "Could not write file to disk" : "ناتوانی در نوشتن پرونده روی حافظه",
+    "A PHP extension stopped the file upload" : "یک افزونه پی‌اچ‌پی مانع بارگذاری پرونده شد",
     "Invalid file provided" : "فایل داده‌شده نا معتبر است",
     "No image or file provided" : "هیچ فایل یا تصویری وارد نشده است",
     "Unknown filetype" : "نوع فایل ناشناخته",
-    "Invalid image" : "عکس نامعتبر",
     "An error occurred. Please contact your admin." : "یک خطا رخ داده است. لطفا با مدیر سیستم تماس بگیرید.",
+    "Invalid image" : "عکس نامعتبر",
     "No temporary profile picture available, try again" : "تصویر پروفایل موقت در حال حاضر در دسترس نیست ، دوباره تلاش کنید ",
     "No crop data provided" : "هیچ داده برش داده شده ارائه نشده است",
     "No valid crop data provided" : "هیچ داده برش داده شده معتبر ارائه نشده است",
@@ -18,27 +26,24 @@ OC.L10N.register(
     "Invalid app password" : "کلمه عبور اپلیکیشن اشتباه است",
     "Could not complete login" : "فرایند ورود شما به سیستم کامل نشد",
     "Your login token is invalid or has expired" : "اطلاعات توکن ورود شما اشتباه یا منقضی است",
+    "Login" : "ورود",
     "Password reset is disabled" : "تنظیم مجدد رمز عبور فعال نیست",
-    "Couldn't reset password because the token is invalid" : "تنظیم مجدد گذرواژه میسر نیست, Token نامعتبر است",
-    "Couldn't reset password because the token is expired" : "تنظیم مجدد گذرواژه میسر نیست, Token منقضی شده است",
     "%s password reset" : "%s رمزعبور تغییر کرد",
     "Password reset" : "تنظیم مجدد رمز عبور",
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "برای بازنشانی رمز عبور خود، روی دکمه زیر کلیک کنید. اگر شما تنظیم مجدد رمز عبور را درخواست نکردید، این ایمیل را نادیده بگیرید.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "برای بازنشانی رمز عبور خود، روی لینک زیر کلیک کنید. اگر شما تنظیم مجدد رمز عبور را درخواست نکردید، این ایمیل را نادیده بگیرید.",
     "Reset your password" : "تنظیم مجدد رمز عبور",
+    "Nextcloud Server" : "کارساز نکست‌کلود",
     "Some of your link shares have been removed" : "برخی از لینک های اشتراک گذاری شده شما حذف شده است",
+    "Learn more ↗" : "بیشتر بدانید ↗",
     "Preparing update" : "آماده‌سازی به روز‌ رسانی",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Please use the command line updater because automatic updating is disabled in the config.php." : "Please use the command line updater because automatic updating is disabled in the config.php.",
-    "[%d / %d]: Checking table %s" : "[%d / %d]: چک کردن جدول %s",
     "Turned on maintenance mode" : "حالت \" در دست تعمیر \" فعال شد .",
     "Turned off maintenance mode" : "حالت \" در دست تعمیر \" غیرفعال شد .",
     "Maintenance mode is kept active" : "حالت تعمیرات فعال نگه‌داشته شده است",
     "Updating database schema" : "به روز رسانی طرح پایگاه داده",
     "Updated database" : "بروز رسانی پایگاه داده انجام شد .",
-    "Checking for update of app \"%s\" in appstore" : "بررسی به روزرسانی های برنامه \"%s\" در فروشگاه App",
-    "Update app \"%s\" from appstore" : " \"%s\" به روز رسانی شد",
-    "Checked for update of app \"%s\" in appstore" : "بررسی به روزرسانی های برنامه %s",
     "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "بررسی اینکه آیا طرح پایگاه داده %s می تواند به روز شود (این ممکن است بسته به اندازه پایگاه داده طولانی باشد)",
     "Set log level to debug" : "Set log level to debug",
     "Reset log level" : "Reset log level",
@@ -61,30 +66,32 @@ OC.L10N.register(
     "Please reload the page." : "لطفا صفحه را دوباره بارگیری کنید.",
     "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "به روزرسانی ناموفق بود. برای اطلاعات بیشتر <a href=\"{url}\">فروم ما را بررسی کنید</a>",
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "به روزرسانی ناموفق بود. لطفا این مسئله را در <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">جامعه Nextcloud</a> گزارش دهید",
+    "More apps" : "برنامه های بیشتر",
     "Log in" : "ورود",
     "Logging in …" : "ورود به سیستم ...",
     "Server side authentication failed!" : "تأیید هویت از سوی سرور انجام نشد!",
     "Please contact your administrator." : "لطفا با مدیر وب‌سایت تماس بگیرید.",
     "An internal error occurred." : "یک اشتباه داخلی رخ داد.",
     "Please try again or contact your administrator." : "لطفا مجددا تلاش کنید یا با مدیر سیستم تماس بگیرید.",
-    "Username or email" : "نام کاربری یا ایمیل",
     "Password" : "گذرواژه",
     "Wrong username or password." : "شناسه کاربری و کلمه عبور اشتباه است",
     "User disabled" : "کاربر غیرفعال",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "از این آی پی چندین بار تلاش ناموفق برای ورود انجام شده است فلذا برای ورود مجدد حداقل ۳۰ ثانیه باید صبر کنید.",
+    "Username or email" : "نام کاربری یا ایمیل",
     "Reset password" : "تنظیم مجدد رمز عبور",
     "Couldn't send reset email. Please contact your administrator." : "ارسال ایمیل مجدد با مشکل مواجه شد . لطفا با مدیر سیستم تماس بگیرید .",
-    "Password can not be changed. Please contact your administrator." : "رمز عبور نمی تواند تغییر بکند . لطفا با مدیر سیستم تماس بگیرید .",
     "New password" : "گذرواژه جدید",
     "I know what I'm doing" : "اطلاع از انجام این کار دارم",
     "Resetting password" : "در حال ریست کردن کلمه عبور...",
     "Installing apps …" : "در حال نصب برنامه",
-    "Cancel" : "منصرف شدن",
+    "Skip" : "پرش",
+    "Install recommended apps" : "نصب کاره‌های پیشنهادی",
     "Schedule work & meetings, synced with all your devices." : "برنامه کار و جلسات ، همگام سازی با تمام دستگاه های شما",
     "Keep your colleagues and friends in one place without leaking their private info." : "همکاران و دوستان خود را در یک مکان نگه دارید بدون اینکه اطلاعات خصوصی آنها را بشناسید.",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "برنامه ایمیل ساده با پرونده ها ، مخاطبین و تقویم یکپارچه شده است.",
     "Forgot password?" : "رمز فراموش شده؟",
     "Back" : "بازگشت",
+    "Search" : "جست‌و‌جو",
     "Settings" : "تنظیمات",
     "Search contacts …" : "جستجو مخاطبین ...",
     "No contacts found" : "مخاطبین یافت نشد",
@@ -115,6 +122,7 @@ OC.L10N.register(
     "Already existing files" : "فایل های موجود در حال حاضر ",
     "Which files do you want to keep?" : "کدام فایل ها را می خواهید نگه دارید ؟",
     "If you select both versions, the copied file will have a number added to its name." : "اگر هر دو نسخه را انتخاب کنید، فایل کپی شده یک شماره به نام آن اضافه خواهد شد.",
+    "Cancel" : "منصرف شدن",
     "Continue" : "ادامه",
     "(all selected)" : "(همه انتخاب شده اند)",
     "({count} selected)" : "({count} انتخاب شده)",
@@ -138,8 +146,7 @@ OC.L10N.register(
     "No action available" : "هیچ عملی قابل انجام نیست",
     "Error fetching contact actions" : "خطا در دریافت فعالیتهای تماس",
     "Non-existing tag #{tag}" : "برچسب غیر موجود #{tag}",
-    "restricted" : "محدود",
-    "invisible" : "غیر قابل مشاهده",
+    "Invisible" : "غیر قابل مشاهده",
     "Delete" : "حذف",
     "Rename" : "تغییرنام",
     "Collaborative tags" : "برچسب های همکاری",
@@ -150,8 +157,9 @@ OC.L10N.register(
     "Admin" : "مدیر",
     "Help" : "راه‌نما",
     "Access forbidden" : "اجازه دسترسی به مناطق ممنوعه را ندارید",
-    "File not found" : "فایل یافت نشد",
+    "Page not found" : "صفحه یافت نشد",
     "Error" : "خطا",
+    "Previous" : "قبلی",
     "Internal Server Error" : "خطای داخلی سرور",
     "The server was unable to complete your request." : "سرور قادر به تکمیل درخواست شما نبود.",
     "If this happens again, please send the technical details below to the server administrator." : "اگر این اتفاق دوباره افتاد، لطفا جزئیات فنی زیر را به مدیر سرور ارسال کنید.",
@@ -169,6 +177,7 @@ OC.L10N.register(
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "فایلها و فهرست های داده های شما قابل از اینترنت قابل دسترسی هستند، چونکه فایل htacces. کار نمی کند.",
     "Create an <strong>admin account</strong>" : "لطفا یک <strong> شناسه برای مدیر</strong> بسازید",
     "Username" : "نام کاربری",
+    "Show password" : "نمایش گذرواژه",
     "Storage & database" : "انبارش و پایگاه داده",
     "Data folder" : "پوشه اطلاعاتی",
     "Configure the database" : "پایگاه داده برنامه ریزی شدند",
@@ -182,12 +191,10 @@ OC.L10N.register(
     "Database host" : "هاست پایگاه داده",
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Please specify the port number along with the host name (e.g., localhost:5432).",
     "Performance warning" : "اخطار کارایی",
-    "Finish setup" : "اتمام نصب",
-    "Finishing …" : "در حال اتمام ...",
+    "You chose SQLite as database." : "شما SQLite را به عنوان پایگاه داده انتخاب کردید.",
+    "Install" : "نصب",
     "Need help?" : "کمک لازم دارید ؟",
     "See the documentation" : "مشاهده‌ی مستندات",
-    "More apps" : "برنامه های بیشتر",
-    "More" : "بیش‌تر",
     "Contacts" : "مخاطبین",
     "Contacts menu" : "منوی دفتر تلفن",
     "Confirm your password" : "گذرواژه خود را تأیید کنید",
@@ -195,24 +202,22 @@ OC.L10N.register(
     "Grant access" : " مجوز اعطا دسترسی",
     "Account access" : "دسترسی به حساب",
     "This share is password-protected" : "این اشتراک توسط رمز عبور محافظت می شود",
-    "The password is wrong. Try again." : "رمزعبور اشتباه می باشد. دوباره امتحان کنید.",
+    "Email address" : "آدرس ایمیل",
+    "Go to %s" : "برو به %s",
     "Use backup code" : "از کد پشتیبان استفاده شود",
     "App update required" : "نیاز به بروزرسانی برنامه وجود دارد",
+    "These incompatible apps will be disabled:" : "این برنامه های ناسازگار غیر فعال می شوند:",
     "The theme %s has been disabled." : "قالب %s غیر فعال شد.",
     "Start update" : "اغاز به روز رسانی",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "برای جلوگیری از وقفه در نصب های طولانی تر، شما می توانید دستورات زیر را از مسیر نصبتان اجرا کنید:",
     "Detailed logs" : "Detailed logs",
     "Update needed" : "نیاز به روز رسانی دارد",
-    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "بررسی اینکه آیا طرح پایگاه داده می تواند به روز شود (این ممکن است بسته به اندازه پایگاه داده طولانی باشد)",
-    "Checked database schema update" : "به روز رسانی طرح پایگاه داده بررسی شد",
-    "Checking updates of apps" : "بررسی به روزرسانی های برنامه ها",
-    "Checked database schema update for apps" : "Checked database schema update for apps",
-    "Following apps have been disabled: %s" : "برنامه های زیر غیر فعال شده اند %s",
-    "Continue to Nextcloud" : "ادامه به Nextcloud",
-    "_The update was successful. Redirecting you to Nextcloud in %n second._::_The update was successful. Redirecting you to Nextcloud in %n seconds._" : ["به روز رسانی موفقیت آمیز بود هدایت شما به Nextcloud در %nثانیه ","به روز رسانی موفقیت آمیز بود هدایت شما به Nextcloud در %nثانیه "],
-    "Searching other places" : "جستجو در مکان‌های دیگر",
-    "No search results in other folders for {tag}{filter}{endtag}" : "جستجو در پوشه های دیگر برای {tag}{filter}{endtag} یافت نشد",
-    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} نتایج جستجو در پوشه های دیگر","{count} نتایج جستجو در پوشه های دیگر"],
-    "Search" : "جست‌و‌جو",
-    "These apps will be updated:" : "این برنامه‌ها بروزرسانی شده‌اند:"
+    "Contact your system administrator if this message persists or appeared unexpectedly." : "اگر این پیغام همچنان وجود داشت یا به صورت غیر منتظره ظاهر شد با مدیر سیستم تماس بگیرید.",
+    "[%d / %d]: Checking table %s" : "[%d / %d]: چک کردن جدول %s",
+    "restricted" : "محدود",
+    "invisible" : "غیر قابل مشاهده",
+    "File not found" : "فایل یافت نشد",
+    "More" : "بیش‌تر",
+    "The password is wrong. Try again." : "رمزعبور اشتباه می باشد. دوباره امتحان کنید."
 },
 "nplurals=2; plural=(n > 1);");
