@@ -40,7 +40,7 @@ OC.L10N.register(
     "Some of your link shares have been removed" : "Jotkin linkkijakosi on poistettu",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Tietoturvaongelman vuoksi jouduimme poistaa joitakin linkkijakojasi. Lue lisätietoja linkin kautta.",
     "The user limit of this instance is reached." : "Tämän instanssin käyttäjäraja on täynnä.",
-    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Syötä tilausavaimesi lisätäksesi käyttäjärajaa. Lisätietoja Nextcloud Enterprisestä saat nettisivuiltamme.",
+    "Learn more ↗" : "Lue lisää ↗",
     "Preparing update" : "Valmistellaan päivitystä",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Korjausvaihe:",
@@ -144,6 +144,7 @@ OC.L10N.register(
     "Keep your colleagues and friends in one place without leaking their private info." : "Pidä työkaverisi ja kaverisi samassa paikassa vuotamatta heidän yksityisiä tietojaan.",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "Yksinkertainen sähköpostisovellus, joka toimii yhdessä Tiedostojen, Kontaktien ja Kalenterin kanssa.",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Keskustelu, videopuhelut, näytön jako, verkkotapaamiset ja web-konferenssit - selaimessasi ja puhelinsovelluksilla.",
+    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Asiakirjat, laskentataulukot ja esitykset yhteistyönä, taustavoimana Collabora Online.",
     "Forgot password?" : "Unohditko salasanasi?",
     "Log in with a device" : "Kirjaudu laitteella",
     "Back" : "Takaisin",
@@ -164,6 +165,11 @@ OC.L10N.register(
     "Search" : "Etsi",
     "An error occurred while searching for {type}" : "Haettaessa tyyppiä {type} tapahtui virhe.",
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Kirjoita vähintään {minSearchLength} merkki etsiäksesi","Kirjoita vähintään {minSearchLength} merkkiä etsiäksesi"],
+    "This browser is not supported" : "Tämä selain ei ole tuettu",
+    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Selaimesi ei ole tuettu. Päivitä uudempaan versioon tai muuhun tuettuun selaimeen.",
+    "Continue with this unsupported browser" : "Jatka tällä tuen ulkopuolella olevalla selaimella",
+    "Supported versions" : "Tuetut versiot",
+    "{name} version {version} and above" : "Selaimen {name} versio {version} ja uudempi",
     "Search {types} …" : "Etsi {types}…",
     "Settings" : "Asetukset",
     "Could not load your contacts" : "Yhteystietojasi ei voitu ladata",
@@ -251,8 +257,8 @@ OC.L10N.register(
     "Profile not found" : "Profiilia ei löytynyt",
     "The profile does not exist." : "Profiilia ei ole olemassa",
     "Back to %s" : "Takaisin kohtaan %s",
-    "File not found" : "Tiedostoa ei löytynyt",
-    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Tätä asiakirjaa ei löytynyt palvelimelta. Kenties jako on poistettu tai se oli asetettu vanhenemaan.",
+    "Page not found" : "Sivua ei löytynyt",
+    "The page could not be found on the server." : "Sivua ei löytynyt palvelimelta.",
     "Too many requests" : "Liian monta pyyntöä",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Verkostasi tehtiin liian monta pyyntöä. Yritä myöhemmin uudelleen tai ole yhteydessä ylläpitäjään, jos tämä on mielestäsi virhe.",
     "Error" : "Virhe",
@@ -355,6 +361,7 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Tämä %s-instanssi on parhaillaan huoltotilassa, huollossa saattaa kestää hetki.",
     "This page will refresh itself when the instance is available again." : "Tämä sivu päivittyy itsestään, kun instanssi on jälleen käytettävissä.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Ota yhteys järjestelmän ylläpitäjään, jos tämä viesti ilmenee uudelleen tai odottamatta.",
+    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Syötä tilausavaimesi lisätäksesi käyttäjärajaa. Lisätietoja Nextcloud Enterprisestä saat nettisivuiltamme.",
     "[%d / %d]: Checking table %s" : "[%d / %d]: Tarkistetaan taulua %s",
     "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Nextcloud 20 on viimeinen julkaisu, joka tukee PHP:n versiota 7.2. Nextcloud 21 vaatii vähintään version 7.3 PHP:sta.",
     "The PHP OPcache module is not loaded. {linkstart}For better performance it is recommended ↗{linkend} to load it into your PHP installation." : "PHP OPCache moduuli ei ole ladattuna. {linkstart}Paremman suorituskyvyn saavuttamiseksi↗{linkend}  suosittelemme sen lataamista PHP asennukseesi.",
@@ -364,6 +371,8 @@ OC.L10N.register(
     "Local document editing back-end used by the Collabora Online app." : "Collabora Online-sovelluksen käyttämä taustasovellus paikalliseen dokumenttien muokkaamiseen.",
     "restricted" : "rajoitettu",
     "invisible" : "näkymätön",
+    "File not found" : "Tiedostoa ei löytynyt",
+    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Tätä asiakirjaa ei löytynyt palvelimelta. Kenties jako on poistettu tai se oli asetettu vanhenemaan.",
     "More" : "Lisää",
     "More apps menu" : "Lisäsovellusvalikko",
     "Settings menu" : "Asetusvalikko",
