@@ -40,7 +40,8 @@ OC.L10N.register(
     "Some of your link shares have been removed" : "Certains de vos liens partagés ont été supprimés.",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "En raison d'une faille de sécurité, nous avons supprimé certains de vos liens partagés. Consultez le lien ci-dessus pour plus d'information.",
     "The user limit of this instance is reached." : "Le nombre maximum d'utilisateurs a été atteint sur cette instance.",
-    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Entrez votre clé d’abonnement pour augmenter la limite par utilisateur. Pour plus d'informations sur Nextcloud Enterprise, consultez notre site web.",
+    "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Saisissez votre clé de licence dans l'application Support afin d'augmenter la limite d'utilisateurs. Cela vous donne également tous les avantages supplémentaires que Nextcloud Enterprise offre et est fortement recommandé pour l'exploitation dans les entreprises.",
+    "Learn more ↗" : " En savoir plus ↗",
     "Preparing update" : "Préparation de la mise à jour",
     "[%d / %d]: %s" : "[%d / %d] : %s",
     "Repair step:" : "Étape de réparation :",
@@ -79,7 +80,7 @@ OC.L10N.register(
     "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "La tâche cron n'a pu s'exécuter via CLI. Ces erreurs techniques sont apparues :",
     "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "La dernière tâche de fond a été exécutée {relativeTime}. Quelque chose s'est mal passé. {linkstart}Vérifier le réglage des tâches de fond ↗{linkend}.",
     "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {linkstart}https://nextcloud.com/enterprise{linkend}." : "Ceci est la version communautaire non prise en charge de Nextcloud. Compte tenu de la taille de cette instance, la performance, la fiabilité et la scalabilité ne peuvent être garanties. Les notifications push sont limitées pour éviter de surcharger notre service gratuit. Apprenez-en davantage sur les bénéfices de la version 'Nextcloud Entreprise' sur {linkstart}https://nextcloud.com/enterprise{linkend}.",
-    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Ce serveur ne peut se connecter à Internet : plusieurs points finaux ne peuvent être atteints. Cela signifie que certaines fonctionnalités, telles que le montage de supports de stockage distants, les notifications de mises à jour ou l'installation d'applications tierces ne fonctionneront pas. L'accès aux fichiers à distance, ainsi que l'envoi de notifications par mail peuvent aussi être indisponibles. Il est recommandé d'activer la connexion internet pour ce serveur si vous souhaitez disposer de l'ensemble des fonctionnalités offertes.",
+    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Ce serveur ne peut se connecter à Internet : plusieurs points finaux ne peuvent être atteints. Cela signifie que certaines fonctionnalités, telles que le montage de stockages externes, les notifications de mises à jour ou l'installation d'applications tierces, ne fonctionneront pas. L'accès aux fichiers à distance, ainsi que l'envoi de notifications par e-mail peuvent aussi être indisponibles. Il est recommandé d'activer la connexion internet pour ce serveur si vous souhaitez disposer de l'ensemble des fonctionnalités offertes.",
     "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Pas de mémoire cache configurée. Pour améliorer les performances, merci de configurer un memcache, si disponible. Des informations sont disponibles dans la {linkstart}documentation ↗{linkend}.",
     "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Aucune source appropriée pour l'aléatoire n'a été trouvée par PHP, ce qui est fortement déconseillé pour des raisons de sécurité. Des informations complémentaires peuvent être trouvées dans la {linkstart}documentation ↗{linkend}.",
     "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "Vous disposez actuellement de PHP {version}. Mettez à niveau votre version de PHP pour bénéficier des {linkstart}améliorations de performance et de correctifs de sécurité fournis par le groupe PHP ↗{linkend} dès que votre distribution les supporte.",
@@ -99,7 +100,6 @@ OC.L10N.register(
     "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "Cette instance ne dispose pas de plusieurs modules PHP recommandés. Il est recommandé de les installer pour améliorer les performances, et la compatibilité.",
     "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "Le module PHP \"imagick\" n'est pas actif mais l'application Theming est activée. Pour que la génération du Favicon fonctionne correctement, ce module doit être installé et actif.",
     "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required." : "Les modules PHP \"gmp\" et/ou \"bcmath\" ne sont pas actifs. Si vous utilisez l'authentification sans mot de passe WebAuthn, ces modules sont requis.",
-    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page about this ↗{linkend}." : "Il semble que vous utilisez une version 32-bits de PHP. Nextcloud nécessite une version 64-bits pour bien fonctionner. Merci de mettre à niveau votre système d'exploitation et PHP en 64-bits. Pour plus de détails consultez {linkstart}the documentation page about this ↗{linkend}.",
     "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "Le module php-imagick n’a aucun support SVG dans cette instance. Pour une meilleure compatibilité, il est recommandé de l’installer.",
     "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Certaines colonnes de la base de données n'ont pas été converties en 'big int'. Changer le type de colonne dans de grandes tables peut prendre beaucoup de temps, elles n'ont donc pas été converties automatiquement. En exécutant la commande 'occ db:convert-filecache-bigint', ces changements en suspens peuvent être déclenchés manuellement. Cette opération doit être exécutée pendant que l'instance est hors ligne. Pour plus d'information, consulter {linkstart}la page de documentation à ce propos ↗{linkend}.",
     "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite est actuellement utilisé comme système de gestion de base de données. Pour des installations plus volumineuses, nous vous recommandons de migrer vers un autre système de gestion de base de données.",
@@ -129,7 +129,7 @@ OC.L10N.register(
     "new" : "nouveau ",
     "_download %n file_::_download %n files_" : ["télécharger %n fichier","télécharger %n fichiers","télécharger %n fichiers"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "La mise à jour est en cours, quitter la page peut interrompre le processus dans de nombreux environnements.",
-    "Update to {version}" : "Mise à jour vers {version}",
+    "Update to {version}" : "Mettre à jour vers {version}",
     "An error occurred." : "Une erreur est survenue.",
     "Please reload the page." : "Veuillez recharger la page.",
     "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "La mise à jour a échoué. Pour plus d'informations <a href=\"{url}\">consultez notre publication sur le forum</a> à propos de ce problème.",
@@ -145,13 +145,13 @@ OC.L10N.register(
     "Please contact your administrator." : "Veuillez contacter votre administrateur.",
     "An internal error occurred." : "Une erreur interne est survenue.",
     "Please try again or contact your administrator." : "Veuillez réessayer ou contactez votre administrateur.",
-    "Log in to {productName}" : "Se connecter dans {productName}",
+    "Log in to {productName}" : "Se connecter à {productName}",
     "Account name or email" : "Nom d'utilisateur ou adresse e-mail",
     "Password" : "Mot de passe",
     "Wrong username or password." : "Utilisateur ou mot de passe incorrect.",
     "User disabled" : "Utilisateur désactivé",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Nous avons détecté plusieurs tentatives de connexion invalides depuis votre adresse IP. C'est pourquoi votre prochaine connexion sera retardée de 30 secondes.",
-    "Username or email" : "Utilisateur ou e-mail",
+    "Username or email" : "Nom d'utilisateur ou e-mail",
     "Your account is not setup for passwordless login." : "Votre compte n'est pas paramétré pour une authentification sans mot de passe.",
     "Browser not supported" : "Navigateur non compatible",
     "Passwordless authentication is not supported in your browser." : "L'authentification sans mot de passe n'est pas supportée par votre navigateur.",
@@ -182,7 +182,7 @@ OC.L10N.register(
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Discussions, appels vidéo, partage d'écran, réunions en ligne et conférences web – depuis votre navigateur et les applications mobiles.",
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Documents, feuilles de calculs ou présentations créées sur Collabora Online.",
     "Forgot password?" : "Mot de passe oublié ?",
-    "Log in with a device" : "Se connecter avec un appareil",
+    "Log in with a device" : "Se connecter avec un périphérique",
     "Back" : "Retour",
     "Login form is disabled." : "Le formulaire de connexion est désactivé.",
     "Edit Profile" : "Modifier le profil",
@@ -202,6 +202,11 @@ OC.L10N.register(
     "Search" : "Rechercher",
     "An error occurred while searching for {type}" : "Une erreur s'est produite lors de la recherche de {type}",
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Veuillez saisir au moins {minSearchLength} caractère pour lancer la recherche","Veuillez saisir au moins {minSearchLength} caractères pour lancer la recherche","Veuillez saisir au moins {minSearchLength} caractères pour lancer la recherche"],
+    "This browser is not supported" : "Ce navigateur n'est pas supporté",
+    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Votre navigateur n'est pas pris en charge. Veuillez passer à une version plus récente ou à un navigateur supporté.",
+    "Continue with this unsupported browser" : "Continuer avec ce navigateur non pris en charge",
+    "Supported versions" : "Versions supportées",
+    "{name} version {version} and above" : "{nom} version {version} et supérieure",
     "Search {types} …" : "Rechercher {types}…",
     "Settings" : "Paramètres",
     "Could not load your contacts" : "Impossible de charger vos contacts",
@@ -289,8 +294,8 @@ OC.L10N.register(
     "Profile not found" : "Profile introuvable",
     "The profile does not exist." : "Le profile n'existe pas.",
     "Back to %s" : "Retour à %s",
-    "File not found" : "Fichier non trouvé",
-    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Le document n'a pas pu être trouvé sur le serveur. Peut-être que le partage a été supprimé ou est expiré ?",
+    "Page not found" : "Page non trouvée",
+    "The page could not be found on the server." : "La page n'a pas pu être trouvée sur le serveur.",
     "Too many requests" : "Trop de requêtes",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Il y a trop de requêtes depuis votre réseau. Réessayez plus tard ou contactez votre administrateur s'il s'agit d'une erreur.",
     "Error" : "Erreur",
@@ -314,7 +319,7 @@ OC.L10N.register(
     "Create an <strong>admin account</strong>" : "Créer un <strong>compte administrateur</strong>",
     "Username" : "Nom d'utilisateur",
     "Show password" : "Afficher le mot de passe",
-    "Toggle password visibility" : "Activer/désactiver la visibilité du mot de passe",
+    "Toggle password visibility" : "Activer/Désactiver la visibilité du mot de passe",
     "Storage & database" : "Stockage & base de données",
     "Data folder" : "Répertoire des données",
     "Configure the database" : "Configurer la base de données",
@@ -386,7 +391,7 @@ OC.L10N.register(
     "The theme %s has been disabled." : "Le thème %s a été désactivé.",
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Veuillez vous assurer qu'une copie de sauvegarde de la base de données, du dossier de configuration (config) et du dossier de données (data) a été réalisée avant de commencer.",
     "Start update" : "Démarrer la mise à jour",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Afin d'éviter les timeouts avec les installations de volume conséquent, vous pouvez exécuter la commande suivante depuis le répertoire d'installation :",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Afin d'éviter les timeout avec les installations de volume conséquent, vous pouvez exécuter la commande suivante depuis le répertoire d'installation :",
     "Detailed logs" : "Journaux détaillés",
     "Update needed" : "Mise à jour nécessaire",
     "Please use the command line updater because you have a big instance with more than 50 users." : "Veuillez utiliser la mise à jour en ligne de commande car votre instance est volumineuse avec plus de 50 utilisateurs.",
@@ -397,8 +402,9 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Cette instance de %s est en cours de maintenance, cela peut prendre du temps.",
     "This page will refresh itself when the instance is available again." : "Cette page se rafraîchira d'elle-même lorsque le serveur sera de nouveau disponible.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Veuillez contacter votre administrateur système si ce message persiste ou apparaît de façon inattendue.",
+    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Entrez votre clé d’abonnement pour augmenter la limite par utilisateur. Pour plus d'informations sur Nextcloud Enterprise, consultez notre site web.",
     "[%d / %d]: Checking table %s" : "[%d / %d] : Vérification de la table %s",
-    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Ce serveur ne peut se connecter à Internet : plusieurs point finaux ne peuvent être atteints. Cela signifie que certaines fonctionnalités, telles que le montage de supports de stockage distants, les notifications de mises à jour ou l'installation d'applications tierces ne fonctionneront pas. L'accès aux fichiers à distance, ainsi que l'envoi de notifications par mail peuvent aussi être indisponibles. Il est recommandé d'activer la connexion internet pour ce serveur si vous souhaitez disposer de l'ensemble des fonctionnalités offertes.",
+    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Ce serveur ne peut se connecter à Internet : plusieurs point finaux ne peuvent être atteints. Cela signifie que certaines fonctionnalités, telles que le montage de stockages externes, les notifications de mises à jour ou l'installation d'applications tierces, ne fonctionneront pas. L'accès aux fichiers à distance, ainsi que l'envoi de notifications par e-mail peuvent aussi être indisponibles. Il est recommandé d'activer la connexion internet pour ce serveur si vous souhaitez disposer de l'ensemble des fonctionnalités offertes.",
     "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Nextcloud 20 est la dernière version prenant en charge PHP 7.2. Nextcloud 21 nécessite au moins PHP 7.3.",
     "The PHP OPcache module is not loaded. {linkstart}For better performance it is recommended ↗{linkend} to load it into your PHP installation." : "Le module PHP OPcache n'est pas chargé. {linkstart}Pour de meilleures performances, il est recommandé ↗{linkend} de le charger dans votre installation php.",
     "The PHP OPcache module is not properly configured. {linkstart}For better performance it is recommended ↗{linkend} to use the following settings in the <code>php.ini</code>:" : "Le module PHP OPcache n'est pas bien configuré. {linkstart}Pour de meilleures performances, il est recommandé ↗{linkend} d'utiliser les paramètres suivants dans le fichier <code>php.ini</code>:",
@@ -410,12 +416,14 @@ OC.L10N.register(
     "Local document editing back-end used by the Collabora Online app." : "Moteur d'édition de document local utilisé par l'application Collabora Online.",
     "restricted" : "Restreint",
     "invisible" : "invisible",
+    "File not found" : "Fichier non trouvé",
+    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Le document n'a pas pu être trouvé sur le serveur. Peut-être que le partage a été supprimé ou a expiré ?",
     "More" : "Plus",
     "More apps menu" : "Menu des autres applications",
     "Settings menu" : "Menu des paramètres",
     "The password is wrong. Try again." : "Le mot de passe est incorrect. Veuillez réessayer.",
     "Setup two-factor authentication" : "Paramétrer l'authentification à double facteur",
-    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Cette version communautaire de Nextcloud n'est pas prise en charge et les notifications instantanées ne sont pas disponibles.",
+    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Cette version communautaire de Nextcloud n'est pas prise en charge et les notifications push ne sont pas disponibles.",
     "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "Il s'agit de la version communautaire non prise en charge de Nextcloud. Compte tenu de la taille de cette instance, les performances, la fiabilité et l'extensibilité ne peuvent être garanties. Les notifications push ont été désactivées pour éviter de surcharger notre service gratuit. Apprenez-en plus sur les avantages de Nextcloud Enterprise sur nextcloud.com/enterprise.",
     "You haven't added any info yet" : "Vous n'avez pas encore ajouté de données",
     "{user} hasn't added any info yet" : "{user} n'a pas encore ajouté de données"
