@@ -37,7 +37,7 @@ OC.L10N.register(
     "Some of your link shares have been removed" : "Elimináronse algunhas das súas ligazóns de compartición",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Por mor dun erro de seguridade tivemos que eliminar algunhas das súas ligazóns de compartición. Vexa a ligazón para obter máis información.",
     "The user limit of this instance is reached." : "Acadouse o límite de usuarios desta instancia.",
-    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Introduza a súa clave de subscrición para aumentar o límite de usuarios. Para obter máis información sobre Nextcloud Enterprise, consulte o noso sitio web.",
+    "Learn more ↗" : "Aprender máis ↗",
     "Preparing update" : "Preparando a actualización",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Paso do arranxo:",
@@ -249,8 +249,7 @@ OC.L10N.register(
     "Help" : "Axuda",
     "Access forbidden" : "Acceso denegado",
     "Back to %s" : "Volver a %s",
-    "File not found" : "Non se atopou o ficheiro",
-    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Non foi posíbel atopar o documento no servidor. É posíbel que a ligazón for eliminada ou que xa teña caducado.",
+    "Page not found" : "Non se atopou a páxina",
     "Too many requests" : "Demasiadas solicitudes",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Houbo demasiadas solicitudes da súa rede. Volva tentalo máis adiante ou póñase en contacto co seu administrador se se trata dun erro.",
     "Error" : "Erro",
@@ -350,6 +349,7 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Esta instancia de %s atopase en modo de mantemento, isto pode levar un anaco.",
     "This page will refresh itself when the instance is available again." : "Esta páxina actualizarase automaticamente cando a instancia estea dispoñíbel de novo.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Póñase en contacto co administrador do sistema se persiste esta mensaxe ou se aparece de forma inesperada.",
+    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Introduza a súa clave de subscrición para aumentar o límite de usuarios. Para obter máis información sobre Nextcloud Enterprise, consulte o noso sitio web.",
     "[%d / %d]: Checking table %s" : "[%d / %d]: Comprobando a táboa %s",
     "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Este servidor non ten conexión activa a Internet. Non foi posíbel estabelecer varias conexións. Isto significa que algunhas características como a montaxe do almacenamento externo, as notificacións sobre actualizacións ou a instalación de engadidos de terceiros non funcionarán. Así mesmo, o acceso remoto a ficheiros e enviar correos de notificación poderían non funcionar. Estabeleza unha conexión do servidor a Internet para gozar todas as características.",
     "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Nextcloud 20 é a última versión que admite PHP 7.2. Nextcloud 21 require polo menos PHP 7.3.",
@@ -363,6 +363,8 @@ OC.L10N.register(
     "Local document editing back-end used by the Collabora Online app." : "Infraestrutura para a edición de documentos locais utilizada pola aplicación Collabora Online.",
     "restricted" : "restrinxido",
     "invisible" : "invisíbel",
+    "File not found" : "Non se atopou o ficheiro",
+    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Non foi posíbel atopar o documento no servidor. É posíbel que a ligazón for eliminada ou que xa teña caducado.",
     "More" : "Máis",
     "More apps menu" : "Menú doutras aplicacións",
     "Settings menu" : "Menú de axustes",
