@@ -40,7 +40,7 @@ OC.L10N.register(
     "Some of your link shares have been removed" : "일부 링크 공유가 삭제됨",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "보안 버그로 인하여 일부 링크 공유를 삭제했습니다. 링크를 눌러서 더 많은 정보를 볼 수 있습니다.",
     "The user limit of this instance is reached." : "이 인스턴스의 사용자수 한계에 도달함.",
-    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "사용자수 제한을 해제하기 위해 구독키를 입력하세요. 기업용 Nextcloud에 대해 자세히 알고 싶다면, 저희 웹사이트를 방문하세요.",
+    "Learn more ↗" : "더 알아보기 ↗",
     "Preparing update" : "업데이트 준비 중",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "수리 단계:",
@@ -272,8 +272,7 @@ OC.L10N.register(
     "Profile not found" : "프로파일 찾을 수 없음",
     "The profile does not exist." : "프로파일이 존재하지 않습니다.",
     "Back to %s" : "%s(으)로 돌아가기",
-    "File not found" : "파일을 찾을 수 없음",
-    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "서버에서 문서를 찾을 수 없습니다. 공유가 삭제되었거나 만료되었습니까?",
+    "Page not found" : "페이지를 찾을 수 없음",
     "Too many requests" : "너무 많은 요청",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "이 네트워크에 너무 요청이 많습니다. 나중에 다시 시도하십시오. 이것이 오류일 경우 관리자에게 문의하십시오.",
     "Error" : "오류",
@@ -380,6 +379,7 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "이 %s 인스턴스는 현재 점검 모드입니다. 시간이 걸릴 수도 있습니다.",
     "This page will refresh itself when the instance is available again." : "인스턴스를 다시 사용할 수 있을 때 페이지를 자동으로 새로 고칩니다.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "이 메시지가 계속 표시되거나 예상하지 못하였을 때 표시된다면 시스템 관리자에게 연락하십시오.",
+    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "사용자수 제한을 해제하기 위해 구독키를 입력하세요. 기업용 Nextcloud에 대해 자세히 알고 싶다면, 저희 웹사이트를 방문하세요.",
     "[%d / %d]: Checking table %s" : "[%d / %d]: 테이블 %s 확인 중",
     "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "웹 서버에서 인터넷에 연결할 수 없습니다. 여러 종단점에 접근할 수 없습니다. 외부 저장소 마운트, 업데이트 알림, 추가 앱 설치 등 기능이 작동하지 않을 것입니다. 원격으로 파일에 접근하거나 알림 이메일을 보내지 못할 수도 있습니다. 모든 기능을 사용하려면 이 서버를 인터넷에 연결하십시오.",
     "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Nextcloud 20이 PHP 7.2를 지원하는 마지막 릴리즈입니다. Nextcloud 21은 PHP 7.3 이상이 필요합니다.",
@@ -392,6 +392,8 @@ OC.L10N.register(
     "Local document editing back-end used by the Collabora Online app." : "Collabora Online 앱을 로컬 문서 수정 백엔드로 사용 함.",
     "restricted" : "제한됨",
     "invisible" : "보이지 않음",
+    "File not found" : "파일을 찾을 수 없음",
+    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "서버에서 문서를 찾을 수 없습니다. 공유가 삭제되었거나 만료되었습니까?",
     "More" : "더 보기",
     "More apps menu" : "더 많은 앱 메뉴",
     "Settings menu" : "설정 메뉴",
