@@ -8,8 +8,8 @@ OC.L10N.register(
     "Invalid file provided" : "ຟາຍບໍ່ຖືກຕ້ອງ",
     "No image or file provided" : "ບໍ່ມີຮູບພາບ ຫຼື ຟາຍ",
     "Unknown filetype" : "ບໍ່ຮູ້ປະເພດຂອງຟາຍ",
-    "Invalid image" : "ບໍ່ມີຮູບພາບ",
     "An error occurred. Please contact your admin." : "ຄັດຂ້ອງ ກະລຸນລາຕິດຕໍ່ ທີມບໍລິຫານ",
+    "Invalid image" : "ບໍ່ມີຮູບພາບ",
     "No temporary profile picture available, try again" : "ບໍ່ມີຮູບພາບ ຫຼື ຟາຍຊົ່ວຄາວ, ກະລຸນນາ ລອງໃໝ່",
     "No crop data provided" : "ບໍ່ມີຂໍ້ມູນທີຕັດຕໍ່ປ້ອນເຂົ້າ",
     "No valid crop data provided" : "ບໍ່ມີຂໍ້ມູນຕັດຕໍ່ທີຖືກຕ້ອງປ້ອນເຂົ້າ",
@@ -28,7 +28,6 @@ OC.L10N.register(
     "Some of your link shares have been removed" : "ບາງລີ້ງທີທ່ານໄດ້ແບ່ງປັນຖືກຍົກເລີກແລ້ວ",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "ເນື່ອງຈາກບັນຫາດ້ານຄວາມປອດໄພ, ພວກເຮົາໄດ້ຍົກເລິກການແບ່ງປັນລີ້ງ. ສໍາລັບຂໍ້ມູນເພີ່ມເຕີ່ມ ກະລຸນນາກົດເບີ່ງລີງ ",
     "The user limit of this instance is reached." : "ຮອດກໍານົດ ຈໍາກັດຈໍານວນຜູ້ໃຊ້ແລ້ວ",
-    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "ໃສ່ລະຫັດຜ່ານສະໝັກ ເພື່ອເພີ່ມຂີດຄວາມສາມາດຂອງຜູ້ໃຊ້. ສຳລັບຂໍ້ມູນເພີ່ມເຕີມກ່ຽວກັບ Nextcloud ສາມາດເບິ່ງເວັບໄຊທ໌ຂອງພວກເຮົາ.",
     "Preparing update" : "ກະກຽມອັບເດດ",
     "[%d / %d]: %s" : "[%d/%d]:%s",
     "Repair step:" : "ຂັ້ນຕອນໃນການປັບປຸງ",
@@ -36,7 +35,6 @@ OC.L10N.register(
     "Repair warning:" : "ຄໍາເຕືອນ ການປັບປຸງ",
     "Repair error:" : "ການປັບປຸງຄັດຂ້ອງ",
     "Please use the command line updater because automatic updating is disabled in the config.php." : "ກະລຸນາໃຊ້ ຄໍາສັ່ງ ປັບປຸງ ເພາະການອັບເດດໂດຍອັດຕະໂນມັດຖືກປິດໃນລະບົບການຕັ້ງຄ່າ config.php.",
-    "[%d / %d]: Checking table %s" : "[%d/%d]:ກວດເບີ່ງຕາຕະລາງ %s",
     "Turned on maintenance mode" : "ເປີດໂມດການບໍາລຸງຮັກສາ",
     "Turned off maintenance mode" : "ປິດໂມດການບໍາລຸງຮັກສາ",
     "Maintenance mode is kept active" : "ໂມດການບໍາລຸງຮັກສາໄດ້ຖືກເປີດປະໄວ້",
@@ -61,7 +59,6 @@ OC.L10N.register(
     "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "ຖານຂໍ້ມູນຂອງທ່ານບໍ່ສາມາດດຳເນີນການກັບ \"READ COMMITTED”. ປະເພດການເຮັດທຸລະກຳລະດັບນີ້ “ ຊື່ງອາດເຮັດໃຫ້ເກີດບັນຫາ ໃນເວລາ ເປີດການປະຕິບັດການຫຼາຍ ລາຍການພ້ອມກັນ.",
     "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "ໂມດູນ PHP \"fileinfo\" ຫາຍໄປ. ແນະນຳ ໃຫ້ເປີດໃຊ້ໂມດູນນີ້ ເພື່ອໃຫ້ ໄດ້ຜົນທີ່ດີທີ່ສຸດ ເມື່ອຮ່ວມການກວດກາ MIME",
     "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "ການລັອກຟາຍ ທຸລະກຳ ແມ່ນຖືກປິດ, ອາດຈະນໍາໄປສູ່ບັນຫາຈຳເເນກ. ເຮັດໃຫ້ \"filelocking.enabled\" ໃນ config.php ເພື່ອຫຼີກເວັ້ນບັນຫາເຫຼົ່ານີ້. ເບິ່ງ{linkstart}ເອກະສານ ↗{linkend} ສໍາລັບຂໍ້ມູນເພີ່ມເຕີມ.",
-    "If your installation is not installed at the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (suggestion: \"{suggestedOverwriteCliURL}\")" : "ຖ້າ ການຕິດຕັ້ງລະບົບຂອງທ່ານບໍສໍາເລັດ ໃນ root ຂອງໂດເມນ ແລະ ນໍາໃຊ້ໃນລະບົບ cron, ອາດຈະເກີດມາຈາກ ບັນຫາການສ້າງ URL. ເພື່ອຫຼີກລ້ຽງບັນຫາດດັ່ງກ່າວ, ກະລຸນນາ ຕັ້ງຄ່າທາງເລືອກໃນ config.php file ເປັນ \"overwrite.cli.url\" ໃນ webroot ຂອງການຕັ້ງຄ່າ. ( ແນະນໍາ : \"{suggestedOverwriteCliURL}\")",
     "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "ການຕິດຕັ້ງຂອງທ່ານບໍ່ໄດ້ກໍານົດເຂດບໍລິການໂທລະສັບ. ນີ້ແມ່ນຈໍາເປັນເພື່ອຢັ້ງຢືນເບີໂທລະສັບໃນການຕັ້ງຄ່າໂປຟາຍ ທີບໍ່ມີລະຫັດປະເທດ. ເພື່ອອະນຸຍາດ ເລກໝາຍ ທີ່ບໍ່ມີລະຫັດປະເທດ, ກະລຸນາເພີ່ມ \"ກໍານົດເຂດບໍລິການໂທລະສັບ\" ທີ່ມີລະຫັດ {linkstart}ລະຫັດ ISO 3166-1 ↗{linkend} ເຂດພື້ນທີ່ໃສ່ຟາຍ config ຂອງທ່ານ.",
     "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "ເປັນໄປບໍ່ໄດ້ ທີ່ຈະດໍາເນີນງານcron ຜ່ານ CLI ໄດ້ . ຂໍ້ຜິດພາດທາງດ້ານເຕັກນິກໄດ້ປາກົດຂື້ນ:",
     "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "ການປະຕິບັດວຽກງານພື້ນຖານຄັ້ງສຸດທ້າຍໄດ້ ດຳເນີນ {relativeTime}. ມີ{linkstart} ບາງຢ່າງຜິດ,  ກວດສອບການຕັ້ງຄ່າ↗{linkend}ພື້ນຖານ ",
@@ -81,10 +78,8 @@ OC.L10N.register(
     "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "ຖານຂໍ້ມູນແມ່ນຂາດບາງ columns ທາງເລືອກ. ເນື່ອງຈາກວ່າການເພີ່ມ columns ໃສ່ ຕາຕະລາງໃຫຍ່ ອາດ ຈະ ໃຊ້ເວລາດົນ ທີ່ບໍ່ໄດ້ຕື່ມໂດຍອັດຕະໂນມັດ ເມື່ອເລືອກ ໄດ້ . ໂດຍການດຳ \"occ db:add-missing-columns\" columns ທີ່ຂາດໄປສາມາດເພີ່ມໄດ້ດ້ວຍມືໃນຂະນະທີ່ຕົວຢ່າງຍັງດໍາເນີນການຕໍ່ໄປ. ເມື່ອມີການເພີ່ມ columns ອາດຈະປັບປຸງການຕອບສະຫນອງ ຫຼື ການໃຊ້ງານ.",
     "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "ຕົວຢ່າງເເນະນຳຂາດໂມດູນ PHP,  ສໍາລັບການປັບປຸງ ແລະ ການປະຕິບັດທີ່ດີກວ່າ ນັ້ນ ແມ່ນແນະນໍາໃຫ້ຕິດຕັ້ງ  ",
     "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "ໂມດູນ php-imagick ໃນກໍລະນີນີ້ບໍ່ມີການສະຫນັບສະຫນູນ SVG. ເພື່ອຄວາມສອດຄ່ອງທີ່ດີກວ່າແມ່ນແນະນໍາໃຫ້ຕິດຕັ້ງ.",
-    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running 'occ db:convert-filecache-bigint' those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "ບາງຄໍລໍາໃນຖານຂໍ້ມູນແມ່ນຂາດການປ່ຽນ ໂຕແປໃຫຍ່ ໃຫຍ່ . ເນື່ອງຈາກວ່າການປ່ຽນ ແປງແບບ column ໃນຕາຕະລາງ ອາດຈະໃຊ້ ເວລາດົນ ທີ່ພວກເຂົາເຈົ້າບໍ່ໄດ້ ປ່ຽນແປງ ໂດຍອັດຕະໂນມັດ . ໂດຍການແລ່ນ 'occ db:convert-filecache-bigint' ຜຸ້ທີ່ກໍາລັງປ່ຽນແປງທີ່ກໍາລັງຄ້າງສາມາດນໍາໃຊ້ໄດ້ດ້ວຍມື. ການດໍາເນີນງານນີ້ຈໍາເປັນຕ້ອງໄດ້ ເຮັດ ໃນຂະນະທີ່ຕົວຢ່າງແມ່ນ offline . ສໍາລັບລາຍລະອຽດເພີ່ມເຕີມອ່ານ {linkstart}ຫນ້າເອກະສານກ່ຽວ ກັບ ↗{linkend} ນີ້.",
     "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite ກໍາລັງຖືກນໍາໃຊ້ເປັນຖານຂໍ້ມູນbackend. ສໍາລັບການຕິດຕັ້ງທີ່ໃຫຍ່ກວ່າ   ພວກເຮົາຂໍແນະນໍາໃຫ້ທ່ານປ່ຽນໄປຫາ backend ຖານຂໍ້ມູນທີ່ແຕກຕ່າງ ກັນ .",
     "This is particularly recommended when using the desktop client for file synchronisation." : "ແນະນໍາໂດຍສະເພາະເມື່ອການນໍາໃຊ້ desktop ລູກຄ້າ  ສໍາລັບການ ຢືນຢັນຟາຍ",
-    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the {linkstart}documentation ↗{linkend}." : "ເພື່ອຍົກຍ້າຍໄປຖານຂໍ້ມູນອື່ນໃຊ້ເຄື່ອງມືຄໍາສັ່ງ: 'occ db:convert-type', ຫຼື ເບິ່ງ{linkstart}ເອກະສານ ↗{linkend}.",
     "The PHP memory limit is below the recommended value of 512MB." : "ຂີດຈໍາກັດຄວາມຈໍາ PHP ແມ່ນຕ່ໍາກວ່າຄ່າທີ່ແນະນໍາຂອງ 512MB.",
     "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "ຊອບແວຂອງຜູ້ ໃຊ້ແຕກຕ່າງຈາກເວັບໄຊ  . ອາດຢູ່ເປັນກໍລະນີ ການຕິດຕັ້ງແອັບພລິເຄຊັນດ້ວຍມື. ກວດສອບການອະນຸຍາດຂອງແອັບພລິເຄຊັນດັ່ງຕໍ່ໄປນີ້:",
     "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "MySQL ຖືກນໍາໃຊ້ເປັນຖານຂໍ້ມູນແຕ່ບໍ່ສະຫນັບສະຫນູນຕົວອັກສອນ 4 byte. ເພື່ອ ໃຫ້ ສາມາດຮັບ 4-byteໄດ້(ເຊັ່ນ emojis) ໂດຍບໍ່ມີບັນຫາໃນຊື່ຟາຍ ຫຼື ຄໍາ ເຫັນຍົກຕົວຢ່າງ ແນະນໍາໃຫ້ ເຮັດໃຫ້ ການສະຫນັບສະຫນູນ 4 byte ໃນ MySQL . ສໍາລັບລາຍລະອຽດ ເພີ່ມເຕີມອ່ານ {linkstart} ຫນ້າ ເອກະສານກ່ຽວກັບ ↗{linkend} ນີ້.",
@@ -94,7 +89,6 @@ OC.L10N.register(
     "For more details see the {linkstart}documentation ↗{linkend}." : "ສໍາລັບລາຍລະອຽດເພີ່ມເຕີມເບິ່ງໃນ {linkstart}ເອກະສານ↗{linkend} ",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "ຫົວຂໍ້ HTTP \"{header}\" ບໍ່ໄດ້ຖືກກໍານົດ \"{expected}\". ນີ້ແມ່ນຄວາມສ່ຽງດ້ານຄວາມປອດໄພ ຫຼື ຄວາມເປັນສ່ວນຕົວທີ່ອາດເປັນໄປໄດ້, ແນະນໍາໃຫ້ປັບການຕັ້ງຄ່ານີ້",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "ຫົວຂໍ້ HTTP \"{header}\" ບໍ່ໄດ້ຖືກກໍານົດ\"{expected}\". ບາງຄຸນລັກສະນະອາດຈະເຮັດວຽກບໍ່ຖືກຕ້ອງ , ແນະນໍາໃຫ້ປັບການຕັ້ງຄ່ານີ້ຕາມທີ່ວາງໄວ້.",
-    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "ຫົວຂໍ້ \"{header}\" HTTP ບໍ່ມີ \"{expected}\". ນີ້ແມ່ນຄວາມສ່ຽງດ້ານຄວາມປອດໄພ ຫຼືຄວາມເປັນສ່ວນຕົວ, ແນະນໍາໃຫ້ປັບການຕັ້ງຄ່າຕາມນີ້.",
     "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "ຫົວຂໍ້ \"{header}\" HTTP ບໍ່ໄດ້ກໍານົດ \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" ຫຼື \"{val5}\". ສາມາດເຮັດໃຫ້ຂໍ້ມູນ referer ຮົ່ວ. ເບິ່ງຂໍ້ແນະນໍາ {linkstart}W3C ↗{linkend}.",
     "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "ຫົວຂໍ້ \"Strict-Transport-Security\" HTTP ບໍ່ໄດ້ກໍານົດໄວ້ຢ່າງຫນ້ອຍ \"{seconds}\" ວິນາທີ. ສໍາລັບເພີ່ມຄວາມປອດໄພ, ແນະນໍາໃຫ້ເຮັດໃຫ້ HSTS ຕາມທີ່ໄດ້ບັນຍາຍໄວ້ໃນ{linkstart}↗{linkend}ຄໍາແນະນໍາຄວາມປອດໄພ ",
     "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}." : "ການເຂົ້າເຖິງເວັບໄຊບໍ່ປອດໄພຜ່ານ HTTP. ທ່ານໄດ້ ຮັບຄໍາແນະນໍາທີ່ ຈະ ຕັ້ງ server ຂອງທ່ານ ເພື່ອ ຮຽກໃຊ້ HTTPS ແທນ , ດັ່ງ ທີ່ ໄດ້ ບັນ ຍາຍ ໃນ {linkstart}↗{linkend} ຄໍາແນະນໍາຄວາມປອດໄພ .",
@@ -112,17 +106,18 @@ OC.L10N.register(
     "Please reload the page." : "ກະລຸນາໂຫຼດຫນ້າເພດອີກ.",
     "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "ການປັບປຸງບໍ່ສໍາເລັດ. ສໍາລັບຂໍ້ມູນເພີ່ມເຕີມໃຫ້  <a href=\"{url}\">ກວດສອບການສົ່ງຂໍ້ຄວາມ forum ຂອງ ພວກ ເຮົາ</a>ທີ່ ກ່ຽວ ພັນ ກັບ ບັນ ຫາ ນີ້ .",
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "ການປັບປຸງບໍ່ສໍາເລັດ. ກະລຸນາລາຍງານບັນຫານີ້ຕໍ່ <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud.</a>",
+    "More apps" : "ແອັບພລິເຄຊັນເພີ່ມເຕີມ",
     "Log in" : "ເຂົ້າລະບົບ",
     "Logging in …" : "ກຳລັງໂຫຼດ",
     "Server side authentication failed!" : "ການຢັ້ງຢືນ Server ລົ້ມເຫຼວ!",
     "Please contact your administrator." : "ກະລຸນາຕິດຕໍ່ຜູ້ຄຸມລະບົບຂອງທ່ານ.",
     "An internal error occurred." : "ເກີດຂໍ້ຜິດພາດພາຍໃນ.",
     "Please try again or contact your administrator." : "ກະລຸນາລອງອີກ ຫຼື ຕິດຕໍ່ຜູ້ຄຸ້ມຄອງລະບົບຂອງທ່ານ.",
-    "Username or email" : "ຊື່ຜູ້ໃຊ້ ຫຼື ອີເມວ",
     "Password" : "ລະຫັດຜ່ານ",
     "Wrong username or password." : "ຊື່ຜູ້ໃຊ້ ຫຼື ລະຫັດຜ່ານຜິດ.",
     "User disabled" : "ປິດຊື່ຜູ້ໃຊ້",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "ພວກເຮົາກວດພົບຄວາມພະຍາຍາມ login ທີ່ ບໍ່ຖືກຕ້ອງຈາກ IP ຂອງ ທ່ານ . ດັ່ງນັ້ນການເຄື່ອນໄຫວຕໍ່ໄປຂອງທ່ານແມ່ນ throttled ເຖິງ 30 ວິນາທີ.",
+    "Username or email" : "ຊື່ຜູ້ໃຊ້ ຫຼື ອີເມວ",
     "Your account is not setup for passwordless login." : "ບັນຊີຂອງທ່ານບໍ່ໄດ້ຕັ້ງຄ່າສໍາລັບການເຂົ້າລະຫັດຜ່ານ.",
     "Passwordless authentication is not supported in your browser." : "ການຢັ້ງຢືນແບບບໍ່ມີລະຫັດຜ່ານບໍ່ໄດ້ຮັບການສະຫນັບສະຫນູນໃນເວັບໄຊຂອງທ່ານ.",
     "Passwordless authentication is only available over a secure connection." : "ການຢັ້ງຢືນແບບບໍ່ມີລະຫັດຜ່ານແມ່ນມີພຽງແຕ່ການເຊື່ອມຕໍ່ທີ່ປອດໄພເທົ່ານັ້ນ.",
@@ -134,18 +129,16 @@ OC.L10N.register(
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "ເຂົ້າລະຫັດຟາຍຂອງທ່ານ . ຈະບໍ່ໄດ້ຮັບຂໍ້ມູນຂອງທ່ານພາຍຫຼັງ ທີ່ລະຫັດຜ່ານຂອງທ່ານ ໄດ້ຮັບການຕັ້ງຄ່າໃຫມ່ . ຖ້າທ່ານບໍ່ແນ່ໃຈ, ກະລຸນາຕິດຕໍ່ຜູ້ເບິ່ງລະບົບຂອງທ່ານ ກ່ອນທີ່ທ່ານຈະສືບຕໍ່. ທ່ານຕ້ອງການທີ່ຈະສືບຕໍ່ແທ້ໆບໍ?",
     "I know what I'm doing" : "ຂ້ອຍຮູ້ວ່າຂ້ອຍກຳລັງເຮັດຫຍັງຢູ່",
     "Resetting password" : "ການຕັ້ງລະຫັດຄືນໃຫມ່",
-    "Install recommended apps" : "ຕິດຕັ້ງແອັບທີ່ແນະນໍາ",
     "Recommended apps" : "ແອັບພລິເຄຊັນທີ່ແນະນໍາ",
     "Loading apps …" : "ກຳລັງໂຫຼດເເອັບ",
     "Installing apps …" : "ກໍາລັງຕິດຕັ້ງແອັບ ...",
     "App download or installation failed" : "ການດາວໂຫລດApp ຫຼືການຕິດຕັ້ງຫຼົ້ມເຫລວ",
-    "Cancel" : "ຍົກເລີກ",
+    "Skip" : "ຂ້າມໄປ",
+    "Install recommended apps" : "ຕິດຕັ້ງແອັບທີ່ແນະນໍາ",
     "Schedule work & meetings, synced with all your devices." : "ຕາຕະລາງການເຮັດວຽກ & ການປະຊຸມ, synced ກັບອຸປະກອນທັງຫມົດຂອງທ່ານ.",
     "Keep your colleagues and friends in one place without leaking their private info." : "ຮັກສາເພື່ອນຮ່ວມງານ ແລະ ຫມູ່ ເພື່ອນ ຂອງ ທ່ານ ໄວ້ ໃນບ່ອນດຽວໂດຍບໍ່ໄດ້ ໃຫ້ຂໍ້ ຄວາມ ສ່ວນ ຕົວ ຂອງ ເຂົາ ເຈົ້າຮົ່ວໄຫຼ .",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "ແອັບອີເມວລວມເຂົ້າກັບ ຟາຍຕ່າງໆ, ເບີຕິດຕໍ່ ແລະ ປະຕິທິນ",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatting, ການໂທວິດີໂອ, screen sharing, ການປະຊຸມອອນໄລນ໌ ແລະ ການປະຊຸມເວັບໄຊ – ໃນເວັບໄຊຂອງທ່ານ ແລະ apps ມືຖື.",
-    "Collaboratively edit office documents." : "ຮຽບຮຽງເອກະສານຫ້ອງການຮ່ວມກັນ.",
-    "Local document editing back-end used by the Collabora Online app." : "ບ່ອນເກັບເອກະສານແກ້ໄຂ back-end ທີ່ໃຊ້ໂດຍ app Collabora ອອນໄລນ໌",
     "Forgot password?" : "ລືມລະຫັດຜ່ານ?",
     "Log in with a device" : "ເຂົ້າສູ່ລະບົບດ້ວຍອຸປະກອນ",
     "Back" : "ຫຼັງ",
@@ -194,6 +187,7 @@ OC.L10N.register(
     "Already existing files" : "ຟາຍທີ່ມີຢູ່ແລ້ວ",
     "Which files do you want to keep?" : "ທ່ານຕ້ອງການເກັບຮັກສາຟາຍໃດ?",
     "If you select both versions, the copied file will have a number added to its name." : "ຖ້າທ່ານເລືອກເອົາທັງສອງversions,ຟາຍທີ່ສໍາເນົາຈະມີຈໍານວນເພີ່ມໃສ່ຊື່ຂອງມັນ.",
+    "Cancel" : "ຍົກເລີກ",
     "Continue" : "ສືບຕໍ່",
     "(all selected)" : "(ຄັດເລືອກທັງຫມົດ)",
     "({count} selected)" : "({count} ຖືກຄັດເລືອກ)",
@@ -228,8 +222,7 @@ OC.L10N.register(
     "No action available" : "ບໍ່ມີການກະທໍາທີ່ມີຢູ່",
     "Error fetching contact actions" : "ຜິດພາດໃນການຮັບເອົາການຕິດຕໍ່",
     "Non-existing tag #{tag}" : "ບໍ່ມີtag #{tag}",
-    "restricted" : "ຈໍາກັດ",
-    "invisible" : "ບໍ່ເຫັນ",
+    "Invisible" : "ເບິ່ງບໍ່ເຫັນ",
     "Delete" : "ລຶບ",
     "Rename" : "ປ່ຽນຊື່",
     "Collaborative tags" : "tags ການຮ່ວມມື",
@@ -241,8 +234,6 @@ OC.L10N.register(
     "Help" : "ການຊ່ວຍເຫຼືອ",
     "Access forbidden" : "ຫ້າມການເຂົ້າເຖິງ",
     "Back to %s" : "ຫຼັງ%s",
-    "File not found" : " ບໍ່ພົບຟາຍ",
-    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "ເອກະສານບໍ່ສາມາດຄົ້ນພົບໄດ້ໃນ server.  ບາງທີສ່ວນແບ່ງຖືກລຶບ ຫຼື ໄດ້ສິ້ນສຸດລົງ?",
     "Too many requests" : "ຄໍາຮ້ອງຂໍຫຼາຍເກີນໄປ",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "ມີຄໍາຮ້ອງຂໍຫຼາຍເກີນໄປຈາກເຄືອຂ່າຍຂອງທ່ານ. Retry ໃນເວລາຕໍ່ມາ ຫຼື ຕິດຕໍ່ຜູ້ບໍລິຫານຂອງທ່ານຖ້າຫາກວ່ານີ້ແມ່ນຄວາມຜິດພາດ",
     "Error" : "ຜິດພາດ",
@@ -287,15 +278,11 @@ OC.L10N.register(
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "ເບິ່ງຄືວ່າທ່ານກໍາລັງພະຍາຍາມຕິດຕັ້ງ Nextcloud ຂອງທ່ານຄືນໃຫມ່. ເຖິງ ຢ່າງ ໃດ ກໍ ຕາມ CAN_INSTALLຟາຍ ແມ່ນຂາດໄປຈາກບັນ ຊີການconfig ຂອງ ທ່ານ . ກະລຸນາສ້າງຟາຍ CAN_INSTALL ໃນໂຟນເດີ config ຂອງທ່ານເພື່ອສືບຕໍ່.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "ບໍ່ສາມາດລຶບ CAN_INSTALL ອອກຈາກໂຟນເດີconfig ໄດ້. ກະລຸນາລຶບໄຟລ໌ນີ້ອອກດ້ວຍມື.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "ຊອບແວນີ້ຕ້ອງ ການ JavaScript ສໍາ ລັບການດໍາເນີນງານ ທີ່ຖືກຕ້ອງ . ກະລຸນາເປິດ {linkstart}  JavaScript {linkend} ແລະ ໂຫຼດຫນ້າເພດຄືນໃໝ່.",
-    "Get your own free account" : "ຮັບບັນຊີຟຣີຂອງທ່ານເອງ",
     "Skip to main content" : "ຂ້າມ ໄປຫາເນື້ອຫາຫຼັກ",
     "Skip to navigation of app" : "ຂ້າມໄປຍັງແອັບນຳທາງ",
-    "More apps" : "ແອັບພລິເຄຊັນເພີ່ມເຕີມ",
-    "More" : "ເພີ່ມເຕີມ",
-    "More apps menu" : "ເມນູແອັບເພີ່ມເຕີມ",
+    "Get your own free account" : "ຮັບບັນຊີຟຣີຂອງທ່ານເອງ",
     "Contacts" : "ຕິດຕໍ່",
     "Contacts menu" : "ເມນູຕິດຕໍ່",
-    "Settings menu" : "ການຕັ້ງຄ່າເມນູ",
     "Confirm your password" : "ຢືນຢັນລະຫັດຜ່ານຂອງທ່ານ",
     "Connect to your account" : "ເຊື່ອມຕໍ່ບັນຊີຂອງທ່ານ",
     "Please log in before granting %1$s access to your %2$s account." : "ກະລຸນາເຂົ້າລະບົບກ່ອນທີ່ຈະໃຫ້ %1$sການເຂົ້າເຖິງບັນຊີຂອງທ່ານ%2$s.",
@@ -309,7 +296,6 @@ OC.L10N.register(
     "Your client should now be connected!" : "ຕອນນີ້ລູກຄ້າຂອງທ່ານຄວນຈະເຊື່ອມຕໍ່!",
     "You can close this window." : "ທ່ານສາມາດປິດwindowນີ້ໄດ້.",
     "This share is password-protected" : "ການແບ່ງປັນນີ້ແມ່ນການປ້ອງກັນລະຫັດຜ່ານ",
-    "The password is wrong. Try again." : "ລະຫັດບໍ່ຖືກຕ້ອງ. ລອງໃໝ່ອີກຄັ້ງ.",
     "Two-factor authentication" : "ຮັບຮອງການຢັ້ງຢືນສອງຄັ້ງ",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "ເພີ່ມທະວີຄວາມປອດໄພໃຫ້ບັນຊີຂອງທ່ານ . ເລືອກປັດໃຈທີສອງສໍາລັບການຢັ້ງຢືນ",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "ບໍ່ສາມາດໂຫຼດໄດ້ ຢ່າງຫນ້ອຍໃຊ້ວິທີການ auth ສອງປັດໃຈຂອງທ່ານ. ກະລຸນາຕິດຕໍ່ admin ຂອງທ່ານ.",
@@ -319,7 +305,6 @@ OC.L10N.register(
     "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "ການຢັ້ງຢືນສອງປັດໃຈແມ່ນຖືກບັງຄັບໃຊ້ແຕ່ຍັງບໍ່ໄດ້ຖືກຕັ້ງຄ່າໃນບັນຊີຂອງທ່ານ. ໃຊ້ລະຫັດສໍາຮອງຂອງທ່ານເພື່ອເຂົ້າລະບົບຫຼືຕິດຕໍ່ admin ຂອງທ່ານສໍາລັບການຊ່ວຍເຫຼືອ.",
     "Use backup code" : "ໃຊ້ລະຫັດສໍາຮອງ",
     "Cancel login" : "ຍົກເລີກ login",
-    "Setup two-factor authentication" : "ການຕັ້ງຄ່າຮັບຮອງການຢັ້ງຢືນສອງຄັ້ງ",
     "Enhanced security is enforced for your account. Choose which provider to set up:" : "ເພີ່ມທະວີຄວາມປອດໄພແມ່ນຖືກບັງຄັບໃຊ້ ສໍາລັບບັນຊີ ຂອງທ່ານ . ເລືອກຜູ້ໃຫ້ບໍລິການທີ່ກຳນົດໄວ້",
     "Error while validating your second factor" : "ຄວາມຜິດພາດໃນຂະນະທີ່ການຢັ້ງຢືນທີສອງຂອງທ່ານ",
     "Access through untrusted domain" : "ການເຂົ້າເຖິງຜ່ານໂດເມນທີ່ບໍ່ໜ້າເຊື່ຶອຖື",
@@ -343,53 +328,26 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "%sຕົວຢ່າງນີ້ໃນປັດຈຸບັນແມ່ນຢູ່ໃນວິທີການບໍາລຸງຮັກສາ, ຊຶ່ງອາດຈະໃຊ້ ເວລາໃນໄລຍະໜຶ່ງ",
     "This page will refresh itself when the instance is available again." : "ຫນ້ານີ້ຈະ refresh ເມື່ອມີຕົວຢ່າງອີກ.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "ຕິດຕໍ່ຜູ້ບໍລິຫານລະບົບຂອງທ່ານຖ້າຫາກວ່າຂ່າວສານນີ້ຍັຢູ່ ຫຼື ປາກົດໂດຍບໍ່ຄາດຄິດ.",
-    "Couldn't reset password because the token is invalid" : "ບໍ່ສາມາດປ່ຽນລະຫັດຜ່ານ ເພາະ ໂຕກເກັນ ບໍ່ຖືກຕ້ອງ",
-    "Couldn't reset password because the token is expired" : "ບໍ່ສາມາດປ່ຽນລະຫັດຜ່ານ ເພາະ ໂຕກເກັນ ໝົດອາຍຸ",
-    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "ການກວດສອບວ່າແຜນຜັງຖານຂໍ້ມູນສາມາດອັບເດດໄດ້ ຫລື ບໍ່ (ມັນອາດໃຊ້ເວລາດົນ ຂື້ນກັບຂະໜາດ ຂອງຖານຂໍ້ມູນ)",
-    "Checked database schema update" : "ເລືອກແຜນຜັງຖານຂໍ້ມູນທີຈະອັບເດດ",
-    "Checking updates of apps" : "ກໍາລັງກວດສອບການອັບເດດ ຂອງແອັບ ",
-    "Checking for update of app \"%s\" in appstore" : "ກໍາລັງກວດສອບການເອັບເດດ ແອັບ \"%s\" ໃນແອັບສະຕໍ",
-    "Update app \"%s\" from appstore" : "ອັບເດດ ເອັບ \"%s\" ຈາກ ແອັບສະຕໍ",
-    "Checked for update of app \"%s\" in appstore" : "ກວດການອັບເດດ ແອັບ  \"%s\" ໃນເອັບສະຕໍ",
-    "Checked database schema update for apps" : "ກວດສອບການອັບເດດແຜນຜັງຖານຂໍ້ມູນ ສຳລັບແອັບ.",
-    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "ວັບເຊີບເວີ ຂອງທ່ານຍັງບໍ່ຖືກຕັ້ງຄ່າຢ່າງຖືກຕ້ອງເພື່ອອະນຸຍາດໃຫ້ແກ້ບັນຫາໄດ້ \"{url}\". ລາຍລະອຽດສາມາດເຂົ້າໄປ ທີ <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">ເອກະສານ</a>",
-    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation page</a>. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "ເວັບ ໄຊຂອງ ທ່ານ ບໍ່ໄດ້ຕິດຕັ້ງຢ່າງຖືກຕ້ອງເພື່ອແກ້ ໄຂ \"{url}\" .ກ່ຽວກັບການຕັ້ງຄ່າເວັບໄຊບໍ່ມີການປັບປຸງເພື່ອສົ່ງໂຟນເດີນີ້ໂດຍກົງ. ກະລຸນາປຽບທຽບການຕັ້ງຄ່າຂອງທ່ານກັບການຂຽນຄືນທີ່ຖືກສົ່ງໃນ \".htaccess\" ສໍາລັບ Apache ຫຼືທີ່ສະຫນອງໃຫ້ Nginx<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">ໃນຫນ້າເອກະສານ</a>. ໃນ Nginx ເຫຼົ່ານັ້ນໂດຍປົກກະຕິແລ້ວແມ່ນເລີ່ມຕົ້ນດ້ວຍ \"ສະຖານທີ່ ~\" ທີ່ຕ້ອງການການປັບປຸງ",
-    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "ເວັບໄຊຂອງ ທ່ານ ບໍ່ໄດ້ຕິດຕັ້ງຢ່າງຖືກຕ້ອງເພື່ອແກ້ ໄຂເພື່ອ ສົ່ງ ໄຟ woff2 . ໂດຍປົກກະຕິແລ້ວແມ່ນບັນຫາທີ່ມີການຕັ້ງຄ່າ Nginx. ສໍາລັບ Nextcloud 15 ມັນຈໍາເປັນຕ້ອງມີການປັບຕົວເພື່ອສົ່ງຟາຍ .woff2 ອີກດ້ວຍ. ປຽບທຽບການຕັ້ງຄ່າ Nginx ຂອງທ່ານກັບການຕັ້ງຄ່າທີ່ແນະນໍາໃນ<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">ເອກະສານ</a> ຂອງພວກເຮົາ.",
-    "Please check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">installation documentation ↗</a> for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "ກະລຸນາກວດສອບ <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">ເອກະສານການຕິດຕັ້ງ ↗</a> ສໍາລັບບັນທຶກການຕັ້ງຄ່າ PHP ແລະ ການຕັ້ງຄ່າ PHP ຂອງ server ຂອງທ່ານ, ໂດຍສະເພາະເມື່ອໃຊ້ php-fpm.",
-    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation ↗</a> for more information." : "ການລ໋ອກ ການໂອນຢ້າຍຟາຍໄດ້ຖືກປິດນໍາໃຊ້, ອາດຈະກໍໃຫ້ເກີດບັນຫາຕາມມາ. ກະລຸນນາເປີດ \"filelocking.enabled\" ໃນ config.php ເພື່ອຫຼີກລ້ຽງ ບັນຫາ. ເບີ່ງຂໍ້ມູນເພີ່ມເຕີ່ມທີ <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">ເອກະສານ</a> ",
-    "Last background job execution ran {relativeTime}. Something seems wrong." : "ໄດ້ດໍາເນີນການປະຕິບັດວຽກງານຄັ້ງສຸດທ້າຍ {relativeTime}. ມີບາງຢ່າງບໍຖຶກຕ້ອງ",
-    "Check the background job settings" : "ກວດສອບການຕັ້ງຄ່າພຶ້ນຫຼັງ",
+    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "ໃສ່ລະຫັດຜ່ານສະໝັກ ເພື່ອເພີ່ມຂີດຄວາມສາມາດຂອງຜູ້ໃຊ້. ສຳລັບຂໍ້ມູນເພີ່ມເຕີມກ່ຽວກັບ Nextcloud ສາມາດເບິ່ງເວັບໄຊທ໌ຂອງພວກເຮົາ.",
+    "[%d / %d]: Checking table %s" : "[%d/%d]:ກວດເບີ່ງຕາຕະລາງ %s",
     "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "ເວັບໄຊ ບໍ່ມີການເຊື່ອມຕໍ່ອິນເຕີເນັດ: ຫຼາຍຈຸດສຸດທ້າຍບໍ່ສາມາດເຂົ້າເຖິງໄດ້. ຫມາຍຄວາມວ່າຄຸນສົມບັດບາງຢ່າງເຊັ່ນການ ຕິດຕັ້ງພື້ນທີເກັບຂໍ້ມູນພາຍນອກ,  ການແຈ້ງເຕືອນ ກ່ຽວກັບການອັບເດດ ຫຼື ການ ຕິດຕັ້ງຂອງ apps ຂອງ ພາກ ສ່ວນທີສາມຈະບໍ່ໄດ້ ຜົນ . ການເຂົ້າເຖິງຟາຍຈາກບ່ອນທີ່ຫ່າງໄກ ແລະ ການສົ່ງອີເມວແຈ້ງເຕືອນອາດຈະບໍ່ເຮັດວຽກເຊັ່ນກັນ. ຕ້ອງສ້າງການເຊື່ອມຕໍ່ຈາກ server ກັບອິນເຕີເນັດເພື່ອເຂົ້າເຖິງກັບຄຸນລັກສະນະທັງຫມົດ.",
-    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "ບໍ່ໄດ້ຕັ້ງຄ່າ cache ຄວາມຈໍາຊົວຄາວ. ເພື່ອເພີ່ມປະສິດທິພາບ, ກະລຸນາຕັ້ງຄ່າ cache, ຖ້າມີ. ຂໍ້ມູນເພີ່ມເຕີມສາມາດເບິ່ງໄດ້ໃນ <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">ເອກະສານ</a>",
-    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "ບໍ່ມີການສຸມເລືອກ ໂດຍ PHP ຍ້ອນບັນຫາຄວາມປອດໄພສູງ . ສໍາລັບຂໍ້ມູນເພີ່ມເຕີມສາມາດເບິ່ງໄດ້ໃນ <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">ເອກະສານ</a>.",
-    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "ປະຈຸບັນທ່ານກໍາລັງດໍາເນີນການ PHP {ລູ້ນ}. ອັບເດດລຸ້ນ PHP ຂອງທ່ານເພື່ອ <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">ປັບປຸງປະສິດທິພາບ ແລະ ຄວາມປອດໄພທີ່ສະຫນອງໃຫ້ໂດຍກຸ່ມ PHP</a> ທັນທີທີ່ທ່ານສະຫນັບສະຫນູນມັນ.",
     "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Nextcloud 20 ເປັນສະບັບສຸດທ້າຍທີ່ສະຫນັບສະຫນູນ PHP 7.2. Nextcloud 21 ຊື່ງຕ້ອງມີ PHP 7.3.",
-    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "ການຕັ້ງຄ່າຫົວຂໍ້ reverse proxy ແມ່ນບໍ່ຖືກຕ້ອງ, ຫຼື ທ່ານກໍາລັງເຂົ້າເຖິງ Nextcloud ຈາກ proxy ທີ່ເຊື່ອຖືໄດ້. ຖ້າບໍ່ດັ່ງນັ້ນ, ນີ້ແມ່ນບັນຫາຄວາມປອດໄພ ແລະ ອາດເຮັດໃຫ້ມີຜູ້ໂຈມຕີ spoof ທີ່ຢູ່ IP ດັ່ງທີ່ເຫັນໃນ Nextcloud. ຂໍ້ມູນເພີ່ມເຕີມສາມາດເບິ່ງໄດ້ໃນ <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">ເອກະສານ</a>.",
-    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached ຖືກຕັ້ງຄ່າເປັນ cache ແຈກຢາຍ, ແຕ່ໂມດູນ PHP ທີ່ບໍ່ຖືກຕ້ອງ \"memcache\" ຖືກຕິດຕັ້ງ. OCMemcacheMemcached ສະຫນັບສະຫນູນພຽງແຕ່ \"memcached\" ແລະ ບໍ່ແມ່ນ \"memcache\". ເບິ່ງ  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{wikiLink}\">wiki memcached ກ່ຽວກັບທັງສອງໂມດູນ</a>.",
-    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "ບາງຟາຍບໍ່ໄດ້ຜ່ານການກວດສອບຄວາມລະອຽດ. ຂໍ້ມູນເພີ່ມເຕີມກ່ຽວກັບວິທີແກ້ໄຂບັນຫານີ້ສາມາດເບິ່ງໄດ້ໃນ <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">ເອກະສານ</a>. ( <a href=\"{codeIntegrityDownloadEndpoint}\">ລາຍການຟາຍທີ່ບໍ່ຖືກຕ້ອງ... </a>/ <a href=\"{rescanEndpoint}\">ສະແກນຄືນໃໝ່...</a>)",
-    "The PHP OPcache module is not loaded. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">For better performance it is recommended</a> to load it into your PHP installation." : "ໂມດູນ PHP OPcache ບໍ່ໄດ້ຖືກໂຫຼດ. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">ສໍາລັບການປະຕິບັດທີ່ດີກວ່າມັນແນະນໍາ</a>ໃຫ້ ໂຫຼດ ມັນເຂົ້າໄປໃນການຕິດຕັ້ງ PHP ຂອງ ທ່ານ .",
-    "The PHP OPcache is not properly configured. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">For better performance it is recommended</a> to use the following settings in the <code>php.ini</code>:" : "PHP OPcache ບໍ່ໄດ້ຕັ້ງຄ່າຢ່າງຖືກຕ້ອງ. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">ສໍາລັບການປະຕິບັດທີ່ດີກວ່າແມ່ນແນະນໍາ </a>ໃຫ້ໃຊ້ການຕັ້ງຄ່າດັ່ງຕໍ່ໄປນີ້ໃນ <code>php.ini </code>",
-    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running 'occ db:convert-filecache-bigint' those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">the documentation page about this</a>." : "ບາງ columns ໃນຖານຂໍ້ມູນແມ່ນຂາດການປ່ຽນ int  . ເນື່ອງ ຈາກວ່າການປ່ຽນແປງແບບ column ໃນຕາຕະລາງໃຫຍ່ ອາດຈະໃຊ້ເວລາດົນ . ໂດຍການດຳເນີນ 'occ db:convert-filecache-bigint' ໃນຄະນະການປ່ຽນແປງ ກໍາລັງຄ້າງສາມາດນໍາໃຊ້ມືແປງໄດ້. ການດໍາເນີນ ງານນີ້ຈໍາເປັນຕ້ອງໄດ້ເຮັດໃນຂະນະທີ່ offline . ສໍາລັບລາຍລະອຽດເພີ່ມເຕີມອ່ານ <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">ຫນ້າເອກະສານກ່ຽວກັບສີ່ງນີ້</a>.",
-    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation ↗</a>." : "ເພື່ອຍ້າຍໄປຢູ່ຖານຂໍ້ມູນອື່ນໃຊ້ເຄື່ອງມືຄໍາສັ່ງ: 'occ db:convert-type', ຫຼືເບິ່ງ<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">ເອກະສານ↗</a>.",
-    "Use of the the built in php mailer is no longer supported. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Please update your email server settings ↗<a/>." : "ການໃຊ້ mailer ທີ່ສ້າງຂຶ້ນໃນ php ບໍ່ ໄດ້ ຮັບການສະຫນັບສະຫນູນອີກຕໍ່ໄປ. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">ກະລຸນາອັບເດດການຕັ້ງຄ່າ server ອີເມວຂອງທ່ານ ↗<a/>.",
-    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">the documentation page about this</a>." : "MySQL ຖືກນໍາໃຊ້ເປັນຖານຂໍ້ມູນແຕ່ບໍ່ສະຫນັບສະຫນູນຕົວອັກສອນ 4 byte. ເພື່ອ ໃຫ້ ສາມາດຮັບມືກັບຕົວອັກສອນບັນຈຸເຖິງ 4-byte (ເຊັ່ນ emojis) ຫຼື ຕົວຢ່າງ ແນະນໍາໃຫ້ ການສະຫນັບສະຫນູນບັນຈຸເຖິງ 4 byte ໃນ MySQL . ສໍາລັບລາຍລະອຽດເພີ່ມເຕີມອ່ານ <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">ຫນ້າເອກະສານກ່ຽວກັບເລື່ອງນີ້</a>.",
-    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">the documentation page about this</a>." : "ທ່ານກໍາລັງເຂົ້າເຖິງຕົວຢ່າງກ່ຽວ ກັບການຕິດຕໍ່ທີ່ປອດໄພ, ເຖິງຢ່າງໃດກໍຕາມຕົວຢ່າງ ຂອງທ່ານແມ່ນການ ສ້າງ URLs ທີ່ບໍ່ປອດໄພ . ຫມາຍຄວາມວ່າທ່ານຢູ່ເບື້ອງຫຼັງ proxy reverse ແລະ ຕົວປ່ຽນ config overwrite ບໍ່ໄດ້ກໍານົດຢ່າງຖືກຕ້ອງ. ກະລຸນາອ່ານ<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">ຫນ້າເອກະສານກ່ຽວກັບເລື່ອງນີ້</a>.",
-    "For more details see the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "ສໍາລັບລາຍລະອຽດເພີ່ມເຕີມເບິ່ງ <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">ເອກະສານ</a>.",
-    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "ຊອບແວຂໍ້ມູນ ແລະ ຟາຍຂອງທ່ານອາດຈະສາມາດເຂົ້າເຖິງໄດ້ຈາກອິນເຕີເນັດ .ຟາຍ htaccess ບໍ່ໄດ້ເຮັດວຽກ . ແນະ ນໍາໃຫ້ ທ່ານຕັ້ງຄ່າ ເວັບ ໄຊ ຂອງ ທ່ານ ເພື່ອວ່າຂໍ້ມູນບໍ່ ສາ ມາດ ເຂົ້າ ເຖິງ ໄດ້ ໂດຍກົງ ອີກ ຕໍ່ ໄປ , ຫຼື ການ ເຄື່ອນ ຍ້າຍຂໍ້ ມູນ ຢູ່ ນອກຮາກຖານຂອງເອກະ ສານ web server  ໂດຍກົງ ",
-    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C Recommendation ↗</a>." : "ຫົວຂໍ້ \"{header}\" HTTP ບໍ່ໄດ້ກໍານົດ\"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" ຫຼື \"{val5}\". ສາມາດລະບາຍຂໍ້ມູນ referer. ເບິ່ງ <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">ຄໍາແນະນໍາ 1W3C ↗1</a>.",
-    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the <a href=\"{docUrl}\" rel=\"noreferrer noopener\">security tips ↗</a>." : "ຫົວຂໍ້ \"Strict-Transport-Security\" HTTP ບໍ່ໄດ້ກໍານົດໄວ້ \"{seconds}\" ວິນາທີ. ເພື່ອເພິ່ມຄວາມປອດໄພ, ແນະນໍາໃຫ້ເຮັດ HSTS ຕາມທີ່ໄດ້ລະບຸ<a href=\"{docUrl}\" rel=\"noreferrer noopener\">ໄວ້ໃນຄໍາແນະນໍາດ້ານຄວາມປອດໄພ ↗</a>.",
-    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips ↗</a>." : "ການເຂົ້າເຖິງເວັບໄຊບໍ່ມີຄວາມປອດໄພ ຜ່ານ HTTP. ທ່ານໄດ້ ຮັບຄໍາແນະນໍາ ຕິດຕັ້ງ server ຂອງ ທ່ານ ເພື່ອ ຮຽກຮ້ອງ HTTPS ແທນ , ດັ່ງ ທີ່ໄດ້ບັນ ຍາຍໃນຄໍາ <a href=\"{docUrl}\">ແນະນໍາຄວາມປອດ ໄພ ↗</a> .",
-    "Continue to Nextcloud" : "ສືບຕໍ່ Nextcloud",
-    "_The update was successful. Redirecting you to Nextcloud in %n second._::_The update was successful. Redirecting you to Nextcloud in %n seconds._" : ["ການປັບປຸງໄດ້ສໍາເລັດ. ການນໍາທ່ານໄປຫາ Nextcloud ໃນ %nວິນາທີ."],
-    "A password reset message has been sent to the e-mail address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "ມີການສົ່ງຂໍ້ຄວາມການຕັ້ງລະຫັດຜ່ານໄປຫາທີ່ຢູ່ອີເມວຂອງບັນຊີນີ້. ຖ້າທ່ານບໍ່ໄດ້ຮັບ, ໃຫ້ກວດເບິ່ງໂຟນເດີ spam/junk ຂອງທ່ານ ຫຼື ຂໍຄວາມຊ່ວຍເຫຼືອຈາກເບີ່ງລະບົບຂອງທ່ານ.",
-    "Password can not be changed. Please contact your administrator." : "ບໍ່ສາມາດປ່ຽນລະຫັດຜ່ານໄດ້. ກະລຸນາຕິດຕໍ່ຜູ້ເບິ່ງລະບົບຂອງທ່ານ.",
-    "Could not fetch list of apps from the app store." : "ບໍ່ສາມາດເກັບລາຍຊື່ແອັບ ຈາກບ່ອນເກັບແອັບໄດ້.",
-    "Can't install this app because it is not compatible" : "ບໍ່ສາມາດຕິດຕັ້ງແອັບນີ້ໄດ້ ເພາະມັນບໍ່ເຂົ້າກັນໄດ້",
-    "Can't install this app" : "ບໍ່ສາມາດຕິດຕັ້ງແອັບນີ້ໄດ້",
-    "Calendar, Contacts, Talk, Mail & Collaborative editing" : "ປະຕິທິນ, Contacts, Talk, Mail & ການແກ້ໄຂການຮ່ວມມື",
-    "Finish setup" : "ສໍາເລັດການຕັ້ງຄ່າ",
-    "Finishing …" : "ຈົບ ...",
     "The PHP OPcache module is not loaded. {linkstart}For better performance it is recommended ↗{linkend} to load it into your PHP installation." : "ໂມດູນ PHP OPcache ບໍ່ໄດ້ຖືກໂຫຼດ. {linkstart} ສໍາລັບການປະຕິບັດທີ່ດີກວ່າ ໄດ້ຮັບ ການແນະນໍາ ↗{linkend} ເພື່ອ ໂຫຼດ ມັນ ເຂົ້າ ໄປ ໃນ ການ ຕິດ ຕັ້ງ PHP ຂອງ ທ່ານ .",
-    "The PHP OPcache module is not properly configured. {linkstart}For better performance it is recommended ↗{linkend} to use the following settings in the <code>php.ini</code>:" : "ໂມດູນ PHP OPcache ບໍ່ໄດ້ຕັ້ງຄ່າຢ່າງເຫມາະສົມ. {linkstart} ສໍາລັບການປະຕິບັດງານທີ່ດີກວ່າແມ່ນແນະນໍາໃຫ້ ↗{linkend} ເພື່ອໃຊ້ການຕັ້ງຄ່າດັ່ງຕໍ່ໄປນີ້ໃນ php.ini:"
+    "The PHP OPcache module is not properly configured. {linkstart}For better performance it is recommended ↗{linkend} to use the following settings in the <code>php.ini</code>:" : "ໂມດູນ PHP OPcache ບໍ່ໄດ້ຕັ້ງຄ່າຢ່າງເຫມາະສົມ. {linkstart} ສໍາລັບການປະຕິບັດງານທີ່ດີກວ່າແມ່ນແນະນໍາໃຫ້ ↗{linkend} ເພື່ອໃຊ້ການຕັ້ງຄ່າດັ່ງຕໍ່ໄປນີ້ໃນ php.ini:",
+    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running 'occ db:convert-filecache-bigint' those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "ບາງຄໍລໍາໃນຖານຂໍ້ມູນແມ່ນຂາດການປ່ຽນ ໂຕແປໃຫຍ່ ໃຫຍ່ . ເນື່ອງຈາກວ່າການປ່ຽນ ແປງແບບ column ໃນຕາຕະລາງ ອາດຈະໃຊ້ ເວລາດົນ ທີ່ພວກເຂົາເຈົ້າບໍ່ໄດ້ ປ່ຽນແປງ ໂດຍອັດຕະໂນມັດ . ໂດຍການແລ່ນ 'occ db:convert-filecache-bigint' ຜຸ້ທີ່ກໍາລັງປ່ຽນແປງທີ່ກໍາລັງຄ້າງສາມາດນໍາໃຊ້ໄດ້ດ້ວຍມື. ການດໍາເນີນງານນີ້ຈໍາເປັນຕ້ອງໄດ້ ເຮັດ ໃນຂະນະທີ່ຕົວຢ່າງແມ່ນ offline . ສໍາລັບລາຍລະອຽດເພີ່ມເຕີມອ່ານ {linkstart}ຫນ້າເອກະສານກ່ຽວ ກັບ ↗{linkend} ນີ້.",
+    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the {linkstart}documentation ↗{linkend}." : "ເພື່ອຍົກຍ້າຍໄປຖານຂໍ້ມູນອື່ນໃຊ້ເຄື່ອງມືຄໍາສັ່ງ: 'occ db:convert-type', ຫຼື ເບິ່ງ{linkstart}ເອກະສານ ↗{linkend}.",
+    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "ຊອບແວຂໍ້ມູນ ແລະ ຟາຍຂອງທ່ານອາດຈະສາມາດເຂົ້າເຖິງໄດ້ຈາກອິນເຕີເນັດ .ຟາຍ htaccess ບໍ່ໄດ້ເຮັດວຽກ . ແນະ ນໍາໃຫ້ ທ່ານຕັ້ງຄ່າ ເວັບ ໄຊ ຂອງ ທ່ານ ເພື່ອວ່າຂໍ້ມູນບໍ່ ສາ ມາດ ເຂົ້າ ເຖິງ ໄດ້ ໂດຍກົງ ອີກ ຕໍ່ ໄປ , ຫຼື ການ ເຄື່ອນ ຍ້າຍຂໍ້ ມູນ ຢູ່ ນອກຮາກຖານຂອງເອກະ ສານ web server  ໂດຍກົງ ",
+    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "ຫົວຂໍ້ \"{header}\" HTTP ບໍ່ມີ \"{expected}\". ນີ້ແມ່ນຄວາມສ່ຽງດ້ານຄວາມປອດໄພ ຫຼືຄວາມເປັນສ່ວນຕົວ, ແນະນໍາໃຫ້ປັບການຕັ້ງຄ່າຕາມນີ້.",
+    "Collaboratively edit office documents." : "ຮຽບຮຽງເອກະສານຫ້ອງການຮ່ວມກັນ.",
+    "Local document editing back-end used by the Collabora Online app." : "ບ່ອນເກັບເອກະສານແກ້ໄຂ back-end ທີ່ໃຊ້ໂດຍ app Collabora ອອນໄລນ໌",
+    "restricted" : "ຈໍາກັດ",
+    "invisible" : "ບໍ່ເຫັນ",
+    "File not found" : " ບໍ່ພົບຟາຍ",
+    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "ເອກະສານບໍ່ສາມາດຄົ້ນພົບໄດ້ໃນ server.  ບາງທີສ່ວນແບ່ງຖືກລຶບ ຫຼື ໄດ້ສິ້ນສຸດລົງ?",
+    "More" : "ເພີ່ມເຕີມ",
+    "More apps menu" : "ເມນູແອັບເພີ່ມເຕີມ",
+    "Settings menu" : "ການຕັ້ງຄ່າເມນູ",
+    "The password is wrong. Try again." : "ລະຫັດບໍ່ຖືກຕ້ອງ. ລອງໃໝ່ອີກຄັ້ງ.",
+    "Setup two-factor authentication" : "ການຕັ້ງຄ່າຮັບຮອງການຢັ້ງຢືນສອງຄັ້ງ"
 },
 "nplurals=1; plural=0;");
