@@ -37,6 +37,7 @@ OC.L10N.register(
     "Reset your password" : "Atkurkite savo slaptažodį",
     "Nextcloud Server" : "Nextcloud serveris",
     "The user limit of this instance is reached." : "Yra pasiekta šio egzemplioriaus naudotojų riba.",
+    "Learn more ↗" : "Sužinokite daugiau ↗",
     "Preparing update" : "Ruošiamas atnaujinimas",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Pataisymo žingsnis:",
@@ -216,8 +217,7 @@ OC.L10N.register(
     "Profile not found" : "Profilis nerastas",
     "The profile does not exist." : "Profilio nėra.",
     "Back to %s" : "Atgal į %s",
-    "File not found" : "Failas nerastas",
-    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Nepavyko serveryje rasti dokumento. Galbūt, viešinys buvo ištrintas arba pasibaigė jo galiojimo laikas?",
+    "Page not found" : "Puslapis nerastas",
     "Too many requests" : "Per daug užklausų",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Iš jūsų tinklo buvo per daug užklausų. Bandykite dar kartą vėliau arba, jeigu tai klaida, susisiekite su savo administratoriumi.",
     "Error" : "Klaida",
@@ -318,6 +318,8 @@ OC.L10N.register(
     "[%d / %d]: Checking table %s" : "[%d / %d]: Tikrinama lentelė %s",
     "restricted" : "apribota",
     "invisible" : "nematoma",
+    "File not found" : "Failas nerastas",
+    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Nepavyko serveryje rasti dokumento. Galbūt, viešinys buvo ištrintas arba pasibaigė jo galiojimo laikas?",
     "More" : "Daugiau",
     "More apps menu" : "Daugiau programėlių meniu",
     "Settings menu" : "Nustatymų meniu",
