@@ -39,6 +39,7 @@ OC.L10N.register(
     "Some of your link shares have been removed" : "Некој од вашите линкови што ги споделивте се избришани",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Поради безбедносен ризик некој од вашите споделувања се избришани. Ве молиме видете го линкот за повеќе информации.",
     "The user limit of this instance is reached." : "Лимитот на корисници на оваа истанца е исполнет.",
+    "Learn more ↗" : "Научи повеќе ↗",
     "Preparing update" : "Ја подготвувам надградбата",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Чекори за поправка:",
@@ -265,8 +266,7 @@ OC.L10N.register(
     "Profile not found" : "Профилот не е пронајден",
     "The profile does not exist." : "Профилот на постои",
     "Back to %s" : "Врати се на %s",
-    "File not found" : "Датотеката не е пронајдена",
-    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Документот не може да се пронајде на серверот. Можеби ова споделување е избришано или рекот за пристап му е истечен?",
+    "Page not found" : "Страницата не е пронајдена",
     "Too many requests" : "Премногу барања",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Има испратено премногу барање од вашата мрежа. Обидете се подоцна повторно или контактирајте го администраторот.",
     "Error" : "Грешка",
@@ -384,6 +384,8 @@ OC.L10N.register(
     "Collaboratively edit office documents." : "Колаборативно уредување на документи.",
     "restricted" : "ограничено",
     "invisible" : "невидливо",
+    "File not found" : "Датотеката не е пронајдена",
+    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Документот не може да се пронајде на серверот. Можеби ова споделување е избришано или рекот за пристап му е истечен?",
     "More" : "Повеќе",
     "More apps menu" : "Мени за повеќе апликации",
     "Settings menu" : "Мени за параметри",
