@@ -40,7 +40,7 @@ OC.L10N.register(
     "Some of your link shares have been removed" : "Sommige van je gedeelde links zijn verwijderd",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Door een security-bug moesten we sommige van je gedeelde links verwijderen. Bekijk de link voor meer informatie.",
     "The user limit of this instance is reached." : "De limiet van het aantal gebruikers op deze server is bereikt.",
-    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Voer je abonnementssleutel in om de gebruikerslimiet te verhogen. Zie onze website voor meer informatie over Nextcloud Enterprise.",
+    "Learn more ↗" : "Meer weten",
     "Preparing update" : "Update voorbereiden",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Herstel stap:",
@@ -282,8 +282,7 @@ OC.L10N.register(
     "Profile not found" : "Proefiel niet gevonden",
     "The profile does not exist." : "Het profiel bestaat niet.",
     "Back to %s" : "Terug naar %s",
-    "File not found" : "Bestand niet gevonden",
-    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Het document werd niet gevonden op de server. Misschien is de share verwijderd of verlopen?",
+    "Page not found" : "Pagina niet gevonden",
     "Too many requests" : "Te veel aanvragen",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Er waren te veel aanvragen afkomstig uit uw netwerk. Probeer later opnieuw of contacteer de beheerder als dat niet correct is.",
     "Error" : "Fout",
@@ -343,7 +342,7 @@ OC.L10N.register(
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Als u geen nieuw apparaat of nieuwe app probeert in te stellen, probeert iemand je te misleiden om hem toegang tot je gegevens te verlenen. Ga in dat geval niet verder en neem in plaats daarvan contact op met je systeembeheerder.",
     "App token" : "App token",
     "Grant access" : "Verleen toegang",
-    "Alternative log in using app token" : "Alterenatieve login doormiddel van app token.",
+    "Alternative log in using app token" : "Alternatief aanmelden met app token",
     "Account access" : "Account toegang",
     "You are about to grant %1$s access to your %2$s account." : "Je staat op het punt om %1$s toegang te verlenen tot je %2$s account.",
     "Account connected" : "Account verbonden",
@@ -386,6 +385,7 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Deze %s staat momenteel in de onderhoudsstand, dat kan enige tijd duren.",
     "This page will refresh itself when the instance is available again." : "Deze pagina wordt ververst als de server weer beschikbaar is.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Neem contact op met je systeembeheerder als deze melding aanhoudt of onverwacht verscheen.",
+    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Voer je abonnementssleutel in om de gebruikerslimiet te verhogen. Zie onze website voor meer informatie over Nextcloud Enterprise.",
     "[%d / %d]: Checking table %s" : "[%d / %d]: Tabel controleren %s",
     "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Deze server heeft geen werkende internetverbinding: meerdere endpoints kunnen niet worden bereikt. Dat betekent dat sommige functies, zoals het gebruik van externe opslag, notificaties over updates of installatie van apps van derde partijen niet werken. Ook het benaderen van bestanden vanaf een remote locatie en het versturen van notificatie emails kan mislukken. We adviseren om de internetverbinding voor deze server in te schakelen als je alle functies wilt gebruiken.",
     "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Nextcloud 20 is de laatste release met ondersteuning voor PHP 7.2. Nextcloud 21 heeft minstens PHP 7.3 nodig.",
@@ -399,6 +399,8 @@ OC.L10N.register(
     "Local document editing back-end used by the Collabora Online app." : "Lokale back-end voor bestandsbewerking gebruikt door de Collabora Online app.",
     "restricted" : "beperkt",
     "invisible" : "onzichtbaar",
+    "File not found" : "Bestand niet gevonden",
+    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Het document werd niet gevonden op de server. Misschien is de share verwijderd of verlopen?",
     "More" : "Meer",
     "More apps menu" : "Meer apps menu",
     "Settings menu" : "Instellingenmenu",
