@@ -40,7 +40,8 @@ OC.L10N.register(
     "Some of your link shares have been removed" : "Alguns dos seus compartilhamentos por link foram removidos",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Devido a um bug de segurança, tivemos que remover alguns dos seus compartilhamentos por link. Por favor, veja o link para mais informações.",
     "The user limit of this instance is reached." : "O limite do usuário desta instância foi atingido.",
-    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Digite sua chave de assinatura para aumentar o limite de usuários. Para obter mais informações sobre o Nextcloud Enterprise, consulte nosso website.",
+    "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Insira sua chave de assinatura no aplicativo de suporte para aumentar o limite de usuários. Isso também garante a você todos os benefícios adicionais que o Nextcloud Enterprise oferece e é altamente recomendado para operação em empresas.",
+    "Learn more ↗" : "Saiba mais ↗",
     "Preparing update" : "Preparando a atualização",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Etapa do reparo:",
@@ -99,7 +100,6 @@ OC.L10N.register(
     "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "Nesta instalação estão faltando alguns módulos PHP recomendados. Para melhor desempenho e compatibilidade, é altamente recomendável instalá-los.",
     "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "O módulo PHP \"imagick\" não está habilitado, embora o aplicativo de temas esteja. Para que a geração de favicon funcione corretamente, você precisa instalar e habilitar este módulo.",
     "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required." : "Os módulos PHP \"gmp\" e/ou \"bcmath\" não estão habilitados. Se você usar a autenticação sem senha do WebAuthn, esses módulos serão necessários.",
-    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page about this ↗{linkend}." : "Parece que você está executando uma versão PHP de 32 bits. Nextcloud precisa de 64 bits para funcionar bem. Por favor, atualize seu sistema operacional e PHP para 64 bits! Para mais detalhes, leia {linkstart}a página de documentação sobre este ↗{linkend}.",
     "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "A extensão php-imagick nesta instância não tem suporte para SVG. Para melhor compatibilidade é recomendado instalá-la.",
     "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Algumas colunas no banco de dados não têm uma conversão para big int. Devido ao fato de que alterar os tipos de coluna em tabelas grandes pode levar algum tempo, eles não foram alterados automaticamente. Ao executar \"occ db:convert-filecache-bigint\", essas alterações pendentes podem ser aplicadas manualmente. Esta operação precisa ser feita enquanto a instância estiver offline. Para mais detalhes, leia {linkstart}a página de documentação sobre este ↗{linkend}.",
     "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "Atualmente, o SQLite está sendo usado como plataforma de banco de dados. Para instalações maiores, recomendamos que migre para outra.",
@@ -202,6 +202,11 @@ OC.L10N.register(
     "Search" : "Pesquisar",
     "An error occurred while searching for {type}" : "Ocorreu um erro ao pesquisar por {type}",
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Digite {minSearchLength} caractere ou mais para pesquisar","Digite {minSearchLength} caracteres ou mais para pesquisar","Digite {minSearchLength} caracteres ou mais para pesquisar"],
+    "This browser is not supported" : "Este navegador não é compatível",
+    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Seu navegador não é suportado. Atualize para uma versão mais recente ou compatível.",
+    "Continue with this unsupported browser" : "Continuar com este navegador não compatível",
+    "Supported versions" : "Versões compatíveis",
+    "{name} version {version} and above" : "{name} versão {version} e superior",
     "Search {types} …" : "Pesquisar {types}…",
     "Settings" : "Configurações",
     "Could not load your contacts" : "Não foi possível carregar seus contatos",
@@ -289,8 +294,8 @@ OC.L10N.register(
     "Profile not found" : "Perfil não encontrado",
     "The profile does not exist." : "O perfil não existe. ",
     "Back to %s" : "Voltar para %s",
-    "File not found" : "Arquivo não encontrado",
-    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "O documento não pôde ser encontrado no servidor. Talvez o compartilhamento tenha sido excluído ou tenha expirado.",
+    "Page not found" : "Página não encontrada",
+    "The page could not be found on the server." : "A página não pôde ser encontrada no servidor.",
     "Too many requests" : "Muitas requisições",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Houve muitas solicitações de sua rede. Tente novamente mais tarde ou entre em contato com o administrador se isso for um erro.",
     "Error" : "Erro",
@@ -397,6 +402,7 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Esta instância %s está em modo de manutenção, o que pode demorar um pouco.",
     "This page will refresh itself when the instance is available again." : "Esta página será atualizada quando o Nextcloud estiver disponível novamente.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Entre em contato com o administrador do sistema se esta mensagem persistir ou aparecer inesperadamente.",
+    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Digite sua chave de assinatura para aumentar o limite de usuários. Para obter mais informações sobre o Nextcloud Enterprise, consulte nosso website.",
     "[%d / %d]: Checking table %s" : "[%d / %d]: Verificando tabela %s",
     "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Este servidor não possui conexão com a internet: Vários pontos não puderam ser acessados. Isso significa que alguns dos recursos como montagem de armazenamento externo, notificações sobre atualizações ou instalação de aplicativos de terceiros não funcionarão. Acesso a arquivos remotos e envio de e-mails de notificação não funcionarão também. Estabeleça uma conexão deste servidor com a Internet para aproveitar todos os recursos.",
     "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Nextcloud 20 é a última versão compatível com PHP 7.2. Nextcloud 21 requer ao menos PHP 7.3.",
@@ -410,6 +416,8 @@ OC.L10N.register(
     "Local document editing back-end used by the Collabora Online app." : "Backend de edição de documentos local usado pelo aplicativo Collabora Online.",
     "restricted" : "restrito",
     "invisible" : "Invisível",
+    "File not found" : "Arquivo não encontrado",
+    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "O documento não pôde ser encontrado no servidor. Talvez o compartilhamento tenha sido excluído ou tenha expirado.",
     "More" : "Mais",
     "More apps menu" : "Mais aplicativos",
     "Settings menu" : "Menu de configurações",
