@@ -39,7 +39,7 @@ OC.L10N.register(
     "Some of your link shares have been removed" : "Alguns dos links das suas partilhas foram removidos",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Devido a bugs de segurança tivemos que remover algumas das suas ligações às partilhas.\nPor favor veja o link para mais informação.",
     "The user limit of this instance is reached." : "O limite de utilizador desta instância foi atingido",
-    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Introduza a sua chave de subscrição para aumentar o limite de utilizadores. Para mais informações sobre A Nextcloud Enterprise consulte o website.",
+    "Learn more ↗" : "Aprenda mais ↗",
     "Preparing update" : "A preparar a atualização",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Etapa da reparação:",
@@ -233,8 +233,7 @@ OC.L10N.register(
     "Profile not found" : "Perfil não encontrado",
     "The profile does not exist." : "O perfil não existe.",
     "Back to %s" : "Voltar a %s",
-    "File not found" : "Ficheiro não encontrado",
-    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Este documento não pode ser encontrado no servidor. Talvez a partilha tenha sido apagada ou expirado?",
+    "Page not found" : "Página não encontrada",
     "Too many requests" : "Muitos pedidos",
     "Error" : "Erro",
     "Previous" : "Anterior",
@@ -322,12 +321,15 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Esta instância %s está atualmente no modo de manutenção, o que poderá demorar algum tempo.",
     "This page will refresh itself when the instance is available again." : "Esta página irá ser atualizada quando a instância ficar novamente disponível.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacte o seu administrador do sistema se esta mensagem persistir ou apareceu inesperadamente.",
+    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Introduza a sua chave de subscrição para aumentar o limite de utilizadores. Para mais informações sobre A Nextcloud Enterprise consulte o website.",
     "[%d / %d]: Checking table %s" : "[%d / %d]: a verificar a tabela %s",
     "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Este servidor não tem ligação à Internet: Não foi possível detetar vários endpoints. Isso significa que algumas das funcionalidades como a montagem de armazenamento externo, notificações sobre atualizações ou instalação de aplicações de terceiros não funcionarão. Pode também não ser possível aceder a ficheiros remotamente e enviar e-mails de notificação. Sugerimos que ative a ligação à Internet para este servidor, caso pretenda ter todas as funcionalidades.",
     "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Os directórios de datos e ficheiros estão provavelmente acessíveis através da Internet. O ficheiro .htaccess não está a funcionar. É altamente recomendado que configure o seu servidor web para que o directório de dados deixa de estar acessível, ou movê-lo para fora da raiz de documentos do servidor web. ",
     "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "O cabeçalho HTTP \"{header}\" não está definido como \"{expected}\". Isto é um potencial risco de segurança ou privacidade, pelo que se recomenda que ajuste esta opção em conformidade.",
     "restricted" : "limitado",
     "invisible" : "invisível",
+    "File not found" : "Ficheiro não encontrado",
+    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Este documento não pode ser encontrado no servidor. Talvez a partilha tenha sido apagada ou expirado?",
     "More" : "Mais",
     "More apps menu" : "Menu de mais aplicações",
     "Settings menu" : "Menu de configurações",
