@@ -40,7 +40,7 @@ OC.L10N.register(
     "Some of your link shares have been removed" : "Некоторые из ваших ссылок на общие ресурсы были удалены",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Из-за ошибки в безопасности нам пришлось удалить некоторые из ваших ссылок на опубликованные файлы или папки. Перейдите по ссылке для получения дополнительной информации.",
     "The user limit of this instance is reached." : "Достигнут лимит пользователей этого экземпляра",
-    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Введите ключ подписки, чтобы увеличить лимит пользователей. Для получения дополнительной информации о Nextcloud Enterprise посетите наш веб-сайт.",
+    "Learn more ↗" : "Дополнительная информация ↗",
     "Preparing update" : "Подготовка к обновлению",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Шаг восстановления:",
@@ -99,7 +99,6 @@ OC.L10N.register(
     "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "В системе не установлены рекомендуемые модули PHP. Для улучшения производительности и совместимости рекомендуется установить эти модули.",
     "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "Для создания значка favicon приложением «Оформления» необходимо установить и активировать модуль «imagic» подсистемы PHP. ",
     "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required." : "Модули «gmp» и / или «bcmath» подсистемы PHP не активированы. Эти модули необходимы при использовании аутентификации без пароля WebAuth.",
-    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page about this ↗{linkend}." : "Похоже что вы используете 32-битную версию PHP. Для нормальной работы Nextcloud требуется 64-битная версия. Пожалуйста обновите вашу операционную систему и PHP до 64-битных версий. Для дополнительной информации {linkstart}обратитесь к документации.{linkend}",
     "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "Модуль php-imagick в этом случае не поддерживает SVG. Для лучшей совместимости рекомендуется установить его.",
     "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Некоторые поля базы данных не были преобразованы в тип big int. Операция преобразования таких полей может занять продолжительное время и должа быть запущена вручную. Чтобы выполнить преобразование, необходимо включить режим обслуживания и запустить в терминале команду «occ db:convert-filecache-bigint». Дополнительная информация представлена в {linkstart}документации ↗{linkend}.",
     "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "В настоящее время в качестве механизма БД используется SQLite. Для более крупных развёртываний рекомендуется перейти к использованию других баз данных.",
@@ -289,8 +288,7 @@ OC.L10N.register(
     "Profile not found" : "Профиль не найден",
     "The profile does not exist." : "Профиль не существует",
     "Back to %s" : "Вернуться к %s",
-    "File not found" : "Файл не найден",
-    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Документ не найден на сервере. Возможно доступ к нему был удален или истек срок действия доступа.",
+    "Page not found" : "Страница не найдена",
     "Too many requests" : "Превышено количество запросов",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Превышено количество запросов из вашей сети. Попробуйте позднее или сообщите администратору об этой ошибке.",
     "Error" : "Ошибка",
@@ -397,6 +395,7 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Этот сервер %s находится в режиме технического обслуживания, которое может занять некоторое время.",
     "This page will refresh itself when the instance is available again." : "Эта страница обновится автоматически когда сервер снова станет доступен.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Обратитесь к вашему системному администратору если это сообщение не исчезает или появляется неожиданно.",
+    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Введите ключ подписки, чтобы увеличить лимит пользователей. Для получения дополнительной информации о Nextcloud Enterprise посетите наш веб-сайт.",
     "[%d / %d]: Checking table %s" : "[%d / %d]: Проверка таблицы %s",
     "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Этот сервер не подключён к интернету: множество конечных устройств не могут быть доступны. Это означает, что не будут работать некоторые функции, такие как подключение внешнего хранилища, уведомления об обновлениях или установка сторонних приложений. Так же могут не работать удалённый доступ к файлам и отправка уведомлений по электронной почте. Для использования всех возможностей рекомендуется разрешить серверу доступ в Интернет.",
     "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Nextcloud версии 20 — последний выпуск, поддерживающий PHP версии 7.2. Для работы Nextcloud версии 21 потребуется PHP версии не ниже 7.3.",
@@ -410,6 +409,8 @@ OC.L10N.register(
     "Local document editing back-end used by the Collabora Online app." : "Исполняемый на стороне клиента компонент для редактирования документов, используемый приложением Collabora Online.",
     "restricted" : "ограниченный",
     "invisible" : "невидимый",
+    "File not found" : "Файл не найден",
+    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Документ не найден на сервере. Возможно доступ к нему был удален или истек срок действия доступа.",
     "More" : "Дополнительно",
     "More apps menu" : "Меню дополнительных приложений",
     "Settings menu" : "Меню настроек",
