@@ -40,7 +40,7 @@ OC.L10N.register(
     "Some of your link shares have been removed" : "Niektoré odkazy sprístupnenia boli odstránené.",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Kvôli bezpečnostnej chyba sme museli odstrániť niektoré z vašich odkazov pre sprístupnenie. Pre viac informácií nasledujte tento link.",
     "The user limit of this instance is reached." : "Limit pre počet užívateľov pre túto inštanciu bol dosiahnutý.",
-    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Zadaním kľúča na prihlásenie zvýšite limit pre počet užívateľov. Viac informácií o Nextcloud Enterprise nájdete na našom webe.",
+    "Learn more ↗" : "Viac informácií ↗",
     "Preparing update" : "Pripravuje sa aktualizácia",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Krok opravy:",
@@ -99,7 +99,6 @@ OC.L10N.register(
     "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "V tejto inštancii chýbajú niektoré odporúčané moduly PHP.\nAk chcete zlepšiť výkon a kompatibilitu, dôrazne odporúčame, aby ste ich nainštalovali.",
     "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "PHP modul „imagick“ nie je povolený, hoci tematická aplikácia áno. Aby generovanie favicon správne fungovalo, musíte nainštalovať a povoliť tento modul.",
     "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required." : "PHP moduly \"gmp\" a/alebo \"bcmath\" nie sú povolené. Ak používate autentifikáciu WebAuthn bez hesla, tieto moduly sú povinné.",
-    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page about this ↗{linkend}." : "Zdá sa, že používate 32-bitovú verziu PHP. Nextcloud potrebuje 64-bit, aby fungoval dobre. Inovujte svoj OS a PHP na 64-bitové! Ďalšie podrobnosti nájdete na {linkstart}stránke dokumentácie↗{linkend}.",
     "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "Modul php-imagick nemá podporu SVG. Pre lepšiu kompatibilitu sa odporúča nainštalovať ho.",
     "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Niektorým stĺpcom v databáze chýba konverzia na big int. Vzhľadom na to, že zmena typov stĺpcov na veľkých tabuľkách by mohla chvíľu trvať, neboli zmenené automaticky. Spustením príkazu „occ db: convert-filecache-bigint“ budú zmeny aplikované manuálne. Túto operáciu je potrebné vykonať v čase, keď je inštancia offline. Ďalšie informácie nájdete na {linkstart} dokumentačnej stránke ↗{linkend}.",
     "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "Ako databáza je použitá SQLite. Pre väčšie inštalácie odporúčame prejsť na inú databázu.",
@@ -289,8 +288,7 @@ OC.L10N.register(
     "Profile not found" : "Profil nenájdený",
     "The profile does not exist." : "Profil neexistuje.",
     "Back to %s" : "Späť na %s",
-    "File not found" : "Súbor nenájdený",
-    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Na serveri sa nepodarilo nájsť dokument. Je možné, že bolo zrušené sprístupnenie alebo skončila jeho platnosť.",
+    "Page not found" : "Stránka nenájdená",
     "Too many requests" : "Priveľa požiadavok",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Príliš mnoho požiadaviek z vašej siete. Skúste to znovu neskôr alebo kontaktujte svojho administrátora ak je toto chyba.",
     "Error" : "Chyba",
@@ -397,6 +395,7 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Táto %s inštancia je v súčasnej dobe v režime údržby. Počkajte prosím.",
     "This page will refresh itself when the instance is available again." : "Táto stránka sa obnoví sama hneď ako bude inštancia znovu dostupná.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontaktujte prosím správcu systému, ak sa táto správa objavuje opakovane alebo neočakávane.",
+    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Zadaním kľúča na prihlásenie zvýšite limit pre počet užívateľov. Viac informácií o Nextcloud Enterprise nájdete na našom webe.",
     "[%d / %d]: Checking table %s" : "[%d / %d]: Kontrola tabuľky %s",
     "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Server nemá funkčné pripojenie k internetu. Niektoré moduly ako napr. externé úložisko, oznámenie o dostupných aktualizáciách alebo inštalácia aplikácií tretích strán nebudú fungovať. Vzdialený prístup k súborom a odosielanie oznamovacích emailov tiež nemusí fungovať. Ak chcete využívať všetky funkcie, odporúčame povoliť tomuto serveru pripojenie k internetu.",
     "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Nextcloud 20 je posledné vydanie podporujúce PHP 7.2. Nextcloud 21 vyžaduje aspoň PHP 7.3.",
@@ -410,6 +409,8 @@ OC.L10N.register(
     "Local document editing back-end used by the Collabora Online app." : "Miestna úprava dokumentov využíva aplikáciu Collabora Online.",
     "restricted" : "obmedzený",
     "invisible" : "neviditeľný",
+    "File not found" : "Súbor nenájdený",
+    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Na serveri sa nepodarilo nájsť dokument. Je možné, že bolo zrušené sprístupnenie alebo skončila jeho platnosť.",
     "More" : "Viac",
     "More apps menu" : "Menu ostatných aplikácií",
     "Settings menu" : "Menu nastavení",
