@@ -39,7 +39,7 @@ OC.L10N.register(
     "Some of your link shares have been removed" : "Några av dina delade länkar har tagits bort",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "På grund av ett säkerhetsfel var vi tvungna att ta bort några av dina delade länkar. Se länken för mer information.",
     "The user limit of this instance is reached." : "Maximala användarantalet för denna instansen har uppnåts",
-    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Ange din subscription-nyckel för att öka användarbegränsningen. Se våran hemsida för mer information om Nextcloud Enterprise.",
+    "Learn more ↗" : "Läs mer ↗",
     "Preparing update" : "Förbereder uppdatering",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Reparationssteg: ",
@@ -114,12 +114,16 @@ OC.L10N.register(
     "Continue to {productName}" : "Fortsätt till {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Uppdateringen lyckades. Omdirigerar dig till {productName} om %n sekund.","Uppdateringen lyckades. Omdirigerar dig till {productName} om %n sekunder."],
     "More apps" : "Fler appar",
+    "Currently open" : "För närvarande öppen",
+    "_{count} notification_::_{count} notifications_" : ["{count} meddelande","{count} meddelanden"],
     "Log in" : "Logga in",
     "Logging in …" : "Loggar in ...",
     "Server side authentication failed!" : "Servern misslyckades med autentisering!",
     "Please contact your administrator." : "Kontakta din administratör.",
     "An internal error occurred." : "Ett internt fel uppstod.",
     "Please try again or contact your administrator." : "Försök igen eller kontakta din administratör.",
+    "Log in to {productName}" : "Logga in på {productName}",
+    "Account name or email" : "Användarnamn eller e-post",
     "Password" : "Lösenord",
     "Wrong username or password." : "Felaktigt användarnamn eller lösenord",
     "User disabled" : "Användare inaktiverad",
@@ -162,15 +166,23 @@ OC.L10N.register(
     "You have not added any info yet" : "Du har inte angivit någon information ännu",
     "{user} has not added any info yet" : "{user} har inte angivit någon information ännu",
     "Error opening the user status modal, try hard refreshing the page" : "Kunde inte öppna användarstatus-rutan, försök att ladda om sidan",
+    "Search starts once you start typing" : "Sökningen startar när du börjar skriva",
     "Reset search" : "Återställ sökning",
+    "Start search" : "Starta sökning",
     "Search for {name} only" : "Sök efter endast {name}",
     "No results for {query}" : "Inga resultat för {query}",
+    "Press enter to start searching" : "Tryck på enter för att börja söka",
     "Start typing to search" : "Börja skriva för att söka",
     "Loading more results …" : "Hämtar fler resultat ...",
     "Load more results" : "Hämta fler resultat",
     "Search" : "Sök",
     "An error occurred while searching for {type}" : "Ett fel uppstod vid sökning efter {type}",
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Ange {minSearchLength} tecken eller mer för att söka","Ange {minSearchLength} tecken eller mer för att söka"],
+    "This browser is not supported" : "Den här webbläsaren stöds inte",
+    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Din webbläsare stöds inte. Uppgradera till en nyare version eller en som stöds.",
+    "Continue with this unsupported browser" : "Fortsätt med webbläsare som inte stöds",
+    "Supported versions" : "Stödda versioner",
+    "{name} version {version} and above" : "{name} version {version} och högre",
     "Search {types} …" : "Sök {types} …",
     "Settings" : "Inställningar",
     "Could not load your contacts" : "Det gick inte att läsa in dina kontakter",
@@ -211,6 +223,8 @@ OC.L10N.register(
     "(all selected)" : "(Alla valda)",
     "({count} selected)" : "({count} valda)",
     "Error loading file exists template" : "Fel vid inläsning av fil finns i mall",
+    "Show list view" : "Visa listvy",
+    "Show grid view" : "Visa rutnätsvy",
     "Pending" : "Väntar",
     "Copy to {folder}" : "Kopiera till {folder}",
     "Move to {folder}" : "Flytta till {folder}",
@@ -256,8 +270,8 @@ OC.L10N.register(
     "Profile not found" : "Profil kunde inte hittas",
     "The profile does not exist." : "Profilen existerar inte.",
     "Back to %s" : "Tillbaka till %s",
-    "File not found" : "Filen kunde inte hittas",
-    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Dokumentet kunde inte hittas på servern. Kanske var delningen raderad eller har gått ut?",
+    "Page not found" : "Sidan hittades inte",
+    "The page could not be found on the server." : "Sidan kunde inte hittas på servern.",
     "Too many requests" : "För många förfrågningar",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Det kom för många förfrågningar från ditt nätverk. Försök senare eller kontakta din administratör om detta är ett fel.",
     "Error" : "Fel",
@@ -308,8 +322,10 @@ OC.L10N.register(
     "Skip to main content" : "Skippa till huvudinnehållet",
     "Skip to navigation of app" : "Skippa till navigering av app",
     "Get your own free account" : "Skaffa ett eget gratiskonto",
+    "%s's homepage" : "%s's hemsida",
     "Contacts" : "Kontakter",
     "Contacts menu" : "Kontaktmeny",
+    "Open settings menu" : "Öppna inställningsmenyn",
     "Confirm your password" : "Bekräfta ditt lösenord",
     "Connect to your account" : "Anslut ditt konto",
     "Please log in before granting %1$s access to your %2$s account." : "Logga in innan du ger %1$s åtkomst till ditt %2$s konto.",
@@ -318,12 +334,17 @@ OC.L10N.register(
     "Grant access" : "Tillåt åtkomst",
     "Alternative log in using app token" : "Alternativ inloggning med apptoken",
     "Account access" : "Kontoåtkomst",
+    "Currently logged in as %1$s (%2$s)." : "För närvarande inloggad som %1$s (%2$s).",
     "You are about to grant %1$s access to your %2$s account." : "Du håller på att ge %1$s åtkomst till ditt %2$s konto.",
     "Account connected" : "Konto anslutet",
     "Your client should now be connected!" : "Din klient ska nu vara ansluten!",
     "You can close this window." : "Du kan stänga det här fönstret.",
     "This share is password-protected" : "Denna delning är lösenordsskyddad",
+    "The password is wrong or expired. Please try again or request a new one." : "Lösenordet är fel eller har gått ut. Försök igen eller begär ett nytt.",
+    "Please type in your email address to request a temporary password" : "Skriv in din e-postadress för att begära ett tillfälligt lösenord",
     "Email address" : "E-postadress",
+    "Password sent!" : "Lösenord skickat!",
+    "You are not authorized to request a password for this share" : "Du har inte behörighet att begära ett lösenord för denna delning",
     "Go to %s" : "Gå till %s",
     "Two-factor authentication" : "Tvåfaktorsautentisering",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Förbättrad säkerhet är aktiverad för ditt konto. Välj en andra faktor för autentisering:",
@@ -357,6 +378,7 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Denna %s-instans befinner sig för närvarande i underhållsläge, vilket kan ta ett tag.",
     "This page will refresh itself when the instance is available again." : "Denna sida uppdaterar sig själv när instansen är tillgänglig igen.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Hör av dig till din systemadministratör om detta meddelande fortsätter eller visas oväntat.",
+    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Ange din subscription-nyckel för att öka användarbegränsningen. Se våran hemsida för mer information om Nextcloud Enterprise.",
     "[%d / %d]: Checking table %s" : "[%d / %d]: Kontrollerar tabell %s",
     "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Den här servern har ingen fungerande internetuppkoppling: flera slutpunkter kunde inte nås. Det här innebär att några av funktionerna som montering av extern lagring, aviseringar om uppdateringar eller installation av tredjepartsprogram inte fungerar. Åtkomst till filer på distans och skicka e-postmeddelanden kanske inte heller fungerar. Upprätta en anslutning från den här servern till Internet för att njuta av alla funktioner.",
     "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Nextcloud 20 är den sista versionen som stöder PHP 7.2. Nextcloud 21 kräver minst PHP 7.3.",
@@ -367,6 +389,8 @@ OC.L10N.register(
     "Local document editing back-end used by the Collabora Online app." : "Lokal dokumentredigering back-end som används av Collabora Online-appen.",
     "restricted" : "begränsad",
     "invisible" : "osynlig",
+    "File not found" : "Filen kunde inte hittas",
+    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Dokumentet kunde inte hittas på servern. Kanske var delningen raderad eller har gått ut?",
     "More" : "Mer",
     "More apps menu" : "Fler appar - meny",
     "Settings menu" : "Inställningsmeny",
