@@ -40,7 +40,8 @@ OC.L10N.register(
     "Some of your link shares have been removed" : "Bazı paylaşım bağlantılarınız silindi",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Bir güvenlik açığı nedeniyle bazı paylaşım bağlantılarınızı silmek zorunda kaldık. ayrıntılı bilgi almak için bağlantıya bakabilirsiniz.",
     "The user limit of this instance is reached." : "Bu kopya için kullanıcı sayısı sınırına ulaşıldı.",
-    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Kullanıcı sayısı sınırını arttırmak için abonelik anatarınızı yazın. Nextcloud Enterprise sürümü hakkında ayrıntılı bilgi almak için web sitemize bakabilirsiniz.",
+    "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Kullanıcı sayısı sınırını artırmak için destek uygulamasına abonelik anahtarınızı yazın. Bu ayrıca size Nextcloud Enterprise sürümünün sunduğu ve kurumsal operasyonlar için önemle önerilen tüm ek avantajları sağlar.",
+    "Learn more ↗" : "Ayrıntılı bilgi alın ↗",
     "Preparing update" : "Güncelleme hazırlanıyor",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Onarım adımı:",
@@ -99,7 +100,6 @@ OC.L10N.register(
     "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "Bu kopyada önerilen bazı PHP modülleri eksik. Daha iyi başarım ve uyumluluk için bu modüllerin kurulması önemle önerilir.",
     "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "Tema uygulamasında olmasına rağmen \"imagick\" PHP modülü etkinleştirilmemiş. Favicon oluşturma işleminin doğru çalışması için bu modülü kurmanız ve etkinleştirmeniz gerekir.",
     "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required." : "\"gmp\" ve/veya \"bcmath\" PHP modülleri etkinleştirilmemiş. WebAuthn parolasız kimlik doğrulaması kullanıyorsanız, bu modüller gereklidir.",
-    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page about this ↗{linkend}." : "32 bit bir PHP sürümü çalıştırıyorsunuz gibi görünüyor. Nextcloud uygulamasının iyi çalışması için 64 bit bir PHP sürümü kullanılmalıdır. Lütfen işletim sisteminizi ve PHP sürümünüzü 64 bit olacak şekilde yükseltin! Ayrıntılı bilgi almak için {linkstart}ilgili sayfaya bakabilirsiniz ↗{linkend}.",
     "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "Bu kopyadaki php-imagick modülünde SVG desteği yok. Daha iyi başarım ve uyumluluk için bu modülün kurulması önemle önerilir.",
     "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Veritabanında büyük tamsayıya dönüştürülecek bazı sütunlar eksik. Sütun türlerini büyük tablolara dönüştürme işlemi uzun sürebileceğinden bu işlem otomatik olarak yapılmaz. Sunucunuz normal çalışırken bekleyen değişiklikleri el ile uygulamak için \"occ db:convert-filecache-bigint\" komutunu yürütün. Bu işlem yapılırken Nextcloud kopyası çevrimdışı olur. Ayrıntılı bilgi almak için {linkstart}belgeler ↗{linkend} bölümüne bakabilirsiniz.",
     "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "Şu anda veritabanı olarak SQLite kullanılıyor. Daha büyük kurulumlar için farklı bir veritabanı arka ucuna geçmenizi öneriyoruz.",
@@ -202,6 +202,11 @@ OC.L10N.register(
     "Search" : "Arama",
     "An error occurred while searching for {type}" : "{type} aranırken bir sorun çıktı",
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Lütfen aramak için en az {minSearchLength} karakter yazın","Lütfen aramak için en az {minSearchLength} karakter yazın"],
+    "This browser is not supported" : "Bu tarayıcı desteklenmiyor",
+    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Web tarayıcınız desteklenmiyor. Lütfen daha yeni bir sürüme ya da desteklenen bir sürüme yükseltin.",
+    "Continue with this unsupported browser" : "Bu desteklenmeyen web tarayıcı ile ilerle",
+    "Supported versions" : "Desteklenen sürümler",
+    "{name} version {version} and above" : "{name} {version} üzeri sürümler",
     "Search {types} …" : "{types} arama…",
     "Settings" : "Ayarlar",
     "Could not load your contacts" : "Kişileriniz yüklenemedi",
@@ -289,8 +294,8 @@ OC.L10N.register(
     "Profile not found" : "Profil bulunamadı",
     "The profile does not exist." : "Profil bulunamadı.",
     "Back to %s" : "%s sayfasına dön",
-    "File not found" : "Dosya bulunamadı",
-    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Belge sunucu üzerinde bulunamadı. Paylaşım silinmiş ya da geçerlilik süresi dolmuş olabilir mi?",
+    "Page not found" : "Sayfa bulunamadı",
+    "The page could not be found on the server." : "Sayfa sunucuda bulunamadı.",
     "Too many requests" : "Çok fazla istekte bulunuldu",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Ağınızdan çok fazla istekte bulunuldu. Bir süre sonra yeniden deneyin ya da bir sorun olduğunu düşünüyorsanız BT yöneticiniz ile görüşün.",
     "Error" : "Hata",
@@ -397,6 +402,7 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Bu %s kopyası şu anda bakım kipinde, bu işlem biraz zaman alabilir.",
     "This page will refresh itself when the instance is available again." : "Sistem yeniden kullanılabilir olduğunda bu sayfa kendiliğinden yenilenecek",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Bu ileti görüntülenmeye devam ediyor ya da beklenmedik şekilde ortaya çıkıyorsa BT yöneticinizle görüşün.",
+    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Kullanıcı sayısı sınırını arttırmak için abonelik anatarınızı yazın. Nextcloud Enterprise sürümü hakkında ayrıntılı bilgi almak için web sitemize bakabilirsiniz.",
     "[%d / %d]: Checking table %s" : "[%d / %d]: %s tablosu denetleniyor",
     "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Bu sunucunun çalışan bir İnternet bağlantısı yok. Birden çok uç noktaya erişilemez. Bu durumda dış depolama alanı bağlama, güncelleme bildirimleri ya da üçüncü taraf uygulamalarını kurmak gibi bazı özellikler çalışmaz. Dosyalara uzaktan erişim ve bildirim e-postalarının gönderilmesi işlemleri de yapılamaz. Tüm bu özelliklerin kullanılabilmesi için sunucuyu İnternet üzerine bağlamanız önerilir.",
     "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Nextcloud 20 PHP 7.2 sürümünü destekleyen son sürümdür. Nextcloud 21 sürümü için en az PHP 7.3 gereklidir.",
@@ -410,6 +416,8 @@ OC.L10N.register(
     "Local document editing back-end used by the Collabora Online app." : "Collabora Online uygulaması ile yerel belge düzenleme altyapısı.",
     "restricted" : "kısıtlı",
     "invisible" : "görünmez",
+    "File not found" : "Dosya bulunamadı",
+    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Belge sunucu üzerinde bulunamadı. Paylaşım silinmiş ya da geçerlilik süresi dolmuş olabilir mi?",
     "More" : "Diğer",
     "More apps menu" : "Diğer uygulamalar menüsü",
     "Settings menu" : "Ayarlar menüsü",
