@@ -13,13 +13,13 @@ OC.L10N.register(
     "Missing a temporary folder" : "Відсутній каталог тимчасових файлів",
     "Could not write file to disk" : "Неможливо записати файл на диск",
     "A PHP extension stopped the file upload" : "Розширення PHP призупинило завантаження файлу",
-    "Invalid file provided" : "Надано невірний файл",
-    "No image or file provided" : "Зображення або файлу не надано",
+    "Invalid file provided" : "Надано помилковий файл",
+    "No image or file provided" : "Не надано зображення або файл",
     "Unknown filetype" : "Невідомий тип файлу",
     "An error occurred. Please contact your admin." : "Виникла помилка. Будь ласка, зв'яжіться з вашим адміністратором.",
     "Invalid image" : "Невірне зображення",
     "No temporary profile picture available, try again" : "Тимчасове зображення профілю недоступне, спробуйте ще раз",
-    "No crop data provided" : "Не вказана інформація про кадрування",
+    "No crop data provided" : "Відсутня інформація щодо кадрування",
     "No valid crop data provided" : "Не вказані коректні дані про кадрування",
     "Crop is not square" : "Кадр не є квадратом",
     "State token does not match" : "Токен стану не збігається",
@@ -40,7 +40,7 @@ OC.L10N.register(
     "Some of your link shares have been removed" : "Окремі посилання на спільні елементи було вилучено",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Через ваду з безпекою ми вимушені були вилучити деякі ваші спільні посилання. Будь ласка, перегляньте цю докладну інформацію.",
     "The user limit of this instance is reached." : "Досягнуто ліміту користувачів цього екземпляра.",
-    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Введіть ключ підписки, щоб збільшити ліміт користувачів. Для отримання додаткової інформації про Nextcloud Enterprise відвідайте наш веб-сайт.",
+    "Learn more ↗" : "Дізнайтеся більше ↗",
     "Preparing update" : "Підготовка оновлення",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Крок у відновленні:",
@@ -48,7 +48,7 @@ OC.L10N.register(
     "Repair warning:" : "Застереження щодо відновлення:",
     "Repair error:" : "Помилка під час відновлення:",
     "Please use the command line updater because automatic updating is disabled in the config.php." : "Просимо запустити процес оновлення з командного рядка, оскільки автоматичне оновлення вимкнено у файлі config.php.",
-    "Turned on maintenance mode" : "Увімкнено режим технічного обслуговування",
+    "Turned on maintenance mode" : "Активовано режим технічного обслуговування",
     "Turned off maintenance mode" : "Вимкнено режим технічного обслуговування",
     "Maintenance mode is kept active" : "Режим обслуговування залишається активним",
     "Updating database schema" : "Оновлення схеми бази даних",
@@ -99,7 +99,6 @@ OC.L10N.register(
     "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "У цьому екземплярі відсутні деякі рекомендовані модулі PHP. Для кращої продуктивності та кращої сумісності настійно рекомендується встановити їх.",
     "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "PHP-модуль \"imagick\" не ввімкнено, хоча програму для створення тем. Щоб генерація фавіконів працювала коректно, вам необхідно встановити та ввімкнути цей модуль.",
     "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required." : "Модулі PHP \"gmp\" і/або \"bcmath\" не ввімкнено. Якщо ви використовуєте автентифікацію без пароля WebAuthn, ці модулі є обов’язковими.",
-    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page about this ↗{linkend}." : "Здається, ви використовуєте 32-розрядну версію PHP. Для нормальної роботи Nextcloud потрібна 64-розрядна версія. Будь ласка, оновіть свою ОС і PHP до 64-бітної! Для отримання додаткової інформації прочитайте {linkstart}сторінку документації про це ↗{linkend}.",
     "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "Модуль php-imagick у цьому випадку не підтримує SVG. Для кращої сумісності рекомендується встановити його.",
     "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "У деяких стовпцях бази даних відсутнє перетворення на big int. Через те, що зміна типів стовпців у великих таблицях могла зайняти деякий час, вони не були змінені автоматично. Запустивши \"occ db:convert-filecache-bigint\", ці незавершені зміни можна застосувати вручну. Цю операцію потрібно виконати, коли примірник перебуває в автономному режимі. Для отримання додаткової інформації прочитайте {linkstart}сторінку документації про це ↗{linkend}.",
     "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite в даний час використовується як база даних бекенда.  Для великих установок ми рекомендуємо перейти на інший тип серверу баз даних.",
@@ -121,7 +120,7 @@ OC.L10N.register(
     "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "Заголовок HTTP \"Strict-Transport-Security\" не має принаймні значення \"{seconds}\" секунд. Для підвищення безпеки рекомендується ввімкнути HSTS, як описано в {linkstart}порадах щодо безпеки ↗{linkend}.",
     "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}." : "Незахищений доступ до сайту через HTTP. Настійно рекомендуємо налаштувати сервер на вимогу HTTPS, як описано в {linkstart}порадах щодо безпеки ↗{linkend}.",
     "unknown text" : "невідомий текст",
-    "Hello world!" : "Привіт світ!",
+    "Hello world!" : "Привіт, світе!",
     "sunny" : "сонячно",
     "Hello {name}, the weather is {weather}" : "Привіт {name}, погода {weather} ",
     "Hello {name}" : "Привіт {name}",
@@ -190,18 +189,21 @@ OC.L10N.register(
     "You have not added any info yet" : "Ви ще не додали жодної інформації",
     "{user} has not added any info yet" : "{user} ще не додав жодної інформації",
     "Error opening the user status modal, try hard refreshing the page" : "Помилка відкриття режиму статусу користувача. Спробуйте оновити сторінку",
-    "Search starts once you start typing" : "Пошук починається, коли ви починаєте вводити текст",
+    "Search starts once you start typing" : "Пошук здійснюється під час введення тексту",
     "Reset search" : "Повторити пошук",
     "Start search" : "Розпочати пошук",
     "Search for {name} only" : "Пошук лише у {name}",
     "No results for {query}" : "Немає результатів для {query}",
-    "Press enter to start searching" : "Натисніть enter, щоб почати пошук",
-    "Start typing to search" : "Що шукаємо",
+    "Press enter to start searching" : "Натисніть Enter, щоб почати пошук",
+    "Start typing to search" : "Що шукаємо?",
     "Loading more results …" : "Завантаження інших результатів…",
     "Load more results" : "Завантажити більше результатів",
     "Search" : "Пошук",
     "An error occurred while searching for {type}" : "Завантажити більше результатів",
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Для пошуку введіть {minSearchLength} або більше символів","Для пошуку введіть {minSearchLength} або більше символів","Для пошуку введіть {minSearchLength} або більше символів","Для пошуку введіть {minSearchLength} або більше символів"],
+    "This browser is not supported" : "Цей бравзер не підтримується",
+    "Supported versions" : "Підтримувані версії",
+    "{name} version {version} and above" : "{name} версія {version} та вище",
     "Search {types} …" : "Пошук {types} …",
     "Settings" : "Налаштування",
     "Could not load your contacts" : "Неможливо завантажити ваші контакти",
@@ -289,8 +291,8 @@ OC.L10N.register(
     "Profile not found" : "Профіль не знайдено",
     "The profile does not exist." : "Профіль не існує.",
     "Back to %s" : "Назад до %s",
-    "File not found" : "Файл не знайдено",
-    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Документ не знайдено на сервері. Можливо спільний доступ було закрито або термін дії доступу вичерпано.",
+    "Page not found" : "Сторінку не знайдено",
+    "The page could not be found on the server." : "Сторінку не знайдено на сервері.",
     "Too many requests" : "Забагато запитів",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Забагато запитів із вашої мережі. Повторіть спробу пізніше або зверніться до адміністратора, якщо це помилка.",
     "Error" : "Помилка",
@@ -319,7 +321,7 @@ OC.L10N.register(
     "Data folder" : "Каталог з даними",
     "Configure the database" : "Налаштування бази даних",
     "Only %s is available." : "Доступно тільки %s.",
-    "Install and activate additional PHP modules to choose other database types." : "Встановіть та активуйте додаткові модулі PHP для того, щоб вибрати тип БД.",
+    "Install and activate additional PHP modules to choose other database types." : "Встановіть та активуйте додаткові модулі PHP, щоб вибрати інший тип БД.",
     "For more details check out the documentation." : "За подробицями зверніться до документації.",
     "Database user" : "Користувач бази даних",
     "Database password" : "Пароль для бази даних",
@@ -346,7 +348,7 @@ OC.L10N.register(
     "Contacts menu" : "Меню контактів",
     "Open settings menu" : "Відкрийте меню налаштувань",
     "Confirm your password" : "Підтвердіть пароль",
-    "Connect to your account" : "Підключитись до свого облікового запису",
+    "Connect to your account" : "Увійти до вашого облікового запису",
     "Please log in before granting %1$s access to your %2$s account." : "Для надання %1$s доступу до облікового запису %2$s необхідно увійти в систему.",
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Якщо ви не намагаєтеся налаштувати новий пристрій або програму, хтось намагається обманом змусити вас надати доступ до ваших даних. У цьому випадку не продовжуйте, а зверніться до системного адміністратора.",
     "App token" : "Токен застосунку",
@@ -391,12 +393,13 @@ OC.L10N.register(
     "Update needed" : "Оновлення необхідно",
     "Please use the command line updater because you have a big instance with more than 50 users." : "Будь ласка, скористайтеся оновленням з командного рядка, оскільки у вас є більш ніж 50 користувачів.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Щоб отримати допомогу, перегляньте  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">документацію</a>.",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Я знаю, що, якщо я продовжую виконувати оновлення через вебінтерфейс, існує ризик того, що запит завершиться по тайм-ауту, що може призвести до втрати даних, але я маю резервну копію та знаю, як відновити мій екземпляр у випадку невдачі.",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Я знаю, що, якщо я продовжую виконувати оновлення через вебінтерфейс, існує ризик того, що запит завершиться по тайм-ауту, що може призвести до втрати даних, але я маю резервну копію та знаю, як відновити мій сервер у випадку невдачі.",
     "Upgrade via web on my own risk" : "Оновлення через веб-інтерфейс на свій страх і ризик",
     "Maintenance mode" : "Режим технічного обслуговування",
     "This %s instance is currently in maintenance mode, which may take a while." : "Цей сервер %s перебуває в режимі технічного обслуговування, що може зайняти деякий час.",
     "This page will refresh itself when the instance is available again." : "Ця сторінка оновиться автоматично, коли сервер знову стане доступний.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Зверніться до вашого системного адміністратора, якщо це повідомлення не зникає або з'являється несподівано.",
+    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Введіть ключ підписки, щоб збільшити ліміт користувачів. Для отримання додаткової інформації про Nextcloud Enterprise відвідайте наш веб-сайт.",
     "[%d / %d]: Checking table %s" : "[%d / %d]: Перевірка таблиці %s",
     "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Цей сервер не має робочого з’єднання з Інтернетом: неможливо отримати доступ до кількох кінцевих точок. Це означає, що деякі функції, як-от підключення зовнішньої пам’яті, сповіщення про оновлення або встановлення програм сторонніх розробників, не працюватимуть. Віддалений доступ до файлів і надсилання сповіщень електронною поштою також можуть не працювати. Встановіть з’єднання цього сервера з Інтернетом, щоб користуватися всіма функціями.",
     "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Nextcloud 20 є останнім випуском, що підтримує PHP 7.2. Nextcloud 21 вимагає принаймні PHP 7.3.",
@@ -410,6 +413,8 @@ OC.L10N.register(
     "Local document editing back-end used by the Collabora Online app." : "Локальний сервер редагування документів, який використовується програмою Collabora Online.",
     "restricted" : "обмежений",
     "invisible" : "невидимий",
+    "File not found" : "Файл не знайдено",
+    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Документ не знайдено на сервері. Можливо спільний доступ було закрито або термін дії доступу вичерпано.",
     "More" : "Більше",
     "More apps menu" : "Меню з більшим числом застосунків",
     "Settings menu" : "Меню налаштувань",
