@@ -5,62 +5,53 @@ OC.L10N.register(
     "File is too big" : "Tệp quá lớn",
     "The selected file is not an image." : "Tệp tin được chọn không phải là ảnh.",
     "The selected file cannot be read." : "Tệp tin được chọn không thể đọc.",
+    "The file was uploaded" : "Tập tin đã được tải lên",
+    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Tập tin tải lên đã vượt quá upload_max_filesize giới hạn trong hệ thống",
+    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Tập được tải lên vượt quá MAX_FILE_SIZE đã được giới hạn trong biểu mẫu HTML",
+    "The file was only partially uploaded" : "Tệp chỉ được tải lên một phần",
+    "No file was uploaded" : "Chưa có tệp nào dược tải lên",
+    "Missing a temporary folder" : "Thiếu một thư mục tạm thời",
+    "Could not write file to disk" : "Không thể ghi tệp lên ổ đĩa",
+    "A PHP extension stopped the file upload" : "Một phần mở rộng của PHP đã dừng tải tệp lên",
     "Invalid file provided" : "File không hợp lệ",
     "No image or file provided" : "Không có hình ảnh hoặc tập tin được cung cấp",
     "Unknown filetype" : "Không biết kiểu tập tin",
-    "Invalid image" : "Hình ảnh không hợp lệ",
     "An error occurred. Please contact your admin." : "Có lỗi xảy ra. Vui lòng báo cho quản trị viên.",
+    "Invalid image" : "Hình ảnh không hợp lệ",
     "No temporary profile picture available, try again" : "Ảnh cá nhân tạm thời không có giá trị, hãy thử lại",
     "No crop data provided" : "Không có dữ liệu nguồn được cung cấp",
     "No valid crop data provided" : "Dữ liệu trích xuất không hợp lệ",
     "Crop is not square" : "Trích xuất không chuẩn",
     "State token does not match" : "Mã trạng thái không khớp",
+    "Invalid app password" : "Mật khẩu ứng dụng không hợp lệ",
+    "Could not complete login" : "Không thể hoàn thành đăng nhập",
+    "Login" : "Đăng nhập",
     "Password reset is disabled" : "Đã tắt chức năng đặt lại mật khẩu",
-    "Couldn't reset password because the token is invalid" : "Không thể thiết lập lại mật khẩu do token không hợp lệ",
-    "Couldn't reset password because the token is expired" : "Không thể thiết lập lại mật khẩu do token hết hạn",
     "%s password reset" : "%s thiết lập lại mật khẩu",
     "Password reset" : "Đặt lại mật khẩu",
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Nhấp vào nút sau để đặt lại mật khẩu. Nếu bạn không yêu cầu đặt lại mật khẩu, hãy bỏ qua email này.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Nhấp vào liên kết sau để đặt lại mật khẩu của bạn. Nếu bạn không yêu cầu đặt lại mật khẩu, hãy bỏ qua email này.",
     "Reset your password" : "Đổi mật khẩu",
+    "Nextcloud Server" : "Máy chủ vWorkspace",
+    "Learn more ↗" : "Để biết thêm↗",
     "Preparing update" : "Đang chuẩn bị cập nhật",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Please use the command line updater because automatic updating is disabled in the config.php." : "Xin vui lòng sử dụng câu lệnh cập nhật bằng dòng lệnh do cập nhật tự động bị vô hiệu hóa trong file config.php",
-    "[%d / %d]: Checking table %s" : "[%d / %d]: đang kiểm tra bảng được %s",
     "Turned on maintenance mode" : "Bật chế độ bảo trì",
     "Turned off maintenance mode" : "Tắt chế độ bảo trì",
     "Maintenance mode is kept active" : "Chế độ bảo trì đang được kích hoạt",
     "Updating database schema" : "Đang cập nhật lược đồ cơ sở dữ liệu",
     "Updated database" : "Cơ sở dữ liệu đã được cập nhật",
-    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Đang kiểm tra xem lược đồ cơ sở dữ liệu có thể được cập nhật hay không (việc này có thể mất nhiều thời gian do phụ thuộc vào kích cỡ của cơ sở dữ liệu)",
-    "Checked database schema update" : "Cập nhật lược đồ cơ sở dữ liệu đã được kiểm tra",
-    "Checking updates of apps" : "Đang kiểm tra các bản cập nhật của các ứng dụng",
-    "Checking for update of app \"%s\" in appstore" : "Đang kiểm tra cập nhật của ứng dụng %s trong appstore ",
-    "Update app \"%s\" from appstore" : "Cập nhật ứng dụng \"%s\" từ appstore",
-    "Checked for update of app \"%s\" in appstore" : "Đã kiểm tra bản cập nhật của ứng dụng \"%s\" trong kho ứng dụng",
     "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Đang kiểm tra liệu lược đồ cơ sở dữ liệu đối với %s có thể được cập nhật hay không (việc này có thể mất nhiều thời gian phụ thuộc vào kích cỡ của cơ sở dữ liệu)",
-    "Checked database schema update for apps" : "Bản cập nhật lược đồ cơ sở dữ liệu cho các ứng dụng đã được kiểm tra",
+    "Updated \"%1$s\" to %2$s" : "Đã cập nhật \"%1$s\" lên %2$s",
     "Set log level to debug" : "Thiết lập cấp độ ghi nhật ký để gỡ rối",
     "Reset log level" : "Thiế lập lại cấp độ ghi nhật ký hệ thống",
     "Starting code integrity check" : "Bắt đầu mã kiểm tra sự toàn vẹn",
     "Finished code integrity check" : "Kết thúc mã kiểm tra sự toàn vẹn",
     "%s (incompatible)" : "%s (không tương thích)",
-    "Following apps have been disabled: %s" : "Các ứng dụng sau bị vô hiệu hóa: %s",
+    "The following apps have been disabled: %s" : "Những ứng dụng sau đây đã bị tắt: %s",
     "Already up to date" : "Đã được cập nhật bản mới nhất",
-    "Very weak password" : "Mật khẩu rất yếu",
-    "Weak password" : "Mật khẩu yếu",
-    "So-so password" : "Mật khẩu tạm được",
-    "Good password" : "Mật khẩu tốt",
-    "Strong password" : "Mật khẩu mạnh",
     "Error occurred while checking server setup" : "Có lỗi xảy ra khi kiểm tra thiết lập máy chủ",
-    "Non-existing tag #{tag}" : "Thẻ không tồn tại # {tag}",
-    "restricted" : "hạn chế",
-    "invisible" : "không thể nhìn thấy.",
-    "({scope})" : "({scope})",
-    "Delete" : "Xóa",
-    "Rename" : "Sửa tên",
-    "Collaborative tags" : "Thẻ cộng tác",
-    "No tags found" : "Không tìm thấy thẻ",
     "unknown text" : "văn bản không rõ",
     "Hello world!" : "Hello world!",
     "sunny" : "nắng",
@@ -75,28 +66,27 @@ OC.L10N.register(
     "Please reload the page." : "Vui lòng tải lại trang.",
     "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Quá trình cập nhật không thành công. Để biết thêm thông tin chi tiết <a href=\"{url}\">đề nghị xem các bài viết trong diễn đàn </a> để xử lý vấn đề này.",
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Quá trình cập nhật không thành công. Xin vui lòng báo lại vấn đề gặp phải trong tới  <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Cộng đồng Nextcloud</a>.",
-    "Continue to Nextcloud" : "Tiếp tục đến Nextcloud",
-    "_The update was successful. Redirecting you to Nextcloud in %n second._::_The update was successful. Redirecting you to Nextcloud in %n seconds._" : ["Cập nhật thành công. Đang chuyển hướng bạn tới Nextcloud trong %ngiây."],
-    "Searching other places" : "Tìm kiếm các nơi khác",
-    "No search results in other folders for {tag}{filter}{endtag}" : "Không có kết quả tìm kiếm trong các thư mục khác cho {tag} {filter} {endtag}",
-    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} kết quả tìm kiếm trong các thư mục khác"],
+    "More apps" : "Thêm ứng dụng",
+    "Log in" : "Đăng nhập",
+    "Logging in …" : "Đang đăng nhập",
     "Server side authentication failed!" : "Xác thực phía máy chủ không thành công!",
     "Please contact your administrator." : "Vui lòng liên hệ với quản trị viên.",
     "An internal error occurred." : "Đã xảy ra một lỗi nội bộ.",
     "Please try again or contact your administrator." : "Vui lòng thử lại hoặc liên hệ quản trị của bạn.",
-    "Username or email" : "Tên truy cập hoặc email",
     "Password" : "Mật khẩu",
-    "Log in" : "Đăng nhập",
-    "Logging in …" : "Đang đăng nhập",
     "User disabled" : "Vô hiệu hóa sử dụng",
+    "Username or email" : "Tên truy cập hoặc email",
     "Reset password" : "Khôi phục mật khẩu",
     "Couldn't send reset email. Please contact your administrator." : "Không thể gửi thư điện tử yêu cầu thiết lập lại. Xin vui lòng liên hệ quản trị hệ thống",
-    "Password can not be changed. Please contact your administrator." : "Không thể thay đổi được mật khẩu. Xin vui lòng liên hệ người quản trị hệ thống.",
     "Back to login" : "Quay lại trang đăng nhập",
     "New password" : "Mật khẩu mới",
     "I know what I'm doing" : "Tôi biết tôi đang làm gì",
-    "Cancel" : "Hủy",
+    "Skip" : "Bỏ qua",
     "Forgot password?" : "Quên mật khẩu sao?",
+    "Back" : "Quay lại",
+    "Reset search" : "Đặt lại tìm kiếm",
+    "Load more results" : "Tải thêm kết quả",
+    "Search" : "Tìm kiếm",
     "Settings" : "Cài đặt",
     "Could not load your contacts" : "Không thể tải liên hệ của bạn",
     "Search contacts …" : "Tìm liên hệ ...",
@@ -107,6 +97,15 @@ OC.L10N.register(
     "No" : "Không",
     "Yes" : "Có",
     "No files in here" : "Không có file nào ở đây",
+    "New folder" : "Tạo thư mục",
+    "Name" : "Tên",
+    "Size" : "Kích cỡ",
+    "Modified" : "Thay đổi",
+    "\"{name}\" is an invalid file name." : "\"{name}\" không được chấp nhận",
+    "File name cannot be empty." : "Tên file không được rỗng",
+    "\"/\" is not allowed inside a file name." : "\"/\" ‎không được phép có trong tên tệp.‎",
+    "\"{name}\" is not an allowed filetype" : "\"{name}\" không phải là loại tập tin được cho phép",
+    "{newName} already exists" : "{newName} đã có",
     "Choose" : "Chọn",
     "Copy" : "Sao chép",
     "Move" : "Chuyển",
@@ -120,6 +119,7 @@ OC.L10N.register(
     "Already existing files" : "Các file đang tồn tại",
     "Which files do you want to keep?" : "Bạn muốn tiếp tục với những tập tin nào?",
     "If you select both versions, the copied file will have a number added to its name." : "Nếu bạn chọn cả hai phiên bản, tập tin được sao chép sẽ được đánh thêm số vào tên của nó.",
+    "Cancel" : "Hủy",
     "Continue" : "Tiếp tục",
     "(all selected)" : "(Tất cả các lựa chọn)",
     "({count} selected)" : "({count} được chọn)",
@@ -127,7 +127,7 @@ OC.L10N.register(
     "Pending" : "Đang chờ được phê duyệt",
     "Copy to {folder}" : "Sao chép tới thư mục {folder}",
     "Move to {folder}" : "Chuyển tới thư mục {folder}",
-    "Saving..." : "Đang lưu...",
+    "Saving …" : "Đang lưu ...",
     "Authentication required" : "Cần phải được xác thực",
     "This action requires you to confirm your password" : "Để thực hiện hành động này, yêu cầu bạn phải nhập lại mật khẩu",
     "Confirm" : "Xác nhận",
@@ -135,16 +135,30 @@ OC.L10N.register(
     "seconds ago" : "vài giây trước",
     "Connection to server lost" : "Kết nối tới máy chủ bị mất",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Xảy ra lỗi khi tải trang, tải lại trong %n giây"],
+    "Very weak password" : "Mật khẩu rất yếu",
+    "Weak password" : "Mật khẩu yếu",
+    "So-so password" : "Mật khẩu tạm được",
+    "Good password" : "Mật khẩu tốt",
+    "Strong password" : "Mật khẩu mạnh",
     "No action available" : "Không có hành động nào",
     "Error fetching contact actions" : "Lỗi khi nạp liên hệ",
+    "Non-existing tag #{tag}" : "Thẻ không tồn tại # {tag}",
+    "Restricted" : "Bị giới hạn",
+    "Invisible" : "Vô hình",
+    "Delete" : "Xóa",
+    "Rename" : "Sửa tên",
+    "Collaborative tags" : "Thẻ cộng tác",
+    "No tags found" : "Không tìm thấy thẻ",
     "Personal" : "Cá nhân",
     "Users" : "Người dùng",
     "Apps" : "Ứng dụng",
     "Admin" : "Quản trị",
     "Help" : "Giúp đỡ",
     "Access forbidden" : "Truy cập bị cấm",
-    "File not found" : "Không tìm thấy tệp tin",
+    "Back to %s" : "Quay lại %s",
+    "Page not found" : "Trang không tìm thấy",
     "Error" : "Lỗi",
+    "Previous" : "Trước",
     "Internal Server Error" : "Lỗi máy chủ.",
     "The server was unable to complete your request." : "Máy chủ không thể hoàn thành được yêu cầu của bạn",
     "If this happens again, please send the technical details below to the server administrator." : "Nếu điều này tiếp tục xảy ra, xin vui lòng gửi thông tin kỹ thuật chi tiết tới người quản trị hệ thống.",
@@ -162,6 +176,7 @@ OC.L10N.register(
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Thư mục và file dữ liệu của bạn có thể được truy cập từ internet bởi vì file .htaccess không hoạt động",
     "Create an <strong>admin account</strong>" : "Tạo một <strong>tài khoản quản trị</strong>",
     "Username" : "Tên đăng nhập",
+    "Show password" : "Hiện mật khẩu",
     "Storage & database" : "Lưu trữ & cơ sở dữ liệu",
     "Data folder" : "Thư mục dữ liệu",
     "Configure the database" : "Cấu hình cơ sở dữ liệu",
@@ -175,31 +190,26 @@ OC.L10N.register(
     "Database host" : "Database host",
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Vui lòng xác định số cổng cùng với tên máy chủ lưu trữ (ví dụ: localhost: 5432).",
     "Performance warning" : "Cảnh báo hiệu suất",
-    "Finish setup" : "Cài đặt hoàn tất",
-    "Finishing …" : "Đang hoàn thành ...",
+    "Install" : "Cài đặt",
     "Need help?" : "Cần hỗ trợ ?",
     "See the documentation" : "Xem tài liệu",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Ứng dụng này yêu cầu JavaScript để hoạt động chính xác. Vui lòng {linkstart} bật JavaScript {linkend} và tải lại trang.",
-    "More apps" : "Thêm ứng dụng",
-    "More apps menu" : "Nhiều trình đơn ứng dụng hơn",
-    "Search" : "Tìm kiếm",
-    "Reset search" : "Đặt lại tìm kiếm",
     "Contacts" : "Liên hệ",
     "Contacts menu" : "Trình đơn liên hệ",
-    "Settings menu" : "Trình đơn thiết lập",
     "Confirm your password" : "Xác nhận mật khẩu của bạn",
     "Connect to your account" : "Kết nối tài khoản của bạn",
     "App token" : "Dấu hiệu ứng dụng",
+    "Grant access" : "Cấp quyền truy cập",
     "Account access" : "Truy cập tài khoản",
-    "The password is wrong. Try again." : "Sai mật khẩu. Hãy thử lại.",
+    "This share is password-protected" : "Chia sẽ này được bảo vệ bởi mật khẩu",
+    "Email address" : "Địa chỉ thư điện tử",
+    "Go to %s" : "Đi tới %s",
     "Two-factor authentication" : "Xác thực 2 bước",
     "Use backup code" : "Sử dụng mã dự phòng",
-    "Cancel log in" : "Hủy đăng nhập",
     "Error while validating your second factor" : "Lỗi khi xác thực 2 bước",
     "Access through untrusted domain" : "Truy nhập thông qua tên miền không đáng tin",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Xin vui lòng liên hệ với quản trị hệ thống của bạn. Nếu ban là người quản trị hệ thống, sửa phần thiết lập \"trusted_domains\" trong file config/config.php giống như trong ví dụ tại file config.sample.php.",
     "App update required" : "Ứng dụng yêu cầu cập nhật",
-    "These apps will be updated:" : "Những ứng dụng sẽ được cập nhật:",
     "These incompatible apps will be disabled:" : "Những ứng dụng không tương thích sẽ bị tắt:",
     "The theme %s has been disabled." : "Giao diện %s đã bị tắt.",
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Bạn cần phải bảo đảm rằng cơ sở dữ liệu, thư mục chứa file cấu hình hệ thống và thư mục chứa dữ liệu người dùng phải được sao lưu trước khi thực hiện.",
@@ -213,71 +223,13 @@ OC.L10N.register(
     "Upgrade via web on my own risk" : "Nâng cấp qua web",
     "This %s instance is currently in maintenance mode, which may take a while." : "Bản cài đặt%s hiện tại đang trong chế độ \"bảo trì\", do vậy có thể bạn cần phải đợi thêm chút ít thời gian.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Liên hệ với người quản trị nếu lỗi này vẫn tồn tại hoặc xuất hiện bất ngờ.",
-    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Không thể gửi thư điện tử yêu cầu thiết lập lại vì chưa có địa chỉ thư điện tử đối với tên đăng nhập này. Xin vui long liên hệ với quản trị hệ thống.",
-    "Couldn't send reset email. Please make sure your username is correct." : "Không thể gửi thư điện tử yêu cầu thiết lập lại. Xin vui lòng kiểm tra tên tài khoản đăng nhập",
-    "Dismiss" : "Bỏ qua",
-    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Liên kết để thiết lập lại mật khẩu của bạn vừa được gửi tới hộp thư điện tử của bạn. Nếu bạn không nhận được liên kết ấy trong vòng một khoảng thời gian xác định, xin vui long kiểm tra thư mục thư rác (spam/junk). <br> Nếu không nhận được thư có liên kết nói trên, xin vui lòng liên hệ quản trị hệ thống của bạn.",
-    "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Các file của bạn đã được mã hóa. Sẽ không có cách nào lấy lại dữ liệu của bạn sau khi mật khẩu được thiết lập lại. <br/> Nếu bạn không chắc điều gì sẽ xảy ra, xin vui lòng liên hệ người quản trị hệ thốngtrước khi bạn tiếp tục. <br/> Bạn có <b> thực sự muốn </b> tiếp tục?",
-    "Sending email …" : "Đang gửi mail...",
-    "Shared" : "Được chia sẻ",
-    "Shared with" : "Chia sẽ với",
-    "Shared by" : "Đã chia sẽ bởi",
-    "Choose a password for the public link" : "Chọn mật khẩu cho liên kết công khai",
-    "Choose a password for the public link or press the \"Enter\" key" : "Chọn một mật khẩu cho liên kết công cộng hoặc nhấn phím \"Enter\"",
-    "Copied!" : "Được sao chép",
-    "Not supported!" : "Không được hỗ trợ",
-    "Press ⌘-C to copy." : "Nhất  ⌘-C để sao chép",
-    "Press Ctrl-C to copy." : "Nhấn Ctrl-C để sao chép.",
-    "Resharing is not allowed" : "Chia sẻ lại không được cho phép",
-    "Link" : "Liên kết",
-    "Password protect" : "Mật khẩu bảo vệ",
-    "Allow editing" : "Cho phép điều chỉnh",
-    "Email link to person" : "Liên kết email tới cá nhân",
-    "Send" : "Gửi",
-    "Allow upload and editing" : "Cho phép tải lên và chỉnh sửa",
-    "Read only" : "Chỉ xem",
-    "File drop (upload only)" : "Kéo thả file (chỉ áp dụng trong trường hợp tải lên)",
-    "Set expiration date" : "Đặt ngày kết thúc",
-    "Expiration" : "Hết hạn",
-    "Expiration date" : "Ngày kết thúc",
-    "Unshare" : "Bỏ chia sẻ",
-    "Share to {name}" : "Chia sẻ với {name}",
-    "Share link" : "Chia sẻ liên kết",
-    "Password protect by Talk" : "Mật khẩu bảo vệ bằng đàm thoại",
-    "Could not unshare" : "Không thể chia sẻ",
-    "Shared with you and the group {group} by {owner}" : "Đã được chia sẽ với bạn và nhóm {group} bởi {owner}",
-    "Shared with you by {owner}" : "Đã được chia sẽ bởi {owner}",
-    "Choose a password for the mail share" : "Chọn một mật khẩu để chia sẻ qua mail",
-    "group" : "nhóm",
-    "remote" : "Từ xa",
-    "email" : "Thư điện tử",
-    "conversation" : "đàm thoại",
-    "shared by {sharer}" : "được chia sẻ bởi {sharer}",
-    "Can reshare" : "Có thể chia sẻ lại",
-    "Can edit" : "Có thể chỉnh sửa",
-    "Can create" : "Có thể tạo",
-    "Can change" : "Có thể thay đổi",
-    "Can delete" : "Có thể xóa",
-    "Access control" : "Kiểm soát truy cập",
-    "Error while sharing" : "Lỗi trong quá trình chia sẻ",
-    "Share details could not be loaded for this item." : "Các chi tiết chia sẻ không thể được nạp đối với mục này",
-    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Cần ít nhất {count} ký tự cho tự động hoàn thành"],
-    "This list is maybe truncated - please refine your search term to see more results." : "Danh sách này có thể bị cắt ngắn - vui lòng chỉnh cụm từ tìm kiếm của bạn để thấy nhiều hơn kết quả khác.",
-    "No users or groups found for {search}" : "Không có người dùng hoặc nhóm người dùng được tìm với từ khóa {search}",
-    "No users found for {search}" : "Không tìm thấy người dùng cho {search}",
-    "An error occurred (\"{message}\"). Please try again" : "Đã xảy ra lỗi (\"{message}\"). Hãy thử lại",
-    "An error occurred. Please try again" : "Có lỗi vừa xảy ra. Xin vui lòng thử lại",
-    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
-    "Share" : "Chia sẻ",
-    "Name or email address..." : "Tên hoặc địa chỉ email.",
-    "Name or federated cloud ID..." : "Tên hoặc ID đám mây liên kết.",
-    "Name, federated cloud ID or email address..." : "Tên người dùng, ID đám mây liên kết hoặc địa chỉ email.",
-    "Name..." : "Tên người dùng...",
-    "Error removing share" : "Lỗi khi xóa chia sẻ",
-    "SQLite will be used as database." : "SQLite sẽ được sử dụng làm cơ sở dữ liệu.",
-    "For larger installations we recommend to choose a different database backend." : "Đối với các cài đặt hệ thống lớn, chúng tôi khuyên bạn nên chọn một hệ cơ sở dữ liệu khác.",
-    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Đặc biệt khi đang sử dụng phần mềm đồng bộ dữ liệu desktop client  để đồng bộ file thì việc sử dụng CSDL SQLite là không nên.",
-    "Wrong password." : "Sai mật khẩu.",
-    "New Password" : "Mật khẩu mới"
+    "[%d / %d]: Checking table %s" : "[%d / %d]: đang kiểm tra bảng được %s",
+    "restricted" : "hạn chế",
+    "invisible" : "không thể nhìn thấy.",
+    "File not found" : "Không tìm thấy tệp tin",
+    "More" : "hơn",
+    "More apps menu" : "Nhiều trình đơn ứng dụng hơn",
+    "Settings menu" : "Trình đơn thiết lập",
+    "The password is wrong. Try again." : "Sai mật khẩu. Hãy thử lại."
 },
 "nplurals=1; plural=0;");
