@@ -8,6 +8,8 @@ OC.L10N.register(
     "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Файловете на приложението %1$s не бяха заменени правилно. Уверете се, че версията е съвместима със сървъра.",
     "Sample configuration detected" : "Открита е примерна конфигурация",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Усетено беше че примерната конфигурация е копирана. Това може да развли инсталацията ти и не се поддържа. Моля, прочети документацията преди да правиш промени на config.php",
+    "404" : "404",
+    "The page could not be found on the server." : "Страницата не е намерена на сървъра.",
     "%s email verification" : "%s имейл потвърждение",
     "Email verification" : "Имейл потвърждение",
     "Click the following button to confirm your email." : "Щракнете върху следния бутон, за да потвърдите имейла си.",
@@ -125,8 +127,6 @@ OC.L10N.register(
     "PostgreSQL username and/or password not valid" : "Невалидно PostgreSQL потребителско име и/или парола.",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X не се подържа и %s няма да работи правилно на тази платформа. Използвайте го на свой собствен риск!",
     "For the best results, please consider using a GNU/Linux server instead." : "За най-добри резултати, моля, помисли дали не бихте желали да използваште GNU/Linux сървър.",
-    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : " Изглежда, че този екземпляр %s работи в 32-битова PHP среда и open_basedir е конфигуриран в php.ini. Това ще доведе до проблеми с файлове над 4 GB и е силно обезкуражено.",
-    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Моля, премахтене настройката за open_basedir от вашия php.ini или преминете към 64-битово PHP.",
     "Set an admin username." : "Задайте потребителско име за администратор.",
     "Set an admin password." : "Задай парола за администратор.",
     "Cannot create or write into the data directory %s" : "Неуспешно създаване или записване в директорията  с данни \"data\" %s",
@@ -150,6 +150,7 @@ OC.L10N.register(
     "%1$s shared »%2$s« with you." : "%1$s сподели »%2$s« с вас.",
     "Click the button below to open it." : "Щракнете върху бутона по-долу, за да го отворите.",
     "The requested share does not exist anymore" : "Исканото споделяне вече не съществува",
+    "The user limit has been reached and the user was not created. Check your notifications to learn more." : "Потребителският лимит е достигнат и потребителят не е създаден. Проверете вашите известия, за да научите повече.",
     "Could not find category \"%s\"" : "Невъзможно откриване на категорията \"%s\".",
     "Sunday" : "неделя",
     "Monday" : "понеделник",
@@ -196,7 +197,6 @@ OC.L10N.register(
     "Oct." : "окт",
     "Nov." : "ное",
     "Dec." : "дек",
-    "The user limit has been reached and the user was not created." : "Потребителският лимит е достигнат и потребителят не е създаден. ",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Потребителските имена може да съдържат следните знаци: \"a-z\", \"A-Z\", \"0-9\" и \"_.@-'\"",
     "A valid username must be provided" : "Трябва да въведете валидно потребителско.",
     "Username contains whitespace at the beginning or at the end" : "Потребителското име започва или завършва с интервал.",
@@ -264,6 +264,9 @@ OC.L10N.register(
     "%s enter the database username." : "%s въведете потребител за базата данни.",
     "%s enter the database name." : "%s въведи име на базата данни.",
     "%s you may not use dots in the database name" : "%s, не може да ползваш точки в името на базата данни.",
+    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : " Изглежда, че този екземпляр %s работи в 32-битова PHP среда и open_basedir е конфигуриран в php.ini. Това ще доведе до проблеми с файлове над 4 GB и е силно обезкуражено.",
+    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Моля, премахтене настройката за open_basedir от вашия php.ini или преминете към 64-битово PHP.",
+    "The user limit has been reached and the user was not created." : "Потребителският лимит е достигнат и потребителят не е създаден. ",
     "Cannot read file" : "Не може да се прочете файл",
     "Cannot write into \"config\" directory" : "Неуспешен опит за запис в \"config\" папката.",
     "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Това обикновено може да бъде оправено като, се даде достъп на уеб сървъра да записва в config директорията. Погледнете %s",
