@@ -8,6 +8,8 @@ OC.L10N.register(
     "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Soubory aplikace %1$s nebyly nahrazeny řádně. Ověřte, že se jedná o verzi, která je kompatibilní se serverem.",
     "Sample configuration detected" : "Bylo zjištěno setrvání u předváděcího nastavení",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Pravděpodobně byla zkopírována nastavení ze vzorových souborů. Toto není podporováno a může poškodit vaši instalaci. Před prováděním změn v souboru config.php si přečtěte dokumentaci",
+    "404" : "404",
+    "The page could not be found on the server." : "Stránka nebyla na serveru nalezena.",
     "%s email verification" : "%s ověřování e-mailem",
     "Email verification" : "Ověřování e-mailem",
     "Click the following button to confirm your email." : "Pokud chcete potvrdit svůj e-mail, klikněte na následující tlačítko.",
@@ -125,8 +127,6 @@ OC.L10N.register(
     "PostgreSQL username and/or password not valid" : "Neplatné uživatelské jméno a/nebo heslo do PostgreSQL",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "macOS není podporován a %s nebude na této platformě správně fungovat. Používejte pouze na vlastní nebezpečí!",
     "For the best results, please consider using a GNU/Linux server instead." : "Místo toho zvažte pro nejlepší funkčnost použití GNU/Linux serveru.",
-    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Zdá se, že tato instance %s je provozována v 32-bitovém PHP prostředí a v php.ini je nastavena volba open_basedir. Toto povede k problémům se soubory většími než 4 GB a silně není doporučováno.",
-    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Odstraňte z php.ini nastavení volby open_basedir nebo přejděte na 64-bitové PHP.",
     "Set an admin username." : "Nastavte uživatelské jméno správce.",
     "Set an admin password." : "Nastavte heslo pro účet správce.",
     "Cannot create or write into the data directory %s" : "Nedaří se vytvořit nebo zapisovat do datového adresáře %s",
@@ -150,6 +150,7 @@ OC.L10N.register(
     "%1$s shared »%2$s« with you." : "%1$s vám nasdílel(a) „%2$s“.",
     "Click the button below to open it." : "Pro otevření klikněte na tlačítko níže.",
     "The requested share does not exist anymore" : "Požadované sdílení už neexistuje",
+    "The user limit has been reached and the user was not created. Check your notifications to learn more." : "Bylo dosaženo limitu počtu uživatelů a uživatel proto nebyl vytvořen. Podrobnosti viz upozornění pro vás.",
     "Could not find category \"%s\"" : "Nedaří se nalézt kategorii „%s“",
     "Sunday" : "neděle",
     "Monday" : "pondělí",
@@ -196,7 +197,6 @@ OC.L10N.register(
     "Oct." : "říj.",
     "Nov." : "list.",
     "Dec." : "pro.",
-    "The user limit has been reached and the user was not created." : "Bylo dosaženo limitu počtu uživatelů a uživatel proto nebyl vytvořen.",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Pouze následující znaky jsou povoleny pro uživatelské jméno: „a-z“, „A-Z“, „0-9“, a „_.@-'“",
     "A valid username must be provided" : "Je třeba zadat platné uživatelské jméno",
     "Username contains whitespace at the beginning or at the end" : "Uživatelské jméno je chybné – na jeho začátku či konci se nachází prázdný znak (mezera, tabulátor, atp.)",
@@ -264,6 +264,9 @@ OC.L10N.register(
     "%s enter the database username." : "Zadejte uživatelské jméno %s databáze.",
     "%s enter the database name." : "Zadejte název databáze pro %s databázi.",
     "%s you may not use dots in the database name" : "V názvu databáze %s není možné používat tečky.",
+    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Zdá se, že tato instance %s je provozována v 32-bitovém PHP prostředí a v php.ini je nastavena volba open_basedir. Toto povede k problémům se soubory většími než 4 GB a silně není doporučováno.",
+    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Odstraňte z php.ini nastavení volby open_basedir nebo přejděte na 64-bitové PHP.",
+    "The user limit has been reached and the user was not created." : "Bylo dosaženo limitu počtu uživatelů a uživatel proto nebyl vytvořen.",
     "Cannot read file" : "Nelze přečíst soubor",
     "Cannot write into \"config\" directory" : "Nelze zapisovat do adresáře „config“",
     "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Toto obvykle lze vyřešit udělením oprávnění k zápisu do kořenové složky webu pro účet, pod kterým je provozován webový server. Viz %s",
