@@ -93,6 +93,7 @@ OC.L10N.register(
     "Appearance and accessibility" : "Erscheinungsbild und Barrierefreiheit",
     "Apps" : "Apps",
     "Personal settings" : "Persönliche Einstellungen",
+    "Administration settings" : "Administrationseinstellungen",
     "Settings" : "Einstellungen",
     "Log out" : "Abmelden",
     "Users" : "Benutzer",
@@ -113,6 +114,9 @@ OC.L10N.register(
     "Role" : "Funktion",
     "Unknown user" : "Unbekannter Benutzer",
     "Additional settings" : "Zusätzliche Einstellungen",
+    "Enter the database username and name for %s" : "Den Datenbankbenutzernamen und den Namen eingeben für %s",
+    "Enter the database username for %s" : "Den Datenbankbenutzernamen eingeben für %s",
+    "Enter the database name for %s" : "Den Datenbanknamen eingeben für %s",
     "You cannot use dots in the database name %s" : "Du kannst keine Punkte im Datenbanknamen %s verwenden.",
     "MySQL username and/or password not valid" : "MySQL-Benutzername und/oder Passwort ungültig",
     "You need to enter details of an existing account." : "Du musst Details von einem existierenden Benutzer einfügen.",
@@ -121,8 +125,6 @@ OC.L10N.register(
     "PostgreSQL username and/or password not valid" : "PostgreSQL-Benutzername und/oder -Passwort ungültig",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X wird nicht unterstützt und %s wird auf dieser Plattform nicht richtig funktionieren. Die Benutzung erfolgt auf eigene Gefahr!",
     "For the best results, please consider using a GNU/Linux server instead." : "Zur Gewährleistung eines optimalen Betriebs sollte stattdessen ein GNU/Linux-Server verwendet werden.",
-    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Es scheint, dass diese %s-Instanz unter einer 32-Bit-PHP-Umgebung läuft und open_basedir in der Datei php.ini konfiguriert worden ist. Von einem solchen Betrieb wird dringend abgeraten, weil es dabei zu Problemen mit Dateien kommt, deren Größe 4 GB übersteigt.",
-    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Bitte entferne die open_basedir-Einstellung in deiner php.ini oder wechsele zu 64-Bit-PHP.",
     "Set an admin username." : "Einen Administrator-Benutzernamen setzen.",
     "Set an admin password." : "Ein Administrator-Passwort setzen.",
     "Cannot create or write into the data directory %s" : "Das Datenverzeichnis %s kann nicht erstellt oder es kann darin nicht geschrieben werden.",
@@ -134,7 +136,7 @@ OC.L10N.register(
     "»%s« added a note to a file shared with you" : "»%s« hat eine Bemerkung zu einer mit dir geteilten Datei hinzugefügt",
     "Open »%s«" : "»%s« öffnen",
     "%1$s via %2$s" : "%1$s über %2$s",
-    "You are not allowed to share %s" : "Die Freigabe von %s ist dir nicht erlaubt",
+    "You are not allowed to share %s" : "Du bist nicht berechtigt, %s zu teilen.",
     "Cannot increase permissions of %s" : "Kann die Berechtigungen von %s nicht erhöhen",
     "Files cannot be shared with delete permissions" : "Dateien mit Lösch-Berechtigungen können nicht geteilt werden",
     "Files cannot be shared with create permissions" : "Dateien mit Erstell-Berechtigungen können nicht geteilt werden",
@@ -146,6 +148,7 @@ OC.L10N.register(
     "%1$s shared »%2$s« with you." : "%1$s hat »%2$s« mit dir geteilt.",
     "Click the button below to open it." : "Klicke zum Öffnen auf die untere Schaltfläche.",
     "The requested share does not exist anymore" : "Die angeforderte Freigabe existiert nicht mehr",
+    "The user limit has been reached and the user was not created. Check your notifications to learn more." : "Das Benutzerlimit wurde erreicht und der Benutzer wurde nicht erstellt. Überprüfe deine Benachrichtigungen, um mehr zu erfahren.",
     "Could not find category \"%s\"" : "Die Kategorie \"%s“ konnte nicht gefunden werden",
     "Sunday" : "Sonntag",
     "Monday" : "Montag",
@@ -192,7 +195,6 @@ OC.L10N.register(
     "Oct." : "Okt.",
     "Nov." : "Nov.",
     "Dec." : "Dez.",
-    "The user limit has been reached and the user was not created." : "Das Benutzerlimit wurde erreicht und der Benutzer wurde nicht erstellt.",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Folgende Zeichen sind im Benutzernamen erlaubt: „a-z“, „A-Z“, „0-9“ und „_.@-'“",
     "A valid username must be provided" : "Es muss ein gültiger Benutzername angegeben werden",
     "Username contains whitespace at the beginning or at the end" : "Der Benutzername enthält Leerzeichen am Anfang oder am Ende",
@@ -206,6 +208,7 @@ OC.L10N.register(
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Die App „%1$s“ kann nicht installiert werden, da die folgenden Abhängigkeiten nicht erfüllt sind: %2$s",
     "a safe home for all your data" : "ein sicherer Ort für all deine Daten",
     "File is currently busy, please try again later" : "Die Datei ist in Benutzung, bitte versuche es später noch einmal",
+    "Cannot download file" : "Datei kann nicht heruntergeladen werden.",
     "Application is not enabled" : "Die Anwendung ist nicht aktiviert",
     "Authentication error" : "Authentifizierungsfehler",
     "Token expired. Please reload page." : "Token abgelaufen. Bitte lade die Seite neu.",
@@ -259,6 +262,9 @@ OC.L10N.register(
     "%s enter the database username." : "%s gebe den Datenbank-Benutzernamen an.",
     "%s enter the database name." : "%s gebe den Datenbanknamen an.",
     "%s you may not use dots in the database name" : "%s Der Datenbankname darf keine Punkte enthalten",
+    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Es scheint, dass diese %s-Instanz unter einer 32-Bit-PHP-Umgebung läuft und open_basedir in der Datei php.ini konfiguriert worden ist. Von einem solchen Betrieb wird dringend abgeraten, weil es dabei zu Problemen mit Dateien kommt, deren Größe 4 GB übersteigt.",
+    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Bitte entferne die open_basedir-Einstellung in deiner php.ini oder wechsele zu 64-Bit-PHP.",
+    "The user limit has been reached and the user was not created." : "Das Benutzerlimit wurde erreicht und der Benutzer wurde nicht erstellt.",
     "Cannot read file" : "Datei kann nicht gelesen werden",
     "Cannot write into \"config\" directory" : "Schreiben in das „config“-Verzeichnis ist nicht möglich",
     "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Dies kann zumeist behoben werden, indem dem Web-Server Schreibzugriff auf das Konfigurationsverzeichnis eingeräumt wird. Siehe auch %s",
