@@ -7,6 +7,8 @@ OC.L10N.register(
     "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Sovelluksen %1$s tiedostoja ei korvattu oikein Varmista, että sen versio on yhteensopiva palvelimen kanssa.",
     "Sample configuration detected" : "Esimerkkimääritykset havaittu",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "On havaittu, että esimerkkimäärityksen on kopioitu. Se voi rikkoa asennuksesi, eikä sitä tueta. Lue ohjeet ennen kuin muutat config.php tiedostoa.",
+    "404" : "404",
+    "The page could not be found on the server." : "Sivua ei löytynyt palvelimelta.",
     "Email verification" : "Sähköpostin vahvistus",
     "Click the following button to confirm your email." : "Napsauta seuraavaa painiketta vahvistaaksesi sähköpostiosoitteesi.",
     "Click the following link to confirm your email." : "Napsauta seuraavaa linkkiä vahvistaaksesi sähköpostiosoitteesi.",
@@ -109,8 +111,6 @@ OC.L10N.register(
     "PostgreSQL username and/or password not valid" : "PostgreSQL:n käyttäjätunnus ja/tai salasana on väärin",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X ei ole tuettu, joten %s ei toimi kunnolla tällä alustalla. Käytä omalla vastuulla!",
     "For the best results, please consider using a GNU/Linux server instead." : "Käytä parhaan lopputuloksen saamiseksi GNU/Linux-palvelinta.",
-    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Vaikuttaa siltä, että tämä %s-instanssi toimii 32-bittisessä PHP-ympäristössä ja open_basedir-asetus on määritetty php.ini-tiedostossa. Tämä johtaa ongelmiin yli 4 gigatavun tiedostojen kanssa, eikä siksi ole suositeltavaa.",
-    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Poista open_basedir-asetus php.ini-tiedostosta tai vaihda 64-bittiseen PHP:hen.",
     "Set an admin username." : "Aseta ylläpitäjän käyttäjätunnus.",
     "Set an admin password." : "Aseta ylläpitäjän salasana.",
     "Sharing backend %s not found" : "Jakamisen taustaosaa %s ei löytynyt",
@@ -178,7 +178,6 @@ OC.L10N.register(
     "Oct." : "Loka",
     "Nov." : "Marras",
     "Dec." : "Joulu",
-    "The user limit has been reached and the user was not created." : "Käyttäjäraja on tullut täyteen, joten käyttäjää ei luotu.",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Vain seuraavat merkit ovat sallittuja käyttäjätunnuksessa: \"a-z\", \"A-Z\", \"0-9\" ja \"_.@-'\"",
     "A valid username must be provided" : "Anna kelvollinen käyttäjätunnus",
     "Username contains whitespace at the beginning or at the end" : "Käyttäjätunnus sisältää tyhjätilaa joko alussa tai lopussa",
@@ -201,6 +200,7 @@ OC.L10N.register(
     "Cannot write into \"apps\" directory." : "Ei voi kirjoittaa \"apps\"-hakemistoon",
     "Cannot create \"data\" directory." : "Ei voi luoda \"data\"-hakemistoa",
     "Your data directory is not writable." : "Datahakemistosi ei ole kirjoitettavissa.",
+    "Setting locale to %s failed." : "Maa-asetuston %s asettaminen epäonnistui.",
     "PHP module %s not installed." : "PHP-moduulia %s ei ole asennettu.",
     "Please ask your server administrator to install the module." : "Pyydä palvelimen ylläpitäjää asentamaan moduulin.",
     "PHP setting \"%s\" is not set to \"%s\"." : "PHP-asetusta \"%s\" ei ole asetettu arvoon \"%s\".",
@@ -228,6 +228,9 @@ OC.L10N.register(
     "%s enter the database username." : "%s anna tietokannan käyttäjätunnus.",
     "%s enter the database name." : "%s anna tietokannan nimi.",
     "%s you may not use dots in the database name" : "%s et voi käyttää pisteitä tietokannan nimessä",
+    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Vaikuttaa siltä, että tämä %s-instanssi toimii 32-bittisessä PHP-ympäristössä ja open_basedir-asetus on määritetty php.ini-tiedostossa. Tämä johtaa ongelmiin yli 4 gigatavun tiedostojen kanssa, eikä siksi ole suositeltavaa.",
+    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Poista open_basedir-asetus php.ini-tiedostosta tai vaihda 64-bittiseen PHP:hen.",
+    "The user limit has been reached and the user was not created." : "Käyttäjäraja on tullut täyteen, joten käyttäjää ei luotu.",
     "Cannot read file" : "Tiedostoa ei voi lukea",
     "Cannot write into \"config\" directory" : "Hakemistoon \"config\" kirjoittaminen ei onnistu",
     "Cannot write into \"apps\" directory" : "Hakemistoon \"apps\" kirjoittaminen ei onnistu",
