@@ -2,12 +2,14 @@ OC.L10N.register(
     "lib",
     {
     "Cannot write into \"config\" directory!" : "Impossible d’écrire dans le répertoire « config » !",
-    "This can usually be fixed by giving the webserver write access to the config directory." : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire de configuration.",
+    "This can usually be fixed by giving the web server write access to the config directory." : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire de configuration.",
     "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Ou, si vous préférez conserver le fichier config.php en lecture seule, définissez l'option \"config_is_read_only\" sur true.",
     "See %s" : "Voir %s",
     "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Les fichiers de l'application %1$s n'ont pas été remplacés correctement. Veuillez vérifier que c'est une version compatible avec le serveur.",
     "Sample configuration detected" : "Configuration d'exemple détectée",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Il a été détecté que la configuration donnée à titre d'exemple a été copiée. Cela peut rendre votre installation inopérante et n'est pas pris en charge. Veuillez lire la documentation avant d'effectuer des modifications dans config.php",
+    "404" : "404",
+    "The page could not be found on the server." : "La page n'a pas pu être trouvée sur le serveur.",
     "%s email verification" : "Vérification de l'e-mail %s",
     "Email verification" : "Vérification de l'e-mail",
     "Click the following button to confirm your email." : "Cliquez sur le bouton ci-dessous pour confirmer votre e-mail.",
@@ -58,20 +60,20 @@ OC.L10N.register(
     "today" : "aujourd'hui",
     "tomorrow" : "demain",
     "yesterday" : "hier",
-    "_in %n day_::_in %n days_" : ["dans %n jour","dans %n jours"],
-    "_%n day ago_::_%n days ago_" : ["il y a %n jour","il y a %n jours"],
+    "_in %n day_::_in %n days_" : ["dans %n jour","dans %n jours","dans %n jours"],
+    "_%n day ago_::_%n days ago_" : ["il y a %n jour","il y a %n jours","il y a %n jours"],
     "next month" : "mois suivant",
     "last month" : "le mois dernier",
-    "_in %n month_::_in %n months_" : ["dans %n mois","dans %n mois"],
-    "_%n month ago_::_%n months ago_" : ["Il y a %n mois","Il y a %n mois"],
+    "_in %n month_::_in %n months_" : ["dans %n mois","dans %n mois","dans %n mois"],
+    "_%n month ago_::_%n months ago_" : ["Il y a %n mois","Il y a %n mois","Il y a %n mois"],
     "next year" : "année suivante",
     "last year" : "l'année dernière",
-    "_in %n year_::_in %n years_" : ["dans %n an","dans %n ans"],
-    "_%n year ago_::_%n years ago_" : ["il y a %n an","il y a %n ans"],
-    "_in %n hour_::_in %n hours_" : ["dans %n heure","dans %n heures"],
-    "_%n hour ago_::_%n hours ago_" : ["Il y a %n heure","Il y a %n heures"],
-    "_in %n minute_::_in %n minutes_" : ["dans %n minute","dans %n minutes"],
-    "_%n minute ago_::_%n minutes ago_" : ["il y a %n minute","il y a %n minutes"],
+    "_in %n year_::_in %n years_" : ["dans %n an","dans %n ans","dans %n ans"],
+    "_%n year ago_::_%n years ago_" : ["il y a %n an","il y a %n ans","il y a %n ans"],
+    "_in %n hour_::_in %n hours_" : ["dans %n heure","dans %n heures","dans %n heures"],
+    "_%n hour ago_::_%n hours ago_" : ["Il y a %n heure","Il y a %n heures","Il y a %n heures"],
+    "_in %n minute_::_in %n minutes_" : ["dans %n minute","dans %n minutes","dans %n minutes"],
+    "_%n minute ago_::_%n minutes ago_" : ["il y a %n minute","il y a %n minutes","il y a %n minutes"],
     "in a few seconds" : "dans quelques secondes",
     "seconds ago" : "il y a quelques secondes",
     "Empty file" : "Fichier vide",
@@ -90,7 +92,10 @@ OC.L10N.register(
     "__language_name__" : "Français",
     "This is an automatically sent email, please do not reply." : "Ceci est un e-mail envoyé automatiquement, veuillez ne pas y répondre.",
     "Help" : "Aide",
+    "Appearance and accessibility" : "Apparence et accessibilité",
     "Apps" : "Applications",
+    "Personal settings" : "Paramètres personnels",
+    "Administration settings" : "Paramètres d'administration",
     "Settings" : "Paramètres",
     "Log out" : "Se déconnecter",
     "Users" : "Utilisateurs",
@@ -108,13 +113,13 @@ OC.L10N.register(
     "Full name" : "Nom complet",
     "Headline" : "Titre",
     "Organisation" : "Organisme",
-    "Role" : "Rôle",
+    "Role" : "Fonction",
     "Unknown user" : "Utilisateur inconnu",
     "Additional settings" : "Paramètres supplémentaires",
-    "%s enter the database username and name." : "%s entrez le nom d'utilisateur et le nom de la base de données.",
-    "%s enter the database username." : "%s entrez le nom d'utilisateur de la base de données.",
-    "%s enter the database name." : "%s entrez le nom de la base de données.",
-    "%s you may not use dots in the database name" : "%s vous ne pouvez pas utiliser de points dans le nom de la base de données",
+    "Enter the database username and name for %s" : "Entrez le nom d'utilisateur et le nom de la base de données pour %s",
+    "Enter the database username for %s" : "Entrez le nom d'utilisateur de la base de données pour %s",
+    "Enter the database name for %s" : "Entrez le nom de la base de données pour %s",
+    "You cannot use dots in the database name %s" : "Vous ne pouvez pas utiliser de points dans le nom de la base de données %s",
     "MySQL username and/or password not valid" : "Nom d'utilisateur et/ou mot de passe de la base MySQL non valide(s)",
     "You need to enter details of an existing account." : "Vous devez indiquer les détails d'un compte existant.",
     "Oracle connection could not be established" : "La connexion Oracle ne peut être établie",
@@ -122,8 +127,6 @@ OC.L10N.register(
     "PostgreSQL username and/or password not valid" : "Nom d'utilisateur et/ou mot de passe de la base PostgreSQL non valide(s)",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X n'est pas pris en charge et %s ne fonctionnera pas correctement sur cette plate-forme. Son utilisation est à vos risques et périls !",
     "For the best results, please consider using a GNU/Linux server instead." : "Pour obtenir les meilleurs résultats, vous devriez utiliser un serveur GNU/Linux.",
-    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Il semble que cette instance %s fonctionne sur un environnement PHP 32-bit et open_basedir a été configuré dans php.ini. Cela engendre des problèmes avec les fichiers de taille supérieure à 4 Go et est donc fortement déconseillé.",
-    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Veuillez supprimer la configuration open_basedir de votre php.ini ou utiliser une version PHP 64-bit.",
     "Set an admin username." : "Spécifiez un nom d'utilisateur pour l'administrateur.",
     "Set an admin password." : "Spécifiez un mot de passe pour l'administrateur.",
     "Cannot create or write into the data directory %s" : "Impossible de créer ou d'écrire dans le répertoire des données %s",
@@ -140,13 +143,14 @@ OC.L10N.register(
     "Files cannot be shared with delete permissions" : "Les fichiers ne peuvent pas être partagés avec les autorisations de suppression",
     "Files cannot be shared with create permissions" : "Les fichiers ne peuvent pas être partagés avec les autorisations de création",
     "Expiration date is in the past" : "La date d'expiration est dans le passé",
-    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Impossible de définir la date d'expiration à dans plus de %s jour","Impossible de définir la date d'expiration à dans plus de %s jours"],
+    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Impossible de définir la date d'expiration à dans plus de %s jour","Impossible de définir la date d'expiration à dans plus de %s jours","Impossible de définir la date d'expiration à dans plus de %s jours"],
     "Sharing is only allowed with group members" : "Le partage n'est que possible qu'avec les membres du groupe",
     "Sharing %s failed, because this item is already shared with user %s" : "Impossible de partager %s car il est déjà partagé avec l'utilisateur %s",
     "%1$s shared »%2$s« with you" : "%1$s a partagé « %2$s » avec vous",
     "%1$s shared »%2$s« with you." : "%1$s a partagé « %2$s » avec vous.",
     "Click the button below to open it." : "Cliquez sur le bouton ci-dessous pour l'ouvrir",
     "The requested share does not exist anymore" : "Le partage demandé n'existe plus",
+    "The user limit has been reached and the user was not created. Check your notifications to learn more." : "La limite d'utilisateurs à été atteinte et cet utilisateur n'a pas été créé. Consultez vos notifications pour en savoir plus.",
     "Could not find category \"%s\"" : "Impossible de trouver la catégorie \"%s\"",
     "Sunday" : "Dimanche",
     "Monday" : "Lundi",
@@ -193,7 +197,6 @@ OC.L10N.register(
     "Oct." : "Oct.",
     "Nov." : "Nov.",
     "Dec." : "Déc.",
-    "The user limit has been reached and the user was not created." : "Le nombre maximum d'utilisateurs a été atteint, l'utilisateur n'a pas pu être créé.",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Seuls les caractères suivants sont autorisés dans un nom d'utilisateur : \"a-z\", \"A-Z\", \"0-9\", \"_@-\" et \".\" (le point)",
     "A valid username must be provided" : "Un nom d'utilisateur valide doit être saisi",
     "Username contains whitespace at the beginning or at the end" : "Le nom d'utilisateur contient des espaces au début ou à la fin",
@@ -207,40 +210,43 @@ OC.L10N.register(
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "L'application \"%1$s\" ne peut pas être installée à cause des dépendances suivantes non satisfaites : %2$s",
     "a safe home for all your data" : "un lieu sûr pour toutes vos données",
     "File is currently busy, please try again later" : "Le fichier est actuellement utilisé, veuillez réessayer plus tard",
-    "Cannot read file" : "Impossible de lire le fichier",
+    "Cannot download file" : "Impossible de télécharger le fichier",
     "Application is not enabled" : "L'application n'est pas activée",
     "Authentication error" : "Erreur d'authentification",
     "Token expired. Please reload page." : "La session a expiré. Veuillez recharger la page.",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Aucun pilote de base de données n’est installé (sqlite, mysql ou postgresql).",
-    "Cannot write into \"config\" directory" : "Impossible d’écrire dans le répertoire \"config\"",
-    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire \"config\". Voir %s",
+    "Cannot write into \"config\" directory." : "Impossible d’écrire dans le répertoire \"config\".",
+    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire \"config\". Voir %s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Ou, si vous préférez conserver le fichier config.php en lecture seule, définissez l'option \"config_is_read_only\" sur true. Voir %s",
-    "Cannot write into \"apps\" directory" : "Impossible d’écrire dans le répertoire \"apps\"",
-    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the App Store in the config file." : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire des applications ou en désactivant le magasin d'applications dans le fichier de configuration.",
-    "Cannot create \"data\" directory" : "Impossible de créer le dossier \"data\"",
-    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire racine. Voir %s",
-    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Le problème de permissions peut généralement être résolu en donnant au serveur web un accès en écriture au répertoire racine. Voir %s.",
-    "Setting locale to %s failed" : "Echec de la spécification des paramètres régionaux à %s",
-    "Please install one of these locales on your system and restart your webserver." : "Veuillez installer l'un de ces paramètres régionaux sur votre système et redémarrer votre serveur web.",
+    "Cannot write into \"apps\" directory." : "Impossible d'écrire dans le répertoire \"apps\".",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire des applications ou en désactivant le magasin d'applications dans le fichier de configuration.",
+    "Cannot create \"data\" directory." : "Impossible de créer le dossier \"data\".",
+    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire racine. Voir %s",
+    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Le problème de permissions peut généralement être résolu en donnant au serveur web un accès en écriture au répertoire racine. Voir %s.",
+    "Your data directory is not writable." : "Votre répertoire des données n'est pas accessible en écriture.",
+    "Setting locale to %s failed." : "Échec de la spécification des paramètres régionaux à %s.",
+    "Please install one of these locales on your system and restart your web server." : "Veuillez installer l'un de ces paramètres régionaux sur votre système et redémarrer votre serveur web.",
     "PHP module %s not installed." : "Le module PHP %s n’est pas installé.",
     "Please ask your server administrator to install the module." : "Veuillez demander à votre administrateur d’installer le module.",
     "PHP setting \"%s\" is not set to \"%s\"." : "Le paramètre PHP \"%s\" n'est pas \"%s\".",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Ajuster ce paramètre dans php.ini fera fonctionner Nextcould à nouveau",
-    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload est à \"%s\" alors que la valeur \"0\" est attendue",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Pour corriger ce problème mettez <code>mbstring.func_overload</code> à <code>0</code> dans votre php.ini",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> est défini à <code>%s</code> alors que la valeur <code>0</code> est attendue.",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Pour corriger ce problème définissez <code>mbstring.func_overload</code> à <code>0</code> dans votre php.ini.",
     "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 2.7.0 au moins est requis. Actuellement %s est installé.",
     "To fix this issue update your libxml2 version and restart your web server." : "Pour régler ce problème, mettez à jour votre version de libxml2 et redémarrez votre serveur web.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP semble configuré de manière à supprimer les blocs PHPdoc du code. Cela rendra plusieurs applications de base inaccessibles.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "La raison est probablement l'utilisation d'un cache / accélérateur tel que Zend OPcache ou eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "Les modules PHP ont été installés mais sont toujours indiqués comme manquants ?",
     "Please ask your server administrator to restart the web server." : "Veuillez demander à votre administrateur serveur de redémarrer le serveur web.",
-    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 requis",
-    "Please upgrade your database version" : "Veuillez mettre à jour votre gestionnaire de base de données",
-    "Your data directory is readable by other users" : "Votre répertoire est lisible par les autres utilisateurs",
+    "The required %s config variable is not configured in the config.php file." : "La valeur de configuration requise %s n'est pas configurée dans votre fichier config.php.",
+    "Please ask your server administrator to check the Nextcloud configuration." : "Veuillez demander à votre administrateur serveur de vérifier la configuration de Nextcloud.",
+    "PostgreSQL >= 9 required." : "PostgreSQL >= 9 requis.",
+    "Please upgrade your database version." : "Veuillez mettre à jour votre gestionnaire de base de données.",
+    "Your data directory is readable by other users." : "Votre répertoire est lisible par d'autres utilisateurs.",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Veuillez changer les permissions du répertoire en mode 0770 afin que son contenu ne puisse pas être listé par les autres utilisateurs.",
-    "Your data directory must be an absolute path" : "Le chemin de votre répertoire doit être un lien absolu",
-    "Check the value of \"datadirectory\" in your configuration" : "Verifiez la valeur de \"datadirectory\" dans votre configuration",
-    "Your data directory is invalid" : "Votre répertoire n'est pas valide",
+    "Your data directory must be an absolute path." : "Le chemin de votre répertoire doit être un chemin absolu.",
+    "Check the value of \"datadirectory\" in your configuration." : "Verifiez la valeur de \"datadirectory\" dans votre configuration.",
+    "Your data directory is invalid." : "Votre répertoire des données n'est pas valide.",
     "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Assurez-vous que le répertoire de données contient un fichier \".ocdata\" à sa racine.",
     "Action \"%s\" not supported or implemented." : "Action \"%s\" non supportée ou implémentée.",
     "Authentication failed, wrong token or provider ID given" : "Échec de l'authentification, jeton erroné ou identification du fournisseur donnée",
@@ -253,15 +259,31 @@ OC.L10N.register(
     "Storage connection error. %s" : "Erreur de connexion à l'espace stockage. %s",
     "Storage is temporarily not available" : "Le support de stockage est temporairement indisponible",
     "Storage connection timeout. %s" : "Le délai d'attente pour la connexion à l'espace de stockage a été dépassé. %s",
-    "This can usually be fixed by giving the webserver write access to the config directory" : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire \"config\"",
-    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Ou, si vous préférez conserver le fichier config.php en lecture seule, définissez l'option \"config_is_read_only\" sur true.",
-    "Can't create or write into the data directory %s" : "Impossible de créer, ou d'écrire dans, le répertoire des données %s",
-    "Invalid Federated Cloud ID" : "ID Federated Cloud incorrect",
-    "Can’t increase permissions of %s" : "Impossible d'augmenter les permissions de %s",
-    "Files can’t be shared with delete permissions" : "Les fichiers ne peuvent pas être partagés avec les autorisations de suppression",
-    "Files can’t be shared with create permissions" : "Les fichiers ne peuvent pas être partagés avec les autorisations de création",
-    "Can’t set expiration date more than %s days in the future" : "Impossible de définir la date d'expiration à plus de %s jours dans le futur",
-    "Can't read file" : "Impossible de lire le fichier",
-    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file." : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire des applications ou en désactivant l'appstore dans le fichier de configuration."
+    "This can usually be fixed by giving the webserver write access to the config directory." : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire de configuration.",
+    "%s enter the database username and name." : "%s entrez le nom d'utilisateur et le nom de la base de données.",
+    "%s enter the database username." : "%s entrez le nom d'utilisateur de la base de données.",
+    "%s enter the database name." : "%s entrez le nom de la base de données.",
+    "%s you may not use dots in the database name" : "%s vous ne pouvez pas utiliser de points dans le nom de la base de données",
+    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Il semble que cette instance %s fonctionne sur un environnement PHP 32-bit et open_basedir a été configuré dans php.ini. Cela engendre des problèmes avec les fichiers de taille supérieure à 4 Go et est donc fortement déconseillé.",
+    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Veuillez supprimer la configuration open_basedir de votre php.ini ou utiliser une version PHP 64-bit.",
+    "The user limit has been reached and the user was not created." : "Le nombre maximum d'utilisateurs a été atteint, l'utilisateur n'a pas pu être créé.",
+    "Cannot read file" : "Impossible de lire le fichier",
+    "Cannot write into \"config\" directory" : "Impossible d’écrire dans le répertoire \"config\"",
+    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire \"config\". Voir %s",
+    "Cannot write into \"apps\" directory" : "Impossible d’écrire dans le répertoire \"apps\"",
+    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the App Store in the config file." : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire des applications ou en désactivant le magasin d'applications dans le fichier de configuration.",
+    "Cannot create \"data\" directory" : "Impossible de créer le dossier \"data\"",
+    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire racine. Voir %s",
+    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Le problème de permissions peut généralement être résolu en donnant au serveur web un accès en écriture au répertoire racine. Voir %s.",
+    "Setting locale to %s failed" : "Echec de la spécification des paramètres régionaux à %s",
+    "Please install one of these locales on your system and restart your webserver." : "Veuillez installer l'un de ces paramètres régionaux sur votre système et redémarrer votre serveur web.",
+    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload est à \"%s\" alors que la valeur \"0\" est attendue",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Pour corriger ce problème mettez <code>mbstring.func_overload</code> à <code>0</code> dans votre php.ini",
+    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 requis",
+    "Please upgrade your database version" : "Veuillez mettre à jour votre gestionnaire de base de données",
+    "Your data directory is readable by other users" : "Votre répertoire est lisible par les autres utilisateurs",
+    "Your data directory must be an absolute path" : "Le chemin de votre répertoire doit être un lien absolu",
+    "Check the value of \"datadirectory\" in your configuration" : "Verifiez la valeur de \"datadirectory\" dans votre configuration",
+    "Your data directory is invalid" : "Votre répertoire n'est pas valide"
 },
-"nplurals=2; plural=(n > 1);");
+"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
