@@ -8,6 +8,8 @@ OC.L10N.register(
     "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Pliki aplikacji %1$s nie zostały poprawnie zastąpione. Upewnij się, że jest to wersja zgodna z serwerem.",
     "Sample configuration detected" : "Wykryto przykładową konfigurację",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Wykryto, że przykładowa konfiguracja została skopiowana. Może to spowodować przerwanie instalacji, która nie jest wspierana. Przeczytaj dokumentację przed dokonaniem zmian w pliku config.php",
+    "404" : "404",
+    "The page could not be found on the server." : "Nie znaleziono strony na serwerze.",
     "%s email verification" : "Weryfikacja adresu e-mail %s",
     "Email verification" : "Weryfikacja adresu e-mail",
     "Click the following button to confirm your email." : "Kliknij poniższy przycisk, aby potwierdzić swój adres e-mail.",
@@ -59,7 +61,7 @@ OC.L10N.register(
     "tomorrow" : "jutro",
     "yesterday" : "wczoraj",
     "_in %n day_::_in %n days_" : ["za %n dzień","za %n dni","za %n dni","za %n dni"],
-    "_%n day ago_::_%n days ago_" : ["%d dzień temu","%n dni temu","%n dni temu","%n dni temu"],
+    "_%n day ago_::_%n days ago_" : ["%n dzień temu","%n dni temu","%n dni temu","%n dni temu"],
     "next month" : "następny miesiąc",
     "last month" : "w zeszłym miesiącu",
     "_in %n month_::_in %n months_" : ["za %n miesiąc","za %n miesiące","za %n miesięcy","za %n miesięcy"],
@@ -90,7 +92,10 @@ OC.L10N.register(
     "__language_name__" : "Polski",
     "This is an automatically sent email, please do not reply." : "Jest to wiadomość e-mail wysłana automatycznie, prosimy nie odpowiadać na nią.",
     "Help" : "Pomoc",
+    "Appearance and accessibility" : "Wygląd i dostępność",
     "Apps" : "Aplikacje",
+    "Personal settings" : "Ustawienia osobiste",
+    "Administration settings" : "Ustawienia administracyjne",
     "Settings" : "Ustawienia",
     "Log out" : "Wyloguj",
     "Users" : "Użytkownicy",
@@ -111,10 +116,10 @@ OC.L10N.register(
     "Role" : "Rola społeczna",
     "Unknown user" : "Nieznany użytkownik",
     "Additional settings" : "Ustawienia dodatkowe",
-    "%s enter the database username and name." : "Podaj nazwę bazy danych i nazwę użytkownika dla %s.",
-    "%s enter the database username." : "Podaj nazwę użytkownika dla %s.",
-    "%s enter the database name." : "Podaj nazwę bazy danych dla %s.",
-    "%s you may not use dots in the database name" : "Nie możesz używać kropek w nazwie bazy danych %s.",
+    "Enter the database username and name for %s" : "Podaj nazwę użytkownika i nazwę bazy danych dla %s",
+    "Enter the database username for %s" : "Podaj nazwę użytkownika bazy danych dla %s",
+    "Enter the database name for %s" : "Podaj nazwę bazy danych dla %s",
+    "You cannot use dots in the database name %s" : "Nie można używać kropek w nazwie bazy danych %s",
     "MySQL username and/or password not valid" : "Błędna nazwa użytkownika i/lub hasło do bazy danych MySQL",
     "You need to enter details of an existing account." : "Musisz wprowadzić szczegółowe dane dla istniejącego konta.",
     "Oracle connection could not be established" : "Nie można nawiązać połączenia z bazą danych Oracle",
@@ -122,8 +127,6 @@ OC.L10N.register(
     "PostgreSQL username and/or password not valid" : "Zła nazwa użytkownika i/lub hasło do bazy danych PostgreSQL",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X nie jest wspierany i %s nie będzie działać poprawnie na tej platformie. Używasz go na własne ryzyko!",
     "For the best results, please consider using a GNU/Linux server instead." : "Aby uzyskać najlepszy efekt, rozważ użycie serwera GNU/Linux.",
-    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Wydaje się, że ta instancja %s używa PHP dla 32-bitowego środowiska, ponieważ open_basedir został tak skonfigurowany w php.ini. Doprowadzi to do problemów z plikami powyżej 4 GB i jest bardzo niezalecane.",
-    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Usuń ustawienie open_basedir w php.ini lub przełącz na PHP 64-bitowe.",
     "Set an admin username." : "Ustaw nazwę administratora.",
     "Set an admin password." : "Ustaw hasło administratora.",
     "Cannot create or write into the data directory %s" : "Nie można tworzyć ani zapisywać w katalogu %s",
@@ -147,6 +150,7 @@ OC.L10N.register(
     "%1$s shared »%2$s« with you." : "%1$s udostępnił Tobie »%2$s«.",
     "Click the button below to open it." : "Kliknij przycisk poniżej, aby otworzyć.",
     "The requested share does not exist anymore" : "Żądane udostępnienie już nie istnieje",
+    "The user limit has been reached and the user was not created. Check your notifications to learn more." : "Osiągnięto limit użytkowników i użytkownik nie został utworzony. Sprawdź swoje powiadomienia, aby dowiedzieć się więcej.",
     "Could not find category \"%s\"" : "Nie można znaleźć kategorii \"%s\"",
     "Sunday" : "Niedziela",
     "Monday" : "Poniedziałek",
@@ -193,7 +197,6 @@ OC.L10N.register(
     "Oct." : "Paź.",
     "Nov." : "Lis.",
     "Dec." : "Gru.",
-    "The user limit has been reached and the user was not created." : "Osiągnięto limit użytkowników, dlatego użytkownik nie został utworzony.",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "W nazwie użytkownika dozwolone są tylko następujące znaki : \"a-z\", \"A-Z\", \"0-9\" i \"_.@-'\"",
     "A valid username must be provided" : "Należy podać prawidłową nazwę użytkownika",
     "Username contains whitespace at the beginning or at the end" : "Nazwa użytkownika zawiera spację na początku albo na końcu",
@@ -205,9 +208,9 @@ OC.L10N.register(
     "User disabled" : "Użytkownik zablokowany",
     "Login canceled by app" : "Logowanie anulowane przez aplikację",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Nie można zainstalować aplikacji \"%1$s\", ponieważ nie są spełnione następujące zależności: %2$s",
-    "a safe home for all your data" : "bezpieczny dom dla wszystkich danych",
+    "a safe home for all your data" : "bezpieczny dom dla wszystkich Twoich danych",
     "File is currently busy, please try again later" : "Plik jest obecnie niedostępny, spróbuj później",
-    "Cannot read file" : "Nie można odczytać pliku",
+    "Cannot download file" : "Nie można pobrać pliku",
     "Application is not enabled" : "Aplikacja nie jest włączona",
     "Authentication error" : "Błąd uwierzytelniania",
     "Token expired. Please reload page." : "Token wygasł. Przeładuj stronę.",
@@ -216,7 +219,7 @@ OC.L10N.register(
     "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Zwykle można to naprawić, nadając serwerowi WWW dostęp do zapisu do katalogu config. Zobacz %s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Jeśli, albo wolisz zachować plik config.php tylko do odczytu, ustaw w nim opcję \"config_is_read_only\" na true. Zobacz %s",
     "Cannot write into \"apps\" directory." : "Nie można zapisać do katalogu \"apps\".",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Zwykle można to naprawić, przyznając serwerowi WWW dostęp do zapisu do katalogu aplikacji lub wyłączając sklep z aplikacjami w pliku konfiguracyjnym.",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Zwykle można to naprawić, przyznając serwerowi WWW dostęp do zapisu do katalogu aplikacji lub wyłączając Nextcloud App Store w pliku konfiguracyjnym.",
     "Cannot create \"data\" directory." : "Nie można utworzyć katalogu \"data\".",
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Zwykle można to naprawić, nadając serwerowi WWW dostęp do zapisu do katalogu głównego. Zobacz %s",
     "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Uprawnienia można zazwyczaj naprawić, nadając serwerowi WWW dostęp do zapisu do katalogu głównego. Zobacz %s.",
@@ -235,6 +238,8 @@ OC.L10N.register(
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Jest to prawdopodobnie spowodowane przez cache lub akcelerator, taki jak Zend OPcache lub eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "Moduły PHP zostały zainstalowane, ale nadal brakuje ich na liście?",
     "Please ask your server administrator to restart the web server." : "Poproś administratora serwera o ponowne uruchomienie serwera WWW.",
+    "The required %s config variable is not configured in the config.php file." : "Wymagana zmienna konfiguracyjna %s nie jest skonfigurowana w pliku config.php.",
+    "Please ask your server administrator to check the Nextcloud configuration." : "Poproś administratora serwera o sprawdzenie konfiguracji Nextcloud.",
     "PostgreSQL >= 9 required." : "Wymagany PostgreSQL >= 9",
     "Please upgrade your database version." : "Zaktualizuj wersję bazy danych.",
     "Your data directory is readable by other users." : "Twój katalog danych jest widoczny dla innych użytkowników.",
@@ -254,20 +259,19 @@ OC.L10N.register(
     "Storage connection error. %s" : "Błąd połączenia z magazynem. %s",
     "Storage is temporarily not available" : "Magazyn jest tymczasowo niedostępny",
     "Storage connection timeout. %s" : "Limit czasu połączenia do magazynu. %s",
-    "This can usually be fixed by giving the webserver write access to the config directory" : "Zwykle można to naprawić, nadając serwerowi WWW dostęp do zapisu do katalogu config.",
-    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Jeśli, albo wolisz zachować plik config.php tylko do odczytu, ustaw w nim opcję \"config_is_read_only\" na true.",
     "This can usually be fixed by giving the webserver write access to the config directory." : "Zwykle można to naprawić, nadając serwerowi WWW dostęp do zapisu do katalogu config.",
-    "Can't create or write into the data directory %s" : "Nie można tworzyć ani zapisywać w katalogu %s",
-    "Invalid Federated Cloud ID" : "Nieprawidłowy ID Chmury Federacyjnej",
-    "Can’t increase permissions of %s" : "Nie można zwiększyć uprawnień %s",
-    "Files can’t be shared with delete permissions" : "Pliki nie mogą zostać udostępnione z prawem do usuwania",
-    "Files can’t be shared with create permissions" : "Pliki nie mogą zostać udostępnione z prawem do tworzenia",
-    "Can’t set expiration date more than %s days in the future" : "Nie można ustawić daty wygaśnięcia na dłuższą niż %s dni",
-    "Can't read file" : "Nie można odczytać pliku",
+    "%s enter the database username and name." : "Podaj nazwę bazy danych i nazwę użytkownika dla %s.",
+    "%s enter the database username." : "Podaj nazwę użytkownika dla %s.",
+    "%s enter the database name." : "Podaj nazwę bazy danych dla %s.",
+    "%s you may not use dots in the database name" : "Nie możesz używać kropek w nazwie bazy danych %s.",
+    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Wydaje się, że ta instancja %s używa PHP dla 32-bitowego środowiska, ponieważ open_basedir został tak skonfigurowany w php.ini. Doprowadzi to do problemów z plikami powyżej 4 GB i jest bardzo niezalecane.",
+    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Usuń ustawienie open_basedir w php.ini lub przełącz na PHP 64-bitowe.",
+    "The user limit has been reached and the user was not created." : "Osiągnięto limit użytkowników, dlatego użytkownik nie został utworzony.",
+    "Cannot read file" : "Nie można odczytać pliku",
     "Cannot write into \"config\" directory" : "Nie można zapisać do katalogu \"config\"",
     "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Zwykle można to naprawić, nadając serwerowi WWW dostęp do zapisu do katalogu config. Zobacz %s",
     "Cannot write into \"apps\" directory" : "Nie można zapisać do katalogu \"apps\"",
-    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file." : "Zwykle można to naprawić, przyznając serwerowi dostęp do zapisu do katalogu aplikacji lub wyłączając sklep z aplikacjami w pliku konfiguracyjnym.",
+    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the App Store in the config file." : "Zwykle można to naprawić, przyznając serwerowi dostęp do zapisu do katalogu aplikacji lub wyłączając sklep z aplikacjami w pliku konfiguracyjnym.",
     "Cannot create \"data\" directory" : "Nie mozna utworzyć katalogu \"data\"",
     "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Zwykle można to naprawić, nadając serwerowi WWW dostęp do zapisu do katalogu głównego. Zobacz %s",
     "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Uprawnienia można zazwyczaj naprawić, nadając serwerowi WWW dostęp do zapisu do katalogu głównego. Zobacz %s.",
@@ -280,7 +284,6 @@ OC.L10N.register(
     "Your data directory is readable by other users" : "Twój katalog danych jest widoczny dla innych użytkowników",
     "Your data directory must be an absolute path" : "Katalog danych musi mieć ścieżkę absolutną",
     "Check the value of \"datadirectory\" in your configuration" : "Sprawdź wartość \"datadirectory\" w swojej konfiguracji",
-    "Your data directory is invalid" : "Katalog danych jest nieprawidłowy",
-    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the App Store in the config file." : "Zwykle można to naprawić, przyznając serwerowi dostęp do zapisu do katalogu aplikacji lub wyłączając sklep z aplikacjami w pliku konfiguracyjnym."
+    "Your data directory is invalid" : "Katalog danych jest nieprawidłowy"
 },
 "nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
