@@ -8,6 +8,8 @@ OC.L10N.register(
     "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Os arquivos do aplicativo %1$s não foram instalados corretamente. Certifique-se que é uma versão compatível com seu servidor.",
     "Sample configuration detected" : "Configuração de exemplo detectada",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Foi detectado que a configuração de exemplo foi copiada. Isso pode terminar sua instalação e não é suportado. Por favor leia a documentação antes de realizar mudanças no config.php",
+    "404" : "404",
+    "The page could not be found on the server." : "A página não pôde ser encontrada no servidor.",
     "%s email verification" : "%s e-mail de verificação",
     "Email verification" : "E-mail de verificação",
     "Click the following button to confirm your email." : "Clique no botão a seguir para confirmar seu e-mail.",
@@ -125,8 +127,6 @@ OC.L10N.register(
     "PostgreSQL username and/or password not valid" : "Nome de usuário e/ou senha PostgreSQL inválidos",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X não é suportado e %s não funcionará corretamente nesta plataforma. Use-o por sua conta e risco!",
     "For the best results, please consider using a GNU/Linux server instead." : "Para obter melhores resultados, por favor considere o uso de um servidor GNU/Linux em seu lugar.",
-    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Aparentemente a instância %s está rodando em um ambiente PHP de 32 bits e o open_basedir foi configurado no php.ini. Isto pode gerar problemas com arquivos maiores que 4GB e é altamente não recomendável.",
-    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Por favor, remova a configuração de open_basedir de seu php.ini ou mude o PHP para 64bit.",
     "Set an admin username." : "Defina um nome do usuário administrador.",
     "Set an admin password." : "Defina uma senha para o administrador.",
     "Cannot create or write into the data directory %s" : "Não foi possível criar ou escrever no diretório de dados %s",
@@ -150,6 +150,7 @@ OC.L10N.register(
     "%1$s shared »%2$s« with you." : "%1$s compartilhou »%2$s« com você.",
     "Click the button below to open it." : "Clique no botão abaixo para abri-lo.",
     "The requested share does not exist anymore" : "O compartilhamento solicitado não existe mais",
+    "The user limit has been reached and the user was not created. Check your notifications to learn more." : "O limite de usuários foi atingido e o usuário não foi criado. Verifique suas notificações para saber mais.",
     "Could not find category \"%s\"" : "Impossível localizar a categoria \"%s\"",
     "Sunday" : "Domingo",
     "Monday" : "Segunda-feira",
@@ -196,7 +197,6 @@ OC.L10N.register(
     "Oct." : "Out.",
     "Nov." : "Nov.",
     "Dec." : "Dez.",
-    "The user limit has been reached and the user was not created." : "O limite de usuários foi atingido e o usuário não foi criado.",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Somente os seguintes caracteres são permitidos em um nome de usuário: \"a-z\", \"A-Z\", \"0-9\", e \"_.@-'\"",
     "A valid username must be provided" : "Um nome de usuário válido deve ser fornecido",
     "Username contains whitespace at the beginning or at the end" : "O nome de usuário contém espaço em branco no início ou no fim",
@@ -264,6 +264,9 @@ OC.L10N.register(
     "%s enter the database username." : "%s insira o nome de usuário do banco de dados.",
     "%s enter the database name." : "%s insira o nome do banco de dados.",
     "%s you may not use dots in the database name" : "%s você não pode usar pontos no nome do banco de dados",
+    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Aparentemente a instância %s está rodando em um ambiente PHP de 32 bits e o open_basedir foi configurado no php.ini. Isto pode gerar problemas com arquivos maiores que 4GB e é altamente não recomendável.",
+    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Por favor, remova a configuração de open_basedir de seu php.ini ou mude o PHP para 64bit.",
+    "The user limit has been reached and the user was not created." : "O limite de usuários foi atingido e o usuário não foi criado.",
     "Cannot read file" : "Não foi possível ler o arquivo",
     "Cannot write into \"config\" directory" : "Não foi possível gravar no diretório \"config\"",
     "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Normalmente isso pode ser resolvido dando ao webserver permissão de escritura no diretório config. Veja %s",
