@@ -90,7 +90,10 @@ OC.L10N.register(
     "__language_name__" : "Slovenčina",
     "This is an automatically sent email, please do not reply." : "Toto je automaticky odosielaný e-mail, prosím, neodpovedajte.",
     "Help" : "Pomoc",
+    "Appearance and accessibility" : "Vzhľad a správanie",
     "Apps" : "Aplikácie",
+    "Personal settings" : "Osobné nastavenia",
+    "Administration settings" : "Nastavenia administrácie",
     "Settings" : "Nastavenia",
     "Log out" : "Odhlásiť sa",
     "Users" : "Používatelia",
@@ -111,10 +114,10 @@ OC.L10N.register(
     "Role" : "Rola",
     "Unknown user" : "Neznámy používateľ",
     "Additional settings" : "Ďalšie nastavenia",
-    "%s enter the database username and name." : "%s zadajte používateľské meno a meno databázy",
-    "%s enter the database username." : "Zadajte používateľské meno %s databázy.",
-    "%s enter the database name." : "Zadajte názov databázy pre %s databázy.",
-    "%s you may not use dots in the database name" : "V názve databázy %s nemôžete používať bodky",
+    "Enter the database username and name for %s" : "Zadajte užívateľské meno a názov databázy pre %s",
+    "Enter the database username for %s" : "Zadajte užívateľské meno databázy pre %s",
+    "Enter the database name for %s" : "Zadajte názov databázy pre %s",
+    "You cannot use dots in the database name %s" : "V názve databázy %s nemôžete používať bodky",
     "MySQL username and/or password not valid" : "Neplatné užívateľské meno a/alebo heslo do MySQL",
     "You need to enter details of an existing account." : "Musíte zadať údaje existujúceho účtu.",
     "Oracle connection could not be established" : "Nie je možné pripojiť sa k Oracle",
@@ -122,8 +125,6 @@ OC.L10N.register(
     "PostgreSQL username and/or password not valid" : "Používateľské meno a/alebo heslo pre PostgreSQL databázu je neplatné",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X nie je podporovaný a %s nebude správne fungovať na tejto platforme. Použite ho na vlastné riziko!",
     "For the best results, please consider using a GNU/Linux server instead." : "Pre dosiahnutie najlepších výsledkov, prosím zvážte použitie GNU/Linux servera.",
-    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Zdá sa, že táto inštancia %s beží v 32-bitovom prostredí PHP a v php.ini bola nastavená voľba open_basedir. To bude zdrojom problémov so súbormi väčšími ako 4GB a dôrazne sa neodporúča.",
-    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Prosím, odstráňte nastavenie open_basedir vo vašom php.ini alebo prejdite na 64-bit PHP.",
     "Set an admin username." : "Zadajte používateľské meno administrátora.",
     "Set an admin password." : "Zadajte heslo administrátora.",
     "Cannot create or write into the data directory %s" : "Nemožno vytvoriť alebo zapisovať do priečinka dát %s",
@@ -193,7 +194,6 @@ OC.L10N.register(
     "Oct." : "Okt.",
     "Nov." : "Nov.",
     "Dec." : "Dec.",
-    "The user limit has been reached and the user was not created." : "Bol dosiahnutý limit používateľov a používateľ nebol vytvorený.",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "V mene používateľa je možné použiť iba nasledovné znaky: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"",
     "A valid username must be provided" : "Musíte zadať platné používateľské meno",
     "Username contains whitespace at the beginning or at the end" : "Meno používateľa obsahuje na začiatku, alebo na konci medzeru",
@@ -207,6 +207,7 @@ OC.L10N.register(
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Aplikáciu \"%1$s\" nie je možné inštalovať, pretože nie sú splnené nasledovné závislosti: %2$s",
     "a safe home for all your data" : "bezpečný domov pre všetky vaše dáta",
     "File is currently busy, please try again later" : "Súbor sa práve používa, skúste prosím neskôr",
+    "Cannot download file" : "Nemožno stiahnuť súbor",
     "Application is not enabled" : "Aplikácia nie je zapnutá",
     "Authentication error" : "Chyba autentifikácie",
     "Token expired. Please reload page." : "Token vypršal. Obnovte, prosím, stránku.",
@@ -256,6 +257,13 @@ OC.L10N.register(
     "Storage is temporarily not available" : "Úložisko je dočasne nedostupné",
     "Storage connection timeout. %s" : "Vypršanie pripojenia k úložisku. %s",
     "This can usually be fixed by giving the webserver write access to the config directory." : "Toto sa zvyčajne dá opraviť poskytnutím práva webového servera na zápis do priečinka s nastaveniami.",
+    "%s enter the database username and name." : "%s zadajte používateľské meno a meno databázy",
+    "%s enter the database username." : "Zadajte používateľské meno %s databázy.",
+    "%s enter the database name." : "Zadajte názov databázy pre %s databázy.",
+    "%s you may not use dots in the database name" : "V názve databázy %s nemôžete používať bodky",
+    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Zdá sa, že táto inštancia %s beží v 32-bitovom prostredí PHP a v php.ini bola nastavená voľba open_basedir. To bude zdrojom problémov so súbormi väčšími ako 4GB a dôrazne sa neodporúča.",
+    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Prosím, odstráňte nastavenie open_basedir vo vašom php.ini alebo prejdite na 64-bit PHP.",
+    "The user limit has been reached and the user was not created." : "Bol dosiahnutý limit používateľov a používateľ nebol vytvorený.",
     "Cannot read file" : "Nemožno čítať súbor.",
     "Cannot write into \"config\" directory" : "Nie je možné zapisovať do priečinka \"config\"",
     "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "To je zvyčajne možné opraviť tým, že udelíte webovému serveru oprávnenie na zápis do adresára s konfiguráciou. Viď %s",
