@@ -7,6 +7,7 @@ OC.L10N.register(
     "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Filerna i appen %1$s ersattes inte korrekt. Kontrollera att det är en version som är kompatibel med servern.",
     "Sample configuration detected" : "Exempel-konfiguration detekterad",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Det har upptäckts att provkonfigurationen har kopierats. Detta kan bryta din installation och stöds inte. Läs dokumentationen innan du utför ändringar på config.php",
+    "The page could not be found on the server." : "Sidan kunde inte hittas på servern.",
     "%s email verification" : "%s e-postverifikation",
     "Email verification" : "E-postverifikation",
     "Click the following button to confirm your email." : "Klicka på följande knapp för att verifiera din e-postadress.",
@@ -87,9 +88,12 @@ OC.L10N.register(
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "Appen \"%s\" kan inte installeras eftersom appinfo-filen inte kan läsas.",
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Appen \"%s\" kan inte installeras eftersom den inte är kompatibel med den här versionen av servern.",
     "__language_name__" : "Svenska",
-    "This is an automatically sent email, please do not reply." : "Detta är ett automatiskt skickat e-postmeddelande, svara inte på detta meddelande.",
+    "This is an automatically sent email, please do not reply." : "Detta är ett automatiskt e-postmeddelande, du kan därmed inte svara på det.",
     "Help" : "Hjälp",
+    "Appearance and accessibility" : "Utseende och tillgänglighet",
     "Apps" : "Appar",
+    "Personal settings" : "Personlig information",
+    "Administration settings" : "Administration",
     "Settings" : "Inställningar",
     "Log out" : "Logga ut",
     "Users" : "Användare",
@@ -117,8 +121,6 @@ OC.L10N.register(
     "PostgreSQL username and/or password not valid" : "PostgreSQL-användarnamnet och/eller lösenordet är felaktigt",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X stöds inte och %s kommer inte att fungera korrekt på denna plattform. Använd på egen risk!",
     "For the best results, please consider using a GNU/Linux server instead." : "För bästa resultat, överväg att använda en GNU/Linux-server istället.",
-    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Det verkar som om denna %s instans körs på en 32-bitars PHP miljö och open_basedir har konfigurerats i php.ini. Detta kommer att leda till problem med filer över 4 GB och är verkligen inte rekommenderat!",
-    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Ta bort open_basedir-inställningen i din php.ini eller växla till 64-bitars PHP.",
     "Set an admin username." : "Ange ett användarnamn för administratören.",
     "Set an admin password." : "Ange ett administratörslösenord.",
     "Cannot create or write into the data directory %s" : "Kan inte skapa eller skriva till data-katalogen %s",
@@ -188,7 +190,6 @@ OC.L10N.register(
     "Oct." : "Okt.",
     "Nov." : "Nov.",
     "Dec." : "Dec.",
-    "The user limit has been reached and the user was not created." : "Maximala användarantalet har uppnåtts och användaren skapades inte.",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Endast följande tecken är tillåtna i användarnamnet: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"",
     "A valid username must be provided" : "Ett giltigt användarnamn måste anges",
     "Username contains whitespace at the beginning or at the end" : "Användarnamnet består av ett mellanslag i början eller i slutet",
@@ -235,6 +236,9 @@ OC.L10N.register(
     "%s enter the database username." : "%s ange databasanvändare.",
     "%s enter the database name." : "%s ange databasnamn",
     "%s you may not use dots in the database name" : "%s du får inte använda punkter i databasnamnet",
+    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Det verkar som om denna %s instans körs på en 32-bitars PHP miljö och open_basedir har konfigurerats i php.ini. Detta kommer att leda till problem med filer över 4 GB och är verkligen inte rekommenderat!",
+    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Ta bort open_basedir-inställningen i din php.ini eller växla till 64-bitars PHP.",
+    "The user limit has been reached and the user was not created." : "Maximala användarantalet har uppnåtts och användaren skapades inte.",
     "Cannot read file" : "Kan inte läsa fil",
     "Cannot write into \"config\" directory" : "Kan inte skriva till \"config\" katalogen",
     "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Detta kan vanligtvis åtgärda genom att ge webbservern skrivåtkomst till konfigureringsmappen. Se %s",
