@@ -2,20 +2,25 @@ OC.L10N.register(
     "lib",
     {
     "Cannot write into \"config\" directory!" : "\"config\" klasörüne yazılamadı!",
-    "This can usually be fixed by giving the webserver write access to the config directory" : "Bu sorun genellikle, web sunucusuna config klasörüne yazma izni verilerek çözülebilir",
-    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Ya da config.php dosyasının salt okunur olarak kalmasını istiyorsanız içindeki \"config_is_read_only\" seçeneğini true olarak ayarlayın.",
+    "This can usually be fixed by giving the web server write access to the config directory." : "Bu sorun genellikle, web sunucusuna config klasörüne yazma izni verilerek çözülebilir.",
+    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Ama config.php dosyasının salt okunur olarak kalmasını istiyorsanız içindeki \"config_is_read_only\" seçeneğini true olarak ayarlayın.",
     "See %s" : "Şuraya bakın: %s",
-    "This can usually be fixed by giving the webserver write access to the config directory." : "Bu sorun genellikle, web sunucusuna config klasörüne yazma izni verilerek çözülebilir.",
-    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Ya da config.php dosyasının salt okunur olarak kalmasını istiyorsanız içindeki \"config_is_read_only\" seçeneğini true olarak ayarlayın. %s bölümüne bakabilirsiniz",
     "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "%1$s uygulamasının dosyaları doğru şekilde değiştirilmedi. Sunucu ile uyumlu dosyaların yüklü olduğundan emin olun.",
     "Sample configuration detected" : "Örnek yapılandırma algılandı",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Örnek yapılandırmanın kopyalanmış olabileceği tespit edildi. Bu durum kurulumunuzu bozabilir ve desteklenmez. Lütfen config.php dosyasında değişiklik yapmadan önce belgeleri okuyun",
+    "404" : "404",
+    "The page could not be found on the server." : "Sayfa sunucuda bulunamadı.",
+    "%s email verification" : "%s e-posta doğrulaması",
+    "Email verification" : "E-posta doğrulaması",
+    "Click the following button to confirm your email." : "E-posta adresinizi doğrulamak için aşağıdaki düğmeye tıklayın.",
+    "Click the following link to confirm your email." : "E-posta adresinizi doğrulamak için aşağıdaki bağlantıya tıklayın",
+    "Confirm your email" : "E-posta adresinizi doğrulayın",
     "Other activities" : "Diğer işlemler",
     "%1$s and %2$s" : "%1$s ve %2$s",
     "%1$s, %2$s and %3$s" : "%1$s, %2$s ve %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s ve %4$s",
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s ve %5$s",
-    "Education Edition" : "Eğitim Sürümü",
+    "Education Edition" : "Eğitim sürümü",
     "Enterprise bundle" : "Kurumsal paket",
     "Groupware bundle" : "Grup çalışması paketi",
     "Hub bundle" : "Toplayıcı paketi",
@@ -32,6 +37,7 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "Şu platformlar destekleniyor: %s",
     "Server version %s or higher is required." : "Sunucu %s ya da daha sonraki bir sürüm olmalıdır.",
     "Server version %s or lower is required." : "Sunucu %s ya da daha önceki bir sürüm olmalıdır.",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Oturum açmış kullanıcı bir yönetici, bir alt yönetici veya bu ayara erişmek için özel izne sahip olmalıdır",
     "Logged in user must be an admin or sub admin" : "Oturum açmış kullanıcı bir yönetici ya da alt yönetici olmalıdır",
     "Logged in user must be an admin" : "Oturum açmış kullanıcı bir yönetici olmalıdır",
     "Wiping of device %s has started" : "%s aygıtının silinmesine başlandı",
@@ -46,10 +52,11 @@ OC.L10N.register(
     "A remote wipe was started on device %s" : "%s aygıtı üzerinde bir uzaktan silme işlemi başlatıldı",
     "Remote wipe finished" : "Uzaktan silme tamamlandı",
     "The remote wipe on %s has finished" : "%s üzerindeki uzaktan silme işlemi tamamlandı",
-    "Authentication" : "Kimlik Doğrulama",
-    "Unknown filetype" : "Dosya türü bilinmiyor",
+    "Authentication" : "Kimlik doğrulama",
+    "Unknown filetype" : "Dosya türü bilinmiyor",
     "Invalid image" : "Görsel geçersiz",
     "Avatar image is not square" : "Avatar görseli kare değil",
+    "View profile" : "Profili görüntüle",
     "today" : "bugün",
     "tomorrow" : "yarın",
     "yesterday" : "dün",
@@ -75,58 +82,75 @@ OC.L10N.register(
     "Invalid path" : "Yol geçersiz",
     "Failed to create file from template" : "Kalıptan dosya oluşturulamadı",
     "Templates" : "Kalıplar",
-    "File name is a reserved word" : "Bu dosya adı sistem kullanıma ayrılmıştır",
-    "File name contains at least one invalid character" : "Dosya adında en az bir geçersiz karakter var",
+    "File name is a reserved word" : "Bu dosya adı sistem kullanıma ayrılmıştır",
+    "File name contains at least one invalid character" : "Dosya adında en az bir geçersiz karakter var",
     "File name is too long" : "Dosya adı çok uzun",
     "Dot files are not allowed" : "Nokta dosyalarına izin verilmiyor",
     "Empty filename is not allowed" : "Boş dosya adına izin verilmiyor",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "appinfo dosyası okunamadığından \"%s\" uygulaması kurulamaz.",
-    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "\"%s\" uygulaması sunucu sürümüyle uyumlu olmadığından kurulamaz.",
+    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "\"%s\" uygulaması sunucu sürümüyle uyumlu olmadığından kurulamaz.",
     "__language_name__" : "Türkçe",
     "This is an automatically sent email, please do not reply." : "Bu ileti otomatik olarak gönderildiğinden lütfen yanıtlamayın.",
     "Help" : "Yardım",
+    "Appearance and accessibility" : "Görünüm ve erişilebilirlik",
     "Apps" : "Uygulamalar",
+    "Personal settings" : "Kişisel ayarlar",
+    "Administration settings" : "Yönetim ayarları",
     "Settings" : "Ayarlar",
-    "Log out" : "Oturumu Kapat",
+    "Log out" : "Oturumu kapat",
     "Users" : "Kullanıcılar",
+    "Email" : "E-posta",
+    "Mail %s" : "E-posta gönder: %s",
+    "Phone" : "Telefon",
+    "Call %s" : "Çağrı gönder: %s",
+    "Twitter" : "Twitter",
+    "View %s on Twitter" : "Twitter üzerinde bak: %s",
+    "Website" : "Web sitesi",
+    "Visit %s" : "Web sitesini aç: %s",
+    "Address" : "Adres",
+    "Profile picture" : "Profil görseli",
+    "About" : "Hakkında",
+    "Full name" : "Tam ad",
+    "Headline" : "Başlık",
+    "Organisation" : "Kuruluş",
+    "Role" : "Pozisyon",
     "Unknown user" : "Kullanıcı bilinmiyor",
     "Additional settings" : "Ek ayarlar",
-    "%s enter the database username and name." : "%s veritabanı adını ve kullanıcı adını yazın.",
-    "%s enter the database username." : "%s veritabanı kullanıcı adını yazın.",
-    "%s enter the database name." : "%s veritabanı adını yazın.",
-    "%s you may not use dots in the database name" : "%s veritabanı adında nokta kullanamayabilirsiniz",
+    "Enter the database username and name for %s" : "%s için veritabanı adını ve kullanıcı adını yazın",
+    "Enter the database username for %s" : "%s için veritabanı kullanıcı adını yazın",
+    "Enter the database name for %s" : "%s için veritabanı adını yazın",
+    "You cannot use dots in the database name %s" : "%s veritabanı adında nokta kullanamazsınız",
     "MySQL username and/or password not valid" : "MySQL kullanıcı adı ya da parolası geçersiz",
     "You need to enter details of an existing account." : "Var olan bir hesabın bilgilerini yazmalısınız.",
     "Oracle connection could not be established" : "Oracle ile bağlantı kurulamadı",
-    "Oracle username and/or password not valid" : "Oracle kullanıcı adı ya da parolası geçersiz",
-    "PostgreSQL username and/or password not valid" : "PostgreSQL kullanıcı adı ya da parolası geçersiz",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X desteklenmiyor ve %s bu platformda düzgün çalışmayacak. Kullanmaktan doğacak riskler size aittir!",
+    "Oracle username and/or password not valid" : "Oracle kullanıcı adı ya da parolası geçersiz",
+    "PostgreSQL username and/or password not valid" : "PostgreSQL kullanıcı adı ya da parolası geçersiz",
+    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X desteklenmiyor ve %s bu platformda düzgün çalışmayacak. Kullanmaktan doğacak riskler size aittir!",
     "For the best results, please consider using a GNU/Linux server instead." : "En iyi sonucu almak için GNU/Linux sunucusu kullanın.",
-    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Bu %s kopyası 32 bit PHP ortamında çalıştırılıyor ve open_basedir seçeneği php.ini dosyasından ayarlanmış gibi görünüyor. Bu yapılandırma 4 GB boyutundan büyük dosyalarda sorun çıkarır ve kullanılması önerilmez.",
-    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Lütfen php.ini dosyasındaki open_basedir ayarını kaldırın ya da 64-bit PHP sürümüne geçin.",
     "Set an admin username." : "Bir yönetici kullanıcı adı yazın.",
-    "Set an admin password." : "Bir yönetici parolası yazın.",
-    "Can't create or write into the data directory %s" : "%s veri klasörü oluşturulamadı ya da içine yazılamadı",
+    "Set an admin password." : "Bir yönetici parolası yazın.",
+    "Cannot create or write into the data directory %s" : "%s veri klasörü oluşturulamadı ya da içine yazılamadı",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Paylaşım arka ucu %s OCP\\Share_Backend arayüzünü desteklemeli",
     "Sharing backend %s not found" : "%s paylaşım arka ucu bulunamadı",
     "Sharing backend for %s not found" : "%s için paylaşım arka ucu bulunamadı",
     "%1$s shared »%2$s« with you and wants to add:" : "%1$s sizinle »%2$s« ögesini paylaştı ve eklemenizi istiyor:",
     "%1$s shared »%2$s« with you and wants to add" : "%1$s sizinle »%2$s« ögesini paylaştı ve eklemenizi istiyor",
     "»%s« added a note to a file shared with you" : "»%s« sizinle paylaştığı bir dosyaya bir not ekledi",
-    "Open »%s«" : "»%s« Aç",
+    "Open »%s«" : "»%s« aç",
     "%1$s via %2$s" : "%1$s, %2$s aracılığıyla",
     "You are not allowed to share %s" : "%s ögesini paylaşma izniniz yok",
-    "Can’t increase permissions of %s" : "%s izinleri arttırılamadı",
-    "Files can’t be shared with delete permissions" : "Silme izni ile dosya paylaşılamaz",
-    "Files can’t be shared with create permissions" : "Ekleme izni ile dosya paylaşılamaz",
+    "Cannot increase permissions of %s" : "%s izinleri yükseltilemedi",
+    "Files cannot be shared with delete permissions" : "Silme izni ile dosya paylaşılamaz",
+    "Files cannot be shared with create permissions" : "Ekleme izni ile dosya paylaşılamaz",
     "Expiration date is in the past" : "Son kullanma tarihi geçmişte",
-    "Can’t set expiration date more than %s days in the future" : "Son kullanma tarihi %sgünden sonrası olarak ayarlanamaz",
-    "Sharing is only allowed with group members" : "Paylaşım yalnız grup üyeleri ile yapılabilir",
+    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Paylaşımların son kullanım süreleri, gelecekte %n günden fazla olamaz","Paylaşımların son kullanım süreleri, gelecekte %n günden fazla olamaz"],
+    "Sharing is only allowed with group members" : "Paylaşım yalnızca grup üyeleri ile yapılabilir",
     "Sharing %s failed, because this item is already shared with user %s" : "%s paylaşılamadı. Bu öge zaten %s kullanıcısı ile paylaşılmış",
     "%1$s shared »%2$s« with you" : "%1$s, sizinle »%2$s« ögesini paylaştı",
     "%1$s shared »%2$s« with you." : "%1$s, sizinle »%2$s« ögesini paylaştı.",
     "Click the button below to open it." : "Açmak için aşağıdaki düğmeye tıklayın.",
     "The requested share does not exist anymore" : "Erişilmek istenilen paylaşım artık yok",
+    "The user limit has been reached and the user was not created. Check your notifications to learn more." : "Kullanıcı sayısı sınırına ulaşıldığından kullanıcı eklenemedi. Ayrıntılı bilgi almak için bildirimlerinize bakın.",
     "Could not find category \"%s\"" : "\"%s\" kategorisi bulunamadı",
     "Sunday" : "Pazar",
     "Monday" : "Pazartesi",
@@ -159,8 +183,8 @@ OC.L10N.register(
     "August" : "Ağustos",
     "September" : "Eylül",
     "October" : "Ekim",
-    "November" : "Kası",
-    "December" : "Aralı",
+    "November" : "Kasım",
+    "December" : "Aralık",
     "Jan." : "Oca",
     "Feb." : "Şub",
     "Mar." : "Mar",
@@ -173,53 +197,56 @@ OC.L10N.register(
     "Oct." : "Eki",
     "Nov." : "Kas",
     "Dec." : "Ara",
-    "The user limit has been reached and the user was not created." : "Kullanıcı sayısı sınırına ulaşıldığından kullanıcı eklenemedi.",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Kullanıcı adında yalnız şu karakterler kullanılabilir: \"a-z\", \"A-Z\", \"0-9\", ve \"_.@-'\"",
-    "A valid username must be provided" : "Geçerli bir kullanıcı adı yazmalısınız",
-    "Username contains whitespace at the beginning or at the end" : "Kullanıcı adının başı ya da sonunda boşluk var",
-    "Username must not consist of dots only" : "Kullanıcı adı yalnız noktalardan oluşamaz",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Kullanıcı adında yalnızca şu karakterler kullanılabilir: \"a-z\", \"A-Z\", \"0-9\", ve \"_.@-'\"",
+    "A valid username must be provided" : "Geçerli bir kullanıcı adı yazmalısınız",
+    "Username contains whitespace at the beginning or at the end" : "Kullanıcı adının başı ya da sonunda boşluk var",
+    "Username must not consist of dots only" : "Kullanıcı adı yalnızca noktalardan oluşamaz",
     "Username is invalid because files already exist for this user" : "Kullanıcı adı geçersiz, bu kullanıcı için zaten bazı dosyalar var",
-    "A valid password must be provided" : "Geçerli bir parola yazmalısınız",
-    "The username is already being used" : "Bu kullanıcı adı zaten var",
+    "A valid password must be provided" : "Geçerli bir parola yazmalısınız",
+    "The username is already being used" : "Bu kullanıcı adı zaten var",
     "Could not create user" : "Kullanıcı oluşturulamadı",
     "User disabled" : "Kullanıcı devre dışı",
     "Login canceled by app" : "Oturum açma uygulama tarafından iptal edildi",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "\"%1$s\" uygulaması, şu gereklilikler sağlanmadığı için kurulamıyor: %2$s",
     "a safe home for all your data" : "verileriniz için güvenli bir barınak",
-    "File is currently busy, please try again later" : "Dosya şu anda meşgul, lütfen daha sonra deneyin",
-    "Can't read file" : "Dosya okunamadı",
-    "Application is not enabled" : "Uygulama etkinleştirilmemiş",
+    "File is currently busy, please try again later" : "Dosya şu anda meşgul. Lütfen bir süre sonra yeniden deneyin",
+    "Cannot download file" : "Dosya indirilemedi",
+    "Application is not enabled" : "Uygulama etkinleştirilmemiş",
     "Authentication error" : "Kimlik doğrulama sorunu",
-    "Token expired. Please reload page." : "Kodun süresi dolmuş. Lütfen sayfayı yenileyin.",
+    "Token expired. Please reload page." : "Kodun geçerlilik süresi dolmuş. Lütfen sayfayı yenileyin.",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Herhangi bir veritabanı sürücüsü (sqlite, mysql ya da postgresql) kurulmamış.",
-    "Cannot write into \"config\" directory" : "\"config\" klasörüne yazılamıyor",
-    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Bu sorun genellikle, web sunucusuna config klasörüne yazma izni verilerek çözülebilir. %s bölümüne bakın",
-    "Cannot write into \"apps\" directory" : "\"apps\" klasörüne yazılamıyor",
-    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file." : "Bu sorun genellikle, web sunucusuna apps klasörüne yazma izni verilerek ya da yapılandırma dosyasından uygulama mağazasını devre dışı bırakılarak çözülebilir.",
-    "Cannot create \"data\" directory" : "\"data\" klasörü oluşturulamadı",
-    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Bu sorun genellikle, web sunucusuna kök klasöre yazma izni verilerek çözülebilir. %s bölümüne bakın",
-    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "İzinler genellikle, web sunucusuna kök klasöre yazma izni verilerek düzeltilebilir. %s bölümüne bakın.",
-    "Setting locale to %s failed" : "Dil %s olarak ayarlanamadı",
-    "Please install one of these locales on your system and restart your webserver." : "Lütfen bu dillerden birini sisteminize kurun ve web sunucunuzu yeniden başlatın.",
+    "Cannot write into \"config\" directory." : "\"config\" klasörüne yazılamadı.",
+    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Bu sorun genellikle, web sunucusuna config klasörüne yazma izni verilerek çözülebilir. %s bölümüne bakın",
+    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Ya da config.php dosyasının salt okunur olarak kalmasını istiyorsanız içindeki \"config_is_read_only\" seçeneğini true olarak ayarlayın. %s bölümüne bakabilirsiniz",
+    "Cannot write into \"apps\" directory." : "\"apps\" klasörüne yazılamadı.",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Bu sorun genellikle, web sunucusuna apps klasörüne yazma izni verilerek ya da yapılandırma dosyasından Uygulama Mağazası devre dışı bırakılarak çözülebilir.",
+    "Cannot create \"data\" directory." : "\"data\" klasörü oluşturulamadı",
+    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Bu sorun genellikle, web sunucusuna kök klasöre yazma izni verilerek çözülebilir. %s bölümüne bakın",
+    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "İzinler genellikle, web sunucusuna kök klasöre yazma izni verilerek düzeltilebilir. %s bölümüne bakın.",
+    "Your data directory is not writable." : "Veri klasörünüz yazılabilir değil.",
+    "Setting locale to %s failed." : "Dil %s olarak ayarlanamadı.",
+    "Please install one of these locales on your system and restart your web server." : "Lütfen bu dillerden birini sisteminize kurun ve web sunucunuzu yeniden başlatın.",
     "PHP module %s not installed." : "PHP %s modülü kurulmamış.",
     "Please ask your server administrator to install the module." : "Lütfen modülü kurması için BT yöneticinizle görüşün.",
     "PHP setting \"%s\" is not set to \"%s\"." : "\"%s\" PHP ayarı \"%s\" olarak ayarlanmamış.",
-    "Adjusting this setting in php.ini will make Nextcloud run again" : "php.ini dosyasında bu ayar yapıldığında Nextcloud yeniden çalışır",
-    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload, beklenen \"0\" değeri yerine \"%s\" olarak ayarlanmış",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Bu sorunu çözmek için php.ini dosyasındaki <code>mbstring.func_overload</code> seçeneğini <code>0</code> olarak ayarlayın",
+    "Adjusting this setting in php.ini will make Nextcloud run again" : "php.ini dosyasında bu ayar yapıldığında Nextcloud yeniden çalışır",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code>, beklenen <code>0</code> değeri yerine <code>%s</code> olarak ayarlanmış.",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Bu sorunu çözmek için php.ini dosyasındaki <code>mbstring.func_overload</code> seçeneğini <code>0</code> olarak ayarlayın.",
     "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 sürümü en az 2.7.0 olmalıdır. Şu anda %s kurulu.",
     "To fix this issue update your libxml2 version and restart your web server." : "Bu sorunu çözmek için libxml2 sürümünüzü güncelleyin ve web sunucusunu yeniden başlatın.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP girintili doc bloklarını ayıklamak üzere yapılandırılmış gibi görünüyor. Bu durum bazı çekirdek uygulamalarına erişilmesini engelleyecek.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Bu sorun genellikle Zend OPcache ya da eAccelerator gibi bir ön bellek/hızlandırıcı nedeniyle ortaya çıkar.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP modülleri kurulmuş, ancak hala eksik olarak mı görünüyor?",
     "Please ask your server administrator to restart the web server." : "Lütfen web sunucusunu yeniden başlatması için BT yöneticinizle görüşün.",
-    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 gerekli",
-    "Please upgrade your database version" : "Lütfen veritabanı sürümünüzü yükseltin",
-    "Your data directory is readable by other users" : "Veri klasörünüz diğer kullanıcılar tarafından okunabilir",
+    "The required %s config variable is not configured in the config.php file." : "Gereken %s yapılandırma değişkeni config.php dosyasında ayarlanmamış.",
+    "Please ask your server administrator to check the Nextcloud configuration." : "Lütfen Nextcloud yapılandırmasını denetlemesi için BT yöneticinizle görüşün.",
+    "PostgreSQL >= 9 required." : "PostgreSQL >= 9 gerekli.",
+    "Please upgrade your database version." : "Lütfen veritabanı sürümünüzü yükseltin.",
+    "Your data directory is readable by other users." : "Veri klasörünüz diğer kullanıcılar tarafından okunabilir.",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Lütfen izinleri 0770 olarak ayarlayarak diğer kullanıcıların klasörü görebilmesini sağlayın.",
-    "Your data directory must be an absolute path" : "Veri klasörünüz mutlak bir yol olmalıdır",
-    "Check the value of \"datadirectory\" in your configuration" : "Yapılandırmanızdaki \"datadirectory\" seçeneğini denetleyin",
-    "Your data directory is invalid" : "Veri klasörünüz geçersiz",
+    "Your data directory must be an absolute path." : "Veri klasörünüz mutlak bir yol olmalıdır.",
+    "Check the value of \"datadirectory\" in your configuration." : "Yapılandırmanızdaki \"datadirectory\" değerini denetleyin.",
+    "Your data directory is invalid." : "Veri klasörünüz geçersiz.",
     "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Veri klasörü kökünde \".ocdata\" adında bir dosya bulunduğundan emin olun.",
     "Action \"%s\" not supported or implemented." : "\"%s\" işlemi desteklenmiyor ya da henüz kullanılamıyor.",
     "Authentication failed, wrong token or provider ID given" : "Kimlik doğrulanamadı. Belirtilen kod ya da hizmet sağlayıcı kodu hatalı",
@@ -232,8 +259,31 @@ OC.L10N.register(
     "Storage connection error. %s" : "Depolama bağlantısı sorunu. %s",
     "Storage is temporarily not available" : "Depolama geçici olarak kullanılamıyor",
     "Storage connection timeout. %s" : "Depolama bağlantısı zaman aşımı. %s",
-    "Following databases are supported: %s" : "Şu veritabanları destekleniyor: %s",
-    "Following platforms are supported: %s" : "Şu platformlar destekleniyor: %s",
-    "Invalid Federated Cloud ID" : "Birleşik Bulut Kimliği Geçersiz"
+    "This can usually be fixed by giving the webserver write access to the config directory." : "Bu sorun genellikle, web sunucusuna config klasörüne yazma izni verilerek çözülebilir.",
+    "%s enter the database username and name." : "%s veritabanı adını ve kullanıcı adını yazın.",
+    "%s enter the database username." : "%s veritabanı kullanıcı adını yazın.",
+    "%s enter the database name." : "%s veritabanı adını yazın.",
+    "%s you may not use dots in the database name" : "%s veritabanı adında nokta kullanamayabilirsiniz",
+    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Bu %s kopyası 32 bit PHP ortamında çalıştırılıyor ve open_basedir seçeneği php.ini dosyasından ayarlanmış gibi görünüyor. Bu yapılandırma 4 GB boyutundan büyük dosyalarda sorun çıkarır ve kullanılması önerilmez.",
+    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Lütfen php.ini dosyasındaki open_basedir ayarını kaldırın ya da 64-bit PHP sürümüne geçin.",
+    "The user limit has been reached and the user was not created." : "Kullanıcı sayısı sınırına ulaşıldığından kullanıcı eklenemedi.",
+    "Cannot read file" : "Dosya okunamadı",
+    "Cannot write into \"config\" directory" : "\"config\" klasörüne yazılamıyor",
+    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Bu sorun genellikle, web sunucusuna config klasörüne yazma izni verilerek çözülebilir. %s bölümüne bakın",
+    "Cannot write into \"apps\" directory" : "\"apps\" klasörüne yazılamıyor",
+    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the App Store in the config file." : "Bu sorun genellikle, web sunucusuna apps klasörüne yazma izni verilerek ya da yapılandırma dosyasından Uygulama Mağazası devre dışı bırakılarak çözülebilir.",
+    "Cannot create \"data\" directory" : "\"data\" klasörü oluşturulamadı",
+    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Bu sorun genellikle, web sunucusuna kök klasöre yazma izni verilerek çözülebilir. %s bölümüne bakın",
+    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "İzinler genellikle, web sunucusuna kök klasöre yazma izni verilerek düzeltilebilir. %s bölümüne bakın.",
+    "Setting locale to %s failed" : "Dil %s olarak ayarlanamadı",
+    "Please install one of these locales on your system and restart your webserver." : "Lütfen bu dillerden birini sisteminize kurun ve web sunucunuzu yeniden başlatın.",
+    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload, beklenen \"0\" değeri yerine \"%s\" olarak ayarlanmış",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Bu sorunu çözmek için php.ini dosyasındaki <code>mbstring.func_overload</code> seçeneğini <code>0</code> olarak ayarlayın",
+    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 gerekli",
+    "Please upgrade your database version" : "Lütfen veritabanı sürümünüzü yükseltin",
+    "Your data directory is readable by other users" : "Veri klasörünüz diğer kullanıcılar tarafından okunabilir",
+    "Your data directory must be an absolute path" : "Veri klasörünüz mutlak bir yol olmalıdır",
+    "Check the value of \"datadirectory\" in your configuration" : "Yapılandırmanızdaki \"datadirectory\" seçeneğini denetleyin",
+    "Your data directory is invalid" : "Veri klasörünüz geçersiz"
 },
 "nplurals=2; plural=(n > 1);");
