@@ -8,6 +8,7 @@ OC.L10N.register(
     "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Файли програми %1$s замінено неправильно. Переконайтеся, що це версія, сумісна з сервером.",
     "Sample configuration detected" : "Виявлено приклад конфігурації",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Було виявлено, що приклад конфігурації було скопійовано. Це може нашкодити вашій системі та не підтримується. Будь ласка, зверніться до документації перед внесенням змін в файл config.php",
+    "The page could not be found on the server." : "Сторінку не знайдено на сервері.",
     "%s email verification" : "%s підтвердження електронної пошти",
     "Email verification" : "Підтвердження електронної пошти",
     "Click the following button to confirm your email." : "Натисніть наступну кнопку, щоб підтвердити свою електронну адресу.",
@@ -18,11 +19,11 @@ OC.L10N.register(
     "%1$s, %2$s and %3$s" : "%1$s, %2$s та %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s та %4$s",
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s та %5$s",
-    "Education Edition" : "Освітнє видання",
-    "Enterprise bundle" : "Пакет Enterprise",
-    "Groupware bundle" : "Пакет групового програмного забезпечення",
-    "Hub bundle" : "Втулка пучка",
-    "Social sharing bundle" : "Набір соціальних мереж",
+    "Education Edition" : "Для навчання",
+    "Enterprise bundle" : "Для бізнесу",
+    "Groupware bundle" : "Для робочих груп",
+    "Hub bundle" : "Основні застосунки",
+    "Social sharing bundle" : "Для соціальних мереж",
     "PHP %s or higher is required." : "Необхідно PHP %s або вище",
     "PHP with a version lower than %s is required." : "Потрібна версія PHP нижче %s ",
     "%sbit or higher PHP required." : "%sнеобхідний PHP біт або вище.",
@@ -39,20 +40,20 @@ OC.L10N.register(
     "Logged in user must be an admin or sub admin" : "Увійшовши в систему користувач повинен бути адміністратором або підадміністратором",
     "Logged in user must be an admin" : "Зареєстрований користувач має бути адміністратором",
     "Wiping of device %s has started" : "Розпочато очищення пристрою %s",
-    "Wiping of device »%s« has started" : "Розпочато очищення пристрою »%s».",
-    "»%s« started remote wipe" : "»%s« розпочато дистанційне стирання",
-    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Пристрій або програма »%s« розпочала процес віддаленого стирання. Після завершення процесу ви отримаєте інший електронний лист",
+    "Wiping of device »%s« has started" : "Розпочато стирання даних на пристрої \"%s\".",
+    "»%s« started remote wipe" : "\"%s\" розпочато віддалене стирання даних",
+    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Пристрій або застосунок \"%s\" розпочали процес віддаленого стирання даних. Після завершення процесу ви отримаєте відповідне сповіщення електронною поштою.",
     "Wiping of device %s has finished" : "Очищення пристрою %s завершено",
-    "Wiping of device »%s« has finished" : "Очищення пристрою »%s« завершено",
-    "»%s« finished remote wipe" : "»%s« дистанційне стирання завершено",
-    "Device or application »%s« has finished the remote wipe process." : "Пристрій або програма »%s« завершили процес віддаленого стирання.",
+    "Wiping of device »%s« has finished" : "Стирання даних на пристрої \"%s\" завершено",
+    "»%s« finished remote wipe" : "\"%s\" віддалене очищення стирання даних",
+    "Device or application »%s« has finished the remote wipe process." : "Пристрій або застосунок \"%s\" завершили процес віддаленого стирання даних.",
     "Remote wipe started" : "Розпочато віддалене стирання",
     "A remote wipe was started on device %s" : "На пристрої %s розпочато віддалене стирання",
     "Remote wipe finished" : "Віддалене стирання завершено",
     "The remote wipe on %s has finished" : "Дистанційне стирання на %s завершено",
     "Authentication" : "Автентифікація",
     "Unknown filetype" : "Невідомий тип файлу",
-    "Invalid image" : "Невірне зображення",
+    "Invalid image" : "Недійсне зображення",
     "Avatar image is not square" : "Зображення аватара не квадратне",
     "View profile" : "Перегляд профілю",
     "today" : "сьогодні",
@@ -125,17 +126,15 @@ OC.L10N.register(
     "PostgreSQL username and/or password not valid" : "PostgreSQL ім'я користувача та/або пароль не дійсні",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X не підтримується і %s не буде коректно працювати на цій платформі. Випробовуєте на свій риск!",
     "For the best results, please consider using a GNU/Linux server instead." : "Для кращих результатів розгляньте можливість використання GNU/Linux серверу",
-    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Здається що екземпляр цього %s працює в 32-бітному PHP середовищі і open_basedir повинен бути налаштований в php.ini. Це призведе до проблем з файлами більше 4 ГБ і це дуже не рекомендується.",
-    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Будь ласка, вилучіть параметр open_basedir у вашому php.ini або перейдіть на 64-бітний PHP.",
     "Set an admin username." : "Встановіть ім'я адміністратора.",
     "Set an admin password." : "Встановіть пароль адміністратора.",
     "Cannot create or write into the data directory %s" : "Неможливо створити або записати в каталог даних %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Бекенд спільного доступу %s повинен реалізовувати інтерфейс OCP\\Share_Backend",
     "Sharing backend %s not found" : "Бекенд спільного доступу %s не знайдено",
     "Sharing backend for %s not found" : "Бекенд спільного доступу для %s не знайдено",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s надав доступ »%2$s« та хоче додати:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s надав доступ »%2$s« та хоче додати",
-    "»%s« added a note to a file shared with you" : "»%s« додав нотатку до опублікованого файлу",
+    "%1$s shared »%2$s« with you and wants to add:" : "%1$s надано доступ до \"%2$s\" та хоче додати:",
+    "%1$s shared »%2$s« with you and wants to add" : "%1$s надано доступ до \"%2$s\" та хоче додати",
+    "»%s« added a note to a file shared with you" : "\"%s\" додано примітку до файлу у спільному доступі",
     "Open »%s«" : "Відкрити 1%s",
     "%1$s via %2$s" : "%1$s через %2$s",
     "You are not allowed to share %s" : "Вам заборонено поширювати %s",
@@ -146,8 +145,8 @@ OC.L10N.register(
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Неможливо встановити дату закінчення більше ніж %n день у майбутньому","Неможливо встановити дату закінчення більше ніж %n днів у майбутньому","Неможливо встановити дату закінчення більше ніж %n днів у майбутньому","Неможливо встановити дату закінчення більше ніж %n днів у майбутньому"],
     "Sharing is only allowed with group members" : "Спільний доступ дозволений лише для учасників групи",
     "Sharing %s failed, because this item is already shared with user %s" : "Не вдалося поділитися %s, оскільки %s вже має до нього доступ",
-    "%1$s shared »%2$s« with you" : "%1$s надав доступ до »%2$s«",
-    "%1$s shared »%2$s« with you." : "%1$s надав доступ до »%2$s«.",
+    "%1$s shared »%2$s« with you" : "%1$s надано доступ до \"%2$s\"",
+    "%1$s shared »%2$s« with you." : "%1$s надано доступ до \"%2$s\".",
     "Click the button below to open it." : "Щоб відкрити файл, натисніть кнопку нижче.",
     "The requested share does not exist anymore" : "Запитувана частка більше не існує",
     "Could not find category \"%s\"" : "Не вдалося знайти категорію \"%s\"",
@@ -196,7 +195,6 @@ OC.L10N.register(
     "Oct." : "Жов.",
     "Nov." : "Лис.",
     "Dec." : "Гру.",
-    "The user limit has been reached and the user was not created." : "Ліміт користувачів досягнуто, і користувача не було створено.",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Тільки такі символи допускаються в імені користувача: \"a-z\", \"A-Z\", \"0-9\", і \"_.@-'\"",
     "A valid username must be provided" : "Потрібно задати вірне ім'я користувача",
     "Username contains whitespace at the beginning or at the end" : "Ім'я користувача містить символ пробілу в початку або в кінці",
@@ -234,7 +232,7 @@ OC.L10N.register(
     "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Щоб вирішити цю проблему, установіть для <code>mbstring.func_overload</code> значення <code>0</code> у вашому php.ini.",
     "libxml2 2.7.0 is at least required. Currently %s is installed." : "Необхідно libxml2 версії принаймні 2.7.0. На разі встановлена %s.",
     "To fix this issue update your libxml2 version and restart your web server." : "Що виправити це оновіть версію libxml2 та перезапустіть веб-сервер.",
-    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Схоже, що PHP налаштовано на вичищення блоків вбудованої документації. Це зробить кілька основних додатків недоступними.",
+    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Схоже, що PHP налаштовано на обрізання блоків вбудованих документів. Це зробить кілька головних застосунків недоступними.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Це, ймовірно, обумовлено використанням кеша/прискорювача такого як Zend OPcache або eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "Модулі PHP були встановлені, але вони все ще перераховані як відсутні?",
     "Please ask your server administrator to restart the web server." : "Будь ласка, зверніться до адміністратора, щоб перезавантажити сервер.",
@@ -264,6 +262,9 @@ OC.L10N.register(
     "%s enter the database username." : "%s введіть ім'я користувача бази даних.",
     "%s enter the database name." : "%s введіть назву бази даних.",
     "%s you may not use dots in the database name" : "%s не можна використовувати крапки в назві бази даних",
+    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Ймовірно, що сервер %s працює в 32-бітному PHP середовищі і open_basedir повинен бути налаштований в php.ini. Це призведе до проблем з файлами більше 4 ГБ і це дуже не рекомендується.",
+    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Будь ласка, вилучіть параметр open_basedir у вашому php.ini або перейдіть на 64-бітний PHP.",
+    "The user limit has been reached and the user was not created." : "Ліміт користувачів досягнуто, і користувача не було створено.",
     "Cannot read file" : "Неможливо прочитати файл",
     "Cannot write into \"config\" directory" : "Неможливо записувати до каталгу \"config\"",
     "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Зазвичай це можна виправити, надавши веб-серверу доступ для запису до каталогу конфігурації. Побачити %s",
