@@ -8,6 +8,8 @@ OC.L10N.register(
     "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "應用程式 %1$s 中的檔案沒有被正確取代，請確認它的版本與伺服器相容。",
     "Sample configuration detected" : "您目前正在使用範例設定",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "您似乎直接複製了範例設定來使用，這樣的安裝很可能會無法運作，請閱讀說明文件後對 config.php 進行適當的修改",
+    "404" : "404",
+    "The page could not be found on the server." : "無法在伺服器上找到此頁面。",
     "%s email verification" : "%s 電子郵件驗證",
     "Email verification" : "電子郵件驗證",
     "Click the following button to confirm your email." : "點擊以下按鈕以確認您的電子郵件。",
@@ -125,8 +127,6 @@ OC.L10N.register(
     "PostgreSQL username and/or password not valid" : "PostgreSQL 用戶名和/或密碼無效",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "不支援 Mac OS X 而且 %s 在這個平台上面無法正常運作，請自行衡量風險後使用！",
     "For the best results, please consider using a GNU/Linux server instead." : "請考慮使用 GNU/Linux 伺服器以獲得最佳體驗",
-    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "看起來 %s 是在 32 位元的 PHP 環境運行，並且 php.ini 中被設置了 open_basedir 參數，這將讓超過 4GB 的檔案操作發生問題，強烈建議您更改設定。",
-    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "請移除 php.ini 中的 open_basedir 設定，或是改用 64 位元的 PHP",
     "Set an admin username." : "設定管理員帳號",
     "Set an admin password." : "設定管理員密碼",
     "Cannot create or write into the data directory %s" : "無法建立或寫入資料目錄 %s",
@@ -150,6 +150,7 @@ OC.L10N.register(
     "%1$s shared »%2$s« with you." : "%1$s 與您分享了 %2$s",
     "Click the button below to open it." : "點下方連結開啟",
     "The requested share does not exist anymore" : "該分享已經不存在",
+    "The user limit has been reached and the user was not created. Check your notifications to learn more." : "已達使用者限制，所以未建立使用者。請檢查您的通知以取得更多資訊。",
     "Could not find category \"%s\"" : "找不到分類：\"%s\"",
     "Sunday" : "週日",
     "Monday" : "週一",
@@ -196,7 +197,6 @@ OC.L10N.register(
     "Oct." : "十月",
     "Nov." : "十一月",
     "Dec." : "十二月",
-    "The user limit has been reached and the user was not created." : "已達使用者限制，所以未建立使用者。",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "使用者名稱當中只能包含下列字元：\"a-z\", \"A-Z\", \"0-9\", 和 \"_.@-'\"",
     "A valid username must be provided" : "必須提供一個有效的用戶名",
     "Username contains whitespace at the beginning or at the end" : "用戶名的開頭或結尾有空白",
@@ -264,6 +264,9 @@ OC.L10N.register(
     "%s enter the database username." : "%s 輸入資料庫使用者名稱",
     "%s enter the database name." : "%s 輸入資料庫名稱",
     "%s you may not use dots in the database name" : "%s 資料庫名稱不能包含小數點",
+    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "看起來 %s 是在 32 位元的 PHP 環境運行，並且 php.ini 中被設置了 open_basedir 參數，這將讓超過 4GB 的檔案操作發生問題，強烈建議您更改設定。",
+    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "請移除 php.ini 中的 open_basedir 設定，或是改用 64 位元的 PHP",
+    "The user limit has been reached and the user was not created." : "已達使用者限制，所以未建立使用者。",
     "Cannot read file" : "無法讀取檔案",
     "Cannot write into \"config\" directory" : "無法寫入 config 目錄",
     "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "允許網頁伺服器寫入 \"config\" 目錄通常可以解決這個問題，詳見 %s",
